(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   5600418,     126879]
NotebookOptionsPosition[   5516769,     125573]
NotebookOutlinePosition[   5517166,     125589]
CellTagsIndexPosition[   5517123,     125586]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Insert location of downloaded data in \
\[OpenCurlyDoubleQuote]SetDirectory\[CloseCurlyDoubleQuote] below:", "Text",
 CellChangeTimes->{{3.840094423579954*^9, 
  3.840094440679159*^9}},ExpressionUUID->"2fa25836-dd03-4419-8063-\
17fff163b302"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.830419489049081*^9, 3.8304195253765306`*^9}, 
   3.840094053525361*^9, {3.840094412591853*^9, 3.84009441480023*^9}, {
   3.8400944831384306`*^9, 3.8400945057194653`*^9}, 
   3.840094763112236*^9},ExpressionUUID->"30dff19c-bc2b-446c-9fec-\
40472009a359"],

Cell[CellGroupData[{

Cell["READ ME", "Chapter",
 CellChangeTimes->{{3.7459405253365164`*^9, 3.7459405259395866`*^9}, {
  3.8302460960885468`*^9, 3.830246098880521*^9}, {3.8302461980658417`*^9, 
  3.830246199225092*^9}},ExpressionUUID->"991fa0b3-a6fe-44dc-99c5-\
aa960ad719fc"],

Cell[TextData[{
 StyleBox["Algorithms:",
  FontWeight->"Bold"],
 "\n\nMust run one of the group = \[OpenCurlyDoubleQuote]group name\
\[CloseCurlyDoubleQuote] lines. Once data has been downloaded, the below code \
will run algorithms on the social network of any one of the seven observed \
fissions.\n\nOutput of the algorithm for a single trial is in the following \
form (DG = daughter group):\n\n{\n{# individuals in DG1, # individuals in DG \
2, # bonds in DG1, # bonds in DG2, #bonds/individual in DG1, \
#bonds/individual in DG2, global clustering coefficient of DG1, global \
clustering coefficient of DG2, diameter of DG1, diameter of DG2, density of \
DG1, density of DG2, proportion dyads correctly assigned}\n,\n{# broken \
bonds, # maintained bonds, % broken, sum of broken bond weight, average \
broken bond weight, sum of maintained bond weight, average maintained bond \
weight, sparsity, mean b/w centrality of broken bonds, mean b/w centrality of \
maintained bonds, % broken bonds correctly identified, % maintained bond \
correctly identified, % total bonds correctly identified}\n}\n\n\n",
 StyleBox["Figures:\n\n",
  FontWeight->"Bold"],
 "Data simulated from 100 trials for each algorithm and each group deposited \
in \[OpenCurlyDoubleQuote]Simulated data\[CloseCurlyDoubleQuote] folder. \
Loading in this data will allow for replication of figures.\n\n",
 StyleBox["\nANOVA:\n\n",
  FontWeight->"Bold"],
 "Data simulated from 100 trials for each algorithm and each group deposited \
in \[OpenCurlyDoubleQuote]Simulated data\[CloseCurlyDoubleQuote] folder. \
Loading in this data will allow each ANOVA we considered to be run."
}], "Text",
 CellChangeTimes->{{3.830246218608268*^9, 3.8302465506092334`*^9}, {
   3.8302466212122493`*^9, 3.8302466245213633`*^9}, {3.830246659870979*^9, 
   3.8302466884368825`*^9}, {3.830246726366294*^9, 3.830246730685771*^9}, 
   3.8302468095646896`*^9, {3.830250048399565*^9, 3.830250081304841*^9}, {
   3.830250249266136*^9, 3.830250293405234*^9}, {3.8302617478339925`*^9, 
   3.830261765565393*^9}, {3.844182904572152*^9, 
   3.844182961870181*^9}},ExpressionUUID->"a0fddb59-3c08-400b-9e41-\
141eece93698"]
}, Closed]],

Cell[CellGroupData[{

Cell["Algorithms", "Chapter",
 CellChangeTimes->{{3.7459405253365164`*^9, 3.7459405259395866`*^9}, {
  3.8302460960885468`*^9, 3.830246098880521*^9}, {3.8302461980658417`*^9, 
  3.830246199225092*^9}, {3.830246654565133*^9, 
  3.830246656872785*^9}},ExpressionUUID->"adf31fe2-fbb5-453c-b774-\
d91ca8f20e78"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"group", "=", "\"\<dotty\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{"group", "=", "\"\<hook\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{"group", "=", "\"\<linda\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{"group", "=", "\"\<lodge\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{"group", "=", "\"\<nyayo\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{"group", "=", "\"\<viola\>\""}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"group", "=", "\"\<vogue\>\""}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8302455854530745`*^9, 3.830245619286495*^9}, {
  3.830246203689062*^9, 3.8302462073141003`*^9}, {3.8304150489572487`*^9, 
  3.8304150562635794`*^9}, {3.830419480683366*^9, 3.830419485579835*^9}, {
  3.830420219639967*^9, 3.8304202236825714`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"213f8385-3ef6-42a9-9bb8-1e23639a4c61"],

Cell[CellGroupData[{

Cell["Setup (Run First)", "Section",
 CellChangeTimes->{{3.7459405253365164`*^9, 3.7459405259395866`*^9}, {
  3.8302460960885468`*^9, 
  3.830246098880521*^9}},ExpressionUUID->"d66b77ea-40cf-42a8-94c4-\
ef3a6cbad2dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"groomdata", "=", 
    RowBox[{"Import", "[", 
     RowBox[{"group", "<>", "\"\<_coded_grooming.csv\>\""}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"import", " ", "data"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7458636747441187`*^9, 3.7458636914062157`*^9}, {
   3.7458637982398243`*^9, 3.74586381073285*^9}, {3.7458730489107933`*^9, 
   3.7458730559752445`*^9}, {3.748630711202957*^9, 3.74863071319674*^9}, {
   3.7486372725406713`*^9, 3.7486372729999447`*^9}, {3.748637316730669*^9, 
   3.748637324888399*^9}, 3.7486381456481743`*^9, 3.748638425724243*^9, 
   3.7486386808729343`*^9, 3.7486389029930835`*^9, {3.83024563100252*^9, 
   3.830245639499818*^9}, {3.8303401636359653`*^9, 3.830340163923295*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"0b6e94ef-2244-4007-9c63-1e0e12fd860e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"groomdata", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"labels", " ", "of", " ", "each", " ", "entry"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.745863830755395*^9, 3.7458638649650974`*^9}, {
  3.7458639024071074`*^9, 3.7458639522013845`*^9}, {3.74587303859109*^9, 
  3.745873045542172*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"be2cd88f-5041-440b-b6b7-87c420d89f93"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"iid\"\>", ",", "\<\"act\"\>", ",", "\<\"date\"\>", 
   ",", "\<\"actor\"\>", ",", "\<\"actee\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.7458638355789375`*^9, 3.745863865347003*^9}, {
   3.7458639057015867`*^9, 3.745863952833126*^9}, 3.7458641402509184`*^9, 
   3.7459394614466686`*^9, 3.746204598528056*^9, 3.746397305933516*^9, 
   3.746444549052789*^9, 3.748036624544264*^9, 3.748602641748207*^9, 
   3.7486027231502576`*^9, 3.748602803229275*^9, {3.7486373313238864`*^9, 
   3.7486373518777742`*^9}, 3.748637989428753*^9, {3.7486381564411144`*^9, 
   3.74863818537794*^9}, 3.7486382490503917`*^9, 3.748638465754057*^9, 
   3.7486387216862707`*^9, 3.7486389561175995`*^9, 3.7487775930363064`*^9, 
   3.749417431558899*^9, 3.749567331464895*^9, 3.7507685869621525`*^9, 
   3.7512211807499495`*^9, 3.7512887434055543`*^9, 3.7512928209712524`*^9, 
   3.7512993145033684`*^9, 3.7512999851502104`*^9, 3.7547790235655966`*^9, 
   3.7576351638070097`*^9, 3.7613869806799984`*^9, 3.821344010483325*^9, 
   3.830247271039323*^9, {3.8303402123284335`*^9, 3.8303402206655273`*^9}, 
   3.8303407095231943`*^9, 3.830415097282975*^9, 3.8304152851792936`*^9, 
   3.8304154856367908`*^9, 3.8304195351031957`*^9, 3.8304202280468173`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"82d134b7-e1b1-4e8c-a1dd-196376ba4121"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"groomdata", "=", 
    RowBox[{"groomdata", "[", 
     RowBox[{"[", 
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "groomdata", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"remove", " ", "column", " ", "headers"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.745863954174962*^9, 3.745863965255912*^9}, {
   3.7458639967185144`*^9, 3.7458639967296124`*^9}, {3.7458641251490517`*^9, 
   3.7458641265727367`*^9}, {3.7458730588061314`*^9, 3.7458730680999365`*^9}, 
   3.7486373659479647`*^9},
 CellLabel->"In[21]:=",ExpressionUUID->"a5a955ff-ac3f-4232-9f66-409ce59c6172"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"groomdata", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "3"}], "]"}], "]"}], "=", 
     RowBox[{"DateObject", "[", 
      RowBox[{"groomdata", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "3"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", "groomdata", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"format", " ", "correctly", " ", "as", " ", "date"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.8302493314379663`*^9, 3.83024935327365*^9}, {
  3.8302494882761173`*^9, 3.8302494928163085`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"d67e671e-0776-4e2e-8131-df4323187bdc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fisdate", "=", 
   RowBox[{"Which", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"group", "\[Equal]", "\"\<dotty\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<hook\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"1994", ",", "4", ",", "27", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<linda\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "4", ",", "6", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<lodge\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"1995", ",", "7", ",", "13", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<nyayo\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "10", ",", "20", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<viola\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<vogue\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2017", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8302494959281397`*^9, 3.8302495732667723`*^9}, {
  3.8302496050964503`*^9, 3.8302496819484987`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"050df01a-f601-45b3-99fd-ee82ece908ee"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"prefission", "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"groomdata", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "<", "fisdate"}], "&"}]}], "]"}], 
     "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5"}], "}"}]}], "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "select", " ", "only", " ", "grooming", " ", "events", " ", "from", " ", 
    "before", " ", "fission"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.745872835902299*^9, 3.745872864388008*^9}, {
   3.745872919037166*^9, 3.7458729589708157`*^9}, {3.745873071655978*^9, 
   3.745873080885857*^9}, {3.7486374123561354`*^9, 3.7486374277022243`*^9}, {
   3.748638227639842*^9, 3.748638230902342*^9}, {3.7486384399545135`*^9, 
   3.7486384460082693`*^9}, {3.7486386966006866`*^9, 
   3.7486387058383985`*^9}, {3.748638917751003*^9, 3.748638924914632*^9}, 
   3.8302494033735456`*^9, {3.83024955748129*^9, 3.830249570945574*^9}, {
   3.8304146962255135`*^9, 3.830414697366677*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"71681af4-b1f1-4ec0-845e-ffbed0ae5d41"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"prefission", "=", 
    RowBox[{"Sort", "/@", "prefission"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "sort", " ", "grooming", " ", "events", " ", "to", " ", "not", " ", 
    "worry", " ", "about", " ", "reciprocity"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.74587298737788*^9, 3.745873009525176*^9}, {
  3.745873083651064*^9, 3.745873106712079*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"91e62c8d-a216-4e20-a147-0818b37dead5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"bonds", "=", 
    RowBox[{"Tally", "[", "prefission", "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "tallies", " ", "the", " ", "#", " ", "of", " ", "grooming", " ", "events",
     " ", "for", " ", "each", " ", "bond"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.74587965560767*^9, 3.7458796761315084`*^9}, {
  3.745879715314339*^9, 3.745879716242738*^9}, {3.7458798024745283`*^9, 
  3.7458798333781204`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"e808d391-5856-43b4-b31d-814cb6d07779"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"strongbonds", "=", 
    RowBox[{"Select", "[", 
     RowBox[{"bonds", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ">", 
        RowBox[{"Mean", "[", 
         RowBox[{"bonds", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], "&"}]}], "]"}]}],
    ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"select", " ", "bonds", " ", 
    RowBox[{"b", "/", "w"}], " ", "individuals", " ", "that", " ", "groomed", 
    " ", "10", " ", "or", " ", "more", " ", "times"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7458798452557116`*^9, 3.745879888381247*^9}, 
   3.8213436279952397`*^9},
 CellLabel->"In[27]:=",ExpressionUUID->"03547a0d-de00-4c4d-9704-1e9d927be882"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Dimensions", "[", 
  RowBox[{"DeleteDuplicates", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"strongbonds", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", 
  RowBox[{"DeleteDuplicates", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"bonds", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8213437213543673`*^9, 3.8213437241431265`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"85559a74-3eee-4f35-a73a-52762825b7ff"],

Cell[BoxData[
 RowBox[{"{", "36", "}"}]], "Output",
 CellChangeTimes->{3.8213440149566965`*^9, 3.830247275488899*^9, 
  3.830249416481492*^9, 3.8303402712418976`*^9, 3.8303407387805853`*^9, 
  3.8304154100730443`*^9, 3.8304155796639366`*^9, 3.8304195613693542`*^9, 
  3.8304202346272683`*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"d126e3c9-0cec-4fa5-acc0-4dcc3e30f76b"],

Cell[BoxData[
 RowBox[{"{", "43", "}"}]], "Output",
 CellChangeTimes->{3.8213440149566965`*^9, 3.830247275488899*^9, 
  3.830249416481492*^9, 3.8303402712418976`*^9, 3.8303407387805853`*^9, 
  3.8304154100730443`*^9, 3.8304155796639366`*^9, 3.8304195613693542`*^9, 
  3.8304202346308374`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"1712fcd5-f031-4de2-9dbe-c323c68c3a98"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphmax", "=", 
   RowBox[{
    RowBox[{"TakeLargest", "[", 
     RowBox[{
      RowBox[{"strongbonds", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "1"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7613869719704714`*^9, 3.761386972579629*^9}, 
   3.8302459221257515`*^9},
 CellLabel->"In[30]:=",ExpressionUUID->"38dea4b3-7e6b-4dc7-bf32-7950e6df1d1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"edges", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"strongbonds", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1", ",", "1"}], "]"}], "]"}], "\[TwoWayRule]", 
       RowBox[{"strongbonds", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{"Dimensions", "[", "strongbonds", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"put", " ", "edges", " ", "in", " ", "graph", " ", "format"}], " ",
    "*)"}]}]], "Input",
 CellChangeTimes->{{3.745880033494373*^9, 3.74588004433994*^9}, {
  3.7459399836838408`*^9, 3.7459399892587185`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"1585971d-97ab-4b17-8f9d-fd2c7e7b4219"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"weights", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"strongbonds", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{"Dimensions", "[", "strongbonds", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"put", " ", "weights", " ", "onto", " ", "edges"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7458800473460913`*^9, 3.745880056870951*^9}, {
  3.7459399923771787`*^9, 3.745940009035649*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"ab33633a-04fd-45c2-b868-bbe5319547ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graph", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"strongbonds", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1", ",", "1"}], "]"}], "]"}], "\[TwoWayRule]", 
       RowBox[{"strongbonds", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{"Dimensions", "[", "strongbonds", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"EdgeWeight", "\[Rule]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"strongbonds", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{"Dimensions", "[", "strongbonds", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7458798938399963`*^9, 3.7458799817568207`*^9}, {
   3.7459397647238812`*^9, 3.745939766183482*^9}, {3.74863745663439*^9, 
   3.7486374571757865`*^9}, 3.748638145651827*^9, 3.74863842572991*^9, 
   3.7486386808786306`*^9, 3.7486389029976573`*^9, {3.83024567389536*^9, 
   3.8302456744390945`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"03ba8eb9-1ab7-4905-b83b-35534ed76af2"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{6838, 9704, 1690, 3890, 2958, 347, 4505, 1891, 512, 9012, 8918, 
      2330, 115, 4068, 2133, 3439, 7421, 3343, 447, 8609, 4109, 4716, 9761, 
      3937, 6234, 8646, 9562, 7938, 7486, 6145, 2797, 6704, 600, 945, 6147, 
      3236}, {Null, {{1, 2}, {3, 2}, {4, 2}, {5, 2}, {6, 7}, {6, 8}, {6, 9}, {
       6, 10}, {4, 11}, {5, 11}, {12, 11}, {13, 1}, {14, 1}, {15, 1}, {16, 
       1}, {1, 17}, {18, 1}, {19, 1}, {13, 20}, {14, 20}, {21, 20}, {22, 
       20}, {7, 20}, {17, 20}, {18, 20}, {20, 23}, {19, 20}, {24, 20}, {25, 
       20}, {20, 10}, {13, 7}, {13, 8}, {13, 3}, {13, 4}, {13, 18}, {13, 9}, {
       13, 26}, {13, 27}, {13, 23}, {13, 19}, {13, 24}, {13, 25}, {13, 10}, {
       8, 14}, {3, 14}, {14, 17}, {4, 14}, {12, 14}, {9, 21}, {21, 28}, {24, 
       21}, {8, 16}, {3, 16}, {16, 17}, {18, 16}, {5, 16}, {16, 29}, {12, 
       16}, {16, 10}, {8, 7}, {3, 7}, {18, 7}, {3, 8}, {8, 17}, {8, 4}, {8, 
       5}, {8, 30}, {3, 17}, {3, 4}, {3, 18}, {3, 5}, {4, 17}, {18, 17}, {5, 
       17}, {24, 17}, {17, 10}, {5, 4}, {5, 18}, {31, 18}, {18, 30}, {18, 
       32}, {19, 18}, {18, 25}, {5, 24}, {9, 29}, {29, 23}, {12, 29}, {24, 
       29}, {29, 10}, {9, 2}, {9, 28}, {9, 27}, {9, 23}, {19, 9}, {9, 24}, {9,
        10}, {28, 26}, {26, 23}, {30, 26}, {33, 12}, {33, 30}, {33, 32}, {31, 
       24}, {34, 27}, {27, 23}, {35, 27}, {12, 24}, {24, 30}, {36, 25}, {19, 
       24}, {19, 25}, {19, 10}, {24, 25}, {24, 10}, {25, 10}}}, {
      EdgeWeight -> {10, 25, 9, 8, 71, 8, 16, 11, 12, 10, 7, 11, 50, 54, 13, 
        7, 9, 8, 30, 6, 8, 10, 10, 9, 8, 17, 8, 16, 6, 9, 10, 25, 6, 10, 10, 
        6, 7, 21, 13, 23, 7, 8, 9, 14, 8, 7, 14, 20, 7, 7, 22, 9, 8, 15, 13, 
        9, 8, 7, 8, 9, 7, 39, 39, 7, 6, 15, 11, 8, 43, 7, 12, 9, 6, 38, 11, 8,
         11, 8, 7, 18, 7, 15, 8, 6, 35, 6, 10, 6, 7, 6, 28, 6, 10, 6, 13, 12, 
        10, 17, 7, 20, 7, 8, 6, 12, 36, 14, 10, 22, 17, 10, 72, 13, 6, 90, 
        9}}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAACQAAAACAAAAc9yaLoT58j99GMo1evkHQJRr2rJt
TvI/gASNehr0AEAyFhBvDEbzP+Z/UCv77QNAVFb7wPza5j/ce2pkndQAQFyB
OQDwzO4/VAQIVVct/D9IzjJFDssCQOg/rnUCrAlAtLNluNHX/D9fjcjB3nwI
QPgXouDlm/g/XWMql2CYAUDGZieHhPUGQKETn0kJif8/eqvO8VOSAkBignel
PIEDQAAAAAAAAAAA0G3J/apD9T8SfUNohTXxPzB2L75Vt/I/ViihlII4A0BX
OHKj1qsBQKa8+7Mj8uw/tnqpscBKBEDAVxttB+K3P3WkZqZDhBBAppipZoEW
9z8mKECLEVr9P/Xfu28YOvg/Gz8j1LoTBEAmtjmR2Mf+P0wa8MtBuwBAzmyP
lcC0AUDJbcbkaVwGQNPkWvRcFwRAsr8mefrdBUBoMGOCLtcKQMPM0zfzxPg/
3l2X82n+BkCUUNNPB1IRQJ/rZ/vfvApASvIyyaR8/T8kcaPzIS4CQECIrM2D
NP4/BI8xRzlqB0Cqs9c6TEIIQIJt6it7LAhAVNGhfFuB7T9wp+/VKzkRQCDW
dzXVFP4/A0lrTtwqDkBa6JYEAjzsPza7EtTOVgJAIFgipg8E9j/abxv8g2/+
P07FDUMZNO0/va7YJAL/CUCd1B1rNGwDQNTuAwMRYvU/fHk4fvT42z+ZUvS0
gXbwPwAAAAAAAAAAJmR597SVFkDKnllNyjj1P62mxRyS+xZAMv5UP5FXAED4
EqARn4UPQD1i3N1n5RBAT08EIQ==
       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
         LineBox[{{1, 2}, {1, 13}, {1, 14}, {1, 15}, {1, 16}, {1, 17}, {1, 
          18}, {1, 19}, {2, 3}, {2, 4}, {2, 5}, {2, 9}, {3, 4}, {3, 5}, {3, 
          7}, {3, 8}, {3, 13}, {3, 14}, {3, 16}, {3, 17}, {3, 18}, {4, 5}, {4,
           8}, {4, 11}, {4, 13}, {4, 14}, {4, 17}, {5, 8}, {5, 11}, {5, 16}, {
          5, 17}, {5, 18}, {5, 24}, {6, 7}, {6, 8}, {6, 9}, {6, 10}, {7, 8}, {
          7, 13}, {7, 18}, {7, 20}, {8, 13}, {8, 14}, {8, 16}, {8, 17}, {8, 
          30}, {9, 10}, {9, 13}, {9, 19}, {9, 21}, {9, 23}, {9, 24}, {9, 
          27}, {9, 28}, {9, 29}, {10, 13}, {10, 16}, {10, 17}, {10, 19}, {10, 
          20}, {10, 24}, {10, 25}, {10, 29}, {11, 12}, {12, 14}, {12, 16}, {
          12, 24}, {12, 29}, {12, 33}, {13, 18}, {13, 19}, {13, 20}, {13, 
          23}, {13, 24}, {13, 25}, {13, 26}, {13, 27}, {14, 17}, {14, 20}, {
          16, 17}, {16, 18}, {16, 29}, {17, 18}, {17, 20}, {17, 24}, {18, 
          19}, {18, 20}, {18, 25}, {18, 30}, {18, 31}, {18, 32}, {19, 20}, {
          19, 24}, {19, 25}, {20, 21}, {20, 22}, {20, 23}, {20, 24}, {20, 
          25}, {21, 24}, {21, 28}, {23, 26}, {23, 27}, {23, 29}, {24, 25}, {
          24, 29}, {24, 30}, {24, 31}, {25, 36}, {26, 28}, {26, 30}, {27, 
          34}, {27, 35}, {30, 33}, {32, 33}}]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.04714936380225114], DiskBox[2, 0.04714936380225114], 
         DiskBox[3, 0.04714936380225114], DiskBox[4, 0.04714936380225114], 
         DiskBox[5, 0.04714936380225114], DiskBox[6, 0.04714936380225114], 
         DiskBox[7, 0.04714936380225114], DiskBox[8, 0.04714936380225114], 
         DiskBox[9, 0.04714936380225114], DiskBox[10, 0.04714936380225114], 
         DiskBox[11, 0.04714936380225114], DiskBox[12, 0.04714936380225114], 
         DiskBox[13, 0.04714936380225114], DiskBox[14, 0.04714936380225114], 
         DiskBox[15, 0.04714936380225114], DiskBox[16, 0.04714936380225114], 
         DiskBox[17, 0.04714936380225114], DiskBox[18, 0.04714936380225114], 
         DiskBox[19, 0.04714936380225114], DiskBox[20, 0.04714936380225114], 
         DiskBox[21, 0.04714936380225114], DiskBox[22, 0.04714936380225114], 
         DiskBox[23, 0.04714936380225114], DiskBox[24, 0.04714936380225114], 
         DiskBox[25, 0.04714936380225114], DiskBox[26, 0.04714936380225114], 
         DiskBox[27, 0.04714936380225114], DiskBox[28, 0.04714936380225114], 
         DiskBox[29, 0.04714936380225114], DiskBox[30, 0.04714936380225114], 
         DiskBox[31, 0.04714936380225114], DiskBox[32, 0.04714936380225114], 
         DiskBox[33, 0.04714936380225114], DiskBox[34, 0.04714936380225114], 
         DiskBox[35, 0.04714936380225114], 
         DiskBox[36, 0.04714936380225114]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.7458799833398075`*^9, 3.7459394767152987`*^9, 
  3.7459397666469374`*^9, 3.746204222272508*^9, 3.746204600464081*^9, 
  3.7463973075893736`*^9, 3.7464445518078165`*^9, 3.746444606205511*^9, 
  3.7480366652725973`*^9, 3.748602644789257*^9, 3.7486027245249352`*^9, 
  3.7486028046820607`*^9, 3.748637458328537*^9, 3.7486379903249393`*^9, 
  3.7486381570074167`*^9, 3.748638249883832*^9, 3.748638466175482*^9, 
  3.7486387224214616`*^9, 3.7486389567725735`*^9, 3.7487775936756105`*^9, 
  3.749417432420537*^9, 3.749567332371237*^9, 3.750768587652457*^9, 
  3.751221181551961*^9, 3.7512887445171566`*^9, 3.7512928216352167`*^9, 
  3.751299315343111*^9, 3.751299985851986*^9, 3.7547790247362595`*^9, 
  3.7576351645810213`*^9, 3.7613869818863225`*^9, 3.830249422550926*^9, 
  3.8303402761496572`*^9, 3.8303407390969963`*^9, 3.8304155847956567`*^9, 
  3.830419566035618*^9, 3.8304202375070267`*^9},
 CellLabel->"Out[33]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
72.],ExpressionUUID->"0e0d5bdd-4add-405f-8c6e-aff6d02215f8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", 
    RowBox[{"Sort", "[", 
     RowBox[{"VertexList", "[", "graph", "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"vector", " ", "of", " ", "individuals"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7459400118286686`*^9, 3.745940020311623*^9}, {
   3.74640006890417*^9, 3.746400073714134*^9}, {3.748602782109249*^9, 
   3.7486027867337036`*^9}, 3.7486374707554264`*^9, 3.748638145660699*^9, 
   3.748638425733778*^9, 3.748638680885971*^9, 3.748638903002696*^9, {
   3.8302456821489596`*^9, 3.83024568256752*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"24ddf478-05e8-4477-9bfc-860d4d816b05"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deg", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Riffle", "[", 
      RowBox[{"n", ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Total", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"strongbonds", "[", 
                 RowBox[{"[", 
                  RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                RowBox[{"n", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
               RowBox[{
                RowBox[{"strongbonds", "[", 
                 RowBox[{"[", 
                  RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                RowBox[{"n", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
              RowBox[{"strongbonds", "[", 
               RowBox[{"[", 
                RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{
               RowBox[{"Dimensions", "[", "strongbonds", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "n", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
     "2"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"degree", " ", "of", " ", "each", " ", "individual"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.745940033735406*^9, 3.7459400475325823`*^9}, {
   3.7480370147421207`*^9, 3.748037018291253*^9}, 3.7486027145585566`*^9},
 CellLabel->"In[40]:=",ExpressionUUID->"02c2903e-e17f-4b8c-aa6e-26d18198a830"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"224", ",", "135"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"482", ",", "80"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "120"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"977", ",", "138"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "51"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1247", ",", "226"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1523", ",", "60"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1656", ",", "52"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1884", ",", "116"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1896", ",", "165"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2051", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2143", ",", "37"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2350", ",", "61"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3161", ",", "96"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3340", ",", "128"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3560", ",", "95"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3591", ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3685", ",", "56"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3973", ",", "150"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4680", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4684", ",", "146"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5539", ",", "126"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5699", ",", "78"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5908", ",", "93"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5971", ",", "22"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5972", ",", "112"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6333", ",", "116"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6464", ",", "28"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7332", ",", "183"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7460", ",", "67"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7695", ",", "251"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8443", ",", "47"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8607", ",", "179"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8896", ",", "65"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8925", ",", "71"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9166", ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9438", ",", "60"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7486028047601657`*^9, 3.7486374936064744`*^9, 
  3.748637990362711*^9, 3.748638157055865*^9, 3.748638249959818*^9, 
  3.748638466220872*^9, 3.7486387225061097`*^9, 3.748638956858763*^9, 
  3.7487775937381353`*^9, 3.749417432468891*^9, 3.749567332421007*^9, 
  3.750768587692275*^9, 3.7512211815988245`*^9, 3.751288744561098*^9, 
  3.7512928217077174`*^9, 3.7512993154056005`*^9, 3.7512999859366074`*^9, 
  3.754779024836681*^9, 3.7576351646436667`*^9, 3.761386982017502*^9, 
  3.830249427573467*^9, 3.830340282781911*^9, 3.830340739334592*^9, 
  3.83041558874632*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"30e2bfeb-9021-4b6e-879e-90018a984daa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{"graph", ",", 
    RowBox[{"EdgeStyle", "\[Rule]", 
     RowBox[{"Thread", "[", 
      RowBox[{"edges", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"GrayLevel", "[", "#", "]"}], "&"}], "/@", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"(", 
            RowBox[{"weights", "/", 
             RowBox[{"Max", "[", "weights", "]"}]}], ")"}]}], ")"}]}], 
        ")"}]}], "]"}]}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"VertexStyle", "\[Rule]", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"n", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "n", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"GrayLevel", "[", "#", "]"}], "&"}], "/@", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"deg", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "/", 
             RowBox[{"Max", "[", 
              RowBox[{"deg", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ")"}]}], 
          ")"}]}], ")"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7458800608040757`*^9, 3.745880081048403*^9}, {
   3.745880124485776*^9, 3.7458801254224434`*^9}, {3.7458801625583773`*^9, 
   3.745880163120462*^9}, {3.745880248911641*^9, 3.7458802524727316`*^9}, {
   3.745939778571862*^9, 3.7459397790863175`*^9}, {3.7459400677227736`*^9, 
   3.745940115424971*^9}, {3.7459401764827504`*^9, 3.745940184428888*^9}, {
   3.7459403494613466`*^9, 3.7459403497304835`*^9}, 3.7486374707733903`*^9, 
   3.74863814566556*^9, 3.748638425739703*^9, 3.748638680891634*^9, 
   3.7486389030078754`*^9, {3.830245689313541*^9, 3.8302456897506313`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"5c524a95-6e10-48f0-a86a-974d6da22b7a"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1884, 3973, 7332, 8607, 3560, 5908, 5972, 4684, 8925, 1896, 3161, 
      6333, 5539, 1247, 3685, 4680, 3340, 2143, 8443, 482, 977, 7695, 6464, 
      5699, 9166, 9438, 224, 640, 3591, 1523, 7460, 1120, 1656, 8896, 2350, 
      5971, 2051}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {8, 3}, {8, 9}, {
       10, 8}, {11, 8}, {8, 12}, {8, 13}, {14, 8}, {15, 16}, {17, 16}, {18, 
       15}, {18, 19}, {14, 18}, {20, 19}, {20, 13}, {20, 21}, {2, 22}, {2, 
       3}, {2, 23}, {2, 4}, {15, 2}, {2, 13}, {2, 24}, {2, 25}, {3, 22}, {22, 
       26}, {15, 22}, {27, 22}, {28, 22}, {21, 22}, {10, 3}, {11, 3}, {29, 
       3}, {27, 3}, {28, 3}, {30, 3}, {14, 3}, {21, 3}, {3, 31}, {29, 23}, {
       30, 23}, {4, 9}, {15, 9}, {11, 9}, {28, 9}, {14, 9}, {4, 26}, {10, 
       26}, {32, 26}, {11, 26}, {33, 26}, {10, 4}, {32, 4}, {11, 4}, {12, 
       4}, {6, 4}, {13, 4}, {33, 4}, {17, 4}, {14, 4}, {7, 4}, {19, 34}, {6, 
       34}, {27, 34}, {13, 34}, {17, 34}, {32, 10}, {10, 11}, {10, 29}, {10, 
       5}, {10, 24}, {14, 10}, {10, 35}, {21, 10}, {10, 31}, {21, 15}, {11, 
       29}, {11, 6}, {28, 11}, {13, 19}, {5, 12}, {6, 12}, {28, 29}, {5, 6}, {
       27, 5}, {35, 5}, {33, 6}, {6, 36}, {6, 7}, {28, 21}, {28, 25}, {14, 
       30}, {33, 17}, {33, 35}, {33, 7}, {37, 24}, {17, 24}, {14, 24}, {24, 
       31}, {17, 36}, {17, 6}, {14, 17}, {35, 17}, {21, 14}, {14, 7}, {14, 
       31}, {35, 31}, {21, 7}}}, {
      EdgeStyle -> {UndirectedEdge[1247, 7460] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[2051, 5699] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[2350, 3560] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5699, 7460] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3340, 5908] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[5908, 6333] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[640, 7695] -> GrayLevel[
           Rational[23, 45]], UndirectedEdge[1656, 3340] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[2143, 8443] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[6333, 8607] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1247, 2143] -> GrayLevel[
           Rational[4, 5]], UndirectedEdge[4684, 5539] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[977, 7695] -> GrayLevel[
           Rational[47, 90]], UndirectedEdge[3340, 5699] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1247, 5699] -> GrayLevel[
           Rational[32, 45]], UndirectedEdge[7695, 9438] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[224, 7695] -> GrayLevel[0], 
         UndirectedEdge[3685, 3973] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[3161, 7332] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[7332, 7460] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3973, 5699] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1656, 2350] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3973, 8607] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3340, 8896] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3973, 9166] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[640, 7332] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[5539, 8443] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1884, 3560] -> GrayLevel[
           Rational[26, 45]], UndirectedEdge[3685, 4680] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[8443, 8896] -> GrayLevel[
           Rational[73, 90]], UndirectedEdge[5908, 8896] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1247, 1896] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1523, 6464] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[482, 8443] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[977, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[8607, 8925] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3591, 6464] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[977, 1247] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[4684, 6333] -> GrayLevel[
           Rational[1, 30]], UndirectedEdge[977, 1896] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1896, 5699] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[3973, 7695] -> GrayLevel[
           Rational[23, 45]], UndirectedEdge[3161, 8607] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[977, 5972] -> GrayLevel[
           Rational[8, 15]], UndirectedEdge[1884, 3973] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[3973, 7332] -> GrayLevel[
           Rational[19, 30]], UndirectedEdge[977, 7332] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3685, 7695] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[7332, 7695] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3685, 8925] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1896, 3161] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[2350, 3340] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[5539, 8607] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[2143, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1896, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1896, 3591] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1247, 5972] -> GrayLevel[
           Rational[73, 90]], UndirectedEdge[1884, 8607] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[640, 3591] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1247, 3340] -> GrayLevel[
           Rational[11, 30]], UndirectedEdge[1247, 4684] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1896, 8607] -> GrayLevel[
           Rational[7, 15]], UndirectedEdge[1120, 9438] -> GrayLevel[
           Rational[34, 45]], UndirectedEdge[1120, 1896] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[1896, 7332] -> GrayLevel[
           Rational[23, 30]], UndirectedEdge[1120, 8607] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[8607, 9438] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1247, 7332] -> GrayLevel[
           Rational[71, 90]], UndirectedEdge[1884, 7332] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1896, 4684] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3161, 8925] -> GrayLevel[
           Rational[67, 90]], UndirectedEdge[5908, 5971] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[482, 977] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[2350, 7460] -> GrayLevel[
           Rational[61, 90]], UndirectedEdge[1247, 1523] -> GrayLevel[
           Rational[34, 45]], UndirectedEdge[640, 977] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[4684, 7332] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1247, 8607] -> GrayLevel[
           Rational[5, 6]], UndirectedEdge[1656, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[224, 8896] -> GrayLevel[
           Rational[38, 45]], UndirectedEdge[3560, 5908] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1523, 7332] -> GrayLevel[
           Rational[7, 10]], UndirectedEdge[640, 9166] -> GrayLevel[
           Rational[19, 30]], UndirectedEdge[3161, 3591] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[640, 3161] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[4684, 8925] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3340, 5971] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1896, 2350] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5972, 8607] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[482, 5539] -> GrayLevel[
           Rational[13, 45]], UndirectedEdge[1656, 5908] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[3161, 4684] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3560, 6333] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1247, 8925] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[1896, 3560] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5908, 5972] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1656, 5972] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3591, 7332] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3161, 5908] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[640, 8925] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3340, 4680] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[5539, 8896] -> GrayLevel[
           Rational[73, 90]], UndirectedEdge[3340, 8607] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[224, 3560] -> GrayLevel[
           Rational[11, 15]], UndirectedEdge[1884, 5908] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3973, 6464] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[224, 7332] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1896, 7460] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[3161, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5908, 8607] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3973, 5539] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1656, 8607] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1884, 5972] -> GrayLevel[
           Rational[29, 45]]}, 
       EdgeWeight -> {16, 12, 9, 38, 9, 32, 10, 8, 9, 7, 87, 16, 9, 7, 9, 7, 
        12, 18, 9, 64, 7, 44, 33, 9, 8, 13, 10, 8, 9, 8, 9, 13, 90, 44, 43, 
        21, 12, 7, 7, 9, 27, 19, 11, 7, 8, 11, 9, 9, 23, 11, 11, 8, 7, 22, 7, 
        7, 48, 16, 10, 9, 11, 10, 12, 7, 15, 7, 17, 9, 14, 17, 8, 13, 7, 7, 7,
         10, 9, 7, 8, 12, 7, 13, 8, 9, 9, 9, 11, 7, 10, 24, 7, 10, 10, 7, 7, 
        33, 22, 8, 8, 7, 16, 9, 26, 9, 12, 8, 57, 10, 13, 17, 10, 29, 42}, 
       GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {"Name"}, 
       VertexStyle -> {2143 -> GrayLevel[
           Rational[214, 251]], 2350 -> GrayLevel[
           Rational[190, 251]], 5699 -> GrayLevel[
           Rational[173, 251]], 482 -> GrayLevel[
           Rational[171, 251]], 9166 -> GrayLevel[
           Rational[209, 251]], 1896 -> GrayLevel[
           Rational[86, 251]], 5972 -> GrayLevel[
           Rational[139, 251]], 8925 -> GrayLevel[
           Rational[180, 251]], 5971 -> GrayLevel[
           Rational[229, 251]], 3161 -> GrayLevel[
           Rational[155, 251]], 8896 -> GrayLevel[
           Rational[186, 251]], 2051 -> GrayLevel[
           Rational[235, 251]], 5539 -> GrayLevel[
           Rational[125, 251]], 1884 -> GrayLevel[
           Rational[135, 251]], 8607 -> GrayLevel[
           Rational[72, 251]], 5908 -> GrayLevel[
           Rational[158, 251]], 1120 -> GrayLevel[
           Rational[200, 251]], 8443 -> GrayLevel[
           Rational[204, 251]], 3560 -> GrayLevel[
           Rational[156, 251]], 3591 -> GrayLevel[
           Rational[209, 251]], 7332 -> GrayLevel[
           Rational[68, 251]], 224 -> GrayLevel[
           Rational[116, 251]], 1656 -> GrayLevel[
           Rational[199, 251]], 6464 -> GrayLevel[
           Rational[223, 251]], 1523 -> GrayLevel[
           Rational[191, 251]], 977 -> GrayLevel[
           Rational[113, 251]], 4684 -> GrayLevel[
           Rational[105, 251]], 640 -> GrayLevel[
           Rational[131, 251]], 6333 -> GrayLevel[
           Rational[135, 251]], 1247 -> GrayLevel[
           Rational[25, 251]], 3340 -> GrayLevel[
           Rational[123, 251]], 3685 -> GrayLevel[
           Rational[195, 251]], 3973 -> GrayLevel[
           Rational[101, 251]], 7460 -> GrayLevel[
           Rational[184, 251]], 9438 -> GrayLevel[
           Rational[191, 251]], 4680 -> GrayLevel[
           Rational[235, 251]], 7695 -> GrayLevel[0]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.254270855923262, 2.8698464127954573`}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.0878088126360055`, 2.521433088371224}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.6311424972576836`, 1.5590962874045355`}}]}, 
        {GrayLevel[
          NCache[
           Rational[26, 45], 0.5777777777777777]], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.583980036533834, 0.9282266151910459}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          3.1878881389781992`, 0.9722239523255354}}]}, 
        {GrayLevel[
          NCache[
           Rational[29, 45], 0.6444444444444445]], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          3.0950771698088544`, 1.5359535085931357`}}]}, 
        {GrayLevel[
          NCache[
           Rational[19, 30], 0.6333333333333333]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          2.0878088126360055`, 2.521433088371224}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          2.6311424972576836`, 1.5590962874045355`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          3.7199641632770652`, 2.447600728379067}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          3.4427320409738456`, 3.082866302351973}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 45], 0.5111111111111111]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          1.0991774454099354`, 3.724970924197967}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          1.9609481837191605`, 4.23067539877886}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.868381216541333, 1.944461534939188}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 30], 0.7666666666666667]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {2.20178014533537,
           2.1059129902680924`}}]}, 
        {GrayLevel[
          NCache[
           Rational[71, 90], 0.7888888888888889]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          3.2718706661648147`, 1.9615687638283492`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.188854013791599, 3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.374401110837499, 2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[7, 10], 0.7]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.4960812966322448`, 3.3648299807271984`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.1878881389781992`, 0.9722239523255354}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.0950771698088544`, 1.5359535085931357`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.8257372357158785`, 2.6113602770062228`}}]}, 
        {GrayLevel[
          NCache[
           Rational[7, 15], 0.4666666666666667]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.7199641632770652`, 2.447600728379067}}]}, 
        {GrayLevel[
          NCache[
           Rational[5, 6], 0.8333333333333334]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          1.426894169367006, 0.8981408741125645}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          3.1878881389781992`, 0.9722239523255354}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {GrayLevel[
          NCache[
           Rational[11, 15], 0.7333333333333333]], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          3.2718706661648147`, 1.9615687638283492`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.0950771698088544`, 1.5359535085931357`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.6883059376362457`, 0.}}]}, 
        {GrayLevel[
          NCache[
           Rational[73, 90], 0.8111111111111111]], 
         LineBox[{{3.0950771698088544`, 1.5359535085931357`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 15], 0.5333333333333333]], 
         LineBox[{{3.0950771698088544`, 1.5359535085931357`}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.0950771698088544`, 1.5359535085931357`}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          2.8257372357158785`, 2.6113602770062228`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {2.20178014533537, 
          2.1059129902680924`}}]}, 
        {GrayLevel[
          NCache[
           Rational[1, 30], 0.03333333333333333]], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          3.7199641632770652`, 2.447600728379067}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {GrayLevel[
          NCache[
           Rational[67, 90], 0.7444444444444445]], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          3.4427320409738456`, 3.082866302351973}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          2.188854013791599, 3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.374401110837499, 2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.426894169367006, 0.8981408741125645}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.20178014533537, 2.1059129902680924`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.20178014533537, 2.1059129902680924`}, {2.188854013791599,
           3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{2.20178014533537, 2.1059129902680924`}, {1.374401110837499,
           2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{3.7199641632770652`, 2.447600728379067}, {4.73425173666226,
           2.681130220163744}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 45], 0.28888888888888886`]], 
         LineBox[{{3.7199641632770652`, 2.447600728379067}, {
          4.397641903925736, 3.2539845580257283`}}]}, 
        {GrayLevel[
          NCache[
           Rational[73, 90], 0.8111111111111111]], 
         LineBox[{{3.7199641632770652`, 2.447600728379067}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[11, 30], 0.36666666666666664`]], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {GrayLevel[
          NCache[
           Rational[4, 5], 0.8]], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          3.903077256299162, 3.255798740011394}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {GrayLevel[
          NCache[
           Rational[32, 45], 0.7111111111111111]], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {GrayLevel[
          NCache[
           Rational[34, 45], 0.7555555555555555]], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          1.4960812966322448`, 3.3648299807271984`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          4.287142555088807, 2.010102527203237}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          3.903077256299162, 3.255798740011394}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{4.287142555088807, 2.010102527203237}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          3.6883059376362457`, 0.}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{3.903077256299162, 3.255798740011394}, {4.73425173666226, 
          2.681130220163744}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{4.73425173666226, 2.681130220163744}, {4.397641903925736, 
          3.2539845580257283`}}]}, 
        {GrayLevel[
          NCache[
           Rational[73, 90], 0.8111111111111111]], 
         LineBox[{{4.73425173666226, 2.681130220163744}, {4.104459217702431, 
          1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{4.397641903925736, 3.2539845580257283`}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {GrayLevel[
          NCache[
           Rational[47, 90], 0.5222222222222223]], 
         LineBox[{{3.0264201946628146`, 2.80485831460313}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.0264201946628146`, 2.80485831460313}, {2.188854013791599,
           3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.5940113125237874`, 2.7693008373875165`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {GrayLevel[0], 
         LineBox[{{2.5940113125237874`, 2.7693008373875165`}, {
          3.2718706661648147`, 1.9615687638283492`}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 45], 0.5111111111111111]], 
         LineBox[{{2.5940113125237874`, 2.7693008373875165`}, {
          2.188854013791599, 3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{1.0991774454099354`, 3.724970924197967}, {
          1.374401110837499, 2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{1.0991774454099354`, 3.724970924197967}, {
          1.4960812966322448`, 3.3648299807271984`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.4691302208150039`, 1.6601275876173132`}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{1.4691302208150039`, 1.6601275876173132`}, {0., 
          1.1873821379604075`}}]}, 
        {GrayLevel[
          NCache[
           Rational[19, 30], 0.6333333333333333]], 
         LineBox[{{1.9609481837191605`, 4.23067539877886}, {2.188854013791599,
           3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[34, 45], 0.7555555555555555]], 
         LineBox[{{1.9626592733755062`, 1.3741698167689078`}, {
          1.426894169367006, 0.8981408741125645}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.9626592733755062`, 1.3741698167689078`}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {GrayLevel[
          NCache[
           Rational[38, 45], 0.8444444444444444]], 
         LineBox[{{3.2718706661648147`, 1.9615687638283492`}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.188854013791599, 3.306741207795006}, {1.374401110837499, 
          2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[61, 90], 0.6777777777777778]], 
         LineBox[{{1.305774790379798, 1.8813573754580086`}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.5580136313919133`, 0.5769391307265495}, {
          1.9009919110450095`, 0.7781096625592305}}]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         {GrayLevel[
           NCache[
            Rational[135, 251], 0.5378486055776892]], 
          DiskBox[{2.3984649978198687, 1.6667217353021773}, 
           0.0415063096365134]}, 
         InsetBox["1884", 
          Offset[{2, 2}, {2.439971307456382, 1.7082280449386906}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[101, 251], 0.40239043824701193`]], 
          DiskBox[{2.254270855923262, 2.8698464127954573}, 
           0.0415063096365134]}, 
         InsetBox["3973", 
          Offset[{2, 2}, {2.2957771655597754, 2.9113527224319706}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[68, 251], 0.27091633466135456`]], 
          DiskBox[{2.0878088126360055, 2.521433088371224}, 
           0.0415063096365134]}, 
         InsetBox["7332", 
          Offset[{2, 2}, {2.129315122272519, 2.5629393980077375}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[72, 251], 0.2868525896414343]], 
          DiskBox[{2.6311424972576836, 1.5590962874045355}, 
           0.0415063096365134]}, 
         InsetBox["8607", 
          Offset[{2, 2}, {2.672648806894197, 1.600602597041049}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[156, 251], 0.6215139442231076]], 
          DiskBox[{2.583980036533834, 0.9282266151910459}, 
           0.0415063096365134]}, 
         InsetBox["3560", 
          Offset[{2, 2}, {2.6254863461703475, 0.9697329248275592}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[158, 251], 0.6294820717131474]], 
          DiskBox[{3.1878881389781992, 0.9722239523255354}, 
           0.0415063096365134]}, 
         InsetBox["5908", 
          Offset[{2, 2}, {3.2293944486147126, 1.0137302619620487}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[139, 251], 0.5537848605577689]], 
          DiskBox[{3.0950771698088544, 1.5359535085931357}, 
           0.0415063096365134]}, 
         InsetBox["5972", 
          Offset[{2, 2}, {3.1365834794453678, 1.577459818229649}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[105, 251], 0.41832669322709165`]], 
          DiskBox[{2.868381216541333, 1.944461534939188}, 
           0.0415063096365134]}, 
         InsetBox["4684", 
          Offset[{2, 2}, {2.9098875261778465, 1.9859678445757014}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[180, 251], 0.7171314741035857]], 
          DiskBox[{2.8257372357158785, 2.6113602770062228}, 
           0.0415063096365134]}, 
         InsetBox["8925", 
          Offset[{2, 2}, {2.867243545352392, 2.652866586642736}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[86, 251], 0.3426294820717131]], 
          DiskBox[{1.9572951633274314, 1.8099051183928858}, 
           0.0415063096365134]}, 
         InsetBox["1896", 
          Offset[{2, 2}, {1.9988014729639447, 1.8514114280293992}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[155, 251], 0.6175298804780877]], 
          DiskBox[{2.20178014533537, 2.1059129902680924}, 
           0.0415063096365134]}, 
         InsetBox["3161", 
          Offset[{2, 2}, {2.243286454971883, 2.147419299904606}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[135, 251], 0.5378486055776892]], 
          DiskBox[{3.2788700786662375, 0.6451863306944472}, 
           0.0415063096365134]}, 
         InsetBox["6333", 
          Offset[{2, 2}, {3.320376388302751, 0.6866926403309606}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[125, 251], 0.49800796812749004`]], 
          DiskBox[{3.7199641632770652, 2.447600728379067}, 
           0.0415063096365134]}, 
         InsetBox["5539", 
          Offset[{2, 2}, {3.7614704729135786, 2.48910703801558}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[25, 251], 0.099601593625498]], 
          DiskBox[{2.4698388307120833, 2.295865678675766}, 
           0.0415063096365134]}, 
         InsetBox["1247", 
          Offset[{2, 2}, {2.5113451403485967, 2.337371988312279}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[195, 251], 0.7768924302788844]], 
          DiskBox[{3.4427320409738456, 3.082866302351973}, 
           0.0415063096365134]}, 
         InsetBox["3685", 
          Offset[{2, 2}, {3.484238350610359, 3.1243726119884863}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[235, 251], 0.9362549800796812]], 
          DiskBox[{4.287142555088807, 2.010102527203237}, 
           0.0415063096365134]}, 
         InsetBox["4680", 
          Offset[{2, 2}, {4.328648864725321, 2.0516088368397503}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[123, 251], 0.4900398406374502]], 
          DiskBox[{3.0226924541869202, 1.159944789617093}, 
           0.0415063096365134]}, 
         InsetBox["3340", 
          Offset[{2, 2}, {3.0641987638234336, 1.2014510992536063}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[214, 251], 0.852589641434263]], 
          DiskBox[{3.903077256299162, 3.255798740011394}, 
           0.0415063096365134]}, 
         InsetBox["2143", 
          Offset[{2, 2}, {3.9445835659356754, 3.2973050496479073}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[204, 251], 0.8127490039840638]], 
          DiskBox[{4.73425173666226, 2.681130220163744}, 0.0415063096365134]},
          InsetBox["8443", 
          Offset[{2, 2}, {4.775758046298773, 2.7226365298002575}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[171, 251], 0.6812749003984063]], 
          DiskBox[{4.397641903925736, 3.2539845580257283}, 
           0.0415063096365134]}, 
         InsetBox["482", 
          Offset[{2, 2}, {4.43914821356225, 3.2954908676622416}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[113, 251], 0.450199203187251]], 
          DiskBox[{3.0264201946628146, 2.80485831460313}, 
           0.0415063096365134]}, 
         InsetBox["977", 
          Offset[{2, 2}, {3.067926504299328, 2.8463646242396434}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[0], 
          DiskBox[{2.5940113125237874, 2.7693008373875165}, 
           0.0415063096365134]}, 
         InsetBox["7695", 
          Offset[{2, 2}, {2.6355176221603007, 2.81080714702403}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[223, 251], 0.8884462151394422]], 
          DiskBox[{1.0991774454099354, 3.724970924197967}, 
           0.0415063096365134]}, 
         InsetBox["6464", 
          Offset[{2, 2}, {1.1406837550464488, 3.7664772338344803}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[173, 251], 0.6892430278884463]], 
          DiskBox[{1.4691302208150039, 1.6601275876173132}, 
           0.0415063096365134]}, 
         InsetBox["5699", 
          Offset[{2, 2}, {1.5106365304515172, 1.7016338972538265}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[209, 251], 0.8326693227091634]], 
          DiskBox[{1.9609481837191605, 4.23067539877886}, 
           0.0415063096365134]}, 
         InsetBox["9166", 
          Offset[{2, 2}, {2.002454493355674, 4.272181708415374}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[191, 251], 0.7609561752988048]], 
          DiskBox[{1.9626592733755062, 1.3741698167689078}, 
           0.0415063096365134]}, 
         InsetBox["9438", 
          Offset[{2, 2}, {2.0041655830120195, 1.4156761264054212}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[116, 251], 0.46215139442231074`]], 
          DiskBox[{3.2718706661648147, 1.9615687638283492}, 
           0.0415063096365134]}, 
         InsetBox["224", 
          Offset[{2, 2}, {3.313376975801328, 2.0030750734648626}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[131, 251], 0.5219123505976095]], 
          DiskBox[{2.188854013791599, 3.306741207795006}, 
           0.0415063096365134]}, 
         InsetBox["640", 
          Offset[{2, 2}, {2.2303603234281124, 3.348247517431519}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[209, 251], 0.8326693227091634]], 
          DiskBox[{1.374401110837499, 2.8591905382743446}, 
           0.0415063096365134]}, 
         InsetBox["3591", 
          Offset[{2, 2}, {1.4159074204740123, 2.900696847910858}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[191, 251], 0.7609561752988048]], 
          DiskBox[{1.4960812966322448, 3.3648299807271984}, 
           0.0415063096365134]}, 
         InsetBox["1523", 
          Offset[{2, 2}, {1.5375876062687581, 3.4063362903637118}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[184, 251], 0.7330677290836654]], 
          DiskBox[{1.305774790379798, 1.8813573754580086}, 
           0.0415063096365134]}, 
         InsetBox["7460", 
          Offset[{2, 2}, {1.3472811000163114, 1.922863685094522}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[200, 251], 0.796812749003984]], 
          DiskBox[{1.426894169367006, 0.8981408741125645}, 
           0.0415063096365134]}, 
         InsetBox["1120", 
          Offset[{2, 2}, {1.4684004790035194, 0.9396471837490779}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[199, 251], 0.7928286852589641]], 
          DiskBox[{2.5580136313919133, 0.5769391307265495}, 
           0.0415063096365134]}, 
         InsetBox["1656", 
          Offset[{2, 2}, {2.5995199410284267, 0.6184454403630628}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[186, 251], 0.7410358565737052]], 
          DiskBox[{4.104459217702431, 1.6157516950091917}, 
           0.0415063096365134]}, 
         InsetBox["8896", 
          Offset[{2, 2}, {4.145965527338944, 1.657258004645705}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[190, 251], 0.7569721115537849]], 
          DiskBox[{1.9009919110450095, 0.7781096625592305}, 
           0.0415063096365134]}, 
         InsetBox["2350", 
          Offset[{2, 2}, {1.942498220681523, 0.8196159721957439}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[229, 251], 0.9123505976095617]], 
          DiskBox[{3.6883059376362457, 0.}, 0.0415063096365134]}, 
         InsetBox["5971", 
          Offset[{2, 2}, {3.729812247272759, 0.0415063096365134}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[235, 251], 0.9362549800796812]], 
          DiskBox[{0., 1.1873821379604075}, 0.0415063096365134]}, 
         InsetBox["2051", 
          Offset[{2, 2}, {0.0415063096365134, 1.2288884475969208}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.7458801295425224`*^9, 3.7458801637683773`*^9, 3.745880253095614*^9, 
   3.745939779873432*^9, 3.7459400826563087`*^9, 3.745940116187047*^9, 
   3.745940184913289*^9, 3.7459403126450276`*^9, 3.745940350439331*^9, 
   3.7462042240703793`*^9, 3.746204600680188*^9, 3.746397307808074*^9, 
   3.7464445521238885`*^9, 3.7464446074485054`*^9, {3.748036652307449*^9, 
   3.7480366824354267`*^9}, 3.7486026454453545`*^9, 3.748602726040205*^9, 
   3.7486028049007573`*^9, 3.7486374988141403`*^9, 3.748637990458195*^9, 
   3.7486381570834312`*^9, 3.748638250065529*^9, 3.7486384663267775`*^9, 
   3.748638722616296*^9, 3.7486389569392705`*^9, 3.7487775938696165`*^9, 
   3.7494174325568666`*^9, 3.749567332534671*^9, 3.750768587756008*^9, 
   3.7512211816990623`*^9, 3.751288744688928*^9, 3.7512928217992334`*^9, 
   3.751299315543585*^9, 3.751299986032428*^9, 3.7547790250354786`*^9, 
   3.757635164753846*^9, 3.7613869822007384`*^9, 3.8302494307351418`*^9, 
   3.8303407397581186`*^9, 3.8304155909580145`*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"c30808f0-bfe4-486a-9ab1-bb87cd23c75e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Observed (Run Second)", "Section",
 CellChangeTimes->{{3.7464029886576176`*^9, 3.7464029910253773`*^9}, {
  3.8302455454160323`*^9, 3.8302455475184364`*^9}, {3.830246104603462*^9, 
  3.830246106591866*^9}},ExpressionUUID->"671ac954-1f48-4492-bd0a-\
d27668089668"],

Cell[CellGroupData[{

Cell["Vertex", "Subsection",
 CellChangeTimes->{{3.7507015756514826`*^9, 
  3.750701579496445*^9}},ExpressionUUID->"a500f29c-bb95-4b5e-86a1-\
bbeb76709991"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rankdata", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"group", "<>", "\"\<_coded_ranks.csv\>\""}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7464025221575947`*^9, 3.746402589218871*^9}, {
   3.7486307209793096`*^9, 3.7486307224880104`*^9}, 3.7575923085009546`*^9, 
   3.7575958365070887`*^9, 3.7576331020870495`*^9, 3.7576343401893206`*^9, 
   3.7576348265374413`*^9, 3.7576351589198036`*^9, {3.8302457110489583`*^9, 
   3.8302457169409847`*^9}, {3.8303402920694065`*^9, 3.8303402924434805`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"57946373-2359-434b-820d-a2bd36bfd245"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rankdata", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7464026047068634`*^9, 3.746402610650135*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"268fea71-3327-42ed-ba32-5ce6432a4333"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"rnkid\"\>", ",", "\<\"sname\"\>", ",", "\<\"rnkdate\"\>", 
   ",", "\<\"grp\"\>", ",", "\<\"rnktype\"\>", ",", "\<\"ordrank\"\>", 
   ",", "\<\"proprank\"\>"}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB2I9lRS1TS9fO7poyaw6BqRDFNv/nn/z2vFL4lOezvev
HQ85yApPAdLmcaIBIFpqzRbRjI+vHVMC7Xf3AWmXLL7aJ0B6n82E8qdA+leR
2A8QnbF+h+T7T68d3a3l1UD0i21RDiD63QOpi4yfXzv27PX05QTSdSnLzoHo
jtnzdBZ8f+347a5X1qYfrx1FjDdYN/987agufePWKiBtov27ZTWQ1tPaoLnv
32vHqIw1Ok+AdI244wPO/68dZ6TNSeYC0g1566aA6BmTZ98D0REKXnLcQFpM
yTULRL9o1FwKooNmTVgDohmql5+XBdJds7nS5IB0wd+6RSB6BtPK0yBa6rp4
zOnON44l95LrQHSRDpfSByANAAVbqyc=
  "],
 CellLabel->"Out[43]=",ExpressionUUID->"5a5579b7-7b29-490f-b852-c92f9d992084"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rankdata", "=", 
   RowBox[{"rankdata", "[", 
    RowBox[{"[", 
     RowBox[{"2", ";;", 
      RowBox[{
       RowBox[{"Dimensions", "[", "rankdata", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.746402612774135*^9, 3.7464026209652767`*^9}, {
  3.7575959733857284`*^9, 3.75759598233642*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"1abc101b-0aac-4e38-82b5-16855bb357c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"rankdata", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "3"}], "]"}], "]"}], "=", 
     RowBox[{"DateObject", "[", 
      RowBox[{"rankdata", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "3"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", "rankdata", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"format", " ", "correctly", " ", "as", " ", "date"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.8302493314379663`*^9, 3.83024935327365*^9}, {
  3.8302494882761173`*^9, 3.8302494928163085`*^9}, {3.8303406395745134`*^9, 
  3.8303406468481283`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"677a760b-ad47-498e-9efb-ee53645d2935"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fisdate", "=", 
   RowBox[{"Which", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"group", "\[Equal]", "\"\<dotty\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<hook\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"1994", ",", "4", ",", "27", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<linda\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "4", ",", "6", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<lodge\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"1995", ",", "7", ",", "13", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<nyayo\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "10", ",", "20", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<viola\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"group", "\[Equal]", "\"\<vogue\>\""}], ",", 
     RowBox[{"DateObject", "[", 
      RowBox[{"{", 
       RowBox[{"2017", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0"}], 
       "}"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.830415661326829*^9, 
  3.830415663157383*^9}},ExpressionUUID->"e962e57c-d967-4646-b8bb-\
95fea4492734"],

Cell[BoxData[
 RowBox[{
  RowBox[{"postfission", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"rankdata", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "\[GreaterEqual]", "fisdate"}], 
      "&"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.757634328872197*^9, 3.757634810747712*^9, 3.7576351407087946`*^9, {
   3.8303403567489557`*^9, 3.8303403580114946`*^9}, {3.830340684236133*^9, 
   3.8303406853806124`*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"74ce761a-4886-4212-bf85-ce4d0de9e7c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"postfission", "=", 
   RowBox[{"GatherBy", "[", 
    RowBox[{
     RowBox[{"DeleteDuplicates", "[", 
      RowBox[{
       RowBox[{"SortBy", "[", 
        RowBox[{"postfission", ",", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "4", "]"}], "]"}], "&"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.746402738027935*^9, 3.7464027540856466`*^9}, {
  3.746402789641855*^9, 3.7464028327833557`*^9}, {3.7464028860869794`*^9, 
  3.7464029084429574`*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"4450d26d-707f-4877-bebb-0844b2276f72"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"e1", "=", 
   RowBox[{
    RowBox[{"postfission", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e2", "=", 
   RowBox[{
    RowBox[{"postfission", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7464029129601316`*^9, 3.7464029581792574`*^9}, {
  3.74640302962267*^9, 3.7464030302670145`*^9}, {3.74640322632768*^9, 
  3.7464032285946016`*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"c7e51735-195d-495b-a200-4fd67ef32457"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1", "=", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"g", ",", "e1", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7464030359980793`*^9, 3.7464030519490805`*^9}, {
  3.7464032069627705`*^9, 3.7464032336010227`*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"de6fadc2-d6cb-49b0-aa90-3bfe2339e6ca"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{5699, 1247, 3340, 2350, 5972, 8607, 977, 1896, 9438, 6333, 224, 
      3973, 6464, 7332, 3560, 3685, 3161, 8925, 640, 2051, 5971, 2143, 7695, 
      4684, 1523, 9166, 8896, 1884}, {
      Null, {{2, 1}, {3, 1}, {2, 3}, {4, 3}, {2, 5}, {3, 6}, {2, 6}, {5, 6}, {
       7, 2}, {7, 5}, {8, 6}, {8, 1}, {2, 8}, {8, 4}, {7, 8}, {6, 9}, {8, 
       9}, {10, 6}, {12, 6}, {12, 1}, {12, 13}, {12, 14}, {8, 14}, {11, 14}, {
       2, 14}, {7, 14}, {8, 15}, {15, 10}, {11, 15}, {4, 15}, {16, 12}, {7, 
       16}, {17, 14}, {17, 9}, {17, 6}, {8, 17}, {6, 18}, {16, 18}, {17, 
       18}, {2, 18}, {19, 14}, {19, 18}, {19, 17}, {19, 7}, {20, 1}, {3, 
       21}, {22, 16}, {2, 22}, {12, 23}, {14, 23}, {23, 9}, {16, 23}, {11, 
       23}, {19, 23}, {7, 23}, {24, 14}, {24, 18}, {8, 24}, {17, 24}, {24, 
       10}, {2, 24}, {25, 14}, {25, 13}, {2, 25}, {12, 26}, {19, 26}, {11, 
       27}, {3, 27}, {28, 12}, {28, 14}, {28, 6}, {28, 15}, {28, 5}}}, {
      EdgeStyle -> {UndirectedEdge[4684, 7332] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[977, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3973, 6464] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3340, 8896] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[8607, 8925] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[640, 977] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5972, 8607] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1523, 7332] -> GrayLevel[
           Rational[7, 10]], UndirectedEdge[1896, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[6333, 8607] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[2143, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[8607, 9438] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[4684, 8925] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1247, 5699] -> GrayLevel[
           Rational[32, 45]], UndirectedEdge[1247, 3340] -> GrayLevel[
           Rational[11, 30]], UndirectedEdge[3161, 7332] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1523, 6464] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3560, 6333] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1884, 5972] -> GrayLevel[
           Rational[29, 45]], UndirectedEdge[3340, 5699] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[977, 7332] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[640, 7695] -> GrayLevel[
           Rational[23, 45]], UndirectedEdge[640, 7332] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[224, 3560] -> GrayLevel[
           Rational[11, 15]], UndirectedEdge[977, 1896] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1896, 3560] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1896, 4684] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1247, 1523] -> GrayLevel[
           Rational[34, 45]], UndirectedEdge[224, 7695] -> GrayLevel[0], 
         UndirectedEdge[7695, 9438] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3161, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3340, 5971] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[3973, 9166] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1896, 3161] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1884, 7332] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1896, 8607] -> GrayLevel[
           Rational[7, 15]], UndirectedEdge[977, 7695] -> GrayLevel[
           Rational[47, 90]], UndirectedEdge[1896, 5699] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[2350, 3560] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1884, 8607] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3161, 8925] -> GrayLevel[
           Rational[67, 90]], UndirectedEdge[2350, 3340] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[3685, 8925] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1247, 4684] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1896, 2350] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1884, 3973] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[977, 5972] -> GrayLevel[
           Rational[8, 15]], UndirectedEdge[977, 1247] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[640, 3161] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3161, 4684] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[640, 8925] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[224, 8896] -> GrayLevel[
           Rational[38, 45]], UndirectedEdge[3161, 8607] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1247, 1896] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3340, 8607] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1247, 7332] -> GrayLevel[
           Rational[71, 90]], UndirectedEdge[224, 7332] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1247, 2143] -> GrayLevel[
           Rational[4, 5]], UndirectedEdge[640, 9166] -> GrayLevel[
           Rational[19, 30]], UndirectedEdge[1247, 8607] -> GrayLevel[
           Rational[5, 6]], UndirectedEdge[3685, 3973] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[3973, 7332] -> GrayLevel[
           Rational[19, 30]], UndirectedEdge[1247, 5972] -> GrayLevel[
           Rational[73, 90]], UndirectedEdge[3973, 8607] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1884, 3560] -> GrayLevel[
           Rational[26, 45]], UndirectedEdge[1896, 7332] -> GrayLevel[
           Rational[23, 30]], UndirectedEdge[3685, 7695] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[1247, 8925] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3973, 5699] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[4684, 6333] -> GrayLevel[
           Rational[1, 30]], UndirectedEdge[7332, 7695] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[2051, 5699] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[3973, 7695] -> GrayLevel[
           Rational[23, 45]]}, 
       EdgeWeight -> {26, 9, 57, 10, 17, 7, 15, 7, 13, 42, 48, 10, 9, 7, 8, 8,
         7, 9, 8, 8, 9, 33, 21, 7, 19, 11, 7, 9, 24, 7, 13, 7, 12, 7, 10, 7, 
        9, 9, 23, 11, 9, 11, 9, 7, 16, 12, 7, 18, 44, 8, 9, 13, 90, 44, 43, 
        10, 8, 9, 7, 87, 9, 27, 11, 22, 9, 33, 14, 8, 16, 12, 9, 38, 32}, 
       GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {"Name"}, 
       VertexStyle -> {8925 -> GrayLevel[
           Rational[180, 251]], 9438 -> GrayLevel[
           Rational[191, 251]], 8896 -> GrayLevel[
           Rational[186, 251]], 5972 -> GrayLevel[
           Rational[139, 251]], 6333 -> GrayLevel[
           Rational[135, 251]], 977 -> GrayLevel[
           Rational[113, 251]], 4684 -> GrayLevel[
           Rational[105, 251]], 3340 -> GrayLevel[
           Rational[123, 251]], 7332 -> GrayLevel[
           Rational[68, 251]], 2143 -> GrayLevel[
           Rational[214, 251]], 2051 -> GrayLevel[
           Rational[235, 251]], 3560 -> GrayLevel[
           Rational[156, 251]], 9166 -> GrayLevel[
           Rational[209, 251]], 1247 -> GrayLevel[
           Rational[25, 251]], 3685 -> GrayLevel[
           Rational[195, 251]], 6464 -> GrayLevel[
           Rational[223, 251]], 224 -> GrayLevel[
           Rational[116, 251]], 5699 -> GrayLevel[
           Rational[173, 251]], 1884 -> GrayLevel[
           Rational[135, 251]], 8607 -> GrayLevel[
           Rational[72, 251]], 7695 -> GrayLevel[0], 640 -> GrayLevel[
           Rational[131, 251]], 5971 -> GrayLevel[
           Rational[229, 251]], 2350 -> GrayLevel[
           Rational[190, 251]], 3973 -> GrayLevel[
           Rational[101, 251]], 1523 -> GrayLevel[
           Rational[191, 251]], 3161 -> GrayLevel[
           Rational[155, 251]], 1896 -> GrayLevel[
           Rational[86, 251]]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {GrayLevel[
          NCache[
           Rational[32, 45], 0.7111111111111111]], 
         LineBox[{{2.6164219379414764`, 2.5463295116096902`}, {
          1.8734771995400483`, 1.903611651024778}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.6164219379414764`, 2.5463295116096902`}, {
          3.3690329482451054`, 1.937086100057042}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.6164219379414764`, 2.5463295116096902`}, {
          2.415685622919158, 1.1126094410425773`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.6164219379414764`, 2.5463295116096902`}, {
          1.395866475072796, 2.12132490723644}}]}, 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{2.6164219379414764`, 2.5463295116096902`}, {
          3.210940861573713, 3.810068034261915}}]}, 
        {GrayLevel[
          NCache[
           Rational[11, 30], 0.36666666666666664`]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          3.3690329482451054`, 1.937086100057042}}]}, 
        {GrayLevel[
          NCache[
           Rational[73, 90], 0.8111111111111111]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          2.1501235897226065`, 1.7516102044565645`}}]}, 
        {GrayLevel[
          NCache[
           Rational[5, 6], 0.8333333333333334]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          2.1422425407843093`, 1.0918316021294832`}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          1.2830636267829036`, 1.5327323217914604`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          2.415685622919158, 1.1126094410425773`}}]}, 
        {GrayLevel[
          NCache[
           Rational[71, 90], 0.7888888888888889]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          1.7407660728414678`, 1.4627004360743439`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          1.1167652938701984`, 0.9439049839133664}}]}, 
        {GrayLevel[
          NCache[
           Rational[4, 5], 0.8]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          0.5857333203209061, 2.5637837591952874`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          1.937246385641052, 0.645671257545399}}]}, 
        {GrayLevel[
          NCache[
           Rational[34, 45], 0.7555555555555555]], 
         LineBox[{{1.8734771995400483`, 1.903611651024778}, {
          1.4574762623917898`, 2.807238168287663}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{3.3690329482451054`, 1.937086100057042}, {
          3.712999713991894, 1.027488432969465}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.3690329482451054`, 1.937086100057042}, {
          2.1422425407843093`, 1.0918316021294832`}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{3.3690329482451054`, 1.937086100057042}, {
          4.650055187552439, 2.556591894792846}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.3690329482451054`, 1.937086100057042}, {
          4.196060136073973, 1.576264565489734}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.712999713991894, 1.027488432969465}, {2.415685622919158, 
          1.1126094410425773`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.712999713991894, 1.027488432969465}, {3.219837619053982, 
          0.6220636221004945}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.1501235897226065`, 1.7516102044565645`}, {
          2.1422425407843093`, 1.0918316021294832`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 15], 0.5333333333333333]], 
         LineBox[{{2.1501235897226065`, 1.7516102044565645`}, {
          1.2830636267829036`, 1.5327323217914604`}}]}, 
        {GrayLevel[
          NCache[
           Rational[29, 45], 0.6444444444444445]], 
         LineBox[{{2.1501235897226065`, 1.7516102044565645`}, {
          2.5553180405738396`, 1.6109041875959655`}}]}, 
        {GrayLevel[
          NCache[
           Rational[7, 15], 0.4666666666666667]], 
         LineBox[{{2.1422425407843093`, 1.0918316021294832`}, {
          2.415685622919158, 1.1126094410425773`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.1422425407843093`, 1.0918316021294832`}, {
          1.8718533270149371`, 0.17026330196368078`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.1422425407843093`, 1.0918316021294832`}, {
          2.6916966565966964`, 0.}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.1422425407843093`, 1.0918316021294832`}, {
          1.395866475072796, 2.12132490723644}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.1422425407843093`, 1.0918316021294832`}, {
          1.4588611526645745`, 0.5329698631153317}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.1422425407843093`, 1.0918316021294832`}, {
          1.1167652938701984`, 0.9439049839133664}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.1422425407843093`, 1.0918316021294832`}, {
          2.5553180405738396`, 1.6109041875959655`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{1.2830636267829036`, 1.5327323217914604`}, {
          2.415685622919158, 1.1126094410425773`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{1.2830636267829036`, 1.5327323217914604`}, {
          1.7407660728414678`, 1.4627004360743439`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.2830636267829036`, 1.5327323217914604`}, {
          0.6423442775397192, 1.7443413790442135`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.2830636267829036`, 1.5327323217914604`}, {
          0.6482601628486488, 1.0116527763462368`}}]}, 
        {GrayLevel[
          NCache[
           Rational[47, 90], 0.5222222222222223]], 
         LineBox[{{1.2830636267829036`, 1.5327323217914604`}, {
          1.4724700002564628`, 1.121347061787304}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.415685622919158, 1.1126094410425773`}, {
          1.8718533270149371`, 0.17026330196368078`}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 30], 0.7666666666666667]], 
         LineBox[{{2.415685622919158, 1.1126094410425773`}, {
          1.7407660728414678`, 1.4627004360743439`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.415685622919158, 1.1126094410425773`}, {
          3.219837619053982, 0.6220636221004945}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.415685622919158, 1.1126094410425773`}, {
          1.4588611526645745`, 0.5329698631153317}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.415685622919158, 1.1126094410425773`}, {
          1.937246385641052, 0.645671257545399}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.8718533270149371`, 0.17026330196368078`}, {
          1.4588611526645745`, 0.5329698631153317}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.8718533270149371`, 0.17026330196368078`}, {
          1.4724700002564628`, 1.121347061787304}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.6916966565966964`, 0.}, {3.219837619053982, 
          0.6220636221004945}}]}, 
        {GrayLevel[
          NCache[
           Rational[1, 30], 0.03333333333333333]], 
         LineBox[{{2.6916966565966964`, 0.}, {1.937246385641052, 
          0.645671257545399}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.966061894709463, 1.2039607796205312`}, {
          1.7407660728414678`, 1.4627004360743439`}}]}, 
        {GrayLevel[
          NCache[
           Rational[11, 15], 0.7333333333333333]], 
         LineBox[{{2.966061894709463, 1.2039607796205312`}, {
          3.219837619053982, 0.6220636221004945}}]}, 
        {GrayLevel[0], 
         LineBox[{{2.966061894709463, 1.2039607796205312`}, {
          1.4724700002564628`, 1.121347061787304}}]}, 
        {GrayLevel[
          NCache[
           Rational[38, 45], 0.8444444444444444]], 
         LineBox[{{2.966061894709463, 1.2039607796205312`}, {
          4.196060136073973, 1.576264565489734}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.395866475072796, 2.12132490723644}, {0.9560454592996201, 
          3.4120340637304682`}}]}, 
        {GrayLevel[
          NCache[
           Rational[19, 30], 0.6333333333333333]], 
         LineBox[{{1.395866475072796, 2.12132490723644}, {1.7407660728414678`,
           1.4627004360743439`}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{1.395866475072796, 2.12132490723644}, {0.6423442775397192, 
          1.7443413790442135`}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 45], 0.5111111111111111]], 
         LineBox[{{1.395866475072796, 2.12132490723644}, {1.4724700002564628`,
           1.121347061787304}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.395866475072796, 2.12132490723644}, {0., 
          1.7916263394129903`}}]}, 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{1.395866475072796, 2.12132490723644}, {2.5553180405738396`,
           1.6109041875959655`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{0.9560454592996201, 3.4120340637304682`}, {
          1.4574762623917898`, 2.807238168287663}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{1.7407660728414678`, 1.4627004360743439`}, {
          1.4588611526645745`, 0.5329698631153317}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.7407660728414678`, 1.4627004360743439`}, {
          0.6482601628486488, 1.0116527763462368`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{1.7407660728414678`, 1.4627004360743439`}, {
          1.4724700002564628`, 1.121347061787304}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{1.7407660728414678`, 1.4627004360743439`}, {
          1.937246385641052, 0.645671257545399}}]}, 
        {GrayLevel[
          NCache[
           Rational[7, 10], 0.7]], 
         LineBox[{{1.7407660728414678`, 1.4627004360743439`}, {
          1.4574762623917898`, 2.807238168287663}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{1.7407660728414678`, 1.4627004360743439`}, {
          2.5553180405738396`, 1.6109041875959655`}}]}, 
        {GrayLevel[
          NCache[
           Rational[26, 45], 0.5777777777777777]], 
         LineBox[{{3.219837619053982, 0.6220636221004945}, {
          2.5553180405738396`, 1.6109041875959655`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{0.6423442775397192, 1.7443413790442135`}, {
          1.1167652938701984`, 0.9439049839133664}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{0.6423442775397192, 1.7443413790442135`}, {
          0.5857333203209061, 2.5637837591952874`}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{0.6423442775397192, 1.7443413790442135`}, {
          1.4724700002564628`, 1.121347061787304}}]}, 
        {GrayLevel[
          NCache[
           Rational[67, 90], 0.7444444444444445]], 
         LineBox[{{1.4588611526645745`, 0.5329698631153317}, {
          1.1167652938701984`, 0.9439049839133664}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.4588611526645745`, 0.5329698631153317}, {
          0.6482601628486488, 1.0116527763462368`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.4588611526645745`, 0.5329698631153317}, {
          1.937246385641052, 0.645671257545399}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{1.1167652938701984`, 0.9439049839133664}, {
          0.6482601628486488, 1.0116527763462368`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{1.1167652938701984`, 0.9439049839133664}, {
          1.937246385641052, 0.645671257545399}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 45], 0.5111111111111111]], 
         LineBox[{{0.6482601628486488, 1.0116527763462368`}, {
          1.4724700002564628`, 1.121347061787304}}]}, 
        {GrayLevel[
          NCache[
           Rational[19, 30], 0.6333333333333333]], 
         LineBox[{{0.6482601628486488, 1.0116527763462368`}, {0., 
          1.7916263394129903`}}]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         {GrayLevel[
           NCache[
            Rational[173, 251], 0.6892430278884463]], 
          DiskBox[{2.6164219379414764, 2.5463295116096902}, 
           0.041008502178419684]}, 
         InsetBox["5699", 
          Offset[{2, 2}, {2.6574304401198963, 2.58733801378811}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[25, 251], 0.099601593625498]], 
          DiskBox[{1.8734771995400483, 1.903611651024778}, 
           0.041008502178419684]}, 
         InsetBox["1247", 
          Offset[{2, 2}, {1.914485701718468, 1.9446201532031977}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[123, 251], 0.4900398406374502]], 
          DiskBox[{3.3690329482451054, 1.937086100057042}, 
           0.041008502178419684]}, 
         InsetBox["3340", 
          Offset[{2, 2}, {3.4100414504235252, 1.9780946022354617}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[190, 251], 0.7569721115537849]], 
          DiskBox[{3.712999713991894, 1.027488432969465}, 
           0.041008502178419684]}, 
         InsetBox["2350", 
          Offset[{2, 2}, {3.754008216170314, 1.0684969351478846}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[139, 251], 0.5537848605577689]], 
          DiskBox[{2.1501235897226065, 1.7516102044565645}, 
           0.041008502178419684]}, 
         InsetBox["5972", 
          Offset[{2, 2}, {2.1911320919010264, 1.7926187066349841}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[72, 251], 0.2868525896414343]], 
          DiskBox[{2.1422425407843093, 1.0918316021294832}, 
           0.041008502178419684]}, 
         InsetBox["8607", 
          Offset[{2, 2}, {2.183251042962729, 1.1328401043079028}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[113, 251], 0.450199203187251]], 
          DiskBox[{1.2830636267829036, 1.5327323217914604}, 
           0.041008502178419684]}, 
         InsetBox["977", 
          Offset[{2, 2}, {1.3240721289613233, 1.57374082396988}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[86, 251], 0.3426294820717131]], 
          DiskBox[{2.415685622919158, 1.1126094410425773}, 
           0.041008502178419684]}, 
         InsetBox["1896", 
          Offset[{2, 2}, {2.456694125097578, 1.153617943220997}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[191, 251], 0.7609561752988048]], 
          DiskBox[{1.8718533270149371, 0.17026330196368078}, 
           0.041008502178419684]}, 
         InsetBox["9438", 
          Offset[{2, 2}, {1.9128618291933568, 0.21127180414210045}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[135, 251], 0.5378486055776892]], 
          DiskBox[{2.6916966565966964, 0.}, 0.041008502178419684]}, 
         InsetBox["6333", 
          Offset[{2, 2}, {2.7327051587751163, 0.041008502178419684}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[116, 251], 0.46215139442231074`]], 
          DiskBox[{2.966061894709463, 1.2039607796205312}, 
           0.041008502178419684]}, 
         InsetBox["224", 
          Offset[{2, 2}, {3.0070703968878827, 1.2449692817989508}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[101, 251], 0.40239043824701193`]], 
          DiskBox[{1.395866475072796, 2.12132490723644}, 
           0.041008502178419684]}, 
         InsetBox["3973", 
          Offset[{2, 2}, {1.4368749772512157, 2.16233340941486}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[223, 251], 0.8884462151394422]], 
          DiskBox[{0.9560454592996201, 3.4120340637304682}, 
           0.041008502178419684]}, 
         InsetBox["6464", 
          Offset[{2, 2}, {0.9970539614780398, 3.453042565908888}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[68, 251], 0.27091633466135456`]], 
          DiskBox[{1.7407660728414678, 1.4627004360743439}, 
           0.041008502178419684]}, 
         InsetBox["7332", 
          Offset[{2, 2}, {1.7817745750198875, 1.5037089382527635}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[156, 251], 0.6215139442231076]], 
          DiskBox[{3.219837619053982, 0.6220636221004945}, 
           0.041008502178419684]}, 
         InsetBox["3560", 
          Offset[{2, 2}, {3.260846121232402, 0.6630721242789142}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[195, 251], 0.7768924302788844]], 
          DiskBox[{0.6423442775397192, 1.7443413790442135}, 
           0.041008502178419684]}, 
         InsetBox["3685", 
          Offset[{2, 2}, {0.6833527797181389, 1.7853498812226332}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[155, 251], 0.6175298804780877]], 
          DiskBox[{1.4588611526645745, 0.5329698631153317}, 
           0.041008502178419684]}, 
         InsetBox["3161", 
          Offset[{2, 2}, {1.4998696548429942, 0.5739783652937513}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[180, 251], 0.7171314741035857]], 
          DiskBox[{1.1167652938701984, 0.9439049839133664}, 
           0.041008502178419684]}, 
         InsetBox["8925", 
          Offset[{2, 2}, {1.157773796048618, 0.9849134860917861}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[131, 251], 0.5219123505976095]], 
          DiskBox[{0.6482601628486488, 1.0116527763462368}, 
           0.041008502178419684]}, 
         InsetBox["640", 
          Offset[{2, 2}, {0.6892686650270685, 1.0526612785246565}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[235, 251], 0.9362549800796812]], 
          DiskBox[{3.210940861573713, 3.810068034261915}, 
           0.041008502178419684]}, 
         InsetBox["2051", 
          Offset[{2, 2}, {3.251949363752133, 3.8510765364403348}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[229, 251], 0.9123505976095617]], 
          DiskBox[{4.650055187552439, 2.556591894792846}, 
           0.041008502178419684]}, 
         InsetBox["5971", 
          Offset[{2, 2}, {4.691063689730859, 2.597600396971266}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[214, 251], 0.852589641434263]], 
          DiskBox[{0.5857333203209061, 2.5637837591952874}, 
           0.041008502178419684]}, 
         InsetBox["2143", 
          Offset[{2, 2}, {0.6267418224993258, 2.6047922613737073}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[0], 
          DiskBox[{1.4724700002564628, 1.121347061787304}, 
           0.041008502178419684]}, 
         InsetBox["7695", 
          Offset[{2, 2}, {1.5134785024348825, 1.1623555639657237}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[105, 251], 0.41832669322709165`]], 
          DiskBox[{1.937246385641052, 0.645671257545399}, 
           0.041008502178419684]}, 
         InsetBox["4684", 
          Offset[{2, 2}, {1.9782548878194717, 0.6866797597238187}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[191, 251], 0.7609561752988048]], 
          DiskBox[{1.4574762623917898, 2.807238168287663}, 
           0.041008502178419684]}, 
         InsetBox["1523", 
          Offset[{2, 2}, {1.4984847645702095, 2.8482466704660827}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[209, 251], 0.8326693227091634]], 
          DiskBox[{0., 1.7916263394129903}, 0.041008502178419684]}, 
         InsetBox["9166", 
          Offset[{2, 2}, {0.041008502178419684, 1.83263484159141}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[186, 251], 0.7410358565737052]], 
          DiskBox[{4.196060136073973, 1.576264565489734}, 
           0.041008502178419684]}, 
         InsetBox["8896", 
          Offset[{2, 2}, {4.237068638252392, 1.6172730676681537}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[135, 251], 0.5378486055776892]], 
          DiskBox[{2.5553180405738396, 1.6109041875959655}, 
           0.041008502178419684]}, 
         InsetBox["1884", 
          Offset[{2, 2}, {2.5963265427522595, 1.6519126897743852}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.7464030448812237`*^9, 3.746403052483762*^9}, {
   3.746403218864914*^9, 3.746403234675123*^9}, 3.7464032671501923`*^9, 
   3.74644463046099*^9, 3.7480367035946217`*^9, 3.749464167606473*^9, 
   3.749486745045644*^9, 3.749487232990676*^9, 3.7504452299457645`*^9, 
   3.750524378275453*^9, 3.750700008813676*^9, 3.7507020127824097`*^9, 
   3.7507030410130796`*^9, 3.751246030369812*^9, 3.751246129265349*^9, 
   3.7512463391832676`*^9, 3.751284361386427*^9, 3.751299690667635*^9, 
   3.7513007255383554`*^9, 3.753705829382656*^9, 3.7542674748004203`*^9, 
   3.75469513380694*^9, 3.7547762791084385`*^9, 3.7547776404876795`*^9, 
   3.7574372618547487`*^9, 3.757515109724383*^9, 3.7575923225027733`*^9, 
   3.757593383731308*^9, 3.7575937763722677`*^9, 3.757594367885604*^9, 
   3.757594875037199*^9, 3.7575954831610575`*^9, 3.757596013141774*^9, 
   3.7576331496634245`*^9, 3.757634352751078*^9, 3.7576348363771915`*^9, 
   3.757635165705861*^9, 3.8303406975840054`*^9, 3.8303407489367647`*^9, 
   3.830415672500896*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"71f7bb32-785e-4010-853c-d6edf7c44917"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp2", "=", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"g", ",", "e2", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7464030465409575`*^9, 3.7464030625943193`*^9}, {
  3.74640321346434*^9, 3.7464032548781967`*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"8a787253-d2d8-48cf-a3c3-ad9d6597e2d9"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{977, 9438, 224, 3560, 3973, 3685, 640, 7695, 9166, 2143}, {
      Null, {{3, 4}, {6, 5}, {1, 6}, {7, 1}, {5, 8}, {8, 2}, {6, 8}, {3, 8}, {
       7, 8}, {1, 8}, {5, 9}, {7, 9}, {10, 6}}}, {
      EdgeStyle -> {UndirectedEdge[977, 7695] -> GrayLevel[
           Rational[47, 90]], UndirectedEdge[7695, 9438] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3973, 9166] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[224, 7695] -> GrayLevel[0], 
         UndirectedEdge[3685, 7695] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[224, 3560] -> GrayLevel[
           Rational[11, 15]], UndirectedEdge[3685, 3973] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[3973, 7695] -> GrayLevel[
           Rational[23, 45]], UndirectedEdge[640, 7695] -> GrayLevel[
           Rational[23, 45]], UndirectedEdge[2143, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[977, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[640, 9166] -> GrayLevel[
           Rational[19, 30]], UndirectedEdge[640, 977] -> GrayLevel[
           Rational[83, 90]]}, 
       EdgeWeight -> {24, 13, 7, 7, 44, 9, 13, 90, 44, 43, 9, 33, 7}, 
       GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {"Name"}, 
       VertexStyle -> {9166 -> GrayLevel[
           Rational[209, 251]], 640 -> GrayLevel[
           Rational[131, 251]], 224 -> GrayLevel[
           Rational[116, 251]], 977 -> GrayLevel[
           Rational[113, 251]], 3560 -> GrayLevel[
           Rational[156, 251]], 9438 -> GrayLevel[
           Rational[191, 251]], 3685 -> GrayLevel[
           Rational[195, 251]], 2143 -> GrayLevel[
           Rational[214, 251]], 7695 -> GrayLevel[0], 3973 -> GrayLevel[
           Rational[101, 251]]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.4285981890723223`, 1.3263167207179563`}, {
          0.8738942214971049, 1.8114028018455208`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.4285981890723223`, 1.3263167207179563`}, {
          1.6619579968506872`, 0.5285421680323409}}]}, 
        {GrayLevel[
          NCache[
           Rational[47, 90], 0.5222222222222223]], 
         LineBox[{{1.4285981890723223`, 1.3263167207179563`}, {
          1.9968351687928525`, 1.4647070325396023`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.4663193006267496`, 2.42624336989352}, {
          1.9968351687928525`, 1.4647070325396023`}}]}, 
        {GrayLevel[
          NCache[
           Rational[11, 15], 0.7333333333333333]], 
         LineBox[{{3.3588742949463493`, 1.393523159184883}, {
          4.3904562420779705`, 1.3582847457046312`}}]}, 
        {GrayLevel[0], 
         LineBox[{{3.3588742949463493`, 1.393523159184883}, {
          1.9968351687928525`, 1.4647070325396023`}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{0.9614456214848734, 0.9282536766079839}, {
          0.8738942214971049, 1.8114028018455208`}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 45], 0.5111111111111111]], 
         LineBox[{{0.9614456214848734, 0.9282536766079839}, {
          1.9968351687928525`, 1.4647070325396023`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{0.9614456214848734, 0.9282536766079839}, {
          0.9559336534877951, 0.}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{0.8738942214971049, 1.8114028018455208`}, {
          1.9968351687928525`, 1.4647070325396023`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{0.8738942214971049, 1.8114028018455208`}, {0., 
          2.469493933900295}}]}, 
        {GrayLevel[
          NCache[
           Rational[23, 45], 0.5111111111111111]], 
         LineBox[{{1.6619579968506872`, 0.5285421680323409}, {
          1.9968351687928525`, 1.4647070325396023`}}]}, 
        {GrayLevel[
          NCache[
           Rational[19, 30], 0.6333333333333333]], 
         LineBox[{{1.6619579968506872`, 0.5285421680323409}, {
          0.9559336534877951, 0.}}]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         {GrayLevel[
           NCache[
            Rational[113, 251], 0.450199203187251]], 
          DiskBox[{1.4285981890723223, 1.3263167207179563}, 
           0.03944446877198997]}, 
         InsetBox["977", 
          Offset[{2, 2}, {1.4680426578443122, 1.3657611894899462}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[191, 251], 0.7609561752988048]], 
          DiskBox[{2.4663193006267496, 2.42624336989352}, 
           0.03944446877198997]}, 
         InsetBox["9438", 
          Offset[{2, 2}, {2.50576376939874, 2.4656878386655103}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[116, 251], 0.46215139442231074`]], 
          DiskBox[{3.3588742949463493, 1.393523159184883}, 
           0.03944446877198997]}, 
         InsetBox["224", 
          Offset[{2, 2}, {3.3983187637183394, 1.4329676279568728}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[156, 251], 0.6215139442231076]], 
          DiskBox[{4.3904562420779705, 1.3582847457046312}, 
           0.03944446877198997]}, 
         InsetBox["3560", 
          Offset[{2, 2}, {4.42990071084996, 1.3977292144766211}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[101, 251], 0.40239043824701193`]], 
          DiskBox[{0.9614456214848734, 0.9282536766079839}, 
           0.03944446877198997]}, 
         InsetBox["3973", 
          Offset[{2, 2}, {1.0008900902568634, 0.9676981453799738}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[195, 251], 0.7768924302788844]], 
          DiskBox[{0.8738942214971049, 1.8114028018455208}, 
           0.03944446877198997]}, 
         InsetBox["3685", 
          Offset[{2, 2}, {0.9133386902690949, 1.8508472706175108}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[131, 251], 0.5219123505976095]], 
          DiskBox[{1.6619579968506872, 0.5285421680323409}, 
           0.03944446877198997]}, 
         InsetBox["640", 
          Offset[{2, 2}, {1.7014024656226772, 0.5679866368043308}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[0], 
          DiskBox[{1.9968351687928525, 1.4647070325396023}, 
           0.03944446877198997]}, 
         InsetBox["7695", 
          Offset[{2, 2}, {2.0362796375648426, 1.5041515013115923}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[209, 251], 0.8326693227091634]], 
          DiskBox[{0.9559336534877951, 0.}, 0.03944446877198997]}, 
         InsetBox["9166", 
          Offset[{2, 2}, {0.9953781222597851, 0.03944446877198997}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[214, 251], 0.852589641434263]], 
          DiskBox[{0., 2.469493933900295}, 0.03944446877198997]}, 
         InsetBox["2143", 
          Offset[{2, 2}, {0.03944446877198997, 2.508938402672285}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.7464030630940495`*^9, {3.7464032202027965`*^9, 3.7464032690971985`*^9}, 
   3.7464446317913136`*^9, 3.7480367048419576`*^9, 3.749464167729491*^9, 
   3.749486745076887*^9, 3.74948723325364*^9, 3.7504452300490093`*^9, 
   3.7505243783691797`*^9, 3.750700008929539*^9, 3.7507020128546877`*^9, 
   3.7507030410840397`*^9, 3.7512460304533124`*^9, 3.7512461293196516`*^9, 
   3.751246339244662*^9, 3.7512843615859566`*^9, 3.751299690752254*^9, 
   3.7513007256320887`*^9, 3.753705829470954*^9, 3.754267474903951*^9, 
   3.7546951338759336`*^9, 3.7547762792114587`*^9, 3.7547776407386513`*^9, 
   3.7574372619354954`*^9, 3.7575151098064795`*^9, 3.757592322575445*^9, 
   3.757593386133137*^9, 3.7575937784035516`*^9, 3.757594370080307*^9, 
   3.7575948768180327`*^9, 3.757595485020915*^9, 3.75759601487574*^9, 
   3.7576331497362843`*^9, 3.7576343528212028`*^9, 3.757634836444315*^9, 
   3.757635165764431*^9, 3.830340751419325*^9, 3.8304156739336433`*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"79f8f060-9321-41a8-afc9-64d7ff3406d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"g", ",", 
   RowBox[{"{", 
    RowBox[{"exp1", ",", "exp2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7464453389146247`*^9, 3.746445347183693*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"1de6ed1d-572e-42c7-aac0-63be38cb8d36"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1884, 3973, 7332, 8607, 3560, 5908, 5972, 4684, 8925, 1896, 3161, 
      6333, 5539, 1247, 3685, 4680, 3340, 2143, 8443, 482, 977, 7695, 6464, 
      5699, 9166, 9438, 224, 640, 3591, 1523, 7460, 1120, 1656, 8896, 2350, 
      5971, 2051}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {8, 3}, {8, 9}, {
       10, 8}, {11, 8}, {8, 12}, {8, 13}, {14, 8}, {15, 16}, {17, 16}, {18, 
       15}, {18, 19}, {14, 18}, {20, 19}, {20, 13}, {20, 21}, {2, 22}, {2, 
       3}, {2, 23}, {2, 4}, {15, 2}, {2, 13}, {2, 24}, {2, 25}, {3, 22}, {22, 
       26}, {15, 22}, {27, 22}, {28, 22}, {21, 22}, {10, 3}, {11, 3}, {29, 
       3}, {27, 3}, {28, 3}, {30, 3}, {14, 3}, {21, 3}, {3, 31}, {29, 23}, {
       30, 23}, {4, 9}, {15, 9}, {11, 9}, {28, 9}, {14, 9}, {4, 26}, {10, 
       26}, {32, 26}, {11, 26}, {33, 26}, {10, 4}, {32, 4}, {11, 4}, {12, 
       4}, {6, 4}, {13, 4}, {33, 4}, {17, 4}, {14, 4}, {7, 4}, {19, 34}, {6, 
       34}, {27, 34}, {13, 34}, {17, 34}, {32, 10}, {10, 11}, {10, 29}, {10, 
       5}, {10, 24}, {14, 10}, {10, 35}, {21, 10}, {10, 31}, {21, 15}, {11, 
       29}, {11, 6}, {28, 11}, {13, 19}, {5, 12}, {6, 12}, {28, 29}, {5, 6}, {
       27, 5}, {35, 5}, {33, 6}, {6, 36}, {6, 7}, {28, 21}, {28, 25}, {14, 
       30}, {33, 17}, {33, 35}, {33, 7}, {37, 24}, {17, 24}, {14, 24}, {24, 
       31}, {17, 36}, {17, 6}, {14, 17}, {35, 17}, {21, 14}, {14, 7}, {14, 
       31}, {35, 31}, {21, 7}}}, {
      EdgeStyle -> {UndirectedEdge[3340, 8896] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3161, 3591] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[640, 977] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1120, 1896] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[1523, 6464] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3973, 5699] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3685, 7695] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[3591, 7332] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3973, 7332] -> GrayLevel[
           Rational[19, 30]], UndirectedEdge[3560, 5908] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1896, 3161] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5908, 5971] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1656, 3340] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[977, 1247] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[1884, 3973] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[3340, 8607] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1247, 1523] -> GrayLevel[
           Rational[34, 45]], UndirectedEdge[1896, 2350] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1896, 7332] -> GrayLevel[
           Rational[23, 30]], UndirectedEdge[1896, 5699] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1656, 8607] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1896, 8607] -> GrayLevel[
           Rational[7, 15]], UndirectedEdge[3161, 8607] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[1656, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[2051, 5699] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[3973, 9166] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1896, 7460] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[3161, 7332] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[3161, 5908] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3560, 6333] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1523, 7332] -> GrayLevel[
           Rational[7, 10]], UndirectedEdge[3973, 8607] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[3340, 4680] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[2143, 8443] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1247, 8607] -> GrayLevel[
           Rational[5, 6]], UndirectedEdge[3973, 7695] -> GrayLevel[
           Rational[23, 45]], UndirectedEdge[6333, 8607] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3591, 6464] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[2143, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[3685, 3973] -> GrayLevel[
           Rational[77, 90]], UndirectedEdge[224, 7695] -> GrayLevel[0], 
         UndirectedEdge[1884, 5972] -> GrayLevel[
           Rational[29, 45]], UndirectedEdge[4684, 6333] -> GrayLevel[
           Rational[1, 30]], UndirectedEdge[8443, 8896] -> GrayLevel[
           Rational[73, 90]], UndirectedEdge[1896, 3591] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5699, 7460] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[5908, 8896] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[640, 3591] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1247, 7332] -> GrayLevel[
           Rational[71, 90]], UndirectedEdge[7695, 9438] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[977, 7695] -> GrayLevel[
           Rational[47, 90]], UndirectedEdge[5908, 6333] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3340, 5908] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1884, 7332] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[1247, 4684] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[5908, 8607] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[482, 977] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1247, 5699] -> GrayLevel[
           Rational[32, 45]], UndirectedEdge[7332, 7460] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[5908, 5972] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1656, 5908] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[640, 7695] -> GrayLevel[
           Rational[23, 45]], UndirectedEdge[640, 9166] -> GrayLevel[
           Rational[19, 30]], UndirectedEdge[3685, 4680] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[977, 3685] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[640, 8925] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[3340, 5699] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1896, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1120, 9438] -> GrayLevel[
           Rational[34, 45]], UndirectedEdge[3340, 5971] -> GrayLevel[
           Rational[13, 15]], UndirectedEdge[4684, 7332] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[224, 3560] -> GrayLevel[
           Rational[11, 15]], UndirectedEdge[482, 5539] -> GrayLevel[
           Rational[13, 45]], UndirectedEdge[1896, 4684] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3161, 8925] -> GrayLevel[
           Rational[67, 90]], UndirectedEdge[8607, 8925] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3161, 9438] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1884, 3560] -> GrayLevel[
           Rational[26, 45]], UndirectedEdge[1247, 7460] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[2350, 3560] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[977, 7332] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[1247, 3340] -> GrayLevel[
           Rational[11, 30]], UndirectedEdge[224, 7332] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1884, 8607] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1884, 5908] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[482, 8443] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3973, 6464] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1120, 8607] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[1247, 8925] -> GrayLevel[
           Rational[79, 90]], UndirectedEdge[640, 3161] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[977, 1896] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[5539, 8896] -> GrayLevel[
           Rational[73, 90]], UndirectedEdge[3973, 5539] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[4684, 8925] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[5539, 8607] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[5539, 8443] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[3161, 4684] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[2350, 3340] -> GrayLevel[
           Rational[8, 9]], UndirectedEdge[3685, 8925] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[4684, 5539] -> GrayLevel[
           Rational[37, 45]], UndirectedEdge[1247, 5972] -> GrayLevel[
           Rational[73, 90]], UndirectedEdge[1656, 2350] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[1247, 1896] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[1896, 3560] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[1656, 5972] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[8607, 9438] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[2350, 7460] -> GrayLevel[
           Rational[61, 90]], UndirectedEdge[640, 7332] -> GrayLevel[
           Rational[9, 10]], UndirectedEdge[977, 5972] -> GrayLevel[
           Rational[8, 15]], UndirectedEdge[1247, 2143] -> GrayLevel[
           Rational[4, 5]], UndirectedEdge[7332, 7695] -> GrayLevel[
           Rational[41, 45]], UndirectedEdge[5972, 8607] -> GrayLevel[
           Rational[83, 90]], UndirectedEdge[224, 8896] -> GrayLevel[
           Rational[38, 45]]}, 
       EdgeWeight -> {16, 12, 9, 38, 9, 32, 10, 8, 9, 7, 87, 16, 9, 7, 9, 7, 
        12, 18, 9, 64, 7, 44, 33, 9, 8, 13, 10, 8, 9, 8, 9, 13, 90, 44, 43, 
        21, 12, 7, 7, 9, 27, 19, 11, 7, 8, 11, 9, 9, 23, 11, 11, 8, 7, 22, 7, 
        7, 48, 16, 10, 9, 11, 10, 12, 7, 15, 7, 17, 9, 14, 17, 8, 13, 7, 7, 7,
         10, 9, 7, 8, 12, 7, 13, 8, 9, 9, 9, 11, 7, 10, 24, 7, 10, 10, 7, 7, 
        33, 22, 8, 8, 7, 16, 9, 26, 9, 12, 8, 57, 10, 13, 17, 10, 29, 42}, 
       GraphHighlight -> {
         UndirectedEdge[3973, 8607], 
         UndirectedEdge[1884, 7332], 3340, 
         UndirectedEdge[3685, 3973], 
         UndirectedEdge[1523, 7332], 
         UndirectedEdge[640, 977], 6464, 
         UndirectedEdge[1247, 3340], 
         UndirectedEdge[977, 7695], 
         UndirectedEdge[1896, 9438], 
         UndirectedEdge[1896, 2350], 5971, 
         UndirectedEdge[3340, 8607], 
         UndirectedEdge[1884, 8607], 
         UndirectedEdge[3973, 7332], 
         UndirectedEdge[1247, 2143], 1523, 8925, 8607, 
         UndirectedEdge[1884, 3560], 
         UndirectedEdge[1247, 8607], 
         UndirectedEdge[3161, 8925], 
         UndirectedEdge[7332, 7695], 
         UndirectedEdge[3973, 6464], 
         UndirectedEdge[977, 3685], 
         UndirectedEdge[3161, 9438], 
         UndirectedEdge[2051, 5699], 
         UndirectedEdge[224, 7332], 
         UndirectedEdge[3340, 5699], 
         UndirectedEdge[1884, 3973], 
         UndirectedEdge[1884, 5972], 
         UndirectedEdge[977, 1896], 3560, 
         UndirectedEdge[1896, 5699], 224, 
         UndirectedEdge[1896, 3560], 
         UndirectedEdge[1247, 7332], 
         UndirectedEdge[7695, 9438], 
         UndirectedEdge[3973, 9166], 1247, 
         UndirectedEdge[8607, 9438], 
         UndirectedEdge[640, 9166], 
         UndirectedEdge[977, 7332], 
         UndirectedEdge[640, 3161], 9166, 6333, 
         UndirectedEdge[3161, 8607], 
         UndirectedEdge[1896, 8607], 5972, 
         UndirectedEdge[1247, 1523], 2350, 
         UndirectedEdge[2143, 3685], 
         UndirectedEdge[640, 7695], 4684, 
         UndirectedEdge[640, 8925], 
         UndirectedEdge[224, 7695], 
         UndirectedEdge[3685, 7695], 
         UndirectedEdge[3973, 5699], 7332, 3973, 640, 
         UndirectedEdge[1247, 8925], 2051, 3161, 
         UndirectedEdge[3560, 6333], 
         UndirectedEdge[1896, 3161], 
         UndirectedEdge[1247, 5699], 2143, 
         UndirectedEdge[1247, 1896], 7695, 
         UndirectedEdge[3340, 8896], 5699, 
         UndirectedEdge[1896, 7332], 1896, 
         UndirectedEdge[224, 8896], 
         UndirectedEdge[224, 3560], 
         UndirectedEdge[1247, 5972], 
         UndirectedEdge[4684, 6333], 
         UndirectedEdge[8607, 8925], 1884, 
         UndirectedEdge[1247, 4684], 
         UndirectedEdge[4684, 8925], 8896, 
         UndirectedEdge[640, 7332], 977, 
         UndirectedEdge[3685, 8925], 
         UndirectedEdge[1523, 6464], 
         UndirectedEdge[2350, 3340], 3685, 
         UndirectedEdge[977, 1247], 
         UndirectedEdge[5972, 8607], 
         UndirectedEdge[3161, 4684], 
         UndirectedEdge[3340, 5971], 
         UndirectedEdge[1896, 4684], 
         UndirectedEdge[977, 5972], 
         UndirectedEdge[4684, 7332], 
         UndirectedEdge[3161, 7332], 
         UndirectedEdge[3973, 7695], 
         UndirectedEdge[2350, 3560], 9438, 
         UndirectedEdge[6333, 8607]}, 
       GraphHighlightStyle -> {
        UndirectedEdge[640, 977] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 8607 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[4684, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1884, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         1523 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1523, 6464] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         5972 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         640 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[224, 3560] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[1247, 3340] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 3161] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3973, 7695] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[1523, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         977 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[3973, 5699] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 4684] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3340, 5971] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[977, 7695] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[8607, 8925] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         3973 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[4684, 6333] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3685, 8925] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         2143 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[1247, 8925] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[6333, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         2051 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 9438] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         8896 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[977, 5972] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1247, 5699] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         6333 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1247, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3973, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[977, 1247] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[224, 8896] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1247, 5972] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 3560] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[8607, 9438] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         9166 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[2350, 3560] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1247, 2143] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         8925 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1884, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1884, 3560] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[4684, 8925] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         7695 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[1247, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[2143, 3685] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[2051, 5699] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         5699 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[977, 1896] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3161, 8925] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3161, 4684] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3161, 9438] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3161, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 5699] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         7332 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 2350] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         5971 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3973, 9166] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[5972, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1884, 3973] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[640, 8925] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         3161 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1247, 4684] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         1896 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3560, 6333] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[224, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         6464 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3685, 3973] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[3685, 7695] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[1884, 5972] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3340, 5699] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         3685 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[977, 3685] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[640, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         9438 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[977, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3340, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         2350 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         3560 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 1884 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1247, 1896] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1247, 1523] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3161, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[640, 3161] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[640, 7695] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[7695, 9438] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[7332, 7695] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         1247 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[640, 9166] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[3973, 7332] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[1896, 8607] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         224 -> {VertexStyle -> Directive[
             Hue[0.14, 1, 0.9]]}, 
         UndirectedEdge[3340, 8896] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[2350, 3340] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         3340 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         4684 -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[3973, 6464] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge[224, 7695] -> {EdgeStyle -> Directive[
             Hue[0.14, 1, 0.9]]}}, GraphLayout -> {"Dimension" -> 2}, 
       VertexLabels -> {"Name"}, VertexStyle -> {5971 -> GrayLevel[
           Rational[229, 251]], 5908 -> GrayLevel[
           Rational[158, 251]], 5539 -> GrayLevel[
           Rational[125, 251]], 2051 -> GrayLevel[
           Rational[235, 251]], 4680 -> GrayLevel[
           Rational[235, 251]], 8607 -> GrayLevel[
           Rational[72, 251]], 3340 -> GrayLevel[
           Rational[123, 251]], 4684 -> GrayLevel[
           Rational[105, 251]], 1120 -> GrayLevel[
           Rational[200, 251]], 8896 -> GrayLevel[
           Rational[186, 251]], 9438 -> GrayLevel[
           Rational[191, 251]], 8925 -> GrayLevel[
           Rational[180, 251]], 5699 -> GrayLevel[
           Rational[173, 251]], 482 -> GrayLevel[
           Rational[171, 251]], 1247 -> GrayLevel[
           Rational[25, 251]], 7695 -> GrayLevel[0], 640 -> GrayLevel[
           Rational[131, 251]], 1884 -> GrayLevel[
           Rational[135, 251]], 3685 -> GrayLevel[
           Rational[195, 251]], 1523 -> GrayLevel[
           Rational[191, 251]], 2350 -> GrayLevel[
           Rational[190, 251]], 3591 -> GrayLevel[
           Rational[209, 251]], 7332 -> GrayLevel[
           Rational[68, 251]], 1896 -> GrayLevel[
           Rational[86, 251]], 6464 -> GrayLevel[
           Rational[223, 251]], 8443 -> GrayLevel[
           Rational[204, 251]], 3161 -> GrayLevel[
           Rational[155, 251]], 6333 -> GrayLevel[
           Rational[135, 251]], 2143 -> GrayLevel[
           Rational[214, 251]], 1656 -> GrayLevel[
           Rational[199, 251]], 3973 -> GrayLevel[
           Rational[101, 251]], 3560 -> GrayLevel[
           Rational[156, 251]], 7460 -> GrayLevel[
           Rational[184, 251]], 977 -> GrayLevel[
           Rational[113, 251]], 224 -> GrayLevel[
           Rational[116, 251]], 5972 -> GrayLevel[
           Rational[139, 251]], 9166 -> GrayLevel[
           Rational[209, 251]]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.254270855923262, 2.8698464127954573`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.0878088126360055`, 2.521433088371224}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.6311424972576836`, 1.5590962874045355`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          2.583980036533834, 0.9282266151910459}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          3.1878881389781992`, 0.9722239523255354}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.3984649978198687`, 1.6667217353021773`}, {
          3.0950771698088544`, 1.5359535085931357`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          2.0878088126360055`, 2.521433088371224}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          2.6311424972576836`, 1.5590962874045355`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          3.7199641632770652`, 2.447600728379067}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          3.4427320409738456`, 3.082866302351973}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          1.0991774454099354`, 3.724970924197967}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{2.254270855923262, 2.8698464127954573`}, {
          1.9609481837191605`, 4.23067539877886}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.868381216541333, 1.944461534939188}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {2.20178014533537,
           2.1059129902680924`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          3.2718706661648147`, 1.9615687638283492`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          2.188854013791599, 3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.374401110837499, 2.8591905382743446`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.4960812966322448`, 3.3648299807271984`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.0878088126360055`, 2.521433088371224}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.1878881389781992`, 0.9722239523255354}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.0950771698088544`, 1.5359535085931357`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.8257372357158785`, 2.6113602770062228`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.7199641632770652`, 2.447600728379067}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          1.426894169367006, 0.8981408741125645}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{2.6311424972576836`, 1.5590962874045355`}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          3.1878881389781992`, 0.9722239523255354}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          3.2718706661648147`, 1.9615687638283492`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.583980036533834, 0.9282266151910459}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.0950771698088544`, 1.5359535085931357`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {GrayLevel[
          NCache[
           Rational[79, 90], 0.8777777777777778]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{3.1878881389781992`, 0.9722239523255354}, {
          3.6883059376362457`, 0.}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{3.0950771698088544`, 1.5359535085931357`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{3.0950771698088544`, 1.5359535085931357`}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.0950771698088544`, 1.5359535085931357`}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          2.8257372357158785`, 2.6113602770062228`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          1.9572951633274314`, 1.8099051183928858`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {2.20178014533537, 
          2.1059129902680924`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          3.2788700786662375`, 0.6451863306944472}}]}, 
        {GrayLevel[
          NCache[
           Rational[37, 45], 0.8222222222222222]], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          3.7199641632770652`, 2.447600728379067}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.868381216541333, 1.944461534939188}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          3.4427320409738456`, 3.082866302351973}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.8257372357158785`, 2.6113602770062228`}, {
          2.188854013791599, 3.306741207795006}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          2.20178014533537, 2.1059129902680924`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          2.4698388307120833`, 2.295865678675766}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.374401110837499, 2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.426894169367006, 0.8981408741125645}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.9572951633274314`, 1.8099051183928858`}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.20178014533537, 2.1059129902680924`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.20178014533537, 2.1059129902680924`}, {2.188854013791599,
           3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[77, 90], 0.8555555555555555]], 
         LineBox[{{2.20178014533537, 2.1059129902680924`}, {1.374401110837499,
           2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{3.7199641632770652`, 2.447600728379067}, {4.73425173666226,
           2.681130220163744}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 45], 0.28888888888888886`]], 
         LineBox[{{3.7199641632770652`, 2.447600728379067}, {
          4.397641903925736, 3.2539845580257283`}}]}, 
        {GrayLevel[
          NCache[
           Rational[73, 90], 0.8111111111111111]], 
         LineBox[{{3.7199641632770652`, 2.447600728379067}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          3.903077256299162, 3.255798740011394}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          1.4960812966322448`, 3.3648299807271984`}}]}, 
        {GrayLevel[
          NCache[
           Rational[8, 9], 0.8888888888888888]], 
         LineBox[{{2.4698388307120833`, 2.295865678675766}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          4.287142555088807, 2.010102527203237}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          3.903077256299162, 3.255798740011394}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{3.4427320409738456`, 3.082866302351973}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{4.287142555088807, 2.010102527203237}, {
          3.0226924541869202`, 1.159944789617093}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          1.4691302208150039`, 1.6601275876173132`}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{3.0226924541869202`, 1.159944789617093}, {
          3.6883059376362457`, 0.}}]}, 
        {GrayLevel[
          NCache[
           Rational[13, 15], 0.8666666666666667]], 
         LineBox[{{3.903077256299162, 3.255798740011394}, {4.73425173666226, 
          2.681130220163744}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{4.73425173666226, 2.681130220163744}, {4.397641903925736, 
          3.2539845580257283`}}]}, 
        {GrayLevel[
          NCache[
           Rational[73, 90], 0.8111111111111111]], 
         LineBox[{{4.73425173666226, 2.681130220163744}, {4.104459217702431, 
          1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{4.397641903925736, 3.2539845580257283`}, {
          3.0264201946628146`, 2.80485831460313}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{3.0264201946628146`, 2.80485831460313}, {
          2.5940113125237874`, 2.7693008373875165`}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{3.0264201946628146`, 2.80485831460313}, {2.188854013791599,
           3.306741207795006}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{2.5940113125237874`, 2.7693008373875165`}, {
          1.9626592733755062`, 1.3741698167689078`}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{2.5940113125237874`, 2.7693008373875165`}, {
          3.2718706661648147`, 1.9615687638283492`}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{2.5940113125237874`, 2.7693008373875165`}, {
          2.188854013791599, 3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{1.0991774454099354`, 3.724970924197967}, {
          1.374401110837499, 2.8591905382743446`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.0991774454099354`, 3.724970924197967}, {
          1.4960812966322448`, 3.3648299807271984`}}]}, 
        {GrayLevel[
          NCache[
           Rational[9, 10], 0.9]], 
         LineBox[{{1.4691302208150039`, 1.6601275876173132`}, {
          1.305774790379798, 1.8813573754580086`}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{1.4691302208150039`, 1.6601275876173132`}, {0., 
          1.1873821379604075`}}]}, 
        {Hue[0.14, 1, 0.9], 
         LineBox[{{1.9609481837191605`, 4.23067539877886}, {2.188854013791599,
           3.306741207795006}}]}, 
        {GrayLevel[
          NCache[
           Rational[34, 45], 0.7555555555555555]], 
         LineBox[{{1.9626592733755062`, 1.3741698167689078`}, {
          1.426894169367006, 0.8981408741125645}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{1.9626592733755062`, 1.3741698167689078`}, {
          2.5580136313919133`, 0.5769391307265495}}]}, 
        {Hue[0, 1, 0.8], 
         LineBox[{{3.2718706661648147`, 1.9615687638283492`}, {
          4.104459217702431, 1.6157516950091917`}}]}, 
        {GrayLevel[
          NCache[
           Rational[83, 90], 0.9222222222222223]], 
         LineBox[{{2.188854013791599, 3.306741207795006}, {1.374401110837499, 
          2.8591905382743446`}}]}, 
        {GrayLevel[
          NCache[
           Rational[61, 90], 0.6777777777777778]], 
         LineBox[{{1.305774790379798, 1.8813573754580086`}, {
          1.9009919110450095`, 0.7781096625592305}}]}, 
        {GrayLevel[
          NCache[
           Rational[41, 45], 0.9111111111111111]], 
         LineBox[{{2.5580136313919133`, 0.5769391307265495}, {
          1.9009919110450095`, 0.7781096625592305}}]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.3984649978198687, 1.6667217353021773}, 
           0.0415063096365134]}, 
         InsetBox["1884", 
          Offset[{2, 2}, {2.439971307456382, 1.7082280449386906}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.254270855923262, 2.8698464127954573}, 
           0.0415063096365134]}, 
         InsetBox["3973", 
          Offset[{2, 2}, {2.2957771655597754, 2.9113527224319706}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.0878088126360055, 2.521433088371224}, 
           0.0415063096365134]}, 
         InsetBox["7332", 
          Offset[{2, 2}, {2.129315122272519, 2.5629393980077375}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.6311424972576836, 1.5590962874045355}, 
           0.0415063096365134]}, 
         InsetBox["8607", 
          Offset[{2, 2}, {2.672648806894197, 1.600602597041049}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.583980036533834, 0.9282266151910459}, 
           0.0415063096365134]}, 
         InsetBox["3560", 
          Offset[{2, 2}, {2.6254863461703475, 0.9697329248275592}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[158, 251], 0.6294820717131474]], 
          DiskBox[{3.1878881389781992, 0.9722239523255354}, 
           0.0415063096365134]}, 
         InsetBox["5908", 
          Offset[{2, 2}, {3.2293944486147126, 1.0137302619620487}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.0950771698088544, 1.5359535085931357}, 
           0.0415063096365134]}, 
         InsetBox["5972", 
          Offset[{2, 2}, {3.1365834794453678, 1.577459818229649}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.868381216541333, 1.944461534939188}, 
           0.0415063096365134]}, 
         InsetBox["4684", 
          Offset[{2, 2}, {2.9098875261778465, 1.9859678445757014}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.8257372357158785, 2.6113602770062228}, 
           0.0415063096365134]}, 
         InsetBox["8925", 
          Offset[{2, 2}, {2.867243545352392, 2.652866586642736}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{1.9572951633274314, 1.8099051183928858}, 
           0.0415063096365134]}, 
         InsetBox["1896", 
          Offset[{2, 2}, {1.9988014729639447, 1.8514114280293992}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.20178014533537, 2.1059129902680924}, 
           0.0415063096365134]}, 
         InsetBox["3161", 
          Offset[{2, 2}, {2.243286454971883, 2.147419299904606}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.2788700786662375, 0.6451863306944472}, 
           0.0415063096365134]}, 
         InsetBox["6333", 
          Offset[{2, 2}, {3.320376388302751, 0.6866926403309606}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[125, 251], 0.49800796812749004`]], 
          DiskBox[{3.7199641632770652, 2.447600728379067}, 
           0.0415063096365134]}, 
         InsetBox["5539", 
          Offset[{2, 2}, {3.7614704729135786, 2.48910703801558}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.4698388307120833, 2.295865678675766}, 
           0.0415063096365134]}, 
         InsetBox["1247", 
          Offset[{2, 2}, {2.5113451403485967, 2.337371988312279}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{3.4427320409738456, 3.082866302351973}, 
           0.0415063096365134]}, 
         InsetBox["3685", 
          Offset[{2, 2}, {3.484238350610359, 3.1243726119884863}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[235, 251], 0.9362549800796812]], 
          DiskBox[{4.287142555088807, 2.010102527203237}, 
           0.0415063096365134]}, 
         InsetBox["4680", 
          Offset[{2, 2}, {4.328648864725321, 2.0516088368397503}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.0226924541869202, 1.159944789617093}, 
           0.0415063096365134]}, 
         InsetBox["3340", 
          Offset[{2, 2}, {3.0641987638234336, 1.2014510992536063}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{3.903077256299162, 3.255798740011394}, 
           0.0415063096365134]}, 
         InsetBox["2143", 
          Offset[{2, 2}, {3.9445835659356754, 3.2973050496479073}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[204, 251], 0.8127490039840638]], 
          DiskBox[{4.73425173666226, 2.681130220163744}, 0.0415063096365134]},
          InsetBox["8443", 
          Offset[{2, 2}, {4.775758046298773, 2.7226365298002575}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[171, 251], 0.6812749003984063]], 
          DiskBox[{4.397641903925736, 3.2539845580257283}, 
           0.0415063096365134]}, 
         InsetBox["482", 
          Offset[{2, 2}, {4.43914821356225, 3.2954908676622416}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{3.0264201946628146, 2.80485831460313}, 
           0.0415063096365134]}, 
         InsetBox["977", 
          Offset[{2, 2}, {3.067926504299328, 2.8463646242396434}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.5940113125237874, 2.7693008373875165}, 
           0.0415063096365134]}, 
         InsetBox["7695", 
          Offset[{2, 2}, {2.6355176221603007, 2.81080714702403}], ImageScaled[
          {0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{1.0991774454099354, 3.724970924197967}, 
           0.0415063096365134]}, 
         InsetBox["6464", 
          Offset[{2, 2}, {1.1406837550464488, 3.7664772338344803}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{1.4691302208150039, 1.6601275876173132}, 
           0.0415063096365134]}, 
         InsetBox["5699", 
          Offset[{2, 2}, {1.5106365304515172, 1.7016338972538265}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.9609481837191605, 4.23067539877886}, 
           0.0415063096365134]}, 
         InsetBox["9166", 
          Offset[{2, 2}, {2.002454493355674, 4.272181708415374}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.9626592733755062, 1.3741698167689078}, 
           0.0415063096365134]}, 
         InsetBox["9438", 
          Offset[{2, 2}, {2.0041655830120195, 1.4156761264054212}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{3.2718706661648147, 1.9615687638283492}, 
           0.0415063096365134]}, 
         InsetBox["224", 
          Offset[{2, 2}, {3.313376975801328, 2.0030750734648626}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.188854013791599, 3.306741207795006}, 
           0.0415063096365134]}, 
         InsetBox["640", 
          Offset[{2, 2}, {2.2303603234281124, 3.348247517431519}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[209, 251], 0.8326693227091634]], 
          DiskBox[{1.374401110837499, 2.8591905382743446}, 
           0.0415063096365134]}, 
         InsetBox["3591", 
          Offset[{2, 2}, {1.4159074204740123, 2.900696847910858}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{1.4960812966322448, 3.3648299807271984}, 
           0.0415063096365134]}, 
         InsetBox["1523", Offset[{2, 2}, 
          {1.5375876062687581, 3.4063362903637118}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[184, 251], 0.7330677290836654]], 
          DiskBox[{1.305774790379798, 1.8813573754580086}, 
           0.0415063096365134]}, 
         InsetBox["7460", 
          Offset[{2, 2}, {1.3472811000163114, 1.922863685094522}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[200, 251], 0.796812749003984]], 
          DiskBox[{1.426894169367006, 0.8981408741125645}, 
           0.0415063096365134]}, 
         InsetBox["1120", 
          Offset[{2, 2}, {1.4684004790035194, 0.9396471837490779}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[199, 251], 0.7928286852589641]], 
          DiskBox[{2.5580136313919133, 0.5769391307265495}, 
           0.0415063096365134]}, 
         InsetBox["1656", 
          Offset[{2, 2}, {2.5995199410284267, 0.6184454403630628}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{4.104459217702431, 1.6157516950091917}, 
           0.0415063096365134]}, 
         InsetBox["8896", 
          Offset[{2, 2}, {4.145965527338944, 1.657258004645705}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{1.9009919110450095, 0.7781096625592305}, 
           0.0415063096365134]}, 
         InsetBox["2350", 
          Offset[{2, 2}, {1.942498220681523, 0.8196159721957439}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.6883059376362457, 0.}, 0.0415063096365134]}, 
         InsetBox["5971", 
          Offset[{2, 2}, {3.729812247272759, 0.0415063096365134}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{0., 1.1873821379604075}, 0.0415063096365134]}, 
         InsetBox["2051", 
          Offset[{2, 2}, {0.0415063096365134, 1.2288884475969208}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  ImageSize->{581., Automatic}]], "Output",
 CellChangeTimes->{3.7464453476859674`*^9, 3.7480367079906197`*^9, 
  3.7494641679536242`*^9, 3.7494867452148848`*^9, 3.7494872334385004`*^9, 
  3.7504452302283707`*^9, 3.7505243785410147`*^9, 3.7507000091677713`*^9, 
  3.7507020130021515`*^9, 3.750703041226813*^9, 3.7512460306024294`*^9, 
  3.7512461294972095`*^9, 3.7512463393828506`*^9, 3.751284361904348*^9, 
  3.751299690952732*^9, 3.7513007257700806`*^9, 3.753705829726768*^9, 
  3.7542674752110715`*^9, 3.754695134092041*^9, 3.7547762794582176`*^9, 
  3.7547776410604115`*^9, 3.757437262184705*^9, 3.7575151100240307`*^9, 
  3.75759232268184*^9, 3.7575933882289305`*^9, 3.7575937808101587`*^9, 
  3.7575943726481633`*^9, 3.7575948787771683`*^9, 3.75759548700315*^9, 
  3.7575960167190585`*^9, 3.7576331499339514`*^9, 3.7576343529448357`*^9, 
  3.757634836599517*^9, 3.7576351658789434`*^9, 3.830340759937723*^9, 
  3.8304156756435404`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"84e4ffbc-bc4e-44e0-83b9-d0e0af7e3f02"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"strongbonds1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"strongbonds", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"EdgeList", "[", "exp1", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"EdgeList", "[", "exp1", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
        "]"}], ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", 
         RowBox[{"EdgeList", "[", "exp1", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"strongbonds2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"strongbonds", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"EdgeList", "[", "exp2", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"EdgeList", "[", "exp2", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
        "]"}], ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", 
         RowBox[{"EdgeList", "[", "exp2", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7463977105463195`*^9, 3.7463978203740873`*^9}, {
  3.7463978804819*^9, 3.7463979212468967`*^9}, {3.746397955546936*^9, 
  3.7463979714959116`*^9}, {3.746398009790866*^9, 3.7463981000271263`*^9}, {
  3.746398265882224*^9, 3.7463982835088997`*^9}, {3.746403133050016*^9, 
  3.7464031344769316`*^9}, {3.7464031711519327`*^9, 3.7464031732398996`*^9}},
 CellLabel->
  "In[680]:=",ExpressionUUID->"b812cd4e-0960-4948-94f1-67f6a81de503"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dyads", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"VertexList", "[", "exp1", "]"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"VertexList", "[", "exp1", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"VertexList", "[", "exp1", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"VertexList", "[", "exp1", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
        "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"VertexList", "[", "exp2", "]"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"VertexList", "[", "exp2", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"VertexList", "[", "exp2", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"VertexList", "[", "exp2", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
        "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.746404189658313*^9, 3.746404374701803*^9}, {
  3.746404410924283*^9, 3.7464044371518564`*^9}},
 CellLabel->
  "In[710]:=",ExpressionUUID->"7d883d0a-b34c-4afd-9a0a-520ba3ea021c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Edge", "Subsection",
 CellChangeTimes->{{3.7507015909653344`*^9, 
  3.7507015914461374`*^9}},ExpressionUUID->"144afebd-a7b7-4802-aac0-\
569b732de054"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"g", ",", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"EdgeList", "[", "exp1", "]"}], ",", 
     RowBox[{"EdgeList", "[", "exp2", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7505243892416105`*^9, 3.7505244212422175`*^9}, {
   3.7505246004842186`*^9, 3.7505246154349585`*^9}, 3.7507006466260977`*^9},
 CellLabel->"In[42]:=",ExpressionUUID->"4eeb851b-53db-4acb-8af7-5c874edccdc2"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1146, 7319, 5885, 1652, 6809, 5273, 2101, 2217, 4494, 743, 1403, 
      4205, 3480, 6952, 8012, 8011, 4972, 1452, 7324, 9019, 5279, 4880, 1929, 
      488, 5907, 8287, 7435, 9644, 4250, 1250, 5178, 6905, 6991, 898, 607, 
      3860, 3780, 1615, 7664, 1542, 8052, 1610, 9878, 1129, 4707, 555, 999, 
      4429, 4405, 149}, {
      Null, {{1, 2}, {1, 3}, {4, 5}, {6, 5}, {7, 6}, {8, 3}, {9, 3}, {10, 
       11}, {10, 12}, {10, 4}, {10, 13}, {10, 14}, {10, 15}, {6, 16}, {17, 
       6}, {4, 6}, {18, 9}, {19, 20}, {21, 20}, {17, 21}, {17, 2}, {22, 17}, {
       23, 17}, {17, 19}, {24, 16}, {17, 16}, {2, 16}, {4, 16}, {12, 15}, {4, 
       12}, {25, 5}, {25, 26}, {4, 25}, {18, 25}, {25, 14}, {25, 15}, {25, 
       27}, {14, 28}, {29, 28}, {30, 31}, {24, 30}, {31, 32}, {18, 23}, {18, 
       33}, {18, 4}, {18, 31}, {1, 18}, {18, 15}, {18, 14}, {29, 15}, {1, 
       29}, {4, 29}, {29, 14}, {29, 5}, {4, 26}, {4, 14}, {4, 31}, {4, 23}, {
       4, 15}, {18, 27}, {14, 27}, {9, 27}, {17, 27}, {27, 15}, {4, 27}, {24, 
       31}, {31, 14}, {31, 15}, {14, 15}, {17, 15}, {34, 14}, {35, 14}, {23, 
       14}, {9, 14}, {35, 3}, {36, 5}, {10, 5}, {5, 14}, {3, 32}, {10, 31}, {
       5, 2}, {29, 31}, {23, 27}, {5, 27}, {33, 27}, {37, 31}, {38, 15}, {35, 
       15}, {35, 34}, {35, 5}, {35, 4}, {17, 20}, {18, 39}, {1, 16}, {11, 
       13}, {10, 40}, {10, 8}, {6, 41}, {40, 12}, {29, 41}, {27, 39}, {10, 
       3}, {7, 3}, {9, 2}, {16, 20}, {2, 41}, {29, 32}, {9, 15}, {31, 3}, {8, 
       25}, {32, 14}, {5, 16}, {38, 29}, {23, 3}, {18, 32}, {42, 16}, {18, 
       43}, {29, 16}, {35, 31}, {44, 6}, {2, 43}, {3, 43}, {5, 43}, {18, 
       45}, {46, 14}, {17, 43}, {47, 29}, {10, 48}, {49, 31}, {50, 16}}}, {
      EdgeStyle -> {UndirectedEdge[1615, 8012] -> GrayLevel[
           Rational[2, 3]], UndirectedEdge[1146, 7319] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[1652, 4205] -> GrayLevel[
           Rational[57, 79]], UndirectedEdge[1652, 6952] -> GrayLevel[
           Rational[206, 237]], UndirectedEdge[488, 5178] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge[4250, 6905] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge[1250, 5178] -> GrayLevel[
           Rational[119, 237]], UndirectedEdge[743, 6952] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge[743, 3480] -> GrayLevel[
           Rational[131, 237]], UndirectedEdge[1652, 8287] -> GrayLevel[
           Rational[33, 79]], UndirectedEdge[1929, 7435] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[1452, 6991] -> GrayLevel[
           Rational[176, 237]], UndirectedEdge[999, 4250] -> GrayLevel[
           Rational[206, 237]], UndirectedEdge[1652, 6809] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge[5279, 9019] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge[1929, 4972] -> GrayLevel[
           Rational[220, 237]], UndirectedEdge[4880, 4972] -> GrayLevel[
           Rational[134, 237]], UndirectedEdge[2101, 5885] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge[7319, 9878] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge[2217, 5885] -> GrayLevel[
           Rational[137, 237]], UndirectedEdge[5885, 9878] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge[1452, 5178] -> GrayLevel[
           Rational[200, 237]], UndirectedEdge[4250, 5178] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge[1542, 4205] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge[6809, 8011] -> GrayLevel[
           Rational[70, 79]], UndirectedEdge[4494, 6952] -> GrayLevel[
           Rational[53, 79]], UndirectedEdge[1146, 4250] -> GrayLevel[
           Rational[66, 79]], UndirectedEdge[6952, 7435] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge[1452, 6905] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[3860, 6809] -> GrayLevel[
           Rational[124, 237]], UndirectedEdge[607, 5885] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[1929, 6952] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[6991, 7435] -> GrayLevel[
           Rational[68, 79]], UndirectedEdge[6952, 8012] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge[1652, 1929] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[1452, 8012] -> GrayLevel[
           Rational[199, 237]], UndirectedEdge[1610, 8011] -> GrayLevel[
           Rational[205, 237]], UndirectedEdge[1452, 4707] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge[4972, 9019] -> GrayLevel[
           Rational[48, 79]], UndirectedEdge[898, 6952] -> GrayLevel[
           Rational[139, 237]], UndirectedEdge[607, 8012] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[1452, 7664] -> GrayLevel[
           Rational[164, 237]], UndirectedEdge[1652, 5178] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[1452, 7435] -> GrayLevel[
           Rational[106, 237]], UndirectedEdge[743, 1542] -> GrayLevel[
           Rational[97, 237]], UndirectedEdge[1452, 6952] -> GrayLevel[
           Rational[194, 237]], UndirectedEdge[4250, 8011] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[7435, 8012] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge[1129, 5273] -> GrayLevel[
           Rational[197, 237]], UndirectedEdge[5885, 6905] -> GrayLevel[
           Rational[176, 237]], UndirectedEdge[555, 6952] -> GrayLevel[
           Rational[70, 79]], UndirectedEdge[5178, 6952] -> GrayLevel[
           Rational[218, 237]], UndirectedEdge[8011, 9019] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge[607, 898] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge[4494, 7319] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[1652, 8012] -> GrayLevel[
           Rational[181, 237]], UndirectedEdge[7319, 8011] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge[743, 1652] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge[4494, 8012] -> GrayLevel[
           Rational[202, 237]], UndirectedEdge[7324, 9019] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[4972, 8012] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[1403, 3480] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge[1929, 5885] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge[5907, 6809] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge[2217, 5907] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge[743, 4429] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge[6809, 7435] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[1652, 5907] -> GrayLevel[
           Rational[41, 237]], UndirectedEdge[607, 6952] -> GrayLevel[
           Rational[21, 79]], UndirectedEdge[743, 2217] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge[488, 8011] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge[743, 5885] -> GrayLevel[
           Rational[196, 237]], UndirectedEdge[4250, 9644] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge[4972, 7324] -> GrayLevel[
           Rational[199, 237]], UndirectedEdge[4405, 5178] -> GrayLevel[
           Rational[220, 237]], UndirectedEdge[6905, 6952] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge[1652, 5273] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge[4205, 8012] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge[5273, 6809] -> GrayLevel[
           Rational[65, 79]], UndirectedEdge[5178, 5885] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[743, 5178] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[4250, 6952] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge[5178, 6905] -> GrayLevel[
           Rational[60, 79]], UndirectedEdge[5907, 6952] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge[1452, 1929] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge[1652, 8011] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[488, 1250] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge[1452, 5907] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[5273, 8052] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[6809, 6952] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge[4972, 7319] -> GrayLevel[
           Rational[142, 237]], UndirectedEdge[7435, 7664] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[743, 1403] -> GrayLevel[
           Rational[110, 237]], UndirectedEdge[1452, 1652] -> GrayLevel[
           Rational[202, 237]], UndirectedEdge[4250, 8012] -> GrayLevel[
           Rational[43, 79]], UndirectedEdge[5907, 8012] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge[1146, 1452] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[4494, 7435] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[1146, 8011] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[3780, 5178] -> GrayLevel[
           Rational[118, 237]], UndirectedEdge[1146, 5885] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge[149, 8011] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[6809, 9878] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[743, 4205] -> GrayLevel[0], 
         UndirectedEdge[607, 6809] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[1652, 4250] -> GrayLevel[
           Rational[218, 237]], UndirectedEdge[6809, 7319] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge[607, 5178] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[5907, 8287] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge[6952, 9644] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge[4250, 8052] -> GrayLevel[
           Rational[66, 79]], UndirectedEdge[5178, 8012] -> GrayLevel[
           Rational[208, 237]], UndirectedEdge[5907, 7435] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[1452, 4494] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge[7319, 8052] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge[1652, 7435] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[4972, 7435] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge[743, 8012] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[4972, 9878] -> GrayLevel[
           Rational[211, 237]], UndirectedEdge[4972, 5279] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[4972, 5273] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge[4250, 6809] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge[1615, 4250] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge[5273, 8011] -> GrayLevel[
           Rational[190, 237]], UndirectedEdge[4972, 8011] -> GrayLevel[
           Rational[191, 237]], UndirectedEdge[743, 6809] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge[2101, 5273] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge[607, 1652] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge[4494, 5885] -> GrayLevel[
           Rational[196, 237]], UndirectedEdge[1452, 9878] -> GrayLevel[
           Rational[215, 237]]}, 
       EdgeWeight -> {13, 30, 20, 42, 12, 100, 41, 127, 237, 21, 106, 23, 13, 
        47, 14, 16, 22, 12, 36, 14, 95, 103, 17, 38, 11, 46, 30, 10, 20, 66, 
        16, 22, 196, 14, 23, 11, 13, 23, 11, 118, 23, 57, 16, 61, 35, 37, 12, 
        38, 43, 108, 39, 19, 22, 16, 138, 31, 12, 13, 56, 131, 24, 10, 11, 11,
         14, 36, 19, 29, 30, 14, 98, 174, 10, 78, 10, 113, 13, 24, 61, 14, 15,
         21, 10, 10, 33, 119, 79, 14, 21, 13, 11, 93, 73, 12, 24, 140, 36, 13,
         16, 39, 10, 41, 20, 12, 20, 16, 22, 35, 13, 15, 24, 27, 10, 24, 12, 
        32, 22, 12, 12, 40, 30, 15, 14, 15, 27, 26, 31, 21, 17, 10}, 
       GraphHighlight -> {
         UndirectedEdge[743, 3480], 
         UndirectedEdge[3860, 6809], 
         UndirectedEdge[1929, 5885], 
         UndirectedEdge[1652, 8012], 
         UndirectedEdge[4250, 6952], 
         UndirectedEdge[5178, 6905], 
         UndirectedEdge[4972, 8012], 
         UndirectedEdge[1250, 5178], 
         UndirectedEdge[2217, 5885], 
         UndirectedEdge[2101, 5273], 
         UndirectedEdge[488, 5178], 
         UndirectedEdge[5907, 6809], 
         UndirectedEdge[7319, 9878], 
         UndirectedEdge[4972, 8011], 
         UndirectedEdge[743, 5885], 
         UndirectedEdge[1452, 5907], 
         UndirectedEdge[6952, 7435], 
         UndirectedEdge[5178, 5885], 
         UndirectedEdge[6809, 9878], 
         UndirectedEdge[149, 8011], 
         UndirectedEdge[5907, 8012], 
         UndirectedEdge[6952, 9644], 
         UndirectedEdge[488, 1250], 
         UndirectedEdge[1615, 4250], 
         UndirectedEdge[743, 4205], 
         UndirectedEdge[1452, 6991], 
         UndirectedEdge[4250, 9644], 
         UndirectedEdge[5885, 9878], 
         UndirectedEdge[743, 2217], 
         UndirectedEdge[5885, 6905], 
         UndirectedEdge[4250, 6809], 
         UndirectedEdge[1652, 6809], 
         UndirectedEdge[1452, 7435], 
         UndirectedEdge[6952, 8012], 
         UndirectedEdge[1452, 9878], 
         UndirectedEdge[607, 5178], 
         UndirectedEdge[4205, 8012], 
         UndirectedEdge[743, 4429], 
         UndirectedEdge[6905, 6952], 
         UndirectedEdge[4494, 6952], 
         UndirectedEdge[1652, 6952], 
         UndirectedEdge[1652, 8287], 
         UndirectedEdge[7324, 9019], 
         UndirectedEdge[1129, 5273], 
         UndirectedEdge[5907, 7435], 
         UndirectedEdge[7319, 8011], 
         UndirectedEdge[1929, 4972], 
         UndirectedEdge[1929, 6952], 
         UndirectedEdge[4972, 9019], 
         UndirectedEdge[4250, 8012], 
         UndirectedEdge[607, 1652], 
         UndirectedEdge[743, 1542], 
         UndirectedEdge[1452, 1652], 
         UndirectedEdge[4494, 7319], 
         UndirectedEdge[5178, 8012], 
         UndirectedEdge[1452, 6905], 
         UndirectedEdge[1542, 4205], 
         UndirectedEdge[1615, 8012], 
         UndirectedEdge[4250, 6905], 
         UndirectedEdge[5907, 8287], 
         UndirectedEdge[1652, 4205], 
         UndirectedEdge[743, 8012], 
         UndirectedEdge[4972, 7319], 
         UndirectedEdge[4972, 7324], 
         UndirectedEdge[5178, 6952], 
         UndirectedEdge[743, 6809], 
         UndirectedEdge[4494, 8012], 
         UndirectedEdge[4972, 9878], 
         UndirectedEdge[898, 6952], 
         UndirectedEdge[6809, 8011], 
         UndirectedEdge[6809, 7435], 
         UndirectedEdge[607, 898], 
         UndirectedEdge[1652, 5907], 
         UndirectedEdge[7435, 8012], 
         UndirectedEdge[4880, 4972], 
         UndirectedEdge[5907, 6952], 
         UndirectedEdge[4972, 5273], 
         UndirectedEdge[4250, 5178], 
         UndirectedEdge[607, 6952], 
         UndirectedEdge[4250, 8011], 
         UndirectedEdge[743, 6952], 
         UndirectedEdge[743, 5178], 
         UndirectedEdge[1452, 4707], 
         UndirectedEdge[1652, 1929], 
         UndirectedEdge[1652, 5178], 
         UndirectedEdge[5273, 6809], 
         UndirectedEdge[1652, 8011], 
         UndirectedEdge[2101, 5885], 
         UndirectedEdge[1452, 4494], 
         UndirectedEdge[1652, 4250], 
         UndirectedEdge[1452, 1929], 
         UndirectedEdge[2217, 5907], 
         UndirectedEdge[607, 5885], 
         UndirectedEdge[6809, 6952], 
         UndirectedEdge[1652, 5273], 
         UndirectedEdge[1452, 5178], 
         UndirectedEdge[5273, 8011], 
         UndirectedEdge[6991, 7435], 
         UndirectedEdge[4494, 7435], 
         UndirectedEdge[1929, 7435], 
         UndirectedEdge[1452, 8012], 
         UndirectedEdge[1652, 7435], 
         UndirectedEdge[1452, 6952], 
         UndirectedEdge[743, 1652], 
         UndirectedEdge[4972, 7435], 
         UndirectedEdge[488, 8011], 
         UndirectedEdge[607, 8012], 
         UndirectedEdge[4494, 5885], 
         UndirectedEdge[8011, 9019], 
         UndirectedEdge[6809, 7319], 
         UndirectedEdge[607, 6809]}, GraphLayout -> {"Dimension" -> 2}, 
       VertexLabels -> {"Name"}, 
       VertexStyle -> {743 -> GrayLevel[0], 6991 -> GrayLevel[
           Rational[349, 396]], 8052 -> GrayLevel[
           Rational[181, 198]], 3480 -> GrayLevel[
           Rational[331, 396]], 1129 -> GrayLevel[
           Rational[94, 99]], 8287 -> GrayLevel[
           Rational[79, 99]], 1250 -> GrayLevel[
           Rational[217, 264]], 1652 -> GrayLevel[
           Rational[67, 396]], 1452 -> GrayLevel[
           Rational[29, 88]], 8012 -> GrayLevel[
           Rational[167, 396]], 8011 -> GrayLevel[
           Rational[535, 792]], 4429 -> GrayLevel[
           Rational[257, 264]], 488 -> GrayLevel[
           Rational[361, 396]], 7664 -> GrayLevel[
           Rational[709, 792]], 4405 -> GrayLevel[
           Rational[775, 792]], 7324 -> GrayLevel[
           Rational[371, 396]], 607 -> GrayLevel[
           Rational[179, 264]], 555 -> GrayLevel[
           Rational[85, 88]], 1403 -> GrayLevel[
           Rational[641, 792]], 9644 -> GrayLevel[
           Rational[379, 396]], 1610 -> GrayLevel[
           Rational[95, 99]], 1542 -> GrayLevel[
           Rational[53, 66]], 7435 -> GrayLevel[
           Rational[515, 792]], 999 -> GrayLevel[
           Rational[761, 792]], 4250 -> GrayLevel[
           Rational[221, 396]], 2217 -> GrayLevel[
           Rational[641, 792]], 898 -> GrayLevel[
           Rational[673, 792]], 3860 -> GrayLevel[
           Rational[679, 792]], 6905 -> GrayLevel[
           Rational[7, 9]], 149 -> GrayLevel[
           Rational[391, 396]], 9019 -> GrayLevel[
           Rational[631, 792]], 4205 -> GrayLevel[
           Rational[151, 264]], 3780 -> GrayLevel[
           Rational[673, 792]], 4707 -> GrayLevel[
           Rational[259, 264]], 4880 -> GrayLevel[
           Rational[689, 792]], 1615 -> GrayLevel[
           Rational[703, 792]], 7319 -> GrayLevel[
           Rational[581, 792]], 4494 -> GrayLevel[
           Rational[3, 4]], 5279 -> GrayLevel[
           Rational[371, 396]], 5885 -> GrayLevel[
           Rational[437, 792]], 2101 -> GrayLevel[
           Rational[95, 99]], 5273 -> GrayLevel[
           Rational[76, 99]], 6809 -> GrayLevel[
           Rational[469, 792]], 9878 -> GrayLevel[
           Rational[685, 792]], 1929 -> GrayLevel[
           Rational[39, 44]], 6952 -> GrayLevel[
           Rational[119, 792]], 1146 -> GrayLevel[
           Rational[343, 396]], 5178 -> GrayLevel[
           Rational[4, 11]], 5907 -> GrayLevel[
           Rational[241, 396]], 4972 -> GrayLevel[
           Rational[107, 264]]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {GrayLevel[
          NCache[
           Rational[224, 237], 0.9451476793248945]], 
         LineBox[{{2.115543039152236, 2.0628185435026767`}, {
          1.908518628513834, 2.6339403953581484`}}]}, 
        {GrayLevel[
          NCache[
           Rational[69, 79], 0.8734177215189873]], 
         LineBox[{{2.115543039152236, 2.0628185435026767`}, {
          3.1346678583378504`, 2.6470127480770165`}}]}, 
        {GrayLevel[
          NCache[
           Rational[75, 79], 0.9493670886075949]], 
         LineBox[{{2.115543039152236, 2.0628185435026767`}, {
          1.6566766146031886`, 2.3923339961611485`}}]}, 
        {GrayLevel[
          NCache[
           Rational[75, 79], 0.9493670886075949]], 
         LineBox[{{2.115543039152236, 2.0628185435026767`}, {
          2.8497530967524005`, 1.530024202849447}}]}, 
        {GrayLevel[
          NCache[
           Rational[66, 79], 0.8354430379746836]], 
         LineBox[{{2.115543039152236, 2.0628185435026767`}, {
          2.585696215956411, 1.658399454495948}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.908518628513834, 2.6339403953581484`}, {
          2.790616598133171, 2.7786192877179827`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.908518628513834, 2.6339403953581484`}, {
          2.752640914793099, 2.258822279543445}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.908518628513834, 2.6339403953581484`}, {
          1.6566766146031886`, 2.3923339961611485`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.908518628513834, 2.6339403953581484`}, {
          1.3580492433518554`, 2.1125406473364947`}}]}, 
        {GrayLevel[
          NCache[
           Rational[221, 237], 0.9324894514767933]], 
         LineBox[{{1.908518628513834, 2.6339403953581484`}, {
          1.4996647605008138`, 2.6510293887008882`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.908518628513834, 2.6339403953581484`}, {
          2.233601453834779, 2.477600962050863}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          2.4347435612454333`, 3.773820673105155}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          3.927424506909598, 3.341523645534261}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          2.752640914793099, 2.258822279543445}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          4.171608771395273, 2.8335169859093186`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          2.4833398158424904`, 2.1472669903507877`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          3.3394005380211054`, 1.609620989452162}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          3.759174995105831, 2.2840938139276425`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1346678583378504`, 2.6470127480770165`}, {
          2.233601453834779, 2.477600962050863}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          2.790616598133171, 2.7786192877179827`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          1.861630623572972, 3.199378907033352}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          4.171608771395273, 2.8335169859093186`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          4.240915848938334, 2.507516639535947}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          3.5323864604500335`, 1.9607881854862055`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          3.1431218032594517`, 2.0186238029618524`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          1.6566766146031886`, 2.3923339961611485`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          2.8497530967524005`, 1.530024202849447}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          2.4833398158424904`, 2.1472669903507877`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          3.379343403496603, 2.5846421631543244`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          3.45525438996884, 3.4962917917429888`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          2.585696215956411, 1.658399454495948}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.0613676848615663`, 2.4177450406486196`}, {
          3.759174995105831, 2.2840938139276425`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          1.861630623572972, 3.199378907033352}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          4.171608771395273, 2.8335169859093186`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          3.5323864604500335`, 1.9607881854862055`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          1.6566766146031886`, 2.3923339961611485`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          3.379343403496603, 2.5846421631543244`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          2.585696215956411, 1.658399454495948}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          3.759174995105831, 2.2840938139276425`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          2.836715116896876, 4.261515481506546}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.790616598133171, 2.7786192877179827`}, {
          2.233601453834779, 2.477600962050863}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.861630623572972, 3.199378907033352}, {
          2.4347435612454333`, 3.773820673105155}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.861630623572972, 3.199378907033352}, {
          1.6566766146031886`, 2.3923339961611485`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.861630623572972, 3.199378907033352}, {
          1.3580492433518554`, 2.1125406473364947`}}]}, 
        {GrayLevel[
          NCache[
           Rational[224, 237], 0.9451476793248945]], 
         LineBox[{{1.861630623572972, 3.199378907033352}, {
          1.4996647605008138`, 2.6510293887008882`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.861630623572972, 3.199378907033352}, {
          1.1375417734724396`, 4.3707162341673715`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.927424506909598, 3.341523645534261}, {4.171608771395273, 
          2.8335169859093186`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.927424506909598, 3.341523645534261}, {3.379343403496603, 
          2.5846421631543244`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.752640914793099, 2.258822279543445}, {
          3.5323864604500335`, 1.9607881854862055`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.752640914793099, 2.258822279543445}, {
          3.1431218032594517`, 2.0186238029618524`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.752640914793099, 2.258822279543445}, {
          2.8497530967524005`, 1.530024202849447}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.752640914793099, 2.258822279543445}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {GrayLevel[
          NCache[
           Rational[110, 237], 0.4641350210970464]], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {5.01033462246483,
           3.9341326930645972`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {
          4.240915848938334, 2.507516639535947}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {5.27990425358853,
           3.68677359345517}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {
          3.5323864604500335`, 1.9607881854862055`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {
          3.1431218032594517`, 2.0186238029618524`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {
          5.128411413460875, 2.854944905050802}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.171608771395273, 2.8335169859093186`}, {
          5.555250167303243, 3.2298827071259577`}}]}, 
        {GrayLevel[
          NCache[
           Rational[71, 79], 0.8987341772151899]], 
         LineBox[{{5.01033462246483, 3.9341326930645972`}, {5.27990425358853, 
          3.68677359345517}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.240915848938334, 2.507516639535947}, {
          3.1431218032594517`, 2.0186238029618524`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.240915848938334, 2.507516639535947}, {5.128411413460875, 
          2.854944905050802}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          3.1431218032594517`, 2.0186238029618524`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          2.8497530967524005`, 1.530024202849447}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          2.4833398158424904`, 2.1472669903507877`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          3.379343403496603, 2.5846421631543244`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          3.5864386897916134`, 0.980445959155053}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          2.585696215956411, 1.658399454495948}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          3.3394005380211054`, 1.609620989452162}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          4.63231858334224, 1.983521196973392}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          3.759174995105831, 2.2840938139276425`}}]}, 
        {GrayLevel[
          NCache[
           Rational[70, 79], 0.8860759493670886]], 
         LineBox[{{3.5323864604500335`, 1.9607881854862055`}, {
          4.908081274609965, 1.4698547520268581`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          1.3580492433518554`, 2.1125406473364947`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          2.8497530967524005`, 1.530024202849447}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          3.379343403496603, 2.5846421631543244`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          2.585696215956411, 1.658399454495948}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          3.759174995105831, 2.2840938139276425`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.1431218032594517`, 2.0186238029618524`}, {
          3.0426305943570555`, 0.9051199326861772}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.6566766146031886`, 2.3923339961611485`}, {
          1.3580492433518554`, 2.1125406473364947`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.6566766146031886`, 2.3923339961611485`}, {
          0.5068605653623002, 2.1909329566824614`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.6566766146031886`, 2.3923339961611485`}, {
          2.559522413680018, 1.13809522364013}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.6566766146031886`, 2.3923339961611485`}, {
          2.585696215956411, 1.658399454495948}}]}, 
        {GrayLevel[
          NCache[
           Rational[205, 237], 0.8649789029535865]], 
         LineBox[{{1.6566766146031886`, 2.3923339961611485`}, {
          0.36357940639081177`, 2.9505580679121683`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.6566766146031886`, 2.3923339961611485`}, {
          0.6267174418687622, 3.3298729397918203`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.3580492433518554`, 2.1125406473364947`}, {0., 
          2.2897337015988253`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.3580492433518554`, 2.1125406473364947`}, {
          0.5068605653623002, 2.1909329566824614`}}]}, 
        {GrayLevel[
          NCache[
           Rational[223, 237], 0.9409282700421941]], 
         LineBox[{{1.3580492433518554`, 2.1125406473364947`}, {
          0.06321172247448592, 1.8529329490757083`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.3580492433518554`, 2.1125406473364947`}, {
          0.1777325304598496, 1.334275274385586}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.3580492433518554`, 2.1125406473364947`}, {
          2.4833398158424904`, 2.1472669903507877`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.3580492433518554`, 2.1125406473364947`}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{1.3580492433518554`, 2.1125406473364947`}, {
          2.233601453834779, 2.477600962050863}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          2.4833398158424904`, 2.1472669903507877`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          3.379343403496603, 2.5846421631543244`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          3.3394005380211054`, 1.609620989452162}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          2.112473722118936, 0.8539517047491889}}]}, 
        {GrayLevel[
          NCache[
           Rational[164, 237], 0.6919831223628692]], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          2.5203984401941004`, 0.6457731327543823}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          2.233601453834779, 2.477600962050863}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.8497530967524005`, 1.530024202849447}, {
          3.0349669471631047`, 0.}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{0., 2.2897337015988253`}, {0.5068605653623002, 
          2.1909329566824614`}}]}, 
        {GrayLevel[
          NCache[
           Rational[67, 79], 0.8481012658227848]], 
         LineBox[{{0.5068605653623002, 2.1909329566824614`}, {
          0.06321172247448592, 1.8529329490757083`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.4833398158424904`, 2.1472669903507877`}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.559522413680018, 1.13809522364013}, {3.347015178474344, 
          0.40544960787627726`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.559522413680018, 1.13809522364013}, {3.6703336327530085`,
           1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.379343403496603, 2.5846421631543244`}, {3.45525438996884,
           3.4962917917429888`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.379343403496603, 2.5846421631543244`}, {
          2.5685744740055436`, 1.8401913432642338`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.5685744740055436`, 1.8401913432642338`}, {
          2.112473722118936, 0.8539517047491889}}]}, 
        {GrayLevel[
          NCache[
           Rational[227, 237], 0.9578059071729957]], 
         LineBox[{{2.5685744740055436`, 1.8401913432642338`}, {
          2.5203984401941004`, 0.6457731327543823}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.5864386897916134`, 0.980445959155053}, {
          2.585696215956411, 1.658399454495948}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.585696215956411, 1.658399454495948}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.585696215956411, 1.658399454495948}, {
          3.3394005380211054`, 1.609620989452162}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{2.585696215956411, 1.658399454495948}, {
          3.0426305943570555`, 0.9051199326861772}}]}, 
        {GrayLevel[
          NCache[
           Rational[66, 79], 0.8354430379746836]], 
         LineBox[{{2.585696215956411, 1.658399454495948}, {
          1.4996647605008138`, 2.6510293887008882`}}]}, 
        {GrayLevel[
          NCache[
           Rational[206, 237], 0.869198312236287]], 
         LineBox[{{2.585696215956411, 1.658399454495948}, {
          1.6747131364417198`, 0.44856441237844735`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.347015178474344, 0.40544960787627726`}, {
          3.6703336327530085`, 1.5004101977543813`}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.6703336327530085`, 1.5004101977543813`}, {
          3.3394005380211054`, 1.609620989452162}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{3.6703336327530085`, 1.5004101977543813`}, {
          3.759174995105831, 2.2840938139276425`}}]}, 
        {GrayLevel[
          NCache[
           Rational[118, 237], 0.4978902953586498]], 
         LineBox[{{3.6703336327530085`, 1.5004101977543813`}, {
          4.491057658880921, 0.31976611457832105`}}]}, 
        {GrayLevel[
          NCache[
           Rational[220, 237], 0.9282700421940928]], 
         LineBox[{{3.6703336327530085`, 1.5004101977543813`}, {
          4.854317571361642, 0.6858425063347129}}]}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         LineBox[{{4.63231858334224, 1.983521196973392}, {3.759174995105831, 
          2.2840938139276425`}}]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         {GrayLevel[
           NCache[
            Rational[343, 396], 0.8661616161616161]], 
          DiskBox[{2.115543039152236, 2.0628185435026767}, 
           0.04613222458173305]}, 
         InsetBox["1146", 
          Offset[{2, 2}, {2.1616752637339687, 2.1089507680844095}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[581, 792], 0.7335858585858586]], 
          DiskBox[{1.908518628513834, 2.6339403953581484}, 
           0.04613222458173305]}, 
         InsetBox["7319", 
          Offset[{2, 2}, {1.954650853095567, 2.6800726199398817}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[437, 792], 0.5517676767676768]], 
          DiskBox[{3.1346678583378504, 2.6470127480770165}, 
           0.04613222458173305]}, 
         InsetBox["5885", 
          Offset[{2, 2}, {3.1808000829195837, 2.6931449726587493}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[67, 396], 0.1691919191919192]], 
          DiskBox[{3.0613676848615663, 2.4177450406486196}, 
           0.04613222458173305]}, 
         InsetBox["1652", 
          Offset[{2, 2}, {3.107499909443299, 2.4638772652303524}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[469, 792], 0.5921717171717171]], 
          DiskBox[{2.790616598133171, 2.7786192877179827}, 
           0.04613222458173305]}, 
         InsetBox["6809", 
          Offset[{2, 2}, {2.8367488227149043, 2.8247515122997156}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[76, 99], 0.7676767676767676]], 
          DiskBox[{1.861630623572972, 3.199378907033352}, 
           0.04613222458173305]}, 
         InsetBox["5273", 
          Offset[{2, 2}, {1.907762848154705, 3.2455111316150846}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[95, 99], 0.9595959595959596]], 
          DiskBox[{2.4347435612454333, 3.773820673105155}, 
           0.04613222458173305]}, 
         InsetBox["2101", 
          Offset[{2, 2}, {2.480875785827166, 3.819952897686888}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[641, 792], 0.8093434343434344]], 
          DiskBox[{3.927424506909598, 3.341523645534261}, 
           0.04613222458173305]}, 
         InsetBox["2217", 
          Offset[{2, 2}, {3.973556731491331, 3.387655870115994}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[3, 4], 0.75]], 
          DiskBox[{2.752640914793099, 2.258822279543445}, 
           0.04613222458173305]}, 
         InsetBox["4494", 
          Offset[{2, 2}, {2.7987731393748323, 2.3049545041251784}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[0], 
          DiskBox[{4.171608771395273, 2.8335169859093186}, 
           0.04613222458173305]}, 
         InsetBox["743", 
          Offset[{2, 2}, {4.217740995977006, 2.879649210491052}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[641, 792], 0.8093434343434344]], 
          DiskBox[{5.01033462246483, 3.9341326930645972}, 
           0.04613222458173305]}, 
         InsetBox["1403", 
          Offset[{2, 2}, {5.056466847046563, 3.9802649176463305}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[151, 264], 0.571969696969697]], 
          DiskBox[{4.240915848938334, 2.507516639535947}, 
           0.04613222458173305]}, 
         InsetBox["4205", 
          Offset[{2, 2}, {4.287048073520067, 2.5536488641176804}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[331, 396], 0.8358585858585859]], 
          DiskBox[{5.27990425358853, 3.68677359345517}, 0.04613222458173305]},
          InsetBox["3480", 
          Offset[{2, 2}, {5.326036478170263, 3.732905818036903}], ImageScaled[
          {0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[119, 792], 0.15025252525252525`]], 
          DiskBox[{3.5323864604500335, 1.9607881854862055}, 
           0.04613222458173305]}, 
         InsetBox["6952", 
          Offset[{2, 2}, {3.5785186850317663, 2.0069204100679388}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[167, 396], 0.4217171717171717]], 
          DiskBox[{3.1431218032594517, 2.0186238029618524}, 
           0.04613222458173305]}, 
         InsetBox["8012", 
          Offset[{2, 2}, {3.1892540278411845, 2.0647560275435852}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[535, 792], 0.6755050505050505]], 
          DiskBox[{1.6566766146031886, 2.3923339961611485}, 
           0.04613222458173305]}, 
         InsetBox["8011", 
          Offset[{2, 2}, {1.7028088391849217, 2.4384662207428818}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[107, 264], 0.4053030303030303]], 
          DiskBox[{1.3580492433518554, 2.1125406473364947}, 
           0.04613222458173305]}, 
         InsetBox["4972", 
          Offset[{2, 2}, {1.4041814679335884, 2.1586728719182275}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[29, 88], 0.32954545454545453`]], 
          DiskBox[{2.8497530967524005, 1.530024202849447}, 
           0.04613222458173305]}, 
         InsetBox["1452", 
          Offset[{2, 2}, {2.8958853213341333, 1.5761564274311801}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[371, 396], 0.9368686868686869]], 
          DiskBox[{0., 2.2897337015988253}, 0.04613222458173305]}, 
         InsetBox["7324", 
          Offset[{2, 2}, {0.04613222458173305, 2.335865926180558}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[631, 792], 0.7967171717171717]], 
          DiskBox[{0.5068605653623002, 2.1909329566824614}, 
           0.04613222458173305]}, 
         InsetBox["9019", 
          Offset[{2, 2}, {0.5529927899440332, 2.237065181264194}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[371, 396], 0.9368686868686869]], 
          DiskBox[{0.06321172247448592, 1.8529329490757083}, 
           0.04613222458173305]}, 
         InsetBox["5279", 
          Offset[{2, 2}, {0.10934394705621897, 1.8990651736574413}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[689, 792], 0.8699494949494949]], 
          DiskBox[{0.1777325304598496, 1.334275274385586}, 
           0.04613222458173305]}, 
         InsetBox["4880", 
          Offset[{2, 2}, {0.22386475504158265, 1.380407498967319}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[39, 44], 0.8863636363636364]], 
          DiskBox[{2.4833398158424904, 2.1472669903507877}, 
           0.04613222458173305]}, 
         InsetBox["1929", 
          Offset[{2, 2}, {2.5294720404242232, 2.193399214932521}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[361, 396], 0.9116161616161617]], 
          DiskBox[{2.559522413680018, 1.13809522364013}, 
           0.04613222458173305]}, 
         InsetBox["488", 
          Offset[{2, 2}, {2.6056546382617514, 1.184227448221863}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[241, 396], 0.6085858585858586]], 
          DiskBox[{3.379343403496603, 2.5846421631543244}, 
           0.04613222458173305]}, 
         InsetBox["5907", 
          Offset[{2, 2}, {3.4254756280783356, 2.630774387736057}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[79, 99], 0.797979797979798]], 
          DiskBox[{3.45525438996884, 3.4962917917429888}, 
           0.04613222458173305]}, 
         InsetBox["8287", 
          Offset[{2, 2}, {3.501386614550573, 3.5424240163247216}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[515, 792], 0.6502525252525253]], 
          DiskBox[{2.5685744740055436, 1.8401913432642338}, 
           0.04613222458173305]}, 
         InsetBox["7435", 
          Offset[{2, 2}, {2.614706698587277, 1.8863235678459669}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[379, 396], 0.9570707070707071]], 
          DiskBox[{3.5864386897916134, 0.980445959155053}, 
           0.04613222458173305]}, 
         InsetBox["9644", 
          Offset[{2, 2}, {3.6325709143733462, 1.026578183736786}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[221, 396], 0.5580808080808081]], 
          DiskBox[{2.585696215956411, 1.658399454495948}, 
           0.04613222458173305]}, 
         InsetBox["4250", 
          Offset[{2, 2}, {2.6318284405381442, 1.704531679077681}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[217, 264], 0.821969696969697]], 
          DiskBox[{3.347015178474344, 0.40544960787627726}, 
           0.04613222458173305]}, 
         InsetBox["1250", 
          Offset[{2, 2}, {3.3931474030560773, 0.4515818324580103}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[4, 11], 0.36363636363636365`]], 
          DiskBox[{3.6703336327530085, 1.5004101977543813}, 
           0.04613222458173305]}, 
         InsetBox["5178", 
          Offset[{2, 2}, {3.7164658573347413, 1.5465424223361144}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[7, 9], 0.7777777777777778]], 
          DiskBox[{3.3394005380211054, 1.609620989452162}, 
           0.04613222458173305]}, 
         InsetBox["6905", 
          Offset[{2, 2}, {3.385532762602838, 1.655753214033895}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[349, 396], 0.8813131313131313]], 
          DiskBox[{2.112473722118936, 0.8539517047491889}, 
           0.04613222458173305]}, 
         InsetBox["6991", 
          Offset[{2, 2}, {2.1586059467006686, 0.900083929330922}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[673, 792], 0.8497474747474747]], 
          DiskBox[{4.63231858334224, 1.983521196973392}, 
           0.04613222458173305]}, 
         InsetBox["898", 
          Offset[{2, 2}, {4.678450807923973, 2.0296534215551247}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[179, 264], 0.678030303030303]], 
          DiskBox[{3.759174995105831, 2.2840938139276425}, 
           0.04613222458173305]}, 
         InsetBox["607", 
          Offset[{2, 2}, {3.805307219687564, 2.330226038509376}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[679, 792], 0.8573232323232324]], 
          DiskBox[{2.836715116896876, 4.261515481506546}, 
           0.04613222458173305]}, 
         InsetBox["3860", 
          Offset[{2, 2}, {2.882847341478609, 4.307647706088279}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[673, 792], 0.8497474747474747]], 
          DiskBox[{4.491057658880921, 0.31976611457832105}, 
           0.04613222458173305]}, 
         InsetBox["3780", 
          Offset[{2, 2}, {4.537189883462654, 0.3658983391600541}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[703, 792], 0.8876262626262627]], 
          DiskBox[{3.0426305943570555, 0.9051199326861772}, 
           0.04613222458173305]}, 
         InsetBox["1615", 
          Offset[{2, 2}, {3.088762818938789, 0.9512521572679102}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[709, 792], 0.8952020202020202]], 
          DiskBox[{2.5203984401941004, 0.6457731327543823}, 
           0.04613222458173305]}, 
         InsetBox["7664", 
          Offset[{2, 2}, {2.5665306647758337, 0.6919053573361154}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[53, 66], 0.803030303030303]], 
          DiskBox[{5.128411413460875, 2.854944905050802}, 
           0.04613222458173305]}, 
         InsetBox["1542", 
          Offset[{2, 2}, {5.174543638042608, 2.901077129632535}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[181, 198], 0.9141414141414141]], 
          DiskBox[{1.4996647605008138, 2.6510293887008882}, 
           0.04613222458173305]}, 
         InsetBox["8052", 
          Offset[{2, 2}, {1.5457969850825468, 2.6971616132826215}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[95, 99], 0.9595959595959596]], 
          DiskBox[{0.36357940639081177, 2.9505580679121683}, 
           0.04613222458173305]}, 
         InsetBox["1610", 
          Offset[{2, 2}, {0.4097116309725448, 2.996690292493901}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[685, 792], 0.86489898989899]], 
          DiskBox[{2.233601453834779, 2.477600962050863}, 
           0.04613222458173305]}, 
         InsetBox["9878", 
          Offset[{2, 2}, {2.2797336784165116, 2.5237331866325965}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[94, 99], 0.9494949494949495]], 
          DiskBox[{1.1375417734724396, 4.3707162341673715}, 
           0.04613222458173305]}, 
         InsetBox["1129", 
          Offset[{2, 2}, {1.1836739980541726, 4.416848458749104}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[259, 264], 0.9810606060606061]], 
          DiskBox[{3.0349669471631047, 0.}, 0.04613222458173305]}, 
         InsetBox["4707", 
          Offset[{2, 2}, {3.081099171744838, 0.04613222458173305}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[85, 88], 0.9659090909090909]], 
          DiskBox[{4.908081274609965, 1.4698547520268581}, 
           0.04613222458173305]}, 
         InsetBox["555", 
          Offset[{2, 2}, {4.954213499191698, 1.5159869766085912}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[761, 792], 0.9608585858585859]], 
          DiskBox[{1.6747131364417198, 0.44856441237844735}, 
           0.04613222458173305]}, 
         InsetBox["999", 
          Offset[{2, 2}, {1.7208453610234529, 0.4946966369601804}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[257, 264], 0.9734848484848485]], 
          DiskBox[{5.555250167303243, 3.2298827071259577}, 
           0.04613222458173305]}, 
         InsetBox["4429", 
          Offset[{2, 2}, {5.601382391884976, 3.2760149317076905}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[775, 792], 0.9785353535353535]], 
          DiskBox[{4.854317571361642, 0.6858425063347129}, 
           0.04613222458173305]}, 
         InsetBox["4405", 
          Offset[{2, 2}, {4.900449795943375, 0.7319747309164459}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           NCache[
            Rational[391, 396], 0.9873737373737373]], 
          DiskBox[{0.6267174418687622, 3.3298729397918203}, 
           0.04613222458173305]}, 
         InsetBox["149", 
          Offset[{2, 2}, {0.6728496664504953, 3.376005164373553}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.7505244011606627`*^9, 3.750524422053951*^9}, 
   3.7505246158879757`*^9, 3.7507006472444844`*^9, 3.7507020136371565`*^9, 
   3.7507030418505993`*^9, 3.7512460315690527`*^9, 3.7512461302488775`*^9, 
   3.7512463400599213`*^9, 3.7512843629861794`*^9, 3.751299691870532*^9, 
   3.751300726587773*^9, 3.753705830778249*^9, 3.7542674764472322`*^9, 
   3.754695134824976*^9, 3.754776280606584*^9, 3.7547776422330294`*^9, 
   3.7574372632408113`*^9, 3.757515110863741*^9, 3.7575923239628897`*^9, 
   3.7575934246428576`*^9, 3.7575938136801867`*^9, 3.7575944068381653`*^9, 
   3.7575949055991783`*^9, 3.757595513541356*^9, 3.757596042821663*^9, 
   3.7576331509508104`*^9, 3.757634353835376*^9, 3.757634837407942*^9, 
   3.7576351663809094`*^9, 3.8303407706485386`*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"39eb052c-861f-44ea-8bc9-9c124bfc2bb5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"broken", "=", 
  RowBox[{"Complement", "[", 
   RowBox[{
    RowBox[{"EdgeList", "[", "graph", "]"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"EdgeList", "[", "exp1", "]"}], ",", 
      RowBox[{"EdgeList", "[", "exp2", "]"}]}], "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "bonds", " ", "that", " ", "broke", " ", "during", " ", "fission"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.750700031147353*^9, 3.750700070296363*^9}, {
   3.7507001034427614`*^9, 3.750700107265873*^9}, {3.7507005132145367`*^9, 
   3.750700531385273*^9}, 3.7575923085055094`*^9, 3.757633102094254*^9, 
   3.757634340195679*^9, 3.7576348265374413`*^9, 3.757635158925519*^9, {
   3.8302457422305307`*^9, 3.8302457470994625`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"31bb6346-c66e-4167-8773-54537b6f13c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"555", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "1403"}], ",", 
   RowBox[{"999", "\[UndirectedEdge]", "4250"}], ",", 
   RowBox[{"1146", "\[UndirectedEdge]", "1452"}], ",", 
   RowBox[{"1146", "\[UndirectedEdge]", "4250"}], ",", 
   RowBox[{"1146", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"1146", "\[UndirectedEdge]", "7319"}], ",", 
   RowBox[{"1146", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"1403", "\[UndirectedEdge]", "3480"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "7664"}], ",", 
   RowBox[{"1610", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"3780", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "8052"}], ",", 
   RowBox[{"4405", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "5279"}], ",", 
   RowBox[{"5273", "\[UndirectedEdge]", "8052"}], ",", 
   RowBox[{"5279", "\[UndirectedEdge]", "9019"}], ",", 
   RowBox[{"7319", "\[UndirectedEdge]", "8052"}], ",", 
   RowBox[{"7435", "\[UndirectedEdge]", "7664"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7507000509468594`*^9, 3.7507000708998623`*^9}, 
   3.75070010894396*^9, 3.7507020136778803`*^9, 3.750703041869955*^9, 
   3.751246031600295*^9, 3.7512461302728376`*^9, 3.7512463400895786`*^9, 
   3.7512843630364084`*^9, 3.751299691908293*^9, 3.751300726634637*^9, 
   3.7537058308083425`*^9, 3.7542674765021296`*^9, 3.754695134847103*^9, 
   3.7547762806580715`*^9, 3.754777642276121*^9, 3.757437263274801*^9, 
   3.7575151109451256`*^9, 3.7575923240307775`*^9, 3.757593426974121*^9, 
   3.75759381573067*^9, 3.7575944090385857`*^9, 3.757594907333145*^9, 
   3.757595515275367*^9, 3.7575960445400066`*^9, 3.75763315100118*^9, 
   3.757634353875064*^9, 3.7576348374422026`*^9, 3.757635166420407*^9, 
   3.830340772467568*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"ebe28d61-916c-4d7f-9ed9-683f4af4e503"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"maintained", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"EdgeList", "[", "exp1", "]"}], ",", 
    RowBox[{"EdgeList", "[", "exp2", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "bonds", " ", "that", " ", "were", " ", "maintained", " ", "through", " ", 
    "fission"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7507001139426684`*^9, 3.750700126825451*^9}, {
  3.750700534046118*^9, 3.750700543664417*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"2eb12b2a-04c0-4548-85b6-1f6cd221c1ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"743", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"6952", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "1652"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "1652"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "4250"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"5178", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"5178", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"7435", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"5178", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"6952", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"5273", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "5273"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "5273"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "7319"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "7319"}], ",", 
   RowBox[{"5273", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"7319", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"607", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"607", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"607", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"607", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"607", "\[UndirectedEdge]", "1652"}], ",", 
   RowBox[{"607", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"5907", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "5907"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "5907"}], ",", 
   RowBox[{"5907", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"5907", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"5907", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"2217", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "2217"}], ",", 
   RowBox[{"2217", "\[UndirectedEdge]", "5907"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "4707"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "4205"}], ",", 
   RowBox[{"4205", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "4205"}], ",", 
   RowBox[{"149", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"5178", "\[UndirectedEdge]", "6905"}], ",", 
   RowBox[{"5885", "\[UndirectedEdge]", "6905"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "6905"}], ",", 
   RowBox[{"6905", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "6905"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"7319", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"5885", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"4494", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "4494"}], ",", 
   RowBox[{"4494", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"4494", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"4494", "\[UndirectedEdge]", "7319"}], ",", 
   RowBox[{"4494", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"1929", "\[UndirectedEdge]", "4972"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "1929"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "1929"}], ",", 
   RowBox[{"1929", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"1929", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"1929", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"2101", "\[UndirectedEdge]", "5273"}], ",", 
   RowBox[{"2101", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"6952", "\[UndirectedEdge]", "9644"}], ",", 
   RowBox[{"4250", "\[UndirectedEdge]", "9644"}], ",", 
   RowBox[{"488", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"488", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "3480"}], ",", 
   RowBox[{"1250", "\[UndirectedEdge]", "5178"}], ",", 
   RowBox[{"488", "\[UndirectedEdge]", "1250"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "7324"}], ",", 
   RowBox[{"5907", "\[UndirectedEdge]", "8287"}], ",", 
   RowBox[{"1652", "\[UndirectedEdge]", "8287"}], ",", 
   RowBox[{"1452", "\[UndirectedEdge]", "6991"}], ",", 
   RowBox[{"6991", "\[UndirectedEdge]", "7435"}], ",", 
   RowBox[{"4880", "\[UndirectedEdge]", "4972"}], ",", 
   RowBox[{"898", "\[UndirectedEdge]", "6952"}], ",", 
   RowBox[{"607", "\[UndirectedEdge]", "898"}], ",", 
   RowBox[{"1615", "\[UndirectedEdge]", "8012"}], ",", 
   RowBox[{"1615", "\[UndirectedEdge]", "4250"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "1542"}], ",", 
   RowBox[{"1542", "\[UndirectedEdge]", "4205"}], ",", 
   RowBox[{"1129", "\[UndirectedEdge]", "5273"}], ",", 
   RowBox[{"743", "\[UndirectedEdge]", "4429"}], ",", 
   RowBox[{"2217", "\[UndirectedEdge]", "5885"}], ",", 
   RowBox[{"5273", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "5273"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "7319"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "7319"}], ",", 
   RowBox[{"5273", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"7319", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "9019"}], ",", 
   RowBox[{"8011", "\[UndirectedEdge]", "9019"}], ",", 
   RowBox[{"3860", "\[UndirectedEdge]", "6809"}], ",", 
   RowBox[{"149", "\[UndirectedEdge]", "8011"}], ",", 
   RowBox[{"7319", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"5885", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"6809", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "9878"}], ",", 
   RowBox[{"7324", "\[UndirectedEdge]", "9019"}], ",", 
   RowBox[{"4972", "\[UndirectedEdge]", "7324"}], ",", 
   RowBox[{"4880", "\[UndirectedEdge]", "4972"}], ",", 
   RowBox[{"1129", "\[UndirectedEdge]", "5273"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7507001281499543`*^9, 3.7507020136985197`*^9, 
  3.750703041887727*^9, 3.751246031617335*^9, 3.7512461302917256`*^9, 
  3.7512463401103115`*^9, 3.751284363069033*^9, 3.751299691955157*^9, 
  3.751300726672392*^9, 3.7537058308399253`*^9, 3.7542674765389676`*^9, 
  3.7546951348783503`*^9, 3.754776280692151*^9, 3.7547776423032274`*^9, 
  3.757437263304467*^9, 3.7575151109718094`*^9, 3.7575923241078153`*^9, 
  3.757593429563835*^9, 3.7575938179862456`*^9, 3.757594411271554*^9, 
  3.7575949090303173`*^9, 3.757595517056155*^9, 3.7575960462427464`*^9, 
  3.7576331510488014`*^9, 3.7576343539262104`*^9, 3.7576348374785123`*^9, 
  3.7576351664446826`*^9, 3.8303407736076083`*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"233d009d-51bf-4d4a-ac0c-3419a37ce1b3"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"actualbroken", "=", "broken"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"actualmaintained", "=", "maintained"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7507016431940413`*^9, 3.7507016581102943`*^9}},
 CellLabel->
  "In[728]:=",ExpressionUUID->"e992dc43-7f38-458e-803a-b34d01bcefbb"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Run Despotism", "Section",
 CellChangeTimes->{{3.7512453534950676`*^9, 3.751245355342357*^9}, {
  3.83024576709344*^9, 
  3.8302457675622673`*^9}},ExpressionUUID->"e165b4b9-8009-4bf8-8277-\
6bd66594e701"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dynamic", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.7547762877446065`*^9, 3.7547762893008337`*^9}},
 CellLabel->
  "In[730]:=",ExpressionUUID->"4fe2a4ec-c75a-4f61-9101-2735e3c89b10"],

Cell[BoxData[
 DynamicBox[ToBoxes[$CellContext`t, StandardForm],
  ImageSizeCache->{7., {0., 8.}}]], "Output",
 CellChangeTimes->{3.7547762904688787`*^9, 3.7547776452991433`*^9, 
  3.7575157122511396`*^9, 3.7575923267837615`*^9, 3.757593457700678*^9, 
  3.7575938442517977`*^9, 3.757594436715626*^9, 3.75759492961957*^9, 
  3.7575953843383493`*^9, 3.757595538490164*^9, 3.757596199720706*^9, 
  3.757633154126264*^9, 3.757634354892557*^9, 3.7576348382765656`*^9, 
  3.757635167121215*^9},
 CellLabel->
  "Out[730]=",ExpressionUUID->"3b975aa7-608b-46e9-84a0-184752921bbb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"despotalg", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Clear", "[", 
       RowBox[{
       "list0", ",", "list1", ",", "list2", ",", "list3", ",", "list4", ",", 
        "list5", ",", "list6", ",", "list7", ",", "list8", ",", "list9", ",", 
        "list10", ",", "list11", ",", "list12", ",", "list13", ",", "list14", 
        ",", "list15"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"despot", "=", 
       RowBox[{
        RowBox[{"TakeLargestBy", "[", 
         RowBox[{"deg", ",", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "&"}], ",", "1"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"identify", " ", "despot"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"n1", "=", 
       RowBox[{"{", 
        RowBox[{"despot", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"list0", "=", "n1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"unweighted", "=", 
       RowBox[{"Graph", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"strongbonds", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1", ",", "1"}], "]"}], "]"}], "\[TwoWayRule]", 
           RowBox[{"strongbonds", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1", ",", "2"}], "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "strongbonds", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "create", " ", "graph", " ", "with", " ", "unweighted", " ", "edges"}],
        " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"rescaled", "=", 
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Riffle", "[", 
          RowBox[{
           RowBox[{"strongbonds", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"strongbonds", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
             RowBox[{"Max", "[", 
              RowBox[{"Log", "[", 
               RowBox[{"strongbonds", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}]}], 
            "]"}]}], "]"}], ",", "2"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"log", " ", "transform", " ", "edge", " ", "weights"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"count", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"ConnectedGraphQ", "[", "unweighted", "]"}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
         "loop", " ", "as", " ", "long", " ", "as", " ", "unweighted", " ", 
          "graph", " ", "connected"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"paths", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"FindPath", "[", 
               RowBox[{"unweighted", ",", 
                RowBox[{"despot", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"Complement", "[", 
                  RowBox[{
                   RowBox[{"VertexList", "[", "unweighted", "]"}], ",", 
                   "n1"}], "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"{", "count", "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", 
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"VertexList", "[", "unweighted", "]"}], ",", 
                    "n1"}], "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}],
            "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "identify", " ", "individuals", " ", "distance", " ", "count", " ", 
           "from", " ", "despot"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"paths", "\[Equal]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"pathweights", "=", 
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Riffle", "[", 
             RowBox[{"paths", ",", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Product", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Select", "[", 
                    RowBox[{"rescaled", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"paths", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"paths", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}]}], ")"}], 
                    "\[Or]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"paths", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"paths", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ")"}]}], 
                    "&"}]}], "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"j", ",", "count"}], "}"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "paths", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}]}],
              "]"}], ",", "2"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "path", " ", "weights", " ", "from", " ", "despots", " ", "and", 
           " ", "connected", " ", "individuals"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"prob", "=", "pathweights"}], ";", "\[IndentingNewLine]", 
         RowBox[{"n1", "=", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"Join", "[", 
              RowBox[{"n1", ",", 
               RowBox[{"Flatten", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"RandomVariate", "[", 
                    RowBox[{"BinomialDistribution", "[", 
                    RowBox[{"1", ",", 
                    RowBox[{"prob", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
                   "*", 
                   RowBox[{"prob", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "prob", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}]}],
               "]"}], "]"}], ",", "0"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{"break", " ", "bonds"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{"Symbol", "[", 
            RowBox[{"\"\<list\>\"", "<>", 
             RowBox[{"ToString", "[", "count", "]"}]}], "]"}], "]"}], "=", 
          "n1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"unweighted", "=", 
          RowBox[{"Graph", "[", 
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"EdgeList", "[", "unweighted", "]"}], ",", 
             RowBox[{"Flatten", "[", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "unweighted", "]"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "name1"}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "name2"}]}], 
                    ")"}], "\[Or]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "name2"}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "name1"}]}], 
                    ")"}]}], "&"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"name1", ",", 
                  RowBox[{"Evaluate", "[", 
                   RowBox[{"Symbol", "[", 
                    RowBox[{"\"\<list\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"count", "-", "1"}], "]"}]}], "]"}], "]"}]}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"name2", ",", 
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"prob", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Symbol", "[", 
                    RowBox[{"\"\<list\>\"", "<>", 
                    RowBox[{"ToString", "[", "count", "]"}]}], "]"}], "]"}]}],
                    "]"}]}], "}"}]}], "]"}], "]"}]}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"rescaled", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Select", "[", 
               RowBox[{"rescaled", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "==", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"EdgeList", "[", "unweighted", "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"EdgeList", "[", "unweighted", "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}],
                "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", 
                  RowBox[{"EdgeList", "[", "unweighted", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}],
            "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "generate", " ", "new", " ", "unweighted", " ", "graph", " ", "and",
            " ", "rescale"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"count", "=", 
          RowBox[{"count", "+", "1"}]}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{
         RowBox[{"VertexList", "[", "g", "]"}], ",", "n1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"fission1", "=", 
       RowBox[{"Subgraph", "[", 
        RowBox[{"g", ",", "n1"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"fission2", "=", 
       RowBox[{"Subgraph", "[", 
        RowBox[{"g", ",", "n2"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"strongbonds1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission1", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"strongbonds2", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n1", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"VertexList", "[", "fission1", "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"vector", " ", "of", " ", "individuals"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"VertexList", "[", "fission2", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"deg1", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n1", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds1", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"deg2", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n2", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds2", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"degree", " ", "of", " ", "each", " ", "individual"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"predictions", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"correct", "=", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Tally", "[", 
           RowBox[{"Join", "[", 
            RowBox[{"predictions", ",", "dyads"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"broken", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "g", "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
           RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"maintained", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
         RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg1", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg2", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg1", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg2", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", "\n", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission1", "]"}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission2", "]"}], 
           "]"}], ",", " ", "\n", 
          RowBox[{"GraphDiameter", "[", "fission1", "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"GraphDiameter", "[", "fission2", "]"}], ",", "\n", 
          RowBox[{"N", "[", 
           RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{"up", " ", "from", " ", "about", " ", "0.1"}], " ", "*)"}],
           "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "correct", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dyads", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "broken", " ", "bonds"}], " ", "*)"}],
           ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "maintained", " ", "bonds"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "%", " ", "of", " ", "bonds", " ", "that", " ", "were", " ", 
            "broken"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "broken", " ", 
            "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "broken", " ", "bond"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "maintained", 
            " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "maintained", " ", 
            "bond"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Select", "[", 
                   RowBox[{"strongbonds", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                "1"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{"Min", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission2", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}], " ", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "broken", " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "maintained", " ", "bonds"}], " ", "*)"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualbroken", ",", 
                   RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualbroken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "broken", " ", "bonds", " ", "correct"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualmaintained", ",", 
                   RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualmaintained", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "maintained", " ", "bonds", " ", "correct"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualbroken", ",", 
                    RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualmaintained", ",", 
                    RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"EdgeList", "[", "g", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], 
         RowBox[{"(*", " ", 
          RowBox[{"%", " ", "total", " ", "bonds", " ", "correct"}], " ", 
          "*)"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "100"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.754772687334463*^9, 3.7547727864678893`*^9}, {
   3.7547728485971127`*^9, 3.7547728720445566`*^9}, {3.754772922563967*^9, 
   3.754772980300437*^9}, {3.754773027968115*^9, 3.754773071598239*^9}, {
   3.754773126621607*^9, 3.7547731397441397`*^9}, {3.75477328063094*^9, 
   3.75477329761133*^9}, {3.75477333865178*^9, 3.75477335255693*^9}, 
   3.7547734986939306`*^9, {3.754773726034716*^9, 3.7547738451781693`*^9}, {
   3.754773898243473*^9, 3.7547739048796844`*^9}, {3.754774124818194*^9, 
   3.7547741341280575`*^9}, {3.7547742101326084`*^9, 
   3.7547742237544155`*^9}, {3.7547760751895475`*^9, 3.754776130883393*^9}, {
   3.754776232392015*^9, 3.754776244477132*^9}, 3.7547763751661344`*^9, {
   3.7547764464338646`*^9, 3.7547764626176534`*^9}, {3.7547764942928023`*^9, 
   3.7547764967189636`*^9}, {3.7547774123336496`*^9, 3.7547774130613093`*^9}, 
   3.7575157161402254`*^9, 3.757515789055056*^9, 3.7575923085484333`*^9, {
   3.757633102335453*^9, 3.7576331333586273`*^9}, 3.7576333090314407`*^9, {
   3.7576335270914516`*^9, 3.7576335308231597`*^9}, 3.7576337802046165`*^9, 
   3.7576343851839733`*^9, {3.8302468334622817`*^9, 3.8302468662694087`*^9}, {
   3.83024698811152*^9, 3.830247064331521*^9}, {3.8400926698687525`*^9, 
   3.8400926805508823`*^9}},ExpressionUUID->"b9ad3b0c-ae8d-47b1-9bf9-\
8c309fe66f8e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Mean", "[", "despotalg", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7512463893332653`*^9, 3.7512464005372324`*^9}},
 CellLabel->
  "In[734]:=",ExpressionUUID->"e6a6ca04-563b-402d-8780-3cfb368b3991"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "13.56`", ",", "19.44`", ",", "622.3`", ",", "782.8`", ",", 
     "45.24221950310798`", ",", "39.284331670244924`", ",", 
     "0.10025767842778244`", ",", "0.23549724560837204`", ",", "4.82`", ",", 
     "\[Infinity]", ",", "0.192814158380419`", ",", "0.11275038839903559`", 
     ",", "0.5055048859934854`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "16.05`", ",", "35.95`", ",", "0.3086538461538461`", ",", "277.45`", ",", 
     "17.302628008612512`", ",", "702.55`", ",", "19.562709395285687`", ",", 
     "16.320588235294117`", ",", "72.0085298855883`", ",", 
     "66.40503559096437`", ",", "0.33`", ",", "0.7026470588235294`", ",", 
     "0.5736538461538462`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7512463941085825`*^9, 3.7512464009687185`*^9}, 
   3.751246599667339*^9, 3.754777892878578*^9, 3.7575939173899794`*^9, 
   3.7575945106964645`*^9, 3.75759497118882*^9, 3.7575955786845884`*^9, 
   3.7575962414539695`*^9, 3.757633794360078*^9, 3.7576344045674934`*^9, 
   3.7576349219371333`*^9, 3.757635186981221*^9},
 CellLabel->
  "Out[734]=",ExpressionUUID->"15974e90-f8d5-455a-ac1c-a2bd47cc4fe0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Run Community", "Section",
 CellChangeTimes->{{3.751284221757312*^9, 3.751284226807846*^9}, {
  3.8302457936680765`*^9, 
  3.830245801072069*^9}},ExpressionUUID->"dfc705b5-09bb-45a8-af9d-\
bc354663bbb5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"comm", "=", 
  RowBox[{"FindGraphCommunities", "[", 
   RowBox[{"g", ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Centrality\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.746447462845849*^9, 3.7464474734645996`*^9}, {
  3.7486028954951468`*^9, 3.7486028970974827`*^9}, {3.7512846483418136`*^9, 
  3.7512846633781204`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"54c21042-76b5-48df-8bba-2130d5d8fd05"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "4494", ",", "6952", ",", "1452", ",", "1929", ",", "7435", ",", "6991", 
     ",", "898", ",", "607", ",", "7664"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "7319", ",", "8011", ",", "4972", ",", "7324", ",", "9019", ",", "5279", 
     ",", "4880", ",", "1610", ",", "9878"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "5885", ",", "2217", ",", "488", ",", "1250", ",", "5178", ",", "6905", 
     ",", "3780"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1146", ",", "8012", ",", "4250", ",", "1615", ",", "8052", ",", "999"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "743", ",", "1403", ",", "4205", ",", "3480", ",", "1542", ",", "4429"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6809", ",", "5273", ",", "3860", ",", "1129"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1652", ",", "5907", ",", "8287"}], "}"}], ",", 
   RowBox[{"{", "2101", "}"}], ",", 
   RowBox[{"{", "9644", "}"}], ",", 
   RowBox[{"{", "4707", "}"}], ",", 
   RowBox[{"{", "555", "}"}], ",", 
   RowBox[{"{", "4405", "}"}], ",", 
   RowBox[{"{", "149", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7464474740433197`*^9, 3.7486028975294194`*^9, 3.749466237782589*^9, 
   3.749466284053878*^9, 3.749833134111762*^9, 3.749833929856673*^9, {
   3.74983401603623*^9, 3.749834038054921*^9}, 3.7512015612441387`*^9, 
   3.7512216310604134`*^9, 3.7512844115074625`*^9, 3.7512846884238963`*^9, 
   3.7512850042217555`*^9, 3.751285281985224*^9, 3.751286230293198*^9, 
   3.757516084784504*^9, 3.757593976801529*^9, 3.7575945699711695`*^9, 
   3.7575947641568193`*^9, 3.7575950202346*^9, 3.7575956272614145`*^9, 
   3.7575962910452194`*^9, 3.757634176156885*^9, 3.75763446537195*^9, 
   3.757634923458227*^9, 3.757635188282241*^9, 3.8303407802478437`*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"e1c08c65-62f8-4da1-8c47-f44f65e61044"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dynamic", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.751245954352275*^9, 3.7512459621327105`*^9}, 
   3.751246077544595*^9, 3.751246151910637*^9},
 CellLabel->
  "In[768]:=",ExpressionUUID->"7a52d858-d41f-4d67-a659-58e1ef82a8a8"],

Cell[BoxData[
 DynamicBox[ToBoxes[$CellContext`t, StandardForm],
  ImageSizeCache->{7., {0., 8.}}]], "Output",
 CellChangeTimes->{3.751284412832016*^9, 3.751284688521225*^9, 
  3.7512850042426662`*^9, 3.7512852827756977`*^9, 3.7575160860968275`*^9, 
  3.757593979055188*^9, 3.7575945720180492`*^9, 3.7575947661630387`*^9, 
  3.757595021952945*^9, 3.75759562898582*^9, 3.7575962928416348`*^9, 
  3.757634176276883*^9, 3.7576344654851694`*^9, 3.7576349234943924`*^9, 
  3.7576351883061457`*^9},
 CellLabel->
  "Out[768]=",ExpressionUUID->"ef2bce41-cc15-4ac7-8885-bba9a5690e00"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"centralalg", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"n1", "=", 
       RowBox[{"{", 
        RowBox[{"RandomChoice", "[", "comm", "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"{", 
        RowBox[{"RandomChoice", "[", 
         RowBox[{"Complement", "[", 
          RowBox[{"comm", ",", "n1"}], "]"}], "]"}], "}"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"select", " ", "starting", " ", "communities"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"While", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Complement", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", "comm", "]"}], ",", 
           RowBox[{"Flatten", "[", "n1", "]"}], ",", 
           RowBox[{"Flatten", "[", "n2", "]"}]}], "]"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "loop", " ", "until", " ", "all", " ", "communities", " ", 
          "assigned"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"new", "=", 
          RowBox[{"RandomChoice", "[", 
           RowBox[{"Complement", "[", 
            RowBox[{"comm", ",", "n1", ",", "n2"}], "]"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "randomly", " ", "choose", " ", "new", " ", "focal", " ", 
           "community"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"pref1", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Select", "[", 
                RowBox[{"strongbonds", ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
                   RowBox[{"Sort", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"new", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "n1", "]"}], "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}], "&"}]}],
                 "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", 
                   RowBox[{"Flatten", "[", "n1", "]"}], "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "new", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
            ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"pref2", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Select", "[", 
                RowBox[{"strongbonds", ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
                   RowBox[{"Sort", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"new", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "n2", "]"}], "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}], "&"}]}],
                 "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", 
                   RowBox[{"Flatten", "[", "n2", "]"}], "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "new", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
            ",", "2"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "select", " ", "bonds", " ", "from", " ", "focal", " ", "to", " ", 
           "2", " ", "DGs"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"Which", "[", 
          RowBox[{"(*", " ", 
           RowBox[{
           "choose", " ", "new", " ", "DG", " ", "based", " ", "on", " ", 
            "average", " ", "bond", " ", "strengths"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"pref1", "==", 
             RowBox[{"{", "}"}]}], "&&", 
            RowBox[{"pref2", "==", 
             RowBox[{"{", "}"}]}]}], ",", "Null", ",", "\[IndentingNewLine]", 
           RowBox[{"pref1", "==", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"n2", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n2", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"pref2", "==", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"n1", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n1", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref1", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"Flatten", "[", "n1", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ">", 
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref2", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"Flatten", "[", "n2", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], ",", 
           RowBox[{"n1", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n1", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref1", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"Flatten", "[", "n1", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "<", 
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref2", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", 
               RowBox[{"Flatten", "[", "n2", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], ",", 
           RowBox[{"n2", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n2", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}]}], "]"}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"n1", "=", 
       RowBox[{"Flatten", "[", "n1", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"Flatten", "[", "n2", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[GreaterEqual]", 
         RowBox[{
          RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"fission1", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n1"}], "]"}]}], ";", 
         RowBox[{"fission2", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n2"}], "]"}]}], ";"}], ",", 
        RowBox[{
         RowBox[{"fission1", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n2"}], "]"}]}], ";", 
         RowBox[{"fission2", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n1"}], "]"}]}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"strongbonds1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission1", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"strongbonds2", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n1", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"VertexList", "[", "fission1", "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"vector", " ", "of", " ", "individuals"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"VertexList", "[", "fission2", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"deg1", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n1", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds1", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"deg2", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n2", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds2", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"degree", " ", "of", " ", "each", " ", "individual"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"predictions", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"correct", "=", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Tally", "[", 
           RowBox[{"Join", "[", 
            RowBox[{"predictions", ",", "dyads"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"broken", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "g", "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
           RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"maintained", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
         RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg1", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg2", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg1", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg2", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", "\n", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission1", "]"}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission2", "]"}], 
           "]"}], ",", " ", "\n", 
          RowBox[{"GraphDiameter", "[", "fission1", "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"GraphDiameter", "[", "fission2", "]"}], ",", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"NumericQ", "[", 
             RowBox[{"N", "[", 
              RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], "]"}], 
            ",", 
            RowBox[{"N", "[", 
             RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], ",", 
            "0"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"NumericQ", "[", 
             RowBox[{"N", "[", 
              RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}], "]"}], 
            ",", 
            RowBox[{"N", "[", 
             RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}], ",", 
            "0"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "correct", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dyads", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "broken", " ", "bonds"}], " ", "*)"}],
           ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "maintained", " ", "bonds"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "%", " ", "of", " ", "bonds", " ", "that", " ", "were", " ", 
            "broken"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "broken", " ", 
            "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "broken", " ", "bond"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "maintained", 
            " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "maintained", " ", 
            "bond"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Select", "[", 
                   RowBox[{"strongbonds", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                "1"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{"Min", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission2", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}], " ", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "broken", " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "maintained", " ", "bonds"}], " ", "*)"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualbroken", ",", 
                   RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualbroken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "broken", " ", "bonds", " ", "correct"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualmaintained", ",", 
                   RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualmaintained", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "maintained", " ", "bonds", " ", "correct"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualbroken", ",", 
                    RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualmaintained", ",", 
                    RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"EdgeList", "[", "g", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], 
         RowBox[{"(*", " ", 
          RowBox[{"%", " ", "total", " ", "bonds", " ", "correct"}], " ", 
          "*)"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "100"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.749836434800957*^9, 3.7498364854061866`*^9}, 
   3.7498365226378365`*^9, {3.7512016590848866`*^9, 3.7512016974543805`*^9}, {
   3.751201797684464*^9, 3.751201798884181*^9}, {3.7512018731716995`*^9, 
   3.751201882563041*^9}, {3.7512019436437473`*^9, 3.75120194754767*^9}, {
   3.75120207235962*^9, 3.7512020747778406`*^9}, {3.751202139735099*^9, 
   3.7512021906845584`*^9}, {3.7512022421936765`*^9, 
   3.7512022503210382`*^9}, {3.7512022925583267`*^9, 
   3.7512023177490206`*^9}, {3.7512023960045996`*^9, 3.751202399972433*^9}, {
   3.751202493993651*^9, 3.751202502147435*^9}, {3.751202564662486*^9, 
   3.751202574301344*^9}, {3.7512026317714777`*^9, 3.751202633583722*^9}, {
   3.751284275734757*^9, 3.7512842761265125`*^9}, {3.7512843132739964`*^9, 
   3.751284314775092*^9}, {3.751284440144575*^9, 3.7512844446406946`*^9}, {
   3.7512848733187213`*^9, 3.7512848892247047`*^9}, {3.7512849694927597`*^9, 
   3.751284970424701*^9}, {3.7512852392189693`*^9, 3.7512852764815693`*^9}, 
   3.7512853178894515`*^9, {3.7512860942705393`*^9, 3.751286097356593*^9}, 
   3.7575923085801167`*^9, 3.7575941992307577`*^9, {3.83024707759085*^9, 
   3.830247144588234*^9}, 
   3.8400927238832865`*^9},ExpressionUUID->"71bf6c7f-af36-4d94-bb83-\
11c5967f8c4e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Mean", "[", "centralalg", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7512463893332653`*^9, 3.7512464005372324`*^9}, 
   3.751284479542768*^9, 3.7512851697155905`*^9},
 CellLabel->
  "In[772]:=",ExpressionUUID->"d5551c11-5d40-4c4e-b47b-31c2c8d4f218"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "20.82`", ",", "12.18`", ",", "1152.82`", ",", "636.16`", ",", 
     "54.851685703547425`", ",", "48.23661538461538`", ",", 
     "0.17740156882026478`", ",", "0.21582080200501252`", ",", "6.96`", ",", 
     "5.55`", ",", "0.14300168947609884`", ",", "0.30324242424242426`", ",", 
     "0.5199348534201954`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "6.93`", ",", "45.07`", ",", "0.13326923076923078`", ",", "85.51`", ",", 
     "12.414424603174602`", ",", "894.49`", ",", "19.864080538040415`", ",", 
     "5.03`", ",", "103.54944444444445`", ",", "62.38068576118316`", ",", 
     "0.15444444444444444`", ",", "0.8779411764705882`", ",", "0.6275`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7512463941085825`*^9, 3.7512464009687185`*^9}, 
   3.751246599667339*^9, 3.7512851379989805`*^9, 3.7512851807920294`*^9, 
   3.7512854013445063`*^9, 3.751286380145834*^9, 3.757594020870908*^9, 
   3.7575946122187223`*^9, 3.757595045564274*^9, 3.7575956532703834`*^9, 
   3.7575963165577817`*^9, 3.7576341955007024`*^9, 3.757634476789467*^9, 
   3.757634962891785*^9, 3.7576352001327796`*^9},
 CellLabel->
  "Out[772]=",ExpressionUUID->"a3b9c43b-c896-44fe-ab81-afe720801eec"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Run Democracy", "Section",
 CellChangeTimes->{{3.7512856070324755`*^9, 3.751285608792121*^9}, {
  3.8302458078249607`*^9, 
  3.830245808309453*^9}},ExpressionUUID->"d8e85c89-59fb-4b0a-8c45-\
800904b40e25"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dynamic", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.751285903139934*^9, 3.751285905157492*^9}},
 CellLabel->
  "In[805]:=",ExpressionUUID->"61cbd62b-b9d2-4c9c-ba08-708770bde322"],

Cell[BoxData[
 DynamicBox[ToBoxes[$CellContext`t, StandardForm],
  ImageSizeCache->{7., {0., 8.}}]], "Output",
 CellChangeTimes->{3.7512859056143494`*^9, 3.7513007296994543`*^9, 
  3.7575940795476465`*^9, 3.7575942438021603`*^9, 3.7575946661092653`*^9, 
  3.7575950938866315`*^9, 3.7575957025999346`*^9, 3.7575963665543137`*^9, 
  3.7576341978217115`*^9, 3.7576344789369373`*^9, 3.7576349643169627`*^9, 
  3.7576352015234795`*^9},
 CellLabel->
  "Out[805]=",ExpressionUUID->"ec82b026-24ab-403d-aff3-5006018afd5e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"democalg", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"n1", "=", 
       RowBox[{"{", 
        RowBox[{"RandomChoice", "[", "n", "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"{", 
        RowBox[{"RandomChoice", "[", 
         RowBox[{"Complement", "[", 
          RowBox[{"n", ",", "n1"}], "]"}], "]"}], "}"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "randomly", " ", "choose", " ", "starting", " ", "individuals"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"While", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Complement", "[", 
          RowBox[{"n", ",", "n1", ",", "n2"}], "]"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
         "loop", " ", "until", " ", "all", " ", "individuals", " ", 
          "assigned"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"new", "=", 
          RowBox[{"RandomChoice", "[", 
           RowBox[{"Complement", "[", 
            RowBox[{"n", ",", "n1", ",", "n2"}], "]"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{"choose", " ", "focal", " ", "individual"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"pref1", "=", 
          RowBox[{"DeleteDuplicates", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{"strongbonds", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
                 RowBox[{"Sort", "[", 
                  RowBox[{"{", 
                   RowBox[{"new", ",", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}], "&"}]}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{
                RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"pref2", "=", 
          RowBox[{"DeleteDuplicates", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{"strongbonds", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
                 RowBox[{"Sort", "[", 
                  RowBox[{"{", 
                   RowBox[{"new", ",", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}], "&"}]}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{
                RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}]}], 
         ";", 
         RowBox[{"(*", " ", 
          RowBox[{"bonds", " ", "to", " ", "2", " ", "DGs"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"Which", "[", 
          RowBox[{"(*", " ", 
           RowBox[{
           "choose", " ", "group", " ", "with", " ", "stronger", " ", 
            "average", " ", "bond", " ", "weight"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"pref1", "==", 
             RowBox[{"{", 
              RowBox[{"{", "}"}], "}"}]}], "&&", 
            RowBox[{"pref2", "==", 
             RowBox[{"{", 
              RowBox[{"{", "}"}], "}"}]}]}], ",", "Null", ",", 
           "\[IndentingNewLine]", 
           RowBox[{"pref1", "==", 
            RowBox[{"{", 
             RowBox[{"{", "}"}], "}"}]}], ",", 
           RowBox[{"n2", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n2", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"pref2", "==", 
            RowBox[{"{", 
             RowBox[{"{", "}"}], "}"}]}], ",", 
           RowBox[{"n1", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n1", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref1", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], 
              "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ">", 
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref2", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], 
              "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], ",", 
           RowBox[{"n1", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n1", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref1", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], 
              "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "<", 
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"pref2", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], 
              "]"}], "/", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], ",", 
           RowBox[{"n2", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"n2", ",", 
              RowBox[{"{", "new", "}"}]}], "]"}]}]}], "]"}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[GreaterEqual]", 
         RowBox[{
          RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"fission1", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n1"}], "]"}]}], ";", 
         RowBox[{"fission2", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n2"}], "]"}]}], ";"}], ",", 
        RowBox[{
         RowBox[{"fission1", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n2"}], "]"}]}], ";", 
         RowBox[{"fission2", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n1"}], "]"}]}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"strongbonds1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission1", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"strongbonds2", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n1", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"VertexList", "[", "fission1", "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"vector", " ", "of", " ", "individuals"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"VertexList", "[", "fission2", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"deg1", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n1", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds1", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"deg2", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n2", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds2", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"degree", " ", "of", " ", "each", " ", "individual"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"predictions", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"correct", "=", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Tally", "[", 
           RowBox[{"Join", "[", 
            RowBox[{"predictions", ",", "dyads"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"broken", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "g", "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
           RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"maintained", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
         RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg1", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg2", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg1", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg2", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", "\n", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission1", "]"}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission2", "]"}], 
           "]"}], ",", " ", "\n", 
          RowBox[{"GraphDiameter", "[", "fission1", "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"GraphDiameter", "[", "fission2", "]"}], ",", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"NumericQ", "[", 
             RowBox[{"N", "[", 
              RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], "]"}], 
            ",", 
            RowBox[{"N", "[", 
             RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], ",", 
            "0"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"NumericQ", "[", 
             RowBox[{"N", "[", 
              RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}], "]"}], 
            ",", 
            RowBox[{"N", "[", 
             RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}], ",", 
            "0"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "correct", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dyads", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "broken", " ", "bonds"}], " ", "*)"}],
           ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "maintained", " ", "bonds"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "%", " ", "of", " ", "bonds", " ", "that", " ", "were", " ", 
            "broken"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "broken", " ", 
            "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "broken", " ", "bond"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "maintained", 
            " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "maintained", " ", 
            "bond"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Select", "[", 
                   RowBox[{"strongbonds", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                "1"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{"Min", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission2", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}], " ", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "broken", " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "maintained", " ", "bonds"}], " ", "*)"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualbroken", ",", 
                   RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualbroken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "broken", " ", "bonds", " ", "correct"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualmaintained", ",", 
                   RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualmaintained", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "maintained", " ", "bonds", " ", "correct"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualbroken", ",", 
                    RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualmaintained", ",", 
                    RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"EdgeList", "[", "g", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], 
         RowBox[{"(*", " ", 
          RowBox[{"%", " ", "total", " ", "bonds", " ", "correct"}], " ", 
          "*)"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "100"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.751285671131485*^9, 3.7512856929586596`*^9}, {
   3.7512860313708735`*^9, 3.7512860349547653`*^9}, 3.751300760384522*^9, 
   3.757592308614385*^9, 3.7575942325043135`*^9, {3.830247162515115*^9, 
   3.8302472034986353`*^9}, 
   3.8400927469535017`*^9},ExpressionUUID->"53fbeab8-6831-4ee5-bbf5-\
2bc8693b05bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Mean", "[", "democalg", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7512463893332653`*^9, 3.7512464005372324`*^9}, 
   3.751284479542768*^9, 3.7512850718513007`*^9, 3.751285420264636*^9, 
   3.7512857209181466`*^9},
 CellLabel->
  "In[809]:=",ExpressionUUID->"723d27ec-da8d-49f2-b921-14d30c9564ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "22.68`", ",", "10.32`", ",", "1246.36`", ",", "472.28`", ",", 
     "54.54326429981834`", ",", "42.40753077478078`", ",", 
     "0.19632449902259203`", ",", "0.18436073602800568`", ",", "6.78`", ",", 
     "4.82`", ",", "0.13431491419034175`", ",", "0.3223410755910756`", ",", 
     "0.5586319218241043`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "7.55`", ",", "44.45`", ",", "0.14519230769230768`", ",", "120.68`", ",", 
     "16.13784956709957`", ",", "859.32`", ",", "19.3516748037311`", ",", 
     "7.0988235294117645`", ",", "84.37039682539682`", ",", 
     "65.1785665783827`", ",", "0.14944444444444444`", ",", 
     "0.8570588235294118`", ",", "0.6121153846153846`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7512463941085825`*^9, 3.7512464009687185`*^9}, 
   3.751246599667339*^9, 3.751285867936698*^9, {3.7512860072952757`*^9, 
   3.7512860073767023`*^9}, 3.7512861431607385`*^9, 3.7575941071610594`*^9, 
   3.7575951189414115`*^9, 3.7575957267453804`*^9, 3.7575963908809905`*^9, 
   3.757634222084584*^9, 3.7576345305883846`*^9, 3.757635001908823*^9, 
   3.757635220753096*^9},
 CellLabel->
  "Out[809]=",ExpressionUUID->"adfb1d78-bc6e-43f5-91c8-11ed8fa2178f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Run Random", "Section",
 CellChangeTimes->{{3.7574368582031407`*^9, 3.7574368588312874`*^9}, {
  3.830245810004955*^9, 
  3.8302458104574485`*^9}},ExpressionUUID->"4e15b487-7246-411f-9cd9-\
c4396138481f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dynamic", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.7574372361235356`*^9, 3.757437237651436*^9}},
 CellLabel->
  "In[842]:=",ExpressionUUID->"eb80291f-2ea3-462e-9832-0468f30f44af"],

Cell[BoxData[
 DynamicBox[ToBoxes[$CellContext`t, StandardForm],
  ImageSizeCache->{7., {0., 8.}}]], "Output",
 CellChangeTimes->{3.7574372380201874`*^9, 3.757594160965356*^9, 
  3.7575951660074816`*^9, 3.757595775073722*^9, 3.757596438839326*^9, 
  3.757634224170822*^9, 3.7576345616530886`*^9, 3.757635003468094*^9, 
  3.757635223526148*^9},
 CellLabel->
  "Out[842]=",ExpressionUUID->"2a7c7afb-58f1-49cc-bc69-afb7e5dd2e3a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"randalg", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"randlist", "=", 
       RowBox[{"GatherBy", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"RandomChoice", "[", 
              RowBox[{"{", 
               RowBox[{"n1", ",", "n2"}], "}"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "&"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n1", "=", 
       RowBox[{"randlist", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "All", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n2", "=", 
       RowBox[{"randlist", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "All", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[GreaterEqual]", 
         RowBox[{
          RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"fission1", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n1"}], "]"}]}], ";", 
         RowBox[{"fission2", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n2"}], "]"}]}], ";"}], ",", 
        RowBox[{
         RowBox[{"fission1", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n2"}], "]"}]}], ";", 
         RowBox[{"fission2", "=", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"g", ",", "n1"}], "]"}]}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"strongbonds1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission1", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"strongbonds2", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"strongbonds", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
            "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"EdgeList", "[", "fission2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"deg1", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n1", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds1", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds1", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"deg2", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Riffle", "[", 
           RowBox[{"n2", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Total", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                    RowBox[{
                    RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"n2", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                   RowBox[{"strongbonds2", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "strongbonds2", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
          ",", "2"}], "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"degree", " ", "of", " ", "each", " ", "individual"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"predictions", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"n2", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"correct", "=", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Tally", "[", 
           RowBox[{"Join", "[", 
            RowBox[{"predictions", ",", "dyads"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"broken", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "graph", "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
           RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"maintained", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
         RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg1", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{"deg2", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg1", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"deg2", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", "\n", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission1", "]"}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"GlobalClusteringCoefficient", "[", "fission2", "]"}], 
           "]"}], ",", " ", "\n", 
          RowBox[{"GraphDiameter", "[", "fission1", "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"GraphDiameter", "[", "fission2", "]"}], ",", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"NumericQ", "[", 
             RowBox[{"N", "[", 
              RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], "]"}], 
            ",", 
            RowBox[{"N", "[", 
             RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], ",", 
            "0"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"NumericQ", "[", 
             RowBox[{"N", "[", 
              RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}], "]"}], 
            ",", 
            RowBox[{"N", "[", 
             RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}], ",", 
            "0"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "correct", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dyads", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "broken", " ", "bonds"}], " ", "*)"}],
           ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"#", " ", "of", " ", "maintained", " ", "bonds"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "%", " ", "of", " ", "bonds", " ", "that", " ", "were", " ", 
            "broken"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "broken", " ", 
            "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "broken", " ", "bond"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Total", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"strongbonds", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "sum", " ", "of", " ", "weights", " ", "of", " ", "maintained", 
            " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"strongbonds", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
               "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "average", " ", "weight", " ", "of", " ", "maintained", " ", 
            "bond"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Select", "[", 
                   RowBox[{"strongbonds", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                "1"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
            RowBox[{"Min", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"VertexList", "[", "fission2", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}], " ", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "broken", " ", "bonds"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Mean", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{"edgebw", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{
                   RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"mean", " ", 
            RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", 
            "maintained", " ", "bonds"}], " ", "*)"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualbroken", ",", 
                   RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualbroken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "broken", " ", "bonds", " ", "correct"}], " ", 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"actualmaintained", ",", 
                   RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
              "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", "actualmaintained", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"%", " ", "maintained", " ", "bonds", " ", "correct"}], 
           " ", "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualbroken", ",", 
                    RowBox[{
                    RowBox[{"#", "==", 
                    RowBox[{"broken", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{
               RowBox[{"Dimensions", "[", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Select", "[", 
                    RowBox[{"actualmaintained", ",", 
                    RowBox[{
                    RowBox[{"#", "\[Equal]", 
                    RowBox[{"maintained", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
            RowBox[{
             RowBox[{"Dimensions", "[", 
              RowBox[{"EdgeList", "[", "g", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], 
         RowBox[{"(*", " ", 
          RowBox[{"%", " ", "total", " ", "bonds", " ", "correct"}], " ", 
          "*)"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "100"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7574370083113174`*^9, 3.75743709629762*^9}, {
   3.757437210490589*^9, 3.7574372919744673`*^9}, 3.757592308647376*^9, 
   3.757633102388303*^9, 3.7576343402491226`*^9, 3.757634826596546*^9, 
   3.7576351589896574`*^9, 3.830245950651291*^9, 
   3.8400927636524105`*^9},ExpressionUUID->"225bfa70-e653-40fc-8c02-\
0bd93e85d763"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Mean", "[", "randalg", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7574373002110395`*^9, 3.7574373022909193`*^9}},
 CellLabel->
  "In[846]:=",ExpressionUUID->"1b28b2a9-09be-4782-b1bc-d23393f24f8c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "17.07`", ",", "15.93`", ",", "398.38`", ",", "196.34`", ",", 
     "20.86973093553072`", ",", "13.591883616383615`", ",", 
     "0.16938773362953946`", ",", "0.13936536229443525`", ",", "\[Infinity]", 
     ",", "\[Infinity]", ",", "0.09685807932215255`", ",", 
     "0.09644699744699743`", ",", "0.4744299674267101`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "26.42`", ",", "25.58`", ",", "0.5080769230769231`", ",", "495.01`", ",", 
     "18.706596583252864`", ",", "484.99`", ",", "18.929993907433904`", ",", 
     "29.11823529411765`", ",", "68.38155758774228`", ",", 
     "67.22203029449979`", ",", "0.5066666666666667`", ",", 
     "0.49117647058823527`", ",", "0.49653846153846154`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.757437321490943*^9, 3.7575941748063374`*^9, 
  3.7575951783948116`*^9, 3.757595787808159*^9, 3.75759645117245*^9, 
  3.7576342317826853`*^9, 3.7576345643313017`*^9, 3.757635015771715*^9, 
  3.7576352320218854`*^9},
 CellLabel->
  "Out[846]=",ExpressionUUID->"19f708ba-b6b4-4791-9151-19c8b376b3d8"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Efficient Non-behavioral Network Bisection", "Section",
 CellChangeTimes->{{3.7459405486374826`*^9, 3.7459405515402613`*^9}, {
  3.8400933364305735`*^9, 
  3.840093344472827*^9}},ExpressionUUID->"24f54009-607d-4061-9263-\
bd3e8a79e5c7"],

Cell[CellGroupData[{

Cell["Vertex", "Subsection",
 CellChangeTimes->{{3.7507017595464506`*^9, 
  3.7507017609715137`*^9}},ExpressionUUID->"d7e01044-5b5f-434e-a4d5-\
e719adfc9241"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindGraphPartition", "[", 
  RowBox[{"g", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.7459403188408575`*^9, 3.7459403541719236`*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"75b9931a-6bac-4866-add2-a25d5a0b6ca3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"DOT\"\>", ",", "\<\"VIN\"\>", ",", "\<\"DIV\"\>", 
     ",", "\<\"DUI\"\>", ",", "\<\"MLO\"\>", ",", "\<\"DOV\"\>", 
     ",", "\<\"DUN\"\>", ",", "\<\"PIS\"\>", ",", "\<\"DEA\"\>", 
     ",", "\<\"VOR\"\>", ",", "\<\"VIX\"\>", ",", "\<\"VAA\"\>", 
     ",", "\<\"VAP\"\>", ",", "\<\"VAN\"\>", ",", "\<\"VET\"\>", 
     ",", "\<\"VAZ\"\>", ",", "\<\"VIV\"\>", ",", "\<\"VEG\"\>", 
     ",", "\<\"VAT\"\>", ",", "\<\"VOT\"\>", ",", "\<\"VOG\"\>", 
     ",", "\<\"VOY\"\>", ",", "\<\"DUB\"\>", ",", "\<\"VAI\"\>", 
     ",", "\<\"VIG\"\>", ",", "\<\"DOX\"\>", ",", "\<\"VEX\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"AMA\"\>", ",", "\<\"OFR\"\>", ",", "\<\"ASH\"\>", 
     ",", "\<\"ECH\"\>", ",", "\<\"OST\"\>", ",", "\<\"OMO\"\>", 
     ",", "\<\"VEL\"\>", ",", "\<\"OBI\"\>", ",", "\<\"OKO\"\>", 
     ",", "\<\"OCH\"\>", ",", "\<\"OCE\"\>", ",", "\<\"TUZ\"\>", 
     ",", "\<\"VIL\"\>", ",", "\<\"VIO\"\>", ",", "\<\"VEI\"\>", 
     ",", "\<\"ACA\"\>", ",", "\<\"VOW\"\>", ",", "\<\"ROY\"\>", 
     ",", "\<\"OAT\"\>", ",", "\<\"EDW\"\>", ",", "\<\"ELV\"\>", 
     ",", "\<\"ORB\"\>", ",", "\<\"POW\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.745940336642672*^9, 3.7459403544100947`*^9}, 
   3.7459404117413435`*^9, 3.7463973195709267`*^9, 3.746445311708525*^9, 
   3.750702017563219*^9},
 CellLabel->
  "Out[211]=",ExpressionUUID->"c7523e75-3568-41ac-a887-1886e9d36171"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"g", ",", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Subgraph", "[", 
       RowBox[{"g", ",", "#"}], "]"}], "&"}], ",", " ", "%"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.74594033832807*^9, 3.745940366127347*^9}, 
   3.7459404092505317`*^9},
 CellLabel->
  "In[212]:=",ExpressionUUID->"ff439696-9df0-4394-8e1a-e85311453bfb"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "AMA", "OFR", "DOT", "ASH", "VIN", "ECH", "DIV", "DUI", "MLO", "DOV", 
       "DUN", "PIS", "DEA", "VOR", "VIX", "OST", "OMO", "VEL", "OBI", "OKO", 
       "OCH", "OCE", "TUZ", "VIL", "VAA", "VAP", "VIO", "VAN", "VET", "VAZ", 
       "VIV", "VEG", "VEI", "VAT", "VOT", "ACA", "VOG", "VOY", "VOW", "DUB", 
       "ROY", "OAT", "EDW", "ELV", "ORB", "VAI", "VIG", "DOX", "VEX", 
       "POW"}, {
      Null, {{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 6}, {3, 8}, {3, 9}, {10, 
       11}, {10, 12}, {10, 5}, {13, 10}, {10, 14}, {10, 15}, {6, 16}, {6, 
       17}, {6, 5}, {9, 18}, {19, 20}, {19, 21}, {21, 17}, {2, 17}, {22, 
       17}, {17, 23}, {20, 17}, {16, 24}, {17, 16}, {2, 16}, {16, 5}, {12, 
       15}, {12, 5}, {4, 25}, {25, 26}, {25, 5}, {25, 18}, {25, 14}, {25, 
       15}, {25, 27}, {28, 14}, {28, 29}, {30, 31}, {30, 24}, {32, 31}, {23, 
       18}, {33, 18}, {18, 5}, {18, 31}, {1, 18}, {18, 15}, {18, 14}, {29, 
       15}, {1, 29}, {29, 5}, {29, 14}, {4, 29}, {26, 5}, {5, 14}, {5, 31}, {
       23, 5}, {5, 15}, {18, 27}, {27, 14}, {9, 27}, {17, 27}, {27, 15}, {5, 
       27}, {24, 31}, {31, 14}, {31, 15}, {15, 14}, {17, 15}, {34, 14}, {14, 
       35}, {23, 14}, {9, 14}, {3, 35}, {36, 4}, {4, 10}, {4, 14}, {3, 32}, {
       10, 31}, {4, 2}, {29, 31}, {23, 27}, {4, 27}, {33, 27}, {31, 37}, {15, 
       38}, {15, 35}, {34, 35}, {4, 35}, {5, 35}, {19, 17}, {18, 39}, {1, 
       16}, {13, 11}, {10, 40}, {10, 8}, {6, 41}, {40, 12}, {41, 29}, {27, 
       39}, {3, 10}, {7, 3}, {9, 2}, {19, 16}, {2, 41}, {32, 29}, {9, 15}, {3,
        31}, {8, 25}, {32, 14}, {4, 16}, {29, 38}, {3, 23}, {32, 18}, {42, 
       16}, {43, 18}, {16, 29}, {31, 35}, {6, 44}, {43, 2}, {3, 43}, {4, 
       43}, {45, 18}, {46, 14}, {43, 17}, {29, 47}, {10, 48}, {49, 31}, {16, 
       50}}}, {EdgeStyle -> {UndirectedEdge["DIV", "ECH"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["VIL", "VIV"] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge["AMA", "DOT"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["ASH", "VAA"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["DOT", "MLO"] -> GrayLevel[
           Rational[196, 237]], UndirectedEdge["DOV", "DUB"] -> GrayLevel[
           Rational[97, 237]], UndirectedEdge["VEG", "VEL"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["DEA", "DOV"] -> GrayLevel[
           Rational[131, 237]], UndirectedEdge["OST", "POW"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["OFR", "ROY"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["VIV", "VOT"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["VIO", "VOR"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["ASH", "EDW"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["DOV", "VIX"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["DOV", "DUI"] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge["VAN", "VOR"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["AMA", "OST"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["ECH", "OMO"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VEL", "VIN"] -> GrayLevel[
           Rational[202, 237]], UndirectedEdge["OST", "VET"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["DEA", "DUN"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["OMO", "VIO"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VAT", "VOT"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["OAT", "OST"] -> GrayLevel[
           Rational[205, 237]], UndirectedEdge["VEL", "VOR"] -> GrayLevel[
           Rational[194, 237]], UndirectedEdge["OST", "VIN"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["AMA", "OFR"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["OMO", "OST"] -> GrayLevel[
           Rational[191, 237]], UndirectedEdge["ECH", "ELV"] -> GrayLevel[
           Rational[197, 237]], UndirectedEdge["ACA", "ASH"] -> GrayLevel[
           Rational[124, 237]], UndirectedEdge["DOT", "VEG"] -> GrayLevel[
           Rational[176, 237]], UndirectedEdge["OCE", "OMO"] -> GrayLevel[
           Rational[134, 237]], UndirectedEdge["ASH", "OFR"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["MLO", "VIO"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VIV", "VOR"] -> GrayLevel[
           Rational[218, 237]], UndirectedEdge["DOV", "VOR"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["ECH", "ROY"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["DOV", "DOX"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["ASH", "VIN"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["PIS", "VIX"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["DOT", "VIV"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["OBI", "OCH"] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge["VAZ", "VIL"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["VAA", "VEL"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["OFR", "OMO"] -> GrayLevel[
           Rational[142, 237]], UndirectedEdge["VEL", "VIX"] -> GrayLevel[
           Rational[199, 237]], UndirectedEdge["VEG", "VOR"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["OST", "VIL"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VEI", "VEL"] -> GrayLevel[
           Rational[176, 237]], UndirectedEdge["VEG", "VIV"] -> GrayLevel[
           Rational[60, 79]], UndirectedEdge["DOT", "DOV"] -> GrayLevel[
           Rational[196, 237]], UndirectedEdge["VET", "VIN"] -> GrayLevel[
           Rational[218, 237]], UndirectedEdge["VEL", "VIO"] -> GrayLevel[
           Rational[106, 237]], UndirectedEdge["DOV", "VIV"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VET", "VIX"] -> GrayLevel[
           Rational[43, 79]], UndirectedEdge["VIO", "VIX"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VAN", "VET"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VAT", "VOR"] -> GrayLevel[
           Rational[139, 237]], UndirectedEdge["VIV", "VOG"] -> GrayLevel[
           Rational[118, 237]], UndirectedEdge["OMO", "TUZ"] -> GrayLevel[
           Rational[220, 237]], UndirectedEdge["ORB", "VEL"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["OBI", "OKO"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["EDW", "OMO"] -> GrayLevel[
           Rational[211, 237]], UndirectedEdge["DOV", "DUN"] -> GrayLevel[
           Rational[110, 237]], UndirectedEdge["VAA", "VIN"] -> GrayLevel[
           Rational[41, 237]], UndirectedEdge["VET", "VOR"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["VIN", "VIX"] -> GrayLevel[
           Rational[181, 237]], UndirectedEdge["VIX", "VOT"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VIX", "VOR"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["VAA", "VAP"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["MLO", "VOR"] -> GrayLevel[
           Rational[53, 79]], UndirectedEdge["VIN", "VIV"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["VAP", "VIN"] -> GrayLevel[
           Rational[33, 79]], UndirectedEdge["VEI", "VIO"] -> GrayLevel[
           Rational[68, 79]], UndirectedEdge["VEL", "VOW"] -> GrayLevel[
           Rational[164, 237]], UndirectedEdge["DOV", "VIN"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["VIX", "VOY"] -> GrayLevel[
           Rational[2, 3]], UndirectedEdge["ASH", "VET"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["EDW", "VEL"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["VIN", "VOT"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VET", "VIV"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["MLO", "VIX"] -> GrayLevel[
           Rational[202, 237]], UndirectedEdge["OCH", "OMO"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["EDW", "OFR"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["VIV", "VIX"] -> GrayLevel[
           Rational[208, 237]], UndirectedEdge["VAZ", "VIV"] -> GrayLevel[
           Rational[119, 237]], UndirectedEdge["VET", "VIG"] -> GrayLevel[
           Rational[206, 237]], UndirectedEdge["VEG", "VET"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["TUZ", "VOR"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["DOT", "DUI"] -> GrayLevel[
           Rational[137, 237]], UndirectedEdge["ECH", "OST"] -> GrayLevel[
           Rational[190, 237]], UndirectedEdge["TUZ", "VIO"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VAA", "VOR"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["PIS", "VIN"] -> GrayLevel[
           Rational[57, 79]], UndirectedEdge["TUZ", "VIN"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["OFR", "OST"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["DUI", "VAA"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["VAA", "VIO"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["AMA", "VET"] -> GrayLevel[
           Rational[66, 79]], UndirectedEdge["OBI", "OMO"] -> GrayLevel[
           Rational[48, 79]], UndirectedEdge["DOT", "EDW"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["DIV", "DOT"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["OMO", "VIX"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VOR", "VOT"] -> GrayLevel[
           Rational[21, 79]], UndirectedEdge["OKO", "OMO"] -> GrayLevel[
           Rational[199, 237]], UndirectedEdge["ASH", "DOV"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["DOV", "PIS"] -> GrayLevel[0], 
         UndirectedEdge["DOT", "TUZ"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["DUB", "PIS"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["AMA", "VEL"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["ROY", "VET"] -> GrayLevel[
           Rational[66, 79]], UndirectedEdge["ASH", "VIO"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VAA", "VIX"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["MLO", "VEL"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["VAI", "VOR"] -> GrayLevel[
           Rational[70, 79]], UndirectedEdge["VET", "VOY"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VEL", "VIV"] -> GrayLevel[
           Rational[200, 237]], UndirectedEdge["ASH", "ECH"] -> GrayLevel[
           Rational[65, 79]], UndirectedEdge["ASH", "VOR"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["TUZ", "VEL"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["ASH", "VOT"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["VEX", "VIV"] -> GrayLevel[
           Rational[220, 237]], UndirectedEdge["DOT", "VOT"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VIN", "VOR"] -> GrayLevel[
           Rational[206, 237]], UndirectedEdge["VIO", "VOW"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["ECH", "VIN"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["OBI", "OST"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["MLO", "OFR"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["ASH", "OST"] -> GrayLevel[
           Rational[70, 79]], UndirectedEdge["VIN", "VIO"] -> GrayLevel[
           Rational[223, 237]]}, 
       EdgeWeight -> {13, 30, 20, 42, 12, 100, 41, 127, 237, 21, 106, 23, 13, 
        47, 14, 16, 22, 12, 36, 14, 95, 103, 17, 38, 11, 46, 30, 10, 20, 66, 
        16, 22, 196, 14, 23, 11, 13, 23, 11, 118, 23, 57, 16, 61, 35, 37, 12, 
        38, 43, 108, 39, 19, 22, 16, 138, 31, 12, 13, 56, 131, 24, 10, 11, 11,
         14, 36, 19, 29, 30, 14, 98, 174, 10, 78, 10, 113, 13, 24, 61, 14, 15,
         21, 10, 10, 33, 119, 79, 14, 21, 13, 11, 93, 73, 12, 24, 140, 36, 13,
         16, 39, 10, 41, 20, 12, 20, 16, 22, 35, 13, 15, 24, 27, 10, 24, 12, 
        32, 22, 12, 12, 40, 30, 15, 14, 15, 27, 26, 31, 21, 17, 10}, 
       GraphHighlight -> {
         UndirectedEdge["OAT", "OST"], 
         UndirectedEdge["VAT", "VOR"], "ROY", 
         UndirectedEdge["DOV", "DUN"], 
         UndirectedEdge["DOV", "VOR"], "ACA", 
         UndirectedEdge["VEG", "VET"], 
         UndirectedEdge["VET", "VIN"], "VAA", 
         UndirectedEdge["VEI", "VEL"], 
         UndirectedEdge["VAA", "VOR"], "OMO", "VEX", 
         UndirectedEdge["OFR", "ROY"], 
         UndirectedEdge["AMA", "OST"], "POW", 
         UndirectedEdge["OMO", "TUZ"], "VIX", "DUI", 
         UndirectedEdge["ORB", "VEL"], "PIS", 
         UndirectedEdge["DOT", "VEG"], 
         UndirectedEdge["EDW", "VEL"], "VEG", "DIV", 
         UndirectedEdge["OCE", "OMO"], "VIO", 
         UndirectedEdge["DEA", "DOV"], 
         UndirectedEdge["DOT", "VIV"], "VOR", 
         UndirectedEdge["VAI", "VOR"], 
         UndirectedEdge["ASH", "ECH"], 
         UndirectedEdge["AMA", "OFR"], "VOT", 
         UndirectedEdge["VET", "VOR"], 
         UndirectedEdge["MLO", "VIX"], "VIN", 
         UndirectedEdge["VEG", "VIV"], 
         UndirectedEdge["VAP", "VIN"], "OCH", 
         UndirectedEdge["VIX", "VOR"], 
         UndirectedEdge["OST", "POW"], 
         UndirectedEdge["DOT", "VOT"], 
         UndirectedEdge["VEI", "VIO"], 
         UndirectedEdge["OFR", "OST"], 
         UndirectedEdge["MLO", "VOR"], 
         UndirectedEdge["VIN", "VOR"], 
         UndirectedEdge["ECH", "ROY"], 
         UndirectedEdge["ASH", "OFR"], 
         UndirectedEdge["DOV", "VIN"], "DOX", "VOG", 
         UndirectedEdge["OBI", "OST"], "VAZ", 
         UndirectedEdge["VIV", "VIX"], 
         UndirectedEdge["DOT", "DUI"], 
         UndirectedEdge["VIV", "VOR"], 
         UndirectedEdge["OBI", "OCH"], 
         UndirectedEdge["VAT", "VOT"], 
         UndirectedEdge["ECH", "OMO"], "ASH", 
         UndirectedEdge["OMO", "OST"], 
         UndirectedEdge["VOR", "VOT"], 
         UndirectedEdge["VAA", "VIN"], 
         UndirectedEdge["DUI", "VAA"], "DEA", "DOT", 
         UndirectedEdge["OCH", "OMO"], 
         UndirectedEdge["VIX", "VOY"], 
         UndirectedEdge["OKO", "OMO"], "VIL", "DUN", 
         UndirectedEdge["VIN", "VIV"], 
         UndirectedEdge["VIV", "VOG"], 
         UndirectedEdge["VET", "VIX"], 
         UndirectedEdge["VAA", "VAP"], 
         UndirectedEdge["AMA", "VEL"], "VAN", "OCE", "OAT", "VIV", "MLO", 
         UndirectedEdge["VAA", "VIX"], 
         UndirectedEdge["DIV", "DOT"], "OST", "ORB", 
         UndirectedEdge["OFR", "OMO"], 
         UndirectedEdge["VAN", "VOR"], "VOY", 
         UndirectedEdge["EDW", "OMO"], 
         UndirectedEdge["VET", "VOY"], 
         UndirectedEdge["DOV", "DUB"], "VAI", 
         UndirectedEdge["OST", "VIL"], 
         UndirectedEdge["VAZ", "VIV"], 
         UndirectedEdge["DEA", "DUN"], "VIG", 
         UndirectedEdge["VIV", "VOT"], "DUB", "DOV", 
         UndirectedEdge["PIS", "VIN"], 
         UndirectedEdge["DOV", "VIV"], "TUZ", 
         UndirectedEdge["DOT", "MLO"], 
         UndirectedEdge["OMO", "VIO"], 
         UndirectedEdge["TUZ", "VEL"], 
         UndirectedEdge["OBI", "OKO"], "VOW", 
         UndirectedEdge["ACA", "ASH"], "OFR", 
         UndirectedEdge["EDW", "OFR"], 
         UndirectedEdge["ASH", "EDW"], "VEI", "VEL", "OBI", 
         UndirectedEdge["VET", "VIG"], "AMA", 
         UndirectedEdge["VEG", "VOR"], 
         UndirectedEdge["DOV", "DOX"], 
         UndirectedEdge["VIX", "VOT"], 
         UndirectedEdge["VAN", "VET"], 
         UndirectedEdge["DOV", "DUI"], 
         UndirectedEdge["DOV", "PIS"], "ECH", "VAP", "VAT", 
         UndirectedEdge["VEL", "VIO"], 
         UndirectedEdge["VIN", "VOT"], 
         UndirectedEdge["PIS", "VIX"], 
         UndirectedEdge["DUB", "PIS"], 
         UndirectedEdge["DOT", "DOV"], 
         UndirectedEdge["DOV", "VIX"], 
         UndirectedEdge["VIN", "VIX"], "OKO", 
         UndirectedEdge["ASH", "OST"], "VET", "EDW", "ELV", 
         UndirectedEdge["VEL", "VOW"], 
         UndirectedEdge["VEX", "VIV"], 
         UndirectedEdge["VET", "VIV"], 
         UndirectedEdge["OBI", "OMO"], 
         UndirectedEdge["VIO", "VOW"], 
         UndirectedEdge["ECH", "ELV"], 
         UndirectedEdge["TUZ", "VIO"], 
         UndirectedEdge["ASH", "VIO"], 
         UndirectedEdge["ECH", "OST"]}, 
       GraphHighlightStyle -> {
        "VOR" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         "DIV" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ASH", "OFR"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VIN", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VIV" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OKO", "OMO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VAT", "VOT"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VAI", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VOG" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ECH", "ROY"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["AMA", "OST"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOV", "DUB"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DOT", "MLO"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ACA", "ASH"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["ASH", "ECH"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "POW" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "OCE" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OST", "VIL"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "ACA" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOV", "VIX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ASH", "EDW"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OAT", "OST"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["MLO", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VAZ" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OBI", "OCH"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OST", "POW"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VAZ", "VIV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "DEA" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VEG", "VET"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "PIS" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         "VIG" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         "DOT" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DOT", "DUI"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DUI", "VAA"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DOV", "DUI"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OMO", "VIO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "VAP" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         "DOV" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VEX", "VIV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VIO" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "OAT" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "ELV" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOT", "VOT"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VAI" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VIN", "VIX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VET", "VOY"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VAN" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["AMA", "VEL"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "OMO" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OBI", "OMO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["EDW", "OFR"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VAN", "VET"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ECH", "OMO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "TUZ" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "ROY" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OMO", "TUZ"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VAA", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "OBI" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOV", "VIV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "DUB" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         "EDW" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "VEI" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "OCH" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VAP", "VIN"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VIV", "VIX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OFR", "ROY"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DEA", "DOV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VAT" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         "OST" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["TUZ", "VEL"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "VIL" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "MLO" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["TUZ", "VIO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VIV", "VOG"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VAN", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VEI", "VIO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "VET" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VEG", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ECH", "OST"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OCH", "OMO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "VOW" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VIX", "VOT"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VAA", "VAP"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["EDW", "OMO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "DUN" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         "ASH" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OMO", "OST"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOV", "DUN"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VIN" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VIN", "VIV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VEX" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VIX", "VOY"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "DUI" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ORB", "VEL"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VEL", "VIO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "ORB" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VIV", "VOT"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VEL" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VAA", "VIN"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VIX" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VAT", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VEG", "VIV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "OKO" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["PIS", "VIN"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VET", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VEG" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OBI", "OST"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DUB", "PIS"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "OFR" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VOR", "VOT"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "VAA" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DEA", "DUN"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VEI", "VEL"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VIO", "VOW"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VET", "VIN"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DIV", "DOT"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OFR", "OMO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOV", "DOX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OFR", "OST"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["OCE", "OMO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOV", "VIN"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VET", "VIX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VET", "VIV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ASH", "OST"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "DOX" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DOT", "VIV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["EDW", "VEL"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOT", "VEG"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["PIS", "VIX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DOV", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["OBI", "OKO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VAA", "VIX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ECH", "ELV"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VIN", "VOT"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["ASH", "VIO"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["DOT", "DOV"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VEL", "VOW"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["MLO", "VIX"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "ECH" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         UndirectedEdge["VIX", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         "AMA" -> {VertexStyle -> Hue[0.14, 1, 0.9]}, 
         "VOY" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VIV", "VOR"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["DOV", "PIS"] -> {EdgeStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["AMA", "OFR"] -> {EdgeStyle -> Hue[0.14, 1, 0.9]}, 
         "VOT" -> {VertexStyle -> Hue[0, 1, 0.8]}, 
         UndirectedEdge["VET", "VIG"] -> {EdgeStyle -> Hue[0, 1, 0.8]}}, 
       GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {"Name"}, 
       VertexStyle -> {"VIN" -> GrayLevel[
           Rational[67, 396]], "VOY" -> GrayLevel[
           Rational[703, 792]], "DOT" -> GrayLevel[
           Rational[437, 792]], "ORB" -> GrayLevel[
           Rational[259, 264]], "VAZ" -> GrayLevel[
           Rational[217, 264]], "OAT" -> GrayLevel[
           Rational[95, 99]], "VET" -> GrayLevel[
           Rational[221, 396]], "ACA" -> GrayLevel[
           Rational[679, 792]], "VIL" -> GrayLevel[
           Rational[361, 396]], "OKO" -> GrayLevel[
           Rational[371, 396]], "OMO" -> GrayLevel[
           Rational[107, 264]], "DOX" -> GrayLevel[
           Rational[257, 264]], "VAT" -> GrayLevel[
           Rational[673, 792]], "VEL" -> GrayLevel[
           Rational[29, 88]], "VIG" -> GrayLevel[
           Rational[761, 792]], "VOR" -> GrayLevel[
           Rational[119, 792]], "EDW" -> GrayLevel[
           Rational[685, 792]], "ROY" -> GrayLevel[
           Rational[181, 198]], "VEX" -> GrayLevel[
           Rational[775, 792]], "DUB" -> GrayLevel[
           Rational[53, 66]], "VAP" -> GrayLevel[
           Rational[79, 99]], "ASH" -> GrayLevel[
           Rational[469, 792]], "VAN" -> GrayLevel[
           Rational[379, 396]], "ELV" -> GrayLevel[
           Rational[94, 99]], "VIV" -> GrayLevel[
           Rational[4, 11]], "TUZ" -> GrayLevel[
           Rational[39, 44]], "ECH" -> GrayLevel[
           Rational[76, 99]], "OCH" -> GrayLevel[
           Rational[371, 396]], "DUI" -> GrayLevel[
           Rational[641, 792]], "DIV" -> GrayLevel[
           Rational[95, 99]], "VOG" -> GrayLevel[
           Rational[673, 792]], "VIX" -> GrayLevel[
           Rational[167, 396]], "VOT" -> GrayLevel[
           Rational[179, 264]], "AMA" -> GrayLevel[
           Rational[343, 396]], "VIO" -> GrayLevel[
           Rational[515, 792]], "DUN" -> GrayLevel[
           Rational[641, 792]], "POW" -> GrayLevel[
           Rational[391, 396]], "VAA" -> GrayLevel[
           Rational[241, 396]], "MLO" -> GrayLevel[
           Rational[3, 4]], "OST" -> GrayLevel[
           Rational[535, 792]], "OFR" -> GrayLevel[
           Rational[581, 792]], "VEG" -> GrayLevel[
           Rational[7, 9]], "VAI" -> GrayLevel[
           Rational[85, 88]], "VEI" -> GrayLevel[
           Rational[349, 396]], "VOW" -> GrayLevel[
           Rational[709, 792]], "OBI" -> GrayLevel[
           Rational[631, 792]], "OCE" -> GrayLevel[
           Rational[689, 792]], "DEA" -> GrayLevel[
           Rational[331, 396]], "PIS" -> GrayLevel[
           Rational[151, 264]], "DOV" -> GrayLevel[0]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           1.7490536653376987`, 2.0596769160666244`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[69, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           3.06910335000307, 1.965307568098614}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[66, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           2.6923739957704953`, 2.3116495007135645`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           2.5593984745938423`, 2.5508550429575}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           1.7130052088944134`, 1.0558619988176456`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.3254801139325076`, 0.8427900980487346}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {4.098806202058695,
            2.6040284702046423`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.5593984745938423`, 2.5508550429575}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {4.276805586776847,
            1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[71, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[74, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[217, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.0508254247212463`, 2.3011085273433345`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           1.9350586108814647`, 1.4314573947187421`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           4.276805586776847, 1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[71, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[221, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[221, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.412520993581118, 3.6224390013597016`}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[221, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           1.9350586108814647`, 1.4314573947187421`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           4.276805586776847, 1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           4.056068133125937, 1.577936911527845}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[227, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[202, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.580151017437533, 3.5362323082782128`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[223, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           2.3254801139325076`, 0.8427900980487346}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.7130052088944134`, 1.0558619988176456`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.2345042461710136`, 0.22223793934819325`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.098806202058695, 2.6040284702046423`}, {
           4.276805586776847, 1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.098806202058695, 2.6040284702046423`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[215, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[227, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           5.705942496372727, 1.7037420043212381`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           4.056068133125937, 1.577936911527845}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           5.609486156720985, 1.337650842585623}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           4.842294325772201, 1.0381550924567922`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           5.711158690299976, 2.2642987881564105`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{5.705942496372727, 1.7037420043212381`}, {
           5.609486156720985, 1.337650842585623}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.056068133125937, 1.577936911527845}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.056068133125937, 1.577936911527845}, {
           4.842294325772201, 1.0381550924567922`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[194, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[227, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[71, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.577071127785599, 1.2956185619005178`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           4.3641850672617775`, 3.1416889714552063`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           4.305020433317991, 3.771022748712493}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[223, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[199, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[226, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.7992088083622755`, 0.953005653387923}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           0.5214085110208795, 2.0829862735279354`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           3.0521136330652543`, 0.770227690922028}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           0.42395458198833547`, 1.0268753139750664`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           0.6804972928289903, 0.6187971060378612}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           0.5214085110208795, 2.0829862735279354`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           0.12078515290921654`, 2.650232619453675}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {0., 
           2.26930332084519}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           0.20040482376984903`, 3.2241708698882308`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[223, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[200, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.1038785769545756`, 3.9353441339932367`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.560614392848657, 4.061823599966873}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.9731935590146934`, 4.485354095364575}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{0.5214085110208795, 2.0829862735279354`}, {
           0.12078515290921654`, 2.650232619453675}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{0.5214085110208795, 2.0829862735279354`}, {0., 
           2.26930332084519}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.3724849871837996`, 2.7062903408578323`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[214, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0521136330652543`, 0.770227690922028}, {
           3.900972389572577, 0.4895713159101325}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[67, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0521136330652543`, 0.770227690922028}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.2804975122357636`, 2.9741602758583543`}, {
           3.580151017437533, 3.5362323082782128`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.2804975122357636`, 2.9741602758583543`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.493094552434439, 3.0393162226740644`}, {
           2.1038785769545756`, 3.9353441339932367`}}, 
           0.046966480367839764`]}}, 
        {Hue[0.14, 1, 0.9], 
         {Arrowheads[0.], 
          ArrowBox[{{2.493094552434439, 3.0393162226740644`}, {
           2.560614392848657, 4.061823599966873}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.577071127785599, 1.2956185619005178`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           2.7992088083622755`, 0.953005653387923}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[66, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           1.7130052088944134`, 1.0558619988176456`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           2.7573833949139783`, 0.}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.900972389572577, 0.4895713159101325}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           5.05770479431974, 2.0984234127332657`}}, 0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           5.0023437070107075`, 1.4077748294239933`}}, 
           0.046966480367839764`]}}, 
        {Hue[0, 1, 0.8], 
         {Arrowheads[0.], 
          ArrowBox[{{4.3641850672617775`, 3.1416889714552063`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.2417421967893736, 1.9967248724965296}, 
           0.046966480367839764]}, 
         InsetBox["\<\"AMA\"\>", 
          Offset[{2, 2}, {2.288708677157213, 2.043691352864369}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.7490536653376987, 2.0596769160666244}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OFR\"\>", 
          Offset[{2, 2}, {1.7960201457055385, 2.106643396434464}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.06910335000307, 1.965307568098614}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DOT\"\>", 
          Offset[{2, 2}, {3.11606983037091, 2.0122740484664536}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.6923739957704953, 2.3116495007135645}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ASH\"\>", 
          Offset[{2, 2}, {2.739340476138335, 2.358615981081404}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.0508254247212463, 2.3011085273433345}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIN\"\>", 
          Offset[{2, 2}, {3.097791905089086, 2.348075007711174}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.9350586108814647, 1.4314573947187421}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ECH\"\>", 
          Offset[{2, 2}, {1.9820250912493045, 1.478423875086582}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.3254801139325076, 0.8427900980487346}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DIV\"\>", 
          Offset[{2, 2}, {2.372446594300347, 0.8897565784165744}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{4.098806202058695, 2.6040284702046423}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DUI\"\>", 
          Offset[{2, 2}, {4.145772682426535, 2.650994950572482}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.5593984745938423, 2.5508550429575}, 
           0.046966480367839764]}, 
         InsetBox["\<\"MLO\"\>", 
          Offset[{2, 2}, {2.606364954961682, 2.5978215233253397}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{4.276805586776847, 1.9649816740304353}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DOV\"\>", 
          Offset[{2, 2}, {4.323772067144687, 2.011948154398275}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{5.705942496372727, 1.7037420043212381}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DUN\"\>", 
          Offset[{2, 2}, {5.752908976740567, 1.750708484689078}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{4.056068133125937, 1.577936911527845}, 
           0.046966480367839764]}, 
         InsetBox["\<\"PIS\"\>", 
          Offset[{2, 2}, {4.103034613493777, 1.6249033918956848}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{5.609486156720985, 1.337650842585623}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DEA\"\>", 
          Offset[{2, 2}, {5.656452637088825, 1.3846173229534628}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.3985098954680972, 2.547823829731471}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOR\"\>", 
          Offset[{2, 2}, {3.445476375835937, 2.5947903100993104}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.003863029787065, 2.1431947879426105}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIX\"\>", 
          Offset[{2, 2}, {3.0508295101549048, 2.19016126831045}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.7070907247637195, 1.567411953661388}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OST\"\>", 
          Offset[{2, 2}, {1.7540572051315593, 1.6143784340292278}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.323817058151051, 2.4295893529329433}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OMO\"\>", 
          Offset[{2, 2}, {1.370783538518891, 2.476555833300783}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.8393248416980734, 3.001678912953419}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEL\"\>", 
          Offset[{2, 2}, {2.886291322065913, 3.0486453933212587}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{0.5214085110208795, 2.0829862735279354}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OBI\"\>", 
          Offset[{2, 2}, {0.5683749913887193, 2.129952753895775}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{0.12078515290921654, 2.650232619453675}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OKO\"\>", 
          Offset[{2, 2}, {0.1677516332770563, 2.6971990998215145}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{0., 2.26930332084519}, 0.046966480367839764]}, 
         InsetBox["\<\"OCH\"\>", 
          Offset[{2, 2}, {0.046966480367839764, 2.3162698012130294}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{0.20040482376984903, 3.2241708698882308}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OCE\"\>", 
          Offset[{2, 2}, {0.2473713041376888, 3.2711373502560703}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.3724849871837996, 2.7062903408578323}, 
           0.046966480367839764]}, 
         InsetBox["\<\"TUZ\"\>", 
          Offset[{2, 2}, {2.419451467551639, 2.753256821225672}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{3.0521136330652543, 0.770227690922028}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIL\"\>", 
          Offset[{2, 2}, {3.099080113433094, 0.8171941712898678}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.2804975122357636, 2.9741602758583543}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAA\"\>", 
          Offset[{2, 2}, {3.327463992603603, 3.021126756226194}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.580151017437533, 3.5362323082782128}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAP\"\>", 
          Offset[{2, 2}, {3.6271174978053726, 3.5831987886460523}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.493094552434439, 3.0393162226740644}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIO\"\>", 
          Offset[{2, 2}, {2.5400610328022784, 3.086282703041904}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.577071127785599, 1.2956185619005178}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAN\"\>", 
          Offset[{2, 2}, {3.6240376081534387, 1.3425850422683576}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.7921031203706335, 1.4865966978459673}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VET\"\>", 
          Offset[{2, 2}, {2.839069600738473, 1.533563178213807}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.900972389572577, 0.4895713159101325}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAZ\"\>", 
          Offset[{2, 2}, {3.9479388699404168, 0.5365377962779723}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.7341742761150485, 1.7833992223252553}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIV\"\>", 
          Offset[{2, 2}, {3.781140756482888, 1.830365702693095}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.4345059388892007, 2.1083766127232515}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEG\"\>", 
          Offset[{2, 2}, {3.4814724192570403, 2.155343093091091}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.1038785769545756, 3.9353441339932367}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEI\"\>", 
          Offset[{2, 2}, {2.150845057322415, 3.9823106143610763}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{4.3641850672617775, 3.1416889714552063}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAT\"\>", 
          Offset[{2, 2}, {4.4111515476296175, 3.188655451823046}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{3.6643999386692236, 2.4798935651387697}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOT\"\>", 
          Offset[{2, 2}, {3.711366419037063, 2.5268600455066093}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.412520993581118, 3.6224390013597016}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ACA\"\>", 
          Offset[{2, 2}, {2.4594874739489576, 3.669405481727541}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{5.05770479431974, 2.0984234127332657}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOG\"\>", 
          Offset[{2, 2}, {5.10467127468758, 2.1453898931011053}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.7992088083622755, 0.953005653387923}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOY\"\>", 
          Offset[{2, 2}, {2.846175288730115, 0.9999721337557628}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.560614392848657, 4.061823599966873}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOW\"\>", 
          Offset[{2, 2}, {2.6075808732164965, 4.108790080334713}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{4.842294325772201, 1.0381550924567922}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DUB\"\>", 
          Offset[{2, 2}, {4.889260806140041, 1.085121572824632}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.7130052088944134, 1.0558619988176456}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ROY\"\>", 
          Offset[{2, 2}, {1.7599716892622532, 1.1028284791854854}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{0.42395458198833547, 1.0268753139750664}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OAT\"\>", 
          Offset[{2, 2}, {0.47092106235617526, 1.0738417943429062}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.0159240870708266, 2.565622289742292}, 
           0.046966480367839764]}, 
         InsetBox["\<\"EDW\"\>", 
          Offset[{2, 2}, {2.062890567438666, 2.6125887701101314}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{1.2345042461710136, 0.22223793934819325}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ELV\"\>", 
          Offset[{2, 2}, {1.2814707265388534, 0.26920441971603304}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{2.9731935590146934, 4.485354095364575}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ORB\"\>", 
          Offset[{2, 2}, {3.020160039382533, 4.532320575732415}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{4.305020433317991, 3.771022748712493}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAI\"\>", 
          Offset[{2, 2}, {4.351986913685831, 3.817989229080333}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{2.7573833949139783, 0.}, 0.046966480367839764]}, 
         InsetBox["\<\"VIG\"\>", 
          Offset[{2, 2}, {2.804349875281818, 0.046966480367839764}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{5.711158690299976, 2.2642987881564105}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DOX\"\>", 
          Offset[{2, 2}, {5.758125170667816, 2.31126526852425}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0, 1, 0.8], 
          DiskBox[{5.0023437070107075, 1.4077748294239933}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEX\"\>", 
          Offset[{2, 2}, {5.0493101873785475, 1.4547413097918331}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {Hue[0.14, 1, 0.9], 
          DiskBox[{0.6804972928289903, 0.6187971060378612}, 
           0.046966480367839764]}, 
         InsetBox["\<\"POW\"\>", 
          Offset[{2, 2}, {0.7274637731968301, 0.665763586405701}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.7507020177529707`*^9},
 CellLabel->
  "Out[212]=",ExpressionUUID->"a5165129-385b-4c3b-b687-639105ee418d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fission1", "=", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"g", ",", 
    RowBox[{
     RowBox[{"FindGraphPartition", "[", 
      RowBox[{"g", ",", "2"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.746397355332594*^9, 3.7463974256792173`*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"c35ba10c-b8cf-4afe-addb-d980b47e8386"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "DOT", "VIN", "DIV", "DUI", "MLO", "DOV", "DUN", "PIS", "DEA", "VOR", 
       "VIX", "VAA", "VAP", "VAN", "VET", "VAZ", "VIV", "VEG", "VAT", "VOT", 
       "VOG", "VOY", "DUB", "VAI", "VIG", "DOX", "VEX"}, {
      Null, {{3, 1}, {1, 4}, {1, 5}, {6, 2}, {6, 4}, {1, 6}, {6, 7}, {6, 8}, {
       8, 2}, {9, 6}, {9, 7}, {6, 10}, {2, 10}, {5, 10}, {6, 11}, {8, 11}, {2,
        11}, {11, 10}, {5, 11}, {12, 2}, {12, 10}, {12, 11}, {4, 12}, {12, 
       13}, {13, 2}, {14, 10}, {14, 15}, {15, 11}, {15, 2}, {15, 10}, {16, 
       17}, {2, 17}, {17, 10}, {17, 11}, {6, 17}, {15, 17}, {1, 17}, {18, 
       17}, {1, 18}, {18, 15}, {18, 10}, {19, 10}, {10, 20}, {1, 20}, {11, 
       20}, {19, 20}, {2, 20}, {17, 20}, {17, 21}, {11, 22}, {15, 22}, {6, 
       23}, {23, 8}, {24, 10}, {15, 25}, {6, 26}, {27, 17}}}, {
      VertexLabels -> {"Name"}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[{{2.6401105562004443`, 2.6546721074990183`}, {
          2.9304559196269273`, 3.98503046235914}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.6401105562004443`, 2.6546721074990183`}, {
          3.4850137369302447`, 2.8725439106337487`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.6401105562004443`, 2.6546721074990183`}, {
          2.1343918453173925`, 2.975266688279665}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.6401105562004443`, 2.6546721074990183`}, {
          3.380500128258567, 1.8208937001101135`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.6401105562004443`, 2.6546721074990183`}, {
          2.1449973018033486`, 1.312022158152788}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.6401105562004443`, 2.6546721074990183`}, {
          1.7185236535128143`, 1.960046976473109}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.6401105562004443`, 2.6546721074990183`}, {
          2.127095492348195, 2.396324073315247}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          3.380500128258567, 1.8208937001101135`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          3.158477784353027, 1.2281734084579585`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          1.856656998442277, 2.3472771453998584`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          2.2299715545004193`, 1.829330720213449}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          2.9105940035404982`, 2.3948509293025957`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          3.598153894129342, 2.3876205102139645`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          1.2990702036463808`, 1.7179211898426785`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          2.1449973018033486`, 1.312022158152788}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5961284441032113`, 1.869510661543237}, {
          2.127095492348195, 2.396324073315247}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.4850137369302447`, 2.8725439106337487`}, {
          3.380500128258567, 1.8208937001101135`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.4850137369302447`, 2.8725439106337487`}, {
          2.9105940035404982`, 2.3948509293025957`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1343918453173925`, 2.975266688279665}, {
          1.856656998442277, 2.3472771453998584`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1343918453173925`, 2.975266688279665}, {
          2.2299715545004193`, 1.829330720213449}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          4.670336072813444, 2.2116001686254476`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          3.158477784353027, 1.2281734084579585`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          4.707124488306453, 1.7690110707840234`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          1.856656998442277, 2.3472771453998584`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          2.2299715545004193`, 1.829330720213449}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          2.1449973018033486`, 1.312022158152788}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          3.86711530561215, 0.8698273270195882}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.380500128258567, 1.8208937001101135`}, {
          4.54593594441294, 1.1396456339154728`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.670336072813444, 2.2116001686254476`}, {
          4.707124488306453, 1.7690110707840234`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.158477784353027, 1.2281734084579585`}, {
          2.2299715545004193`, 1.829330720213449}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.158477784353027, 1.2281734084579585`}, {
          3.86711530561215, 0.8698273270195882}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          2.2299715545004193`, 1.829330720213449}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          2.9105940035404982`, 2.3948509293025957`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          0.6987920597636239, 2.2913618681254246`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          1.2990702036463808`, 1.7179211898426785`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          2.1449973018033486`, 1.312022158152788}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          1.7185236535128143`, 1.960046976473109}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          1.515530399220701, 3.2322202971588805`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          2.127095492348195, 2.396324073315247}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.856656998442277, 2.3472771453998584`}, {
          0.8041677739307203, 3.296187386583079}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2299715545004193`, 1.829330720213449}, {
          2.9105940035404982`, 2.3948509293025957`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2299715545004193`, 1.829330720213449}, {
          1.2990702036463808`, 1.7179211898426785`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2299715545004193`, 1.829330720213449}, {
          2.1449973018033486`, 1.312022158152788}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2299715545004193`, 1.829330720213449}, {
          2.127095492348195, 2.396324073315247}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2299715545004193`, 1.829330720213449}, {
          1.091386063401636, 1.2222218456303058`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.9105940035404982`, 2.3948509293025957`}, {
          3.598153894129342, 2.3876205102139645`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.6987920597636239, 2.2913618681254246`}, {
          1.2990702036463808`, 1.7179211898426785`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2990702036463808`, 1.7179211898426785`}, {
          2.1449973018033486`, 1.312022158152788}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2990702036463808`, 1.7179211898426785`}, {
          1.7185236535128143`, 1.960046976473109}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2990702036463808`, 1.7179211898426785`}, {
          1.091386063401636, 1.2222218456303058`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2990702036463808`, 1.7179211898426785`}, {0., 
          1.4368238299695881`}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.4733204265239213`, 0.045065410537910244`}, {
          2.1449973018033486`, 1.312022158152788}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1449973018033486`, 1.312022158152788}, {
          1.7185236535128143`, 1.960046976473109}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1449973018033486`, 1.312022158152788}, {
          2.127095492348195, 2.396324073315247}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1449973018033486`, 1.312022158152788}, {
          1.3517948811579408`, 0.23627737890693323`}}, 
          0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1449973018033486`, 1.312022158152788}, {
          1.8907800269149337`, 0.}}, 0.041346418541877844`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.515530399220701, 3.2322202971588805`}, {
          2.127095492348195, 2.396324073315247}}, 0.041346418541877844`]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{2.6401105562004443, 2.6546721074990183}, 
          0.041346418541877844], 
         InsetBox["\<\"DOT\"\>", 
          Offset[{2, 2}, {2.6814569747423223, 2.696018526040896}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.5961284441032113, 1.869510661543237}, 
          0.041346418541877844], 
         InsetBox["\<\"VIN\"\>", 
          Offset[{2, 2}, {2.6374748626450892, 1.910857080085115}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.9304559196269273, 3.98503046235914}, 
          0.041346418541877844], 
         InsetBox["\<\"DIV\"\>", 
          Offset[{2, 2}, {2.9718023381688052, 4.026376880901018}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.4850137369302447, 2.8725439106337487}, 
          0.041346418541877844], 
         InsetBox["\<\"DUI\"\>", 
          Offset[{2, 2}, {3.5263601554721227, 2.9138903291756266}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.1343918453173925, 2.975266688279665}, 
          0.041346418541877844], 
         InsetBox["\<\"MLO\"\>", 
          Offset[{2, 2}, {2.1757382638592704, 3.0166131068215427}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.380500128258567, 1.8208937001101135}, 
          0.041346418541877844], 
         InsetBox["\<\"DOV\"\>", 
          Offset[{2, 2}, {3.421846546800445, 1.8622401186519915}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.670336072813444, 2.2116001686254476}, 
          0.041346418541877844], 
         InsetBox["\<\"DUN\"\>", 
          Offset[{2, 2}, {4.7116824913553215, 2.2529465871673255}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.158477784353027, 1.2281734084579585}, 
          0.041346418541877844], 
         InsetBox["\<\"PIS\"\>", 
          Offset[{2, 2}, {3.199824202894905, 1.2695198269998365}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.707124488306453, 1.7690110707840234}, 
          0.041346418541877844], 
         InsetBox["\<\"DEA\"\>", 
          Offset[{2, 2}, {4.748470906848331, 1.8103574893259013}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.856656998442277, 2.3472771453998584}, 
          0.041346418541877844], 
         InsetBox["\<\"VOR\"\>", 
          Offset[{2, 2}, {1.8980034169841549, 2.3886235639417364}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.2299715545004193, 1.829330720213449}, 
          0.041346418541877844], 
         InsetBox["\<\"VIX\"\>", 
          Offset[{2, 2}, {2.271317973042297, 1.870677138755327}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.9105940035404982, 2.3948509293025957}, 
          0.041346418541877844], 
         InsetBox["\<\"VAA\"\>", 
          Offset[{2, 2}, {2.951940422082376, 2.4361973478444736}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.598153894129342, 2.3876205102139645}, 
          0.041346418541877844], 
         InsetBox["\<\"VAP\"\>", 
          Offset[{2, 2}, {3.63950031267122, 2.4289669287558424}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6987920597636239, 2.2913618681254246}, 
          0.041346418541877844], 
         InsetBox["\<\"VAN\"\>", 
          Offset[{2, 2}, {0.7401384783055017, 2.3327082866673026}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.2990702036463808, 1.7179211898426785}, 
          0.041346418541877844], 
         InsetBox["\<\"VET\"\>", 
          Offset[{2, 2}, {1.3404166221882587, 1.7592676083845564}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.4733204265239213, 0.045065410537910244}, 
          0.041346418541877844], 
         InsetBox["\<\"VAZ\"\>", 
          Offset[{2, 2}, {2.514666845065799, 0.08641182907978809}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.1449973018033486, 1.312022158152788}, 
          0.041346418541877844], 
         InsetBox["\<\"VIV\"\>", 
          Offset[{2, 2}, {2.1863437203452265, 1.353368576694666}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.7185236535128143, 1.960046976473109}, 
          0.041346418541877844], 
         InsetBox["\<\"VEG\"\>", 
          Offset[{2, 2}, {1.7598700720546923, 2.0013933950149867}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.515530399220701, 3.2322202971588805}, 
          0.041346418541877844], 
         InsetBox["\<\"VAT\"\>", 
          Offset[{2, 2}, {1.556876817762579, 3.2735667157007584}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.127095492348195, 2.396324073315247}, 
          0.041346418541877844], 
         InsetBox["\<\"VOT\"\>", 
          Offset[{2, 2}, {2.1684419108900728, 2.437670491857125}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.3517948811579408, 0.23627737890693323}, 
          0.041346418541877844], 
         InsetBox["\<\"VOG\"\>", 
          Offset[{2, 2}, {1.3931412996998187, 0.27762379744881105}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.091386063401636, 1.2222218456303058}, 
          0.041346418541877844], 
         InsetBox["\<\"VOY\"\>", 
          Offset[{2, 2}, {1.1327324819435138, 1.2635682641721837}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.86711530561215, 0.8698273270195882}, 
          0.041346418541877844], 
         InsetBox["\<\"DUB\"\>", 
          Offset[{2, 2}, {3.908461724154028, 0.911173745561466}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8041677739307203, 3.296187386583079}, 
          0.041346418541877844], 
         InsetBox["\<\"VAI\"\>", 
          Offset[{2, 2}, {0.8455141924725981, 3.337533805124957}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0., 1.4368238299695881}, 0.041346418541877844], 
         InsetBox["\<\"VIG\"\>", 
          Offset[{2, 2}, {0.041346418541877844, 1.478170248511466}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.54593594441294, 1.1396456339154728}, 
          0.041346418541877844], 
         InsetBox["\<\"DOX\"\>", 
          Offset[{2, 2}, {4.587282362954817, 1.1809920524573507}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.8907800269149337, 0.}, 0.041346418541877844], 
         InsetBox["\<\"VEX\"\>", 
          Offset[{2, 2}, {1.9321264454568117, 0.041346418541877844}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.746397394291686*^9, 3.7463974275655394`*^9}, 
   3.7464001271330185`*^9, 3.746404172513296*^9, 3.746444679900404*^9, 
   3.7507020179752*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"78fd1754-8c66-40d1-976b-58ff2f18cd95"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fission2", "=", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"g", ",", 
    RowBox[{
     RowBox[{"FindGraphPartition", "[", 
      RowBox[{"g", ",", "2"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7463974350576286`*^9, 3.7463974400622244`*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"2c81fffe-c9d0-4398-9254-40edd1cc0de3"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "AMA", "OFR", "ASH", "ECH", "OST", "OMO", "VEL", "OBI", "OKO", "OCH", 
       "OCE", "TUZ", "VIL", "VIO", "VEI", "ACA", "VOW", "ROY", "OAT", "EDW", 
       "ELV", "ORB", "POW"}, {
      Null, {{1, 2}, {3, 2}, {3, 4}, {4, 5}, {2, 5}, {1, 5}, {3, 5}, {4, 6}, {
       2, 6}, {6, 5}, {1, 7}, {8, 6}, {8, 5}, {8, 9}, {9, 6}, {8, 10}, {10, 
       6}, {11, 6}, {6, 12}, {12, 7}, {5, 13}, {7, 14}, {6, 14}, {12, 14}, {3,
        14}, {15, 7}, {15, 14}, {16, 3}, {7, 17}, {14, 17}, {4, 18}, {2, 
       18}, {19, 5}, {20, 7}, {20, 2}, {3, 20}, {20, 6}, {4, 21}, {22, 7}, {5,
        23}}}, {VertexLabels -> {"Name"}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[{{2.516230464244764, 1.5846245387756244`}, {
          3.053802900554655, 1.9765262374073886`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.516230464244764, 1.5846245387756244`}, {
          3.738484847664076, 1.5508984492825235`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.516230464244764, 1.5846245387756244`}, {
          1.2302823898557866`, 1.6042145696679064`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.053802900554655, 1.9765262374073886`}, {
          2.7263123617888585`, 2.376546648205876}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.053802900554655, 1.9765262374073886`}, {
          3.738484847664076, 1.5508984492825235`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.053802900554655, 1.9765262374073886`}, {
          2.877390809563707, 1.0802950729345904`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.053802900554655, 1.9765262374073886`}, {
          3.5336832934519506`, 2.893648791670511}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.053802900554655, 1.9765262374073886`}, {
          2.2256450558668686`, 1.8887274571250794`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.7263123617888585`, 2.376546648205876}, {
          3.600842142336785, 2.2791604724578685`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.7263123617888585`, 2.376546648205876}, {
          3.738484847664076, 1.5508984492825235`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.7263123617888585`, 2.376546648205876}, {
          1.6886161971029356`, 1.6654663468426782`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.7263123617888585`, 2.376546648205876}, {
          2.431871087272384, 3.512810624329491}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.7263123617888585`, 2.376546648205876}, {
          2.2256450558668686`, 1.8887274571250794`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.600842142336785, 2.2791604724578685`}, {
          3.738484847664076, 1.5508984492825235`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.600842142336785, 2.2791604724578685`}, {
          2.877390809563707, 1.0802950729345904`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.600842142336785, 2.2791604724578685`}, {
          3.5336832934519506`, 2.893648791670511}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.600842142336785, 2.2791604724578685`}, {
          4.368579895575813, 3.2065092436576665`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.738484847664076, 1.5508984492825235`}, {
          2.877390809563707, 1.0802950729345904`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.738484847664076, 1.5508984492825235`}, {
          3.3559543923430426`, 0.583685847309577}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.738484847664076, 1.5508984492825235`}, {
          4.84592978484009, 2.0013797475155237`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.738484847664076, 1.5508984492825235`}, {
          4.928044179897312, 1.4226377408518727`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.738484847664076, 1.5508984492825235`}, {
          4.713797194361545, 0.8868526433644127}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.877390809563707, 1.0802950729345904`}, {
          3.3559543923430426`, 0.583685847309577}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.877390809563707, 1.0802950729345904`}, {
          3.144795141664268, 0.}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.877390809563707, 1.0802950729345904`}, {
          2.7008979641596658`, 0.11837471298461}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.877390809563707, 1.0802950729345904`}, {
          3.655993021465854, 0.05133371160924982}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.877390809563707, 1.0802950729345904`}, {
          1.7539604044055324`, 0.9987461892727585}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.877390809563707, 1.0802950729345904`}, {
          1.6886161971029356`, 1.6654663468426782`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.877390809563707, 1.0802950729345904`}, {
          2.2256450558668686`, 1.8887274571250794`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2302823898557866`, 1.6042145696679064`}, {
          1.7539604044055324`, 0.9987461892727585}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2302823898557866`, 1.6042145696679064`}, {
          1.6886161971029356`, 1.6654663468426782`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2302823898557866`, 1.6042145696679064`}, {
          0.7027483565369752, 1.3089272509401493`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2302823898557866`, 1.6042145696679064`}, {
          0.7789911484063188, 2.118422269074398}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2302823898557866`, 1.6042145696679064`}, {
          2.2256450558668686`, 1.8887274571250794`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2302823898557866`, 1.6042145696679064`}, {0., 
          1.5984904800777269`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.3559543923430426`, 0.583685847309577}, {
          3.144795141664268, 0.}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.3559543923430426`, 0.583685847309577}, {
          2.7008979641596658`, 0.11837471298461}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.7539604044055324`, 0.9987461892727585}, {
          1.6886161971029356`, 1.6654663468426782`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6886161971029356`, 1.6654663468426782`}, {
          0.7027483565369752, 1.3089272509401493`}}, 0.04263499803386095]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6886161971029356`, 1.6654663468426782`}, {
          0.7789911484063188, 2.118422269074398}}, 0.04263499803386095]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{2.516230464244764, 1.5846245387756244}, 
          0.04263499803386095], 
         InsetBox["\<\"AMA\"\>", 
          Offset[{2, 2}, {2.558865462278625, 1.6272595368094853}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.053802900554655, 1.9765262374073886}, 
          0.04263499803386095], 
         InsetBox["\<\"OFR\"\>", 
          Offset[{2, 2}, {3.096437898588516, 2.0191612354412496}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.7263123617888585, 2.376546648205876}, 
          0.04263499803386095], 
         InsetBox["\<\"ASH\"\>", 
          Offset[{2, 2}, {2.7689473598227194, 2.419181646239737}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.600842142336785, 2.2791604724578685}, 
          0.04263499803386095], 
         InsetBox["\<\"ECH\"\>", 
          Offset[{2, 2}, {3.643477140370646, 2.3217954704917294}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.738484847664076, 1.5508984492825235}, 
          0.04263499803386095], 
         InsetBox["\<\"OST\"\>", 
          Offset[{2, 2}, {3.781119845697937, 1.5935334473163845}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.877390809563707, 1.0802950729345904}, 
          0.04263499803386095], 
         InsetBox["\<\"OMO\"\>", 
          Offset[{2, 2}, {2.920025807597568, 1.1229300709684513}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.2302823898557866, 1.6042145696679064}, 
          0.04263499803386095], 
         InsetBox["\<\"VEL\"\>", 
          Offset[{2, 2}, {1.2729173878896476, 1.6468495677017674}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3559543923430426, 0.583685847309577}, 
          0.04263499803386095], 
         InsetBox["\<\"OBI\"\>", 
          Offset[{2, 2}, {3.3985893903769036, 0.6263208453434379}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.144795141664268, 0.}, 0.04263499803386095], 
         InsetBox["\<\"OKO\"\>", 
          Offset[{2, 2}, {3.187430139698129, 0.04263499803386095}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.7008979641596658, 0.11837471298461}, 0.04263499803386095],
          InsetBox["\<\"OCH\"\>", 
          Offset[{2, 2}, {2.7435329621935267, 0.16100971101847095}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.655993021465854, 0.05133371160924982}, 
          0.04263499803386095], 
         InsetBox["\<\"OCE\"\>", 
          Offset[{2, 2}, {3.698628019499715, 0.09396870964311077}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.7539604044055324, 0.9987461892727585}, 
          0.04263499803386095], 
         InsetBox["\<\"TUZ\"\>", 
          Offset[{2, 2}, {1.7965954024393933, 1.0413811873066194}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.84592978484009, 2.0013797475155237}, 0.04263499803386095],
          InsetBox["\<\"VIL\"\>", 
          Offset[{2, 2}, {4.888564782873951, 2.0440147455493847}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.6886161971029356, 1.6654663468426782}, 
          0.04263499803386095], 
         InsetBox["\<\"VIO\"\>", 
          Offset[{2, 2}, {1.7312511951367966, 1.7081013448765392}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7027483565369752, 1.3089272509401493}, 
          0.04263499803386095], 
         InsetBox["\<\"VEI\"\>", 
          Offset[{2, 2}, {0.7453833545708362, 1.3515622489740102}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.431871087272384, 3.512810624329491}, 0.04263499803386095],
          InsetBox["\<\"ACA\"\>", 
          Offset[{2, 2}, {2.474506085306245, 3.555445622363352}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7789911484063188, 2.118422269074398}, 
          0.04263499803386095], 
         InsetBox["\<\"VOW\"\>", 
          Offset[{2, 2}, {0.8216261464401797, 2.161057267108259}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.5336832934519506, 2.893648791670511}, 
          0.04263499803386095], 
         InsetBox["\<\"ROY\"\>", 
          Offset[{2, 2}, {3.5763182914858116, 2.936283789704372}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.928044179897312, 1.4226377408518727}, 
          0.04263499803386095], 
         InsetBox["\<\"OAT\"\>", 
          Offset[{2, 2}, {4.9706791779311725, 1.4652727388857336}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.2256450558668686, 1.8887274571250794}, 
          0.04263499803386095], 
         InsetBox["\<\"EDW\"\>", 
          Offset[{2, 2}, {2.2682800539007295, 1.9313624551589403}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.368579895575813, 3.2065092436576665}, 
          0.04263499803386095], 
         InsetBox["\<\"ELV\"\>", 
          Offset[{2, 2}, {4.4112148936096744, 3.2491442416915275}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0., 1.5984904800777269}, 0.04263499803386095], 
         InsetBox["\<\"ORB\"\>", 
          Offset[{2, 2}, {0.04263499803386095, 1.6411254781115878}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.713797194361545, 0.8868526433644127}, 
          0.04263499803386095], 
         InsetBox["\<\"POW\"\>", 
          Offset[{2, 2}, {4.7564321923954065, 0.9294876413982737}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.74639743559579*^9, 3.7463974408032265`*^9}, 
   3.7464001280646763`*^9, 3.7464041749410524`*^9, 3.746444680760186*^9, 
   3.7507020180350227`*^9},
 CellLabel->
  "Out[215]=",ExpressionUUID->"65965536-64a7-4282-a8f0-e6b09b9cac3e"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"strongbonds1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"strongbonds", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"EdgeList", "[", "fission1", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
        "]"}], ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", 
         RowBox[{"EdgeList", "[", "fission1", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"strongbonds2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"strongbonds", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"EdgeList", "[", "fission2", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}]}], "&"}]}], 
        "]"}], ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", 
         RowBox[{"EdgeList", "[", "fission2", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7463977105463195`*^9, 3.7463978203740873`*^9}, {
  3.7463978804819*^9, 3.7463979212468967`*^9}, {3.746397955546936*^9, 
  3.7463979714959116`*^9}, {3.746398009790866*^9, 3.7463981000271263`*^9}, {
  3.746398265882224*^9, 3.7463982835088997`*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"2f8fecca-639c-41dd-8bb5-4af46f31112f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"n1", "=", 
    RowBox[{"Sort", "[", 
     RowBox[{"VertexList", "[", "fission1", "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"vector", " ", "of", " ", "individuals"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n2", "=", 
   RowBox[{"Sort", "[", 
    RowBox[{"VertexList", "[", "fission2", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7459400118286686`*^9, 3.745940020311623*^9}, {
  3.7463981332193785`*^9, 3.7463981375904894`*^9}, {3.746398300961608*^9, 
  3.74639830639964*^9}, {3.7464000425075245`*^9, 3.746400053032634*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"90600fee-7625-495c-92f5-afd93b0df866"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Dimensions", "[", "n1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "n2", "]"}]}], "Input",
 CellChangeTimes->{{3.7463983226813374`*^9, 3.7463983295381947`*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"48ae135e-7917-465f-b349-7d00d28072ae"],

Cell[BoxData[
 RowBox[{"{", "27", "}"}]], "Output",
 CellChangeTimes->{3.74639833005914*^9, 3.746400132231003*^9, 
  3.7507020184044676`*^9},
 CellLabel->
  "Out[220]=",ExpressionUUID->"a12933bc-af4b-4aa7-af6d-4dcdc1d1cca4"],

Cell[BoxData[
 RowBox[{"{", "23", "}"}]], "Output",
 CellChangeTimes->{3.74639833005914*^9, 3.746400132231003*^9, 
  3.7507020184126186`*^9},
 CellLabel->
  "Out[221]=",ExpressionUUID->"a2c058c9-ec31-4b03-806e-ac6d4f8159db"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"deg1", "=", 
   RowBox[{"Sort", "[", 
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"Riffle", "[", 
       RowBox[{"n1", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Total", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"strongbonds1", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                 "\[Equal]", 
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                RowBox[{
                 RowBox[{"strongbonds1", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                 "\[Equal]", 
                 RowBox[{"n1", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
               RowBox[{"strongbonds1", "[", 
                RowBox[{"[", 
                 RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", 
               RowBox[{
                RowBox[{"Dimensions", "[", "strongbonds1", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
      "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"deg2", "=", 
    RowBox[{"Sort", "[", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"Riffle", "[", 
        RowBox[{"n2", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Total", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"strongbonds2", "[", 
                   RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "1"}], "]"}], "]"}], 
                  "\[Equal]", 
                  RowBox[{"n2", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], "\[Or]", 
                 RowBox[{
                  RowBox[{"strongbonds2", "[", 
                   RowBox[{"[", 
                    RowBox[{"j", ",", "1", ",", "2"}], "]"}], "]"}], 
                  "\[Equal]", 
                  RowBox[{"n2", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                RowBox[{"strongbonds2", "[", 
                 RowBox[{"[", 
                  RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", 
                RowBox[{
                 RowBox[{"Dimensions", "[", "strongbonds2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
       "2"}], "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"degree", " ", "of", " ", "each", " ", "individual"}], " ", 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.745940033735406*^9, 3.7459400475325823`*^9}, {
  3.746398375143742*^9, 3.746398411644123*^9}, {3.7463984607293034`*^9, 
  3.746398489969491*^9}, {3.7480370908833027`*^9, 3.748037105636234*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"dffc18ee-de75-4c53-a9df-c63148d04e2c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Total", "[", 
  RowBox[{"deg1", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Total", "[", 
  RowBox[{"deg2", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"Total", "[", 
    RowBox[{"deg1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
   RowBox[{
    RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"Total", "[", 
    RowBox[{"deg2", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
   RowBox[{
    RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7463985032374134`*^9, 3.7463985569310923`*^9}, {
  3.746400122383336*^9, 3.746400122479124*^9}},
 CellLabel->
  "In[224]:=",ExpressionUUID->"2a2590ac-ce5a-4596-8422-8aecf60bf334"],

Cell[BoxData["5766"], "Output",
 CellChangeTimes->{{3.7463985095187054`*^9, 3.74639855748592*^9}, 
   3.746400133960019*^9, 3.7507020185034804`*^9},
 CellLabel->
  "Out[224]=",ExpressionUUID->"7aa09eb0-47b9-477d-bf66-0a3f28957a71"],

Cell[BoxData["2766"], "Output",
 CellChangeTimes->{{3.7463985095187054`*^9, 3.74639855748592*^9}, 
   3.746400133960019*^9, 3.750702018509182*^9},
 CellLabel->
  "Out[225]=",ExpressionUUID->"c71fa260-932c-473e-a419-1e6bd1bafb82"],

Cell[BoxData["213.55555555555554`"], "Output",
 CellChangeTimes->{{3.7463985095187054`*^9, 3.74639855748592*^9}, 
   3.746400133960019*^9, 3.7507020185125656`*^9},
 CellLabel->
  "Out[226]=",ExpressionUUID->"4650edb9-d850-4b35-8397-05ba82e5adc1"],

Cell[BoxData["120.26086956521739`"], "Output",
 CellChangeTimes->{{3.7463985095187054`*^9, 3.74639855748592*^9}, 
   3.746400133960019*^9, 3.7507020185176215`*^9},
 CellLabel->
  "Out[227]=",ExpressionUUID->"6a54de89-87cc-442c-b8e1-f851d19ead2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"betweenness1", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Riffle", "[", 
      RowBox[{
       RowBox[{"VertexList", "[", "fission1", "]"}], ",", 
       RowBox[{"BetweennessCentrality", "[", "fission1", "]"}]}], "]"}], ",", 
     "2"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"betweenness2", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Riffle", "[", 
      RowBox[{
       RowBox[{"VertexList", "[", "fission2", "]"}], ",", 
       RowBox[{"BetweennessCentrality", "[", "fission2", "]"}]}], "]"}], ",", 
     "2"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.746204207366505*^9, 3.746204230964226*^9}, {
  3.7462043369718018`*^9, 3.7462043570111065`*^9}, {3.7462044695228004`*^9, 
  3.7462044766472373`*^9}, {3.746398668739292*^9, 3.7463987057084312`*^9}},
 CellLabel->
  "In[228]:=",ExpressionUUID->"861297e4-1491-4dbf-a6a6-adfd2258ea95"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"DEA\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DIV\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DOT\"\>", ",", "37.581746031746036`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DOV\"\>", ",", "103.50555555555557`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DOX\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DUB\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DUI\"\>", ",", "3.6666666666666665`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DUN\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"MLO\"\>", ",", "1.9190476190476191`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"PIS\"\>", ",", "3.535714285714285`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAA\"\>", ",", "8.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAI\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAN\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAP\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAT\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAZ\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEG\"\>", ",", "3.9269841269841272`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VET\"\>", ",", "37.776984126984125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEX\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIG\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIN\"\>", ",", "32.74682539682539`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIV\"\>", ",", "85.17539682539682`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIX\"\>", ",", "36.66349206349206`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOG\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOR\"\>", ",", "75.26587301587304`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOT\"\>", ",", "9.485714285714286`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOY\"\>", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.746204231288288*^9, {3.74620434820236*^9, 3.7462043573439455`*^9}, 
   3.7462044772886105`*^9, 3.746204600733567*^9, 3.746397307870559*^9, {
   3.7463986882079525`*^9, 3.7463987061721687`*^9}, 3.7507020185452023`*^9},
 CellLabel->
  "Out[228]=",ExpressionUUID->"015b7645-40f0-4ae1-b019-4ce3c6982215"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"ACA\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"AMA\"\>", ",", "14.666666666666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ASH\"\>", ",", "35.33333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ECH\"\>", ",", "29.633333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"EDW\"\>", ",", "10.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ELV\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OAT\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OBI\"\>", ",", "5.833333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OCE\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OCH\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OFR\"\>", ",", "17.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OKO\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OMO\"\>", ",", "84.16666666666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ORB\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OST\"\>", ",", "74.13333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"POW\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ROY\"\>", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"TUZ\"\>", ",", "3.833333333333334`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEI\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEL\"\>", ",", "34.166666666666664`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIL\"\>", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIO\"\>", ",", "37.133333333333326`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOW\"\>", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.746204231288288*^9, {3.74620434820236*^9, 3.7462043573439455`*^9}, 
   3.7462044772886105`*^9, 3.746204600733567*^9, 3.746397307870559*^9, {
   3.7463986882079525`*^9, 3.7463987061721687`*^9}, 3.750702018554099*^9},
 CellLabel->
  "Out[229]=",ExpressionUUID->"36bd65e3-5aee-4bfa-b9ae-f93006f1ab22"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eigencent1", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Riffle", "[", 
      RowBox[{
       RowBox[{"VertexList", "[", "fission1", "]"}], ",", 
       RowBox[{"EigenvectorCentrality", "[", "fission1", "]"}]}], "]"}], ",", 
     "2"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"eigencent2", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Riffle", "[", 
      RowBox[{
       RowBox[{"VertexList", "[", "fission2", "]"}], ",", 
       RowBox[{"EigenvectorCentrality", "[", "fission2", "]"}]}], "]"}], ",", 
     "2"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7462046031017632`*^9, 3.7462046246425*^9}, {
  3.7463987596142073`*^9, 3.746398784276246*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"9a775b71-815d-419e-a905-2812eed99957"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"DEA\"\>", ",", "0.012889613304076446`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DIV\"\>", ",", "0.007072913796909347`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DOT\"\>", ",", "0.04855444052273568`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DOV\"\>", ",", "0.07559555426679362`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DOX\"\>", ",", "0.011011986401290091`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DUB\"\>", ",", "0.016629211420277474`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DUI\"\>", ",", "0.024660156412246798`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"DUN\"\>", ",", "0.012889613304076447`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"MLO\"\>", ",", "0.03366389200717564`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"PIS\"\>", ",", "0.03856136606760647`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAA\"\>", ",", "0.04513809950663006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAI\"\>", ",", "0.013681337267967456`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAN\"\>", ",", "0.023277008030042727`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAP\"\>", ",", "0.018792621667568062`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAT\"\>", ",", "0.022699903612084557`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VAZ\"\>", ",", "0.012723092155952406`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEG\"\>", ",", "0.04307301398290449`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VET\"\>", ",", "0.06587277021480566`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEX\"\>", ",", "0.012723092155952407`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIG\"\>", ",", "0.009595670762075277`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIN\"\>", ",", "0.08387029183314945`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIV\"\>", ",", "0.08734202608568756`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIX\"\>", ",", "0.08862265415656903`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOG\"\>", ",", "0.012723092155952406`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOR\"\>", ",", "0.09392022803095494`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOT\"\>", ",", "0.061911039174141376`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOY\"\>", ",", "0.022505311704374115`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7462046261655254`*^9, 3.746397307901805*^9, 
  3.7463987856922216`*^9, 3.750702018575285*^9},
 CellLabel->
  "Out[230]=",ExpressionUUID->"92223c49-5706-4bd2-8b1a-948759eae477"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"ACA\"\>", ",", "0.014797095264403825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"AMA\"\>", ",", "0.0454145514389491`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ASH\"\>", ",", "0.07513679322807668`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ECH\"\>", ",", "0.06275640730632438`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"EDW\"\>", ",", "0.06280743948607381`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ELV\"\>", ",", "0.012358958873112903`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OAT\"\>", ",", "0.018664790662699483`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OBI\"\>", ",", "0.05236077142867659`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OCE\"\>", ",", "0.02126058344542028`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OCH\"\>", ",", "0.03157227349314343`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OFR\"\>", ",", "0.08163523293441535`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OKO\"\>", ",", "0.03157227349314364`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OMO\"\>", ",", "0.10795713845876932`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ORB\"\>", ",", "0.010672892616657935`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OST\"\>", ",", "0.09477620381631492`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"POW\"\>", ",", "0.018664790662699337`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ROY\"\>", ",", "0.02843582703270485`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"TUZ\"\>", ",", "0.0446865706391022`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEI\"\>", ",", "0.02342598719368169`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VEL\"\>", ",", "0.05419488834490581`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIL\"\>", ",", "0.01866479066269928`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VIO\"\>", ",", "0.06475775232434364`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"VOW\"\>", ",", "0.02342598719368174`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7462046261655254`*^9, 3.746397307901805*^9, 
  3.7463987856922216`*^9, 3.7507020185806446`*^9},
 CellLabel->
  "Out[231]=",ExpressionUUID->"c6324b30-a5b8-489f-a60b-d9508469f911"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Correlation", "[", 
  RowBox[{
   RowBox[{"deg1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"betweenness1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Correlation", "[", 
  RowBox[{
   RowBox[{"deg2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"betweenness2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.746204444379741*^9, 3.7462044849081206`*^9}, {
  3.7463988043616085`*^9, 3.7463988156313305`*^9}},
 CellLabel->
  "In[232]:=",ExpressionUUID->"9dd3a91d-cf5f-409c-a320-b719101a1af5"],

Cell[BoxData["0.8742914082093411`"], "Output",
 CellChangeTimes->{3.7462044853086863`*^9, 3.746204600764815*^9, 
  3.746397307979907*^9, 3.746398817476071*^9, 3.7507020186543674`*^9},
 CellLabel->
  "Out[232]=",ExpressionUUID->"9a981e40-9ec2-4114-8cd1-a1c743b3b46b"],

Cell[BoxData["0.8638326038427973`"], "Output",
 CellChangeTimes->{3.7462044853086863`*^9, 3.746204600764815*^9, 
  3.746397307979907*^9, 3.746398817476071*^9, 3.7507020186592484`*^9},
 CellLabel->
  "Out[233]=",ExpressionUUID->"162f056e-5609-4101-983e-274f80c06129"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Correlation", "[", 
  RowBox[{
   RowBox[{"deg1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"eigencent1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Correlation", "[", 
  RowBox[{
   RowBox[{"deg2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"eigencent2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.746204633155404*^9, 3.7462046341137047`*^9}, {
  3.7463988225719776`*^9, 3.746398831302085*^9}},
 CellLabel->
  "In[234]:=",ExpressionUUID->"35f856b7-d767-4dc5-a860-b6392559d4d7"],

Cell[BoxData["0.867104901472983`"], "Output",
 CellChangeTimes->{3.746204634516055*^9, 3.7463973080111504`*^9, 
  3.746398832092216*^9, 3.750702018673237*^9},
 CellLabel->
  "Out[234]=",ExpressionUUID->"74db8bca-dbe6-4aea-baea-f7f61ff452eb"],

Cell[BoxData["0.8151902136136743`"], "Output",
 CellChangeTimes->{3.746204634516055*^9, 3.7463973080111504`*^9, 
  3.746398832092216*^9, 3.7507020186779647`*^9},
 CellLabel->
  "Out[235]=",ExpressionUUID->"029e59fd-ad01-4bef-98b6-18159d2b30a5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Correlation", "[", 
  RowBox[{
   RowBox[{"betweenness1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"eigencent1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Correlation", "[", 
  RowBox[{
   RowBox[{"betweenness2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"eigencent2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7462046367136006`*^9, 3.746204651235958*^9}, {
  3.746398839314082*^9, 3.746398850643673*^9}},
 CellLabel->
  "In[236]:=",ExpressionUUID->"67e8e82b-4e2e-47cd-8102-63e47d93a3e4"],

Cell[BoxData["0.8263824791631531`"], "Output",
 CellChangeTimes->{3.7462046515755157`*^9, 3.746397308058015*^9, 
  3.746398851060089*^9, 3.750702018692342*^9},
 CellLabel->
  "Out[236]=",ExpressionUUID->"934be849-2a3d-4426-9fab-2825803c9161"],

Cell[BoxData["0.8837794918954058`"], "Output",
 CellChangeTimes->{3.7462046515755157`*^9, 3.746397308058015*^9, 
  3.746398851060089*^9, 3.750702018698234*^9},
 CellLabel->
  "Out[237]=",ExpressionUUID->"38e0bd66-ba3b-4ad4-9752-d2dd87ee2133"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"N", "[", 
  RowBox[{"GlobalClusteringCoefficient", "[", "fission1", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"GlobalClusteringCoefficient", "[", "fission2", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"way", " ", "down", " ", "in", " ", "this", " ", "group"}], " ", 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.7462049147147317`*^9, 3.746204925269766*^9}, {
  3.7463988617066617`*^9, 3.746398880075799*^9}},
 CellLabel->
  "In[238]:=",ExpressionUUID->"8f96b70b-8f6f-4220-8441-3a3fa38da16a"],

Cell[BoxData["0.3539325842696629`"], "Output",
 CellChangeTimes->{{3.746204920347142*^9, 3.746204925650424*^9}, 
   3.7463973080892563`*^9, {3.7463988637361326`*^9, 3.7463988697983665`*^9}, 
   3.75070201871329*^9},
 CellLabel->
  "Out[238]=",ExpressionUUID->"09cece21-fe20-4e00-aa5a-72d53ff75ea3"],

Cell[BoxData["0.23333333333333334`"], "Output",
 CellChangeTimes->{{3.746204920347142*^9, 3.746204925650424*^9}, 
   3.7463973080892563`*^9, {3.7463988637361326`*^9, 3.7463988697983665`*^9}, 
   3.7507020187166834`*^9},
 CellLabel->
  "Out[239]=",ExpressionUUID->"7a494594-cb74-4e61-9d89-4d3602be20f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"N", "[", 
  RowBox[{"LocalClusteringCoefficient", "[", "fission1", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{"LocalClusteringCoefficient", "[", "fission2", "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7462052131562433`*^9, 3.7462052198358707`*^9}, {
  3.746398885018448*^9, 3.7463988955773*^9}},
 CellLabel->
  "In[240]:=",ExpressionUUID->"79177244-9b0f-41af-ab13-2ecf5149db2b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.19047619047619047`", ",", "0.4722222222222222`", ",", "0.`", ",", 
   "0.3333333333333333`", ",", "0.3333333333333333`", ",", 
   "0.21818181818181817`", ",", "1.`", ",", "0.6666666666666666`", ",", "1.`",
    ",", "0.2878787878787879`", ",", "0.4`", ",", "0.4`", ",", "1.`", ",", 
   "1.`", ",", "0.35714285714285715`", ",", "0.`", ",", "0.3090909090909091`",
    ",", "0.6666666666666666`", ",", "1.`", ",", "0.5333333333333333`", ",", 
   "0.`", ",", "1.`", ",", "1.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.746205220183516*^9, 3.7463973081361203`*^9, 
  3.746398896425158*^9, 3.7507020187329426`*^9},
 CellLabel->
  "Out[240]=",ExpressionUUID->"913aaf81-c542-485a-87a9-281e3e65511f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3333333333333333`", ",", "0.3333333333333333`", ",", "0.2`", ",", "0.2`",
    ",", "0.16666666666666666`", ",", "0.15555555555555556`", ",", 
   "0.14285714285714285`", ",", "0.5`", ",", "1.`", ",", "1.`", ",", "0.`", 
   ",", "0.6666666666666666`", ",", "0.`", ",", "0.26666666666666666`", ",", 
   "1.`", ",", "0.`", ",", "1.`", ",", "0.`", ",", "0.`", ",", 
   "0.3333333333333333`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.746205220183516*^9, 3.7463973081361203`*^9, 
  3.746398896425158*^9, 3.7507020187373676`*^9},
 CellLabel->
  "Out[241]=",ExpressionUUID->"5edc18b9-0b3d-4a04-8832-0c69630db60c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphDiameter", "[", "fission1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphDiameter", "[", "fission2", "]"}]}], "Input",
 CellChangeTimes->{{3.746205296408753*^9, 3.7462053024019194`*^9}, {
  3.7463989011306057`*^9, 3.746398906597353*^9}},
 CellLabel->
  "In[242]:=",ExpressionUUID->"338bf711-1aeb-4c3e-910b-1af1bd629a89"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.746205302803995*^9, 3.7463973081673646`*^9, {3.7463989022630982`*^9, 
   3.746398906968606*^9}, 3.7507020187517824`*^9},
 CellLabel->
  "Out[242]=",ExpressionUUID->"52bf9174-cf2b-43a1-947f-817e1589862c"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.746205302803995*^9, 3.7463973081673646`*^9, {3.7463989022630982`*^9, 
   3.746398906968606*^9}, 3.7507020187558327`*^9},
 CellLabel->
  "Out[243]=",ExpressionUUID->"39e237d0-9fdd-4133-9255-aff082dc086a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"GraphDensity", "[", "fission1", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"up", " ", "from", " ", "about", " ", "0.1"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{"GraphDensity", "[", "fission2", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.746205334473764*^9, 3.7462053445288687`*^9}, {
  3.7463989123792887`*^9, 3.746398952932589*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"7d0f9049-03b6-48fc-bad4-978ef1b26780"],

Cell[BoxData["0.1623931623931624`"], "Output",
 CellChangeTimes->{{3.74620533888221*^9, 3.746205345518916*^9}, 
   3.7463973081986103`*^9, 3.7463989257777376`*^9, 3.7507020187717133`*^9},
 CellLabel->
  "Out[244]=",ExpressionUUID->"28ba7fde-a1b5-4515-bca9-13920e8a4256"],

Cell[BoxData["0.15810276679841898`"], "Output",
 CellChangeTimes->{{3.74620533888221*^9, 3.746205345518916*^9}, 
   3.7463973081986103`*^9, 3.7463989257777376`*^9, 3.750702018776702*^9},
 CellLabel->
  "Out[245]=",ExpressionUUID->"aee5758b-adaa-4db4-b356-449ac1dcec1c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"predictions", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"n1", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"n1", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n1", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
        "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"n2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"n2", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "n2", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
        "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7464044666718893`*^9, 3.746404519829745*^9}},
 CellLabel->
  "In[246]:=",ExpressionUUID->"58c136e4-7e20-4114-8219-e4acb308959a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"correct", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Tally", "[", 
       RowBox[{"Join", "[", 
        RowBox[{"predictions", ",", "dyads"}], "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7464449731760645`*^9, 3.746445043332802*^9}, 
   3.7464451780271907`*^9},
 CellLabel->
  "In[247]:=",ExpressionUUID->"dc16b8c5-8f80-4d57-b5eb-dd007d90a2f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "predictions", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "-", 
     RowBox[{
      RowBox[{"Dimensions", "[", "correct", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
   RowBox[{
    RowBox[{"Dimensions", "[", "predictions", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.746445058447757*^9, 3.7464450839796534`*^9}},
 CellLabel->
  "In[248]:=",ExpressionUUID->"ceef0b1b-204d-48dc-a5a7-80d00acf82b6"],

Cell[BoxData["0.5811258278145696`"], "Output",
 CellChangeTimes->{{3.746445079630188*^9, 3.7464450843908343`*^9}, 
   3.7507020188283825`*^9},
 CellLabel->
  "Out[248]=",ExpressionUUID->"8ed3e1d5-82c4-4998-8140-e91a423356bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "predictions", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "-", 
     RowBox[{
      RowBox[{"Dimensions", "[", "correct", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
   RowBox[{
    RowBox[{"Dimensions", "[", "dyads", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7464451023560123`*^9, 3.746445103776329*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"a6ac4567-b563-432f-9f21-3a68ec28e001"],

Cell[BoxData["0.8976982097186701`"], "Output",
 CellChangeTimes->{3.7464451044725895`*^9, 3.7507020188425617`*^9},
 CellLabel->
  "Out[249]=",ExpressionUUID->"96554656-5a2e-428b-948d-41069c800079"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Dimensions", "[", "correct", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/", 
   RowBox[{
    RowBox[{"Dimensions", "[", "dyads", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7464451503270907`*^9, 3.746445161398677*^9}},
 CellLabel->
  "In[250]:=",ExpressionUUID->"7d1b5334-34a0-4fc3-ac9d-33cd5d01af34"],

Cell[BoxData["0.6470588235294118`"], "Output",
 CellChangeTimes->{3.7464451650038347`*^9, 3.7507020188575544`*^9},
 CellLabel->
  "Out[250]=",ExpressionUUID->"7c84a9a6-e029-4c7b-83bd-6287d3032b18"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Edge", "Subsection",
 CellChangeTimes->{{3.7507015909653344`*^9, 
  3.7507015914461374`*^9}},ExpressionUUID->"6abcb041-76ce-4a77-891b-\
85d422d38f8b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"g", ",", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
     RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7505243892416105`*^9, 3.7505244212422175`*^9}, {
   3.7505246004842186`*^9, 3.7505246154349585`*^9}, 3.7507006466260977`*^9, {
   3.7507019505935163`*^9, 3.750701970572261*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"59b6b206-4dc5-447d-a336-395819ea9b0f"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "AMA", "OFR", "DOT", "ASH", "VIN", "ECH", "DIV", "DUI", "MLO", "DOV", 
       "DUN", "PIS", "DEA", "VOR", "VIX", "OST", "OMO", "VEL", "OBI", "OKO", 
       "OCH", "OCE", "TUZ", "VIL", "VAA", "VAP", "VIO", "VAN", "VET", "VAZ", 
       "VIV", "VEG", "VEI", "VAT", "VOT", "ACA", "VOG", "VOY", "VOW", "DUB", 
       "ROY", "OAT", "EDW", "ELV", "ORB", "VAI", "VIG", "DOX", "VEX", 
       "POW"}, {
      Null, {{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 6}, {3, 8}, {3, 9}, {10, 
       11}, {10, 12}, {10, 5}, {13, 10}, {10, 14}, {10, 15}, {6, 16}, {6, 
       17}, {6, 5}, {9, 18}, {19, 20}, {19, 21}, {21, 17}, {2, 17}, {22, 
       17}, {17, 23}, {20, 17}, {16, 24}, {17, 16}, {2, 16}, {16, 5}, {12, 
       15}, {12, 5}, {4, 25}, {25, 26}, {25, 5}, {25, 18}, {25, 14}, {25, 
       15}, {25, 27}, {28, 14}, {28, 29}, {30, 31}, {30, 24}, {32, 31}, {23, 
       18}, {33, 18}, {18, 5}, {18, 31}, {1, 18}, {18, 15}, {18, 14}, {29, 
       15}, {1, 29}, {29, 5}, {29, 14}, {4, 29}, {26, 5}, {5, 14}, {5, 31}, {
       23, 5}, {5, 15}, {18, 27}, {27, 14}, {9, 27}, {17, 27}, {27, 15}, {5, 
       27}, {24, 31}, {31, 14}, {31, 15}, {15, 14}, {17, 15}, {34, 14}, {14, 
       35}, {23, 14}, {9, 14}, {3, 35}, {36, 4}, {4, 10}, {4, 14}, {3, 32}, {
       10, 31}, {4, 2}, {29, 31}, {23, 27}, {4, 27}, {33, 27}, {31, 37}, {15, 
       38}, {15, 35}, {34, 35}, {4, 35}, {5, 35}, {19, 17}, {18, 39}, {1, 
       16}, {13, 11}, {10, 40}, {10, 8}, {6, 41}, {40, 12}, {41, 29}, {27, 
       39}, {3, 10}, {7, 3}, {9, 2}, {19, 16}, {2, 41}, {32, 29}, {9, 15}, {3,
        31}, {8, 25}, {32, 14}, {4, 16}, {29, 38}, {3, 23}, {32, 18}, {42, 
       16}, {43, 18}, {16, 29}, {31, 35}, {6, 44}, {43, 2}, {3, 43}, {4, 
       43}, {45, 18}, {46, 14}, {43, 17}, {29, 47}, {10, 48}, {49, 31}, {16, 
       50}}}, {EdgeStyle -> {UndirectedEdge["DIV", "ECH"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["VIL", "VIV"] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge["AMA", "DOT"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["ASH", "VAA"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["DOT", "MLO"] -> GrayLevel[
           Rational[196, 237]], UndirectedEdge["DOV", "DUB"] -> GrayLevel[
           Rational[97, 237]], UndirectedEdge["VEG", "VEL"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["DEA", "DOV"] -> GrayLevel[
           Rational[131, 237]], UndirectedEdge["OST", "POW"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["OFR", "ROY"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["VIV", "VOT"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["VIO", "VOR"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["ASH", "EDW"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["DOV", "DUI"] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge["DOV", "VIX"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["VAN", "VOR"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["AMA", "OST"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["ECH", "OMO"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["DEA", "DUN"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["OST", "VET"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["VEL", "VIN"] -> GrayLevel[
           Rational[202, 237]], UndirectedEdge["VAT", "VOT"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["OMO", "VIO"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VEL", "VOR"] -> GrayLevel[
           Rational[194, 237]], UndirectedEdge["OAT", "OST"] -> GrayLevel[
           Rational[205, 237]], UndirectedEdge["OST", "VIN"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["AMA", "OFR"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["OMO", "OST"] -> GrayLevel[
           Rational[191, 237]], UndirectedEdge["ECH", "ELV"] -> GrayLevel[
           Rational[197, 237]], UndirectedEdge["ACA", "ASH"] -> GrayLevel[
           Rational[124, 237]], UndirectedEdge["DOT", "VEG"] -> GrayLevel[
           Rational[176, 237]], UndirectedEdge["OCE", "OMO"] -> GrayLevel[
           Rational[134, 237]], UndirectedEdge["ASH", "OFR"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["MLO", "VIO"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VIV", "VOR"] -> GrayLevel[
           Rational[218, 237]], UndirectedEdge["DOV", "VOR"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["ECH", "ROY"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["DOV", "DOX"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["ASH", "VIN"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["DOT", "VIV"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["PIS", "VIX"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["OBI", "OCH"] -> GrayLevel[
           Rational[67, 79]], UndirectedEdge["VAZ", "VIL"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["VAA", "VEL"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["OFR", "OMO"] -> GrayLevel[
           Rational[142, 237]], UndirectedEdge["VEL", "VIX"] -> GrayLevel[
           Rational[199, 237]], UndirectedEdge["VEG", "VOR"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["OST", "VIL"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VEI", "VEL"] -> GrayLevel[
           Rational[176, 237]], UndirectedEdge["VEG", "VIV"] -> GrayLevel[
           Rational[60, 79]], UndirectedEdge["DOT", "DOV"] -> GrayLevel[
           Rational[196, 237]], UndirectedEdge["VET", "VIN"] -> GrayLevel[
           Rational[218, 237]], UndirectedEdge["DOV", "VIV"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VEL", "VIO"] -> GrayLevel[
           Rational[106, 237]], UndirectedEdge["VIO", "VIX"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VET", "VIX"] -> GrayLevel[
           Rational[43, 79]], UndirectedEdge["VAN", "VET"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["VAT", "VOR"] -> GrayLevel[
           Rational[139, 237]], UndirectedEdge["VIV", "VOG"] -> GrayLevel[
           Rational[118, 237]], UndirectedEdge["OMO", "TUZ"] -> GrayLevel[
           Rational[220, 237]], UndirectedEdge["ORB", "VEL"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["OBI", "OKO"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["EDW", "OMO"] -> GrayLevel[
           Rational[211, 237]], UndirectedEdge["DOV", "DUN"] -> GrayLevel[
           Rational[110, 237]], UndirectedEdge["VAA", "VIN"] -> GrayLevel[
           Rational[41, 237]], UndirectedEdge["VIN", "VIX"] -> GrayLevel[
           Rational[181, 237]], UndirectedEdge["VET", "VOR"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["VIX", "VOT"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VIX", "VOR"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["MLO", "VOR"] -> GrayLevel[
           Rational[53, 79]], UndirectedEdge["VAA", "VAP"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["VIN", "VIV"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["VAP", "VIN"] -> GrayLevel[
           Rational[33, 79]], UndirectedEdge["VEI", "VIO"] -> GrayLevel[
           Rational[68, 79]], UndirectedEdge["VEL", "VOW"] -> GrayLevel[
           Rational[164, 237]], UndirectedEdge["VIX", "VOY"] -> GrayLevel[
           Rational[2, 3]], UndirectedEdge["DOV", "VIN"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["ASH", "VET"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["EDW", "VEL"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["VET", "VIV"] -> GrayLevel[
           Rational[72, 79]], UndirectedEdge["VIN", "VOT"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["MLO", "VIX"] -> GrayLevel[
           Rational[202, 237]], UndirectedEdge["EDW", "OFR"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["OCH", "OMO"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VIV", "VIX"] -> GrayLevel[
           Rational[208, 237]], UndirectedEdge["VAZ", "VIV"] -> GrayLevel[
           Rational[119, 237]], UndirectedEdge["VET", "VIG"] -> GrayLevel[
           Rational[206, 237]], UndirectedEdge["VEG", "VET"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["TUZ", "VOR"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["DOT", "DUI"] -> GrayLevel[
           Rational[137, 237]], UndirectedEdge["ECH", "OST"] -> GrayLevel[
           Rational[190, 237]], UndirectedEdge["TUZ", "VIO"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VAA", "VOR"] -> GrayLevel[
           Rational[214, 237]], UndirectedEdge["TUZ", "VIN"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["PIS", "VIN"] -> GrayLevel[
           Rational[57, 79]], UndirectedEdge["OFR", "OST"] -> GrayLevel[
           Rational[69, 79]], UndirectedEdge["DUI", "VAA"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["VAA", "VIO"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["AMA", "VET"] -> GrayLevel[
           Rational[66, 79]], UndirectedEdge["OBI", "OMO"] -> GrayLevel[
           Rational[48, 79]], UndirectedEdge["DOT", "EDW"] -> GrayLevel[
           Rational[74, 79]], UndirectedEdge["DIV", "DOT"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["OMO", "VIX"] -> GrayLevel[
           Rational[223, 237]], UndirectedEdge["VOR", "VOT"] -> GrayLevel[
           Rational[21, 79]], UndirectedEdge["ASH", "DOV"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["OKO", "OMO"] -> GrayLevel[
           Rational[199, 237]], UndirectedEdge["DOV", "PIS"] -> GrayLevel[0], 
         UndirectedEdge["DOT", "TUZ"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["AMA", "VEL"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["DUB", "PIS"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["ROY", "VET"] -> GrayLevel[
           Rational[66, 79]], UndirectedEdge["ASH", "VIO"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VAA", "VIX"] -> GrayLevel[
           Rational[226, 237]], UndirectedEdge["MLO", "VEL"] -> GrayLevel[
           Rational[215, 237]], UndirectedEdge["VAI", "VOR"] -> GrayLevel[
           Rational[70, 79]], UndirectedEdge["VET", "VOY"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VEL", "VIV"] -> GrayLevel[
           Rational[200, 237]], UndirectedEdge["ASH", "ECH"] -> GrayLevel[
           Rational[65, 79]], UndirectedEdge["ASH", "VOR"] -> GrayLevel[
           Rational[71, 79]], UndirectedEdge["TUZ", "VEL"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["VEX", "VIV"] -> GrayLevel[
           Rational[220, 237]], UndirectedEdge["ASH", "VOT"] -> GrayLevel[
           Rational[224, 237]], UndirectedEdge["DOT", "VOT"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["VIN", "VOR"] -> GrayLevel[
           Rational[206, 237]], UndirectedEdge["VIO", "VOW"] -> GrayLevel[
           Rational[227, 237]], UndirectedEdge["ECH", "VIN"] -> GrayLevel[
           Rational[221, 237]], UndirectedEdge["OBI", "OST"] -> GrayLevel[
           Rational[217, 237]], UndirectedEdge["MLO", "OFR"] -> GrayLevel[
           Rational[75, 79]], UndirectedEdge["ASH", "OST"] -> GrayLevel[
           Rational[70, 79]], UndirectedEdge["VIN", "VIO"] -> GrayLevel[
           Rational[223, 237]]}, 
       EdgeWeight -> {13, 30, 20, 42, 12, 100, 41, 127, 237, 21, 106, 23, 13, 
        47, 14, 16, 22, 12, 36, 14, 95, 103, 17, 38, 11, 46, 30, 10, 20, 66, 
        16, 22, 196, 14, 23, 11, 13, 23, 11, 118, 23, 57, 16, 61, 35, 37, 12, 
        38, 43, 108, 39, 19, 22, 16, 138, 31, 12, 13, 56, 131, 24, 10, 11, 11,
         14, 36, 19, 29, 30, 14, 98, 174, 10, 78, 10, 113, 13, 24, 61, 14, 15,
         21, 10, 10, 33, 119, 79, 14, 21, 13, 11, 93, 73, 12, 24, 140, 36, 13,
         16, 39, 10, 41, 20, 12, 20, 16, 22, 35, 13, 15, 24, 27, 10, 24, 12, 
        32, 22, 12, 12, 40, 30, 15, 14, 15, 27, 26, 31, 21, 17, 10}, 
       GraphHighlight -> {
         UndirectedEdge["OAT", "OST"], 
         UndirectedEdge["VAT", "VOR"], 
         UndirectedEdge["DOV", "DUN"], 
         UndirectedEdge["DOV", "VOR"], 
         UndirectedEdge["VEG", "VET"], 
         UndirectedEdge["VET", "VIN"], 
         UndirectedEdge["VEI", "VEL"], 
         UndirectedEdge["VAA", "VOR"], 
         UndirectedEdge["OFR", "ROY"], 
         UndirectedEdge["AMA", "OST"], 
         UndirectedEdge["OMO", "TUZ"], 
         UndirectedEdge["ORB", "VEL"], 
         UndirectedEdge["DOT", "VEG"], 
         UndirectedEdge["EDW", "VEL"], 
         UndirectedEdge["OCE", "OMO"], 
         UndirectedEdge["DEA", "DOV"], 
         UndirectedEdge["DOT", "VIV"], 
         UndirectedEdge["VAI", "VOR"], 
         UndirectedEdge["ASH", "ECH"], 
         UndirectedEdge["AMA", "OFR"], 
         UndirectedEdge["VET", "VOR"], 
         UndirectedEdge["MLO", "VIX"], 
         UndirectedEdge["VEG", "VIV"], 
         UndirectedEdge["VAP", "VIN"], 
         UndirectedEdge["VIX", "VOR"], 
         UndirectedEdge["OST", "POW"], 
         UndirectedEdge["DOT", "VOT"], 
         UndirectedEdge["VEI", "VIO"], 
         UndirectedEdge["OFR", "OST"], 
         UndirectedEdge["MLO", "VOR"], 
         UndirectedEdge["VIN", "VOR"], 
         UndirectedEdge["ECH", "ROY"], 
         UndirectedEdge["ASH", "OFR"], 
         UndirectedEdge["DOV", "VIN"], 
         UndirectedEdge["OBI", "OST"], 
         UndirectedEdge["VIV", "VIX"], 
         UndirectedEdge["DOT", "DUI"], 
         UndirectedEdge["VIV", "VOR"], 
         UndirectedEdge["OBI", "OCH"], 
         UndirectedEdge["VAT", "VOT"], 
         UndirectedEdge["ECH", "OMO"], 
         UndirectedEdge["OMO", "OST"], 
         UndirectedEdge["VOR", "VOT"], 
         UndirectedEdge["VAA", "VIN"], 
         UndirectedEdge["DUI", "VAA"], 
         UndirectedEdge["OCH", "OMO"], 
         UndirectedEdge["VIX", "VOY"], 
         UndirectedEdge["OKO", "OMO"], 
         UndirectedEdge["VIN", "VIV"], 
         UndirectedEdge["VIV", "VOG"], 
         UndirectedEdge["VET", "VIX"], 
         UndirectedEdge["VAA", "VAP"], 
         UndirectedEdge["AMA", "VEL"], 
         UndirectedEdge["VAA", "VIX"], 
         UndirectedEdge["DIV", "DOT"], 
         UndirectedEdge["OFR", "OMO"], 
         UndirectedEdge["VAN", "VOR"], 
         UndirectedEdge["EDW", "OMO"], 
         UndirectedEdge["VET", "VOY"], 
         UndirectedEdge["DOV", "DUB"], 
         UndirectedEdge["OST", "VIL"], 
         UndirectedEdge["VAZ", "VIV"], 
         UndirectedEdge["DEA", "DUN"], 
         UndirectedEdge["VIV", "VOT"], 
         UndirectedEdge["PIS", "VIN"], 
         UndirectedEdge["DOV", "VIV"], 
         UndirectedEdge["DOT", "MLO"], 
         UndirectedEdge["OMO", "VIO"], 
         UndirectedEdge["TUZ", "VEL"], 
         UndirectedEdge["OBI", "OKO"], 
         UndirectedEdge["ACA", "ASH"], 
         UndirectedEdge["EDW", "OFR"], 
         UndirectedEdge["ASH", "EDW"], 
         UndirectedEdge["VET", "VIG"], 
         UndirectedEdge["VEG", "VOR"], 
         UndirectedEdge["DOV", "DOX"], 
         UndirectedEdge["VIX", "VOT"], 
         UndirectedEdge["VAN", "VET"], 
         UndirectedEdge["DOV", "DUI"], 
         UndirectedEdge["DOV", "PIS"], 
         UndirectedEdge["VEL", "VIO"], 
         UndirectedEdge["VIN", "VOT"], 
         UndirectedEdge["PIS", "VIX"], 
         UndirectedEdge["DUB", "PIS"], 
         UndirectedEdge["DOT", "DOV"], 
         UndirectedEdge["DOV", "VIX"], 
         UndirectedEdge["VIN", "VIX"], 
         UndirectedEdge["ASH", "OST"], 
         UndirectedEdge["VEL", "VOW"], 
         UndirectedEdge["VEX", "VIV"], 
         UndirectedEdge["VET", "VIV"], 
         UndirectedEdge["OBI", "OMO"], 
         UndirectedEdge["VIO", "VOW"], 
         UndirectedEdge["ECH", "ELV"], 
         UndirectedEdge["TUZ", "VIO"], 
         UndirectedEdge["ASH", "VIO"], 
         UndirectedEdge["ECH", "OST"]}, GraphLayout -> {"Dimension" -> 2}, 
       VertexLabels -> {"Name"}, VertexStyle -> {"VIN" -> GrayLevel[
           Rational[67, 396]], "VOY" -> GrayLevel[
           Rational[703, 792]], "DOT" -> GrayLevel[
           Rational[437, 792]], "ORB" -> GrayLevel[
           Rational[259, 264]], "VAZ" -> GrayLevel[
           Rational[217, 264]], "OAT" -> GrayLevel[
           Rational[95, 99]], "VET" -> GrayLevel[
           Rational[221, 396]], "ACA" -> GrayLevel[
           Rational[679, 792]], "VIL" -> GrayLevel[
           Rational[361, 396]], "OKO" -> GrayLevel[
           Rational[371, 396]], "OMO" -> GrayLevel[
           Rational[107, 264]], "DOX" -> GrayLevel[
           Rational[257, 264]], "VAT" -> GrayLevel[
           Rational[673, 792]], "VEL" -> GrayLevel[
           Rational[29, 88]], "VIG" -> GrayLevel[
           Rational[761, 792]], "VOR" -> GrayLevel[
           Rational[119, 792]], "EDW" -> GrayLevel[
           Rational[685, 792]], "ROY" -> GrayLevel[
           Rational[181, 198]], "DUB" -> GrayLevel[
           Rational[53, 66]], "VEX" -> GrayLevel[
           Rational[775, 792]], "VAP" -> GrayLevel[
           Rational[79, 99]], "ASH" -> GrayLevel[
           Rational[469, 792]], "VAN" -> GrayLevel[
           Rational[379, 396]], "ELV" -> GrayLevel[
           Rational[94, 99]], "VIV" -> GrayLevel[
           Rational[4, 11]], "TUZ" -> GrayLevel[
           Rational[39, 44]], "ECH" -> GrayLevel[
           Rational[76, 99]], "OCH" -> GrayLevel[
           Rational[371, 396]], "DIV" -> GrayLevel[
           Rational[95, 99]], "DUI" -> GrayLevel[
           Rational[641, 792]], "VOG" -> GrayLevel[
           Rational[673, 792]], "VIX" -> GrayLevel[
           Rational[167, 396]], "VOT" -> GrayLevel[
           Rational[179, 264]], "AMA" -> GrayLevel[
           Rational[343, 396]], "VIO" -> GrayLevel[
           Rational[515, 792]], "DUN" -> GrayLevel[
           Rational[641, 792]], "POW" -> GrayLevel[
           Rational[391, 396]], "VAA" -> GrayLevel[
           Rational[241, 396]], "MLO" -> GrayLevel[
           Rational[3, 4]], "OST" -> GrayLevel[
           Rational[535, 792]], "OFR" -> GrayLevel[
           Rational[581, 792]], "VEG" -> GrayLevel[
           Rational[7, 9]], "VAI" -> GrayLevel[
           Rational[85, 88]], "VEI" -> GrayLevel[
           Rational[349, 396]], "VOW" -> GrayLevel[
           Rational[709, 792]], "OBI" -> GrayLevel[
           Rational[631, 792]], "OCE" -> GrayLevel[
           Rational[689, 792]], "DEA" -> GrayLevel[
           Rational[331, 396]], "PIS" -> GrayLevel[
           Rational[151, 264]], "DOV" -> GrayLevel[0]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           1.7490536653376987`, 2.0596769160666244`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[69, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           3.06910335000307, 1.965307568098614}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[66, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.2417421967893736`, 1.9967248724965296`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           2.6923739957704953`, 2.3116495007135645`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           2.5593984745938423`, 2.5508550429575}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           1.7130052088944134`, 1.0558619988176456`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7490536653376987`, 2.0596769160666244`}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.3254801139325076`, 0.8427900980487346}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {4.098806202058695,
            2.6040284702046423`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.5593984745938423`, 2.5508550429575}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {4.276805586776847,
            1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[71, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[74, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.06910335000307, 1.965307568098614}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[217, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.0508254247212463`, 2.3011085273433345`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           1.9350586108814647`, 1.4314573947187421`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           4.276805586776847, 1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[71, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[221, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[221, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.412520993581118, 3.6224390013597016`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.6923739957704953`, 2.3116495007135645`}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[221, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           1.9350586108814647`, 1.4314573947187421`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           4.276805586776847, 1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           4.056068133125937, 1.577936911527845}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[227, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[202, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.580151017437533, 3.5362323082782128`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[223, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0508254247212463`, 2.3011085273433345`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           2.3254801139325076`, 0.8427900980487346}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.7070907247637195`, 1.567411953661388}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.7130052088944134`, 1.0558619988176456`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.9350586108814647`, 1.4314573947187421`}, {
           1.2345042461710136`, 0.22223793934819325`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.098806202058695, 2.6040284702046423`}, {
           4.276805586776847, 1.9649816740304353`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.098806202058695, 2.6040284702046423`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[215, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[227, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.5593984745938423`, 2.5508550429575}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           5.705942496372727, 1.7037420043212381`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           4.056068133125937, 1.577936911527845}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           5.609486156720985, 1.337650842585623}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           3.3985098954680972`, 2.547823829731471}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           4.842294325772201, 1.0381550924567922`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.276805586776847, 1.9649816740304353`}, {
           5.711158690299976, 2.2642987881564105`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{5.705942496372727, 1.7037420043212381`}, {
           5.609486156720985, 1.337650842585623}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.056068133125937, 1.577936911527845}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.056068133125937, 1.577936911527845}, {
           4.842294325772201, 1.0381550924567922`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.003863029787065, 2.1431947879426105`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[194, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[227, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[71, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.577071127785599, 1.2956185619005178`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           4.3641850672617775`, 3.1416889714552063`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.3985098954680972`, 2.547823829731471}, {
           4.305020433317991, 3.771022748712493}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[223, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[199, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.8393248416980734`, 3.001678912953419}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[226, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.003863029787065, 2.1431947879426105`}, {
           2.7992088083622755`, 0.953005653387923}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           1.323817058151051, 2.4295893529329433`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           0.5214085110208795, 2.0829862735279354`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           3.0521136330652543`, 0.770227690922028}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           0.42395458198833547`, 1.0268753139750664`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.7070907247637195`, 1.567411953661388}, {
           0.6804972928289903, 0.6187971060378612}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           0.5214085110208795, 2.0829862735279354`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           0.12078515290921654`, 2.650232619453675}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {0., 
           2.26930332084519}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           0.20040482376984903`, 3.2241708698882308`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{1.323817058151051, 2.4295893529329433`}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.3724849871837996`, 2.7062903408578323`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[223, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           3.2804975122357636`, 2.9741602758583543`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[200, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[75, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.1038785769545756`, 3.9353441339932367`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.560614392848657, 4.061823599966873}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.0159240870708266`, 2.565622289742292}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.8393248416980734`, 3.001678912953419}, {
           2.9731935590146934`, 4.485354095364575}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{0.5214085110208795, 2.0829862735279354`}, {
           0.12078515290921654`, 2.650232619453675}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{0.5214085110208795, 2.0829862735279354`}, {0., 
           2.26930332084519}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.3724849871837996`, 2.7062903408578323`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[214, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0521136330652543`, 0.770227690922028}, {
           3.900972389572577, 0.4895713159101325}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[67, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.0521136330652543`, 0.770227690922028}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.2804975122357636`, 2.9741602758583543`}, {
           3.580151017437533, 3.5362323082782128`}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[224, 237]], 
         {Arrowheads[0.], 
          ArrowBox[{{3.2804975122357636`, 2.9741602758583543`}, {
           2.493094552434439, 3.0393162226740644`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.493094552434439, 3.0393162226740644`}, {
           2.1038785769545756`, 3.9353441339932367`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.493094552434439, 3.0393162226740644`}, {
           2.560614392848657, 4.061823599966873}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.577071127785599, 1.2956185619005178`}, {
           2.7921031203706335`, 1.4865966978459673`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           2.7992088083622755`, 0.953005653387923}}, 0.046966480367839764`]}}, 
        {GrayLevel[
          Rational[66, 79]], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           1.7130052088944134`, 1.0558619988176456`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{2.7921031203706335`, 1.4865966978459673`}, {
           2.7573833949139783`, 0.}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.900972389572577, 0.4895713159101325}, {
           3.7341742761150485`, 1.7833992223252553`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           3.4345059388892007`, 2.1083766127232515`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           5.05770479431974, 2.0984234127332657`}}, 0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{3.7341742761150485`, 1.7833992223252553`}, {
           5.0023437070107075`, 1.4077748294239933`}}, 
           0.046966480367839764`]}}, 
        {Hue[1, 1, 0.7], Opacity[1], 
         {Arrowheads[0.], 
          ArrowBox[{{4.3641850672617775`, 3.1416889714552063`}, {
           3.6643999386692236`, 2.4798935651387697`}}, 
           0.046966480367839764`]}}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         {GrayLevel[
           Rational[343, 396]], 
          DiskBox[{2.2417421967893736, 1.9967248724965296}, 
           0.046966480367839764]}, 
         InsetBox["\<\"AMA\"\>", 
          Offset[{2, 2}, {2.288708677157213, 2.043691352864369}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[581, 792]], 
          DiskBox[{1.7490536653376987, 2.0596769160666244}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OFR\"\>", 
          Offset[{2, 2}, {1.7960201457055385, 2.106643396434464}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[437, 792]], 
          DiskBox[{3.06910335000307, 1.965307568098614}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DOT\"\>", 
          Offset[{2, 2}, {3.11606983037091, 2.0122740484664536}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[469, 792]], 
          DiskBox[{2.6923739957704953, 2.3116495007135645}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ASH\"\>", 
          Offset[{2, 2}, {2.739340476138335, 2.358615981081404}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[67, 396]], 
          DiskBox[{3.0508254247212463, 2.3011085273433345}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIN\"\>", 
          Offset[{2, 2}, {3.097791905089086, 2.348075007711174}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[76, 99]], 
          DiskBox[{1.9350586108814647, 1.4314573947187421}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ECH\"\>", 
          Offset[{2, 2}, {1.9820250912493045, 1.478423875086582}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[95, 99]], 
          DiskBox[{2.3254801139325076, 0.8427900980487346}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DIV\"\>", 
          Offset[{2, 2}, {2.372446594300347, 0.8897565784165744}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[641, 792]], 
          DiskBox[{4.098806202058695, 2.6040284702046423}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DUI\"\>", 
          Offset[{2, 2}, {4.145772682426535, 2.650994950572482}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[3, 4]], 
          DiskBox[{2.5593984745938423, 2.5508550429575}, 
           0.046966480367839764]}, 
         InsetBox["\<\"MLO\"\>", 
          Offset[{2, 2}, {2.606364954961682, 2.5978215233253397}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[0], 
          DiskBox[{4.276805586776847, 1.9649816740304353}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DOV\"\>", 
          Offset[{2, 2}, {4.323772067144687, 2.011948154398275}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[641, 792]], 
          DiskBox[{5.705942496372727, 1.7037420043212381}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DUN\"\>", 
          Offset[{2, 2}, {5.752908976740567, 1.750708484689078}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[151, 264]], 
          DiskBox[{4.056068133125937, 1.577936911527845}, 
           0.046966480367839764]}, 
         InsetBox["\<\"PIS\"\>", 
          Offset[{2, 2}, {4.103034613493777, 1.6249033918956848}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[331, 396]], 
          DiskBox[{5.609486156720985, 1.337650842585623}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DEA\"\>", 
          Offset[{2, 2}, {5.656452637088825, 1.3846173229534628}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[119, 792]], 
          DiskBox[{3.3985098954680972, 2.547823829731471}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOR\"\>", 
          Offset[{2, 2}, {3.445476375835937, 2.5947903100993104}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[167, 396]], 
          DiskBox[{3.003863029787065, 2.1431947879426105}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIX\"\>", 
          Offset[{2, 2}, {3.0508295101549048, 2.19016126831045}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[535, 792]], 
          DiskBox[{1.7070907247637195, 1.567411953661388}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OST\"\>", 
          Offset[{2, 2}, {1.7540572051315593, 1.6143784340292278}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[107, 264]], 
          DiskBox[{1.323817058151051, 2.4295893529329433}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OMO\"\>", 
          Offset[{2, 2}, {1.370783538518891, 2.476555833300783}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[29, 88]], 
          DiskBox[{2.8393248416980734, 3.001678912953419}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEL\"\>", 
          Offset[{2, 2}, {2.886291322065913, 3.0486453933212587}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[631, 792]], 
          DiskBox[{0.5214085110208795, 2.0829862735279354}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OBI\"\>", 
          Offset[{2, 2}, {0.5683749913887193, 2.129952753895775}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[371, 396]], 
          DiskBox[{0.12078515290921654, 2.650232619453675}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OKO\"\>", 
          Offset[{2, 2}, {0.1677516332770563, 2.6971990998215145}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[371, 396]], 
          DiskBox[{0., 2.26930332084519}, 0.046966480367839764]}, 
         InsetBox["\<\"OCH\"\>", 
          Offset[{2, 2}, {0.046966480367839764, 2.3162698012130294}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[689, 792]], 
          DiskBox[{0.20040482376984903, 3.2241708698882308}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OCE\"\>", 
          Offset[{2, 2}, {0.2473713041376888, 3.2711373502560703}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[39, 44]], 
          DiskBox[{2.3724849871837996, 2.7062903408578323}, 
           0.046966480367839764]}, 
         InsetBox["\<\"TUZ\"\>", 
          Offset[{2, 2}, {2.419451467551639, 2.753256821225672}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[361, 396]], 
          DiskBox[{3.0521136330652543, 0.770227690922028}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIL\"\>", 
          Offset[{2, 2}, {3.099080113433094, 0.8171941712898678}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[241, 396]], 
          DiskBox[{3.2804975122357636, 2.9741602758583543}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAA\"\>", 
          Offset[{2, 2}, {3.327463992603603, 3.021126756226194}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[79, 99]], 
          DiskBox[{3.580151017437533, 3.5362323082782128}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAP\"\>", 
          Offset[{2, 2}, {3.6271174978053726, 3.5831987886460523}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[515, 792]], 
          DiskBox[{2.493094552434439, 3.0393162226740644}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIO\"\>", 
          Offset[{2, 2}, {2.5400610328022784, 3.086282703041904}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[379, 396]], 
          DiskBox[{3.577071127785599, 1.2956185619005178}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAN\"\>", 
          Offset[{2, 2}, {3.6240376081534387, 1.3425850422683576}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[221, 396]], 
          DiskBox[{2.7921031203706335, 1.4865966978459673}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VET\"\>", 
          Offset[{2, 2}, {2.839069600738473, 1.533563178213807}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[217, 264]], 
          DiskBox[{3.900972389572577, 0.4895713159101325}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAZ\"\>", 
          Offset[{2, 2}, {3.9479388699404168, 0.5365377962779723}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[4, 11]], 
          DiskBox[{3.7341742761150485, 1.7833992223252553}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VIV\"\>", 
          Offset[{2, 2}, {3.781140756482888, 1.830365702693095}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[7, 9]], 
          DiskBox[{3.4345059388892007, 2.1083766127232515}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEG\"\>", 
          Offset[{2, 2}, {3.4814724192570403, 2.155343093091091}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[349, 396]], 
          DiskBox[{2.1038785769545756, 3.9353441339932367}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEI\"\>", 
          Offset[{2, 2}, {2.150845057322415, 3.9823106143610763}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[673, 792]], 
          DiskBox[{4.3641850672617775, 3.1416889714552063}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAT\"\>", 
          Offset[{2, 2}, {4.4111515476296175, 3.188655451823046}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[179, 264]], 
          DiskBox[{3.6643999386692236, 2.4798935651387697}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOT\"\>", 
          Offset[{2, 2}, {3.711366419037063, 2.5268600455066093}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[679, 792]], 
          DiskBox[{2.412520993581118, 3.6224390013597016}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ACA\"\>", 
          Offset[{2, 2}, {2.4594874739489576, 3.669405481727541}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[673, 792]], 
          DiskBox[{5.05770479431974, 2.0984234127332657}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOG\"\>", 
          Offset[{2, 2}, {5.10467127468758, 2.1453898931011053}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[703, 792]], 
          DiskBox[{2.7992088083622755, 0.953005653387923}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOY\"\>", 
          Offset[{2, 2}, {2.846175288730115, 0.9999721337557628}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[709, 792]], 
          DiskBox[{2.560614392848657, 4.061823599966873}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VOW\"\>", 
          Offset[{2, 2}, {2.6075808732164965, 4.108790080334713}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[53, 66]], 
          DiskBox[{4.842294325772201, 1.0381550924567922}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DUB\"\>", 
          Offset[{2, 2}, {4.889260806140041, 1.085121572824632}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[181, 198]], 
          DiskBox[{1.7130052088944134, 1.0558619988176456}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ROY\"\>", 
          Offset[{2, 2}, {1.7599716892622532, 1.1028284791854854}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[95, 99]], 
          DiskBox[{0.42395458198833547, 1.0268753139750664}, 
           0.046966480367839764]}, 
         InsetBox["\<\"OAT\"\>", 
          Offset[{2, 2}, {0.47092106235617526, 1.0738417943429062}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[685, 792]], 
          DiskBox[{2.0159240870708266, 2.565622289742292}, 
           0.046966480367839764]}, 
         InsetBox["\<\"EDW\"\>", 
          Offset[{2, 2}, {2.062890567438666, 2.6125887701101314}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[94, 99]], 
          DiskBox[{1.2345042461710136, 0.22223793934819325}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ELV\"\>", 
          Offset[{2, 2}, {1.2814707265388534, 0.26920441971603304}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[259, 264]], 
          DiskBox[{2.9731935590146934, 4.485354095364575}, 
           0.046966480367839764]}, 
         InsetBox["\<\"ORB\"\>", 
          Offset[{2, 2}, {3.020160039382533, 4.532320575732415}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[85, 88]], 
          DiskBox[{4.305020433317991, 3.771022748712493}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VAI\"\>", 
          Offset[{2, 2}, {4.351986913685831, 3.817989229080333}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[761, 792]], 
          DiskBox[{2.7573833949139783, 0.}, 0.046966480367839764]}, 
         InsetBox["\<\"VIG\"\>", 
          Offset[{2, 2}, {2.804349875281818, 0.046966480367839764}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[257, 264]], 
          DiskBox[{5.711158690299976, 2.2642987881564105}, 
           0.046966480367839764]}, 
         InsetBox["\<\"DOX\"\>", 
          Offset[{2, 2}, {5.758125170667816, 2.31126526852425}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[775, 792]], 
          DiskBox[{5.0023437070107075, 1.4077748294239933}, 
           0.046966480367839764]}, 
         InsetBox["\<\"VEX\"\>", 
          Offset[{2, 2}, {5.0493101873785475, 1.4547413097918331}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {GrayLevel[
           Rational[391, 396]], 
          DiskBox[{0.6804972928289903, 0.6187971060378612}, 
           0.046966480367839764]}, 
         InsetBox["\<\"POW\"\>", 
          Offset[{2, 2}, {0.7274637731968301, 0.665763586405701}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.7505244011606627`*^9, 3.750524422053951*^9}, 
   3.7505246158879757`*^9, 3.7507006472444844`*^9, 3.7507020190273314`*^9},
 CellLabel->
  "Out[251]=",ExpressionUUID->"251885a2-2675-4b3b-976e-e0645df66c31"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"broken", "=", 
  RowBox[{"Complement", "[", 
   RowBox[{
    RowBox[{"EdgeList", "[", "graph", "]"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
      RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "bonds", " ", "that", " ", "broke", " ", "during", " ", "fission"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.750700031147353*^9, 3.750700070296363*^9}, {
   3.7507001034427614`*^9, 3.750700107265873*^9}, {3.7507005132145367`*^9, 
   3.750700531385273*^9}, {3.750701976608503*^9, 3.7507019808624787`*^9}, 
   3.8302458935139*^9},ExpressionUUID->"0bd5485b-5b96-4bd3-a390-3a592b7eb0d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"DOT\"\>"}], ",", 
   RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"DOV\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VAA\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
   RowBox[{"\<\"DIV\"\>", "\[UndirectedEdge]", "\<\"ECH\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"EDW\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"TUZ\"\>"}], ",", 
   RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
   RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
   RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"ROY\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
   RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"VAZ\"\>", "\[UndirectedEdge]", "\<\"VIL\"\>"}], ",", 
   RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VIL\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"VIO\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"VIO\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7507000509468594`*^9, 3.7507000708998623`*^9}, 
   3.75070010894396*^9, 3.7507020190596604`*^9},
 CellLabel->
  "Out[252]=",ExpressionUUID->"4c7d66bf-c9f2-411c-b1c3-99798845ef36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"maintained", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"EdgeList", "[", "fission1", "]"}], ",", 
    RowBox[{"EdgeList", "[", "fission2", "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "bonds", " ", "that", " ", "were", " ", "maintained", " ", "through", " ", 
    "fission"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7507001139426684`*^9, 3.750700126825451*^9}, {
  3.750700534046118*^9, 3.750700543664417*^9}, {3.7507019829057436`*^9, 
  3.7507019871658993`*^9}},
 CellLabel->
  "In[253]:=",ExpressionUUID->"02742891-720d-41c3-9d2e-28e6a7f97b9c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"DIV\"\>", "\[UndirectedEdge]", "\<\"DOT\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"DUI\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"MLO\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DUI\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"DOV\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DUN\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"PIS\"\>"}], ",", 
   RowBox[{"\<\"PIS\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"DEA\"\>", "\[UndirectedEdge]", "\<\"DOV\"\>"}], ",", 
   RowBox[{"\<\"DEA\"\>", "\[UndirectedEdge]", "\<\"DUN\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"PIS\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"VIX\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"DUI\"\>", "\[UndirectedEdge]", "\<\"VAA\"\>"}], ",", 
   RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VAP\"\>"}], ",", 
   RowBox[{"\<\"VAP\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"VAN\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VAN\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
   RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
   RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VAZ\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"VEG\"\>"}], ",", 
   RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
   RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VAT\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VOR\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
   RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
   RowBox[{"\<\"VIX\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
   RowBox[{"\<\"VAT\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
   RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
   RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
   RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VOG\"\>"}], ",", 
   RowBox[{"\<\"VIX\"\>", "\[UndirectedEdge]", "\<\"VOY\"\>"}], ",", 
   RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VOY\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DUB\"\>"}], ",", 
   RowBox[{"\<\"DUB\"\>", "\[UndirectedEdge]", "\<\"PIS\"\>"}], ",", 
   RowBox[{"\<\"VAI\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
   RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIG\"\>"}], ",", 
   RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DOX\"\>"}], ",", 
   RowBox[{"\<\"VEX\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
   RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"ECH\"\>"}], ",", 
   RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
   RowBox[{"\<\"OFR\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
   RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
   RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
   RowBox[{"\<\"OFR\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
   RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
   RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
   RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
   RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OKO\"\>"}], ",", 
   RowBox[{"\<\"OKO\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
   RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OCH\"\>"}], ",", 
   RowBox[{"\<\"OCH\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
   RowBox[{"\<\"OCE\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
   RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"TUZ\"\>"}], ",", 
   RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"VIL\"\>"}], ",", 
   RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"VEI\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"VEI\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
   RowBox[{"\<\"ACA\"\>", "\[UndirectedEdge]", "\<\"ASH\"\>"}], ",", 
   RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VOW\"\>"}], ",", 
   RowBox[{"\<\"VIO\"\>", "\[UndirectedEdge]", "\<\"VOW\"\>"}], ",", 
   RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"ROY\"\>"}], ",", 
   RowBox[{"\<\"OFR\"\>", "\[UndirectedEdge]", "\<\"ROY\"\>"}], ",", 
   RowBox[{"\<\"OAT\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
   RowBox[{"\<\"EDW\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"EDW\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
   RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"EDW\"\>"}], ",", 
   RowBox[{"\<\"EDW\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
   RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"ELV\"\>"}], ",", 
   RowBox[{"\<\"ORB\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
   RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"POW\"\>"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7507001281499543`*^9, 3.7507020190802503`*^9},
 CellLabel->
  "Out[253]=",ExpressionUUID->"9da4a00c-57ea-4499-9450-88de2981b233"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Dimensions", "[", "broken", "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"#", " ", "of", " ", "broken", " ", "bonds"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dimensions", "[", "maintained", "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"#", " ", "of", " ", "maintained", " ", "bonds"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"%%", "/", 
    RowBox[{"(", 
     RowBox[{"%", "+", "%%"}], ")"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "%", " ", "of", " ", "bonds", " ", "that", " ", "were", " ", "broken"}], 
   " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.750700134052451*^9, 3.7507001780200214`*^9}, {
  3.75070054857069*^9, 3.7507005703695955`*^9}},
 CellLabel->
  "In[254]:=",ExpressionUUID->"5f87165f-b281-44d1-b9c3-1d499da5a30e"],

Cell[BoxData[
 RowBox[{"{", "33", "}"}]], "Output",
 CellChangeTimes->{
  3.7507001419220247`*^9, {3.7507001736829534`*^9, 3.750700178391526*^9}, 
   3.75070201910221*^9},
 CellLabel->
  "Out[254]=",ExpressionUUID->"afed7f81-7a39-4e43-b2c8-dfe063893689"],

Cell[BoxData[
 RowBox[{"{", "97", "}"}]], "Output",
 CellChangeTimes->{
  3.7507001419220247`*^9, {3.7507001736829534`*^9, 3.750700178391526*^9}, 
   3.7507020191079454`*^9},
 CellLabel->
  "Out[255]=",ExpressionUUID->"1394cbf5-10d8-40c1-8444-f646834d4aff"],

Cell[BoxData[
 RowBox[{"{", "0.25384615384615383`", "}"}]], "Output",
 CellChangeTimes->{
  3.7507001419220247`*^9, {3.7507001736829534`*^9, 3.750700178391526*^9}, 
   3.7507020191128635`*^9},
 CellLabel->
  "Out[256]=",ExpressionUUID->"637cd186-c40e-466b-b25d-c815533f1354"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Total", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{"strongbonds", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"broken", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"broken", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{
           RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
     "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "sum", " ", "of", " ", "weights", " ", "of", " ", "broken", " ", "bonds"}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"Mean", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"strongbonds", ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
              RowBox[{"broken", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
              RowBox[{"broken", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
      "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "weight", " ", "of", " ", "broken", " ", "bond"}], 
   " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.7507003174423923`*^9, 3.7507004374483433`*^9}, {
  3.7507005741503367`*^9, 3.7507005906245794`*^9}},
 CellLabel->
  "In[257]:=",ExpressionUUID->"8da4586d-2218-47f9-aec7-fab55eeaeb24"],

Cell[BoxData["680"], "Output",
 CellChangeTimes->{{3.7507003884455147`*^9, 3.750700438523142*^9}, 
   3.75070201917936*^9},
 CellLabel->
  "Out[257]=",ExpressionUUID->"083ca781-8740-4cee-8d44-f134d697dd36"],

Cell[BoxData["20.606060606060606`"], "Output",
 CellChangeTimes->{{3.7507003884455147`*^9, 3.750700438523142*^9}, 
   3.7507020191853495`*^9},
 CellLabel->
  "Out[258]=",ExpressionUUID->"3faa0fd0-d3d5-450d-b1e1-4ab376e29017"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Total", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{"strongbonds", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"maintained", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"maintained", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{
           RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
     "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "sum", " ", "of", " ", "weights", " ", "of", " ", "maintained", " ", 
    "bonds"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"Mean", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"strongbonds", ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
              RowBox[{"maintained", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
              RowBox[{"maintained", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
      "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "average", " ", "weight", " ", "of", " ", "maintained", " ", "bond"}], " ",
    "*)"}]}]}], "Input",
 CellChangeTimes->{{3.750700469589544*^9, 3.7507004731925354`*^9}, {
  3.750700598092454*^9, 3.7507006259531965`*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"3ee53f72-80c5-49ce-b976-09df7ffc2f88"],

Cell[BoxData["4266"], "Output",
 CellChangeTimes->{3.750700478377082*^9, 3.750702019287306*^9},
 CellLabel->
  "Out[259]=",ExpressionUUID->"71788309-5c61-454f-a82e-1baed04b002a"],

Cell[BoxData["43.97938144329897`"], "Output",
 CellChangeTimes->{3.750700478377082*^9, 3.7507020193038454`*^9},
 CellLabel->
  "Out[260]=",ExpressionUUID->"37e33a04-4d8c-45b8-8aab-958bc2cc1683"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Select", "[", 
           RowBox[{"strongbonds", ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
               RowBox[{"broken", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
               RowBox[{"broken", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
       "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "/", 
    RowBox[{"Min", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Dimensions", "[", 
        RowBox[{"VertexList", "[", "fission1", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", 
        RowBox[{"VertexList", "[", "fission2", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"sparsity", " ", "of", " ", "fission"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.750700155980502*^9, 3.750700157620818*^9}, {
   3.750700225116209*^9, 3.750700276741203*^9}, {3.75070049394073*^9, 
   3.750700502336345*^9}, {3.7507006303570213`*^9, 3.7507006355880504`*^9}, 
   3.8400927881613955`*^9},ExpressionUUID->"6f5207f3-4b7c-449c-8e10-\
9ca63edc6c44"],

Cell[BoxData["48.57142857142857`"], "Output",
 CellChangeTimes->{{3.75070023405394*^9, 3.7507002773128085`*^9}, {
   3.7507004961212893`*^9, 3.7507005035890617`*^9}, 3.750702019371336*^9},
 CellLabel->
  "Out[261]=",ExpressionUUID->"4cabe5ad-7009-43d8-beb6-895fd982b318"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"edgebw", "=", 
  RowBox[{"Partition", "[", 
   RowBox[{
    RowBox[{"Riffle", "[", 
     RowBox[{
      RowBox[{"EdgeList", "[", "g", "]"}], ",", 
      RowBox[{"EdgeBetweennessCentrality", "[", "g", "]"}]}], "]"}], ",", 
    "2"}], "]"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"edge", " ", "betweenness", " ", "centralities"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.750700666659169*^9, 3.7507007042335253`*^9}, {
  3.750700735261584*^9, 3.7507007369937077`*^9}, {3.750701186141655*^9, 
  3.7507012028967247`*^9}},
 CellLabel->
  "In[262]:=",ExpressionUUID->"bcf2099e-f1b6-43ae-b2cb-141670bda82b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
     "51.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"DOT\"\>"}], ",", 
     "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "7.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"ECH\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DIV\"\>", "\[UndirectedEdge]", "\<\"ECH\"\>"}], ",", 
     "74.33333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"DUI\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"MLO\"\>"}], ",", 
     "2.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DUN\"\>"}], ",", 
     "96.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"PIS\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "80.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DEA\"\>", "\[UndirectedEdge]", "\<\"DOV\"\>"}], ",", 
     "96.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "28.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "80.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
     "113.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "170.33333333333331`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OKO\"\>"}], ",", 
     "61.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OCH\"\>"}], ",", 
     "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OCH\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
     "96.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OFR\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OCE\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"TUZ\"\>"}], ",", 
     "45.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OKO\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
     "41.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"VIL\"\>"}], ",", 
     "192.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OFR\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "409.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"PIS\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "192.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"PIS\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VAA\"\>"}], ",", 
     "62.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VAP\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "82.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "12.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "114.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAA\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "114.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAN\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAN\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
     "92.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAZ\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAZ\"\>", "\[UndirectedEdge]", "\<\"VIL\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "79.66666666666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEI\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "12.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "72.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "38.666666666666664`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "15.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
     "190.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAP\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "120.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VIN\"\>"}], ",", 
     "99.66666666666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIO\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "113.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "207.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIO\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "99.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "197.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIL\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "27.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIX\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "12.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OMO\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "90.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAT\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VOR\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "101.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
     "62.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ACA\"\>", "\[UndirectedEdge]", "\<\"ASH\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"DOV\"\>"}], ",", 
     "124.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "16.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"VEG\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "54.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
     "77.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "35.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"TUZ\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "66.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "208.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEI\"\>", "\[UndirectedEdge]", "\<\"VIO\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VOG\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIX\"\>", "\[UndirectedEdge]", "\<\"VOY\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIX\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
     "115.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAT\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
     "88.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIN\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
     "89.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEL\"\>", "\[UndirectedEdge]", "\<\"VOW\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"AMA\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
     "82.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DEA\"\>", "\[UndirectedEdge]", "\<\"DUN\"\>"}], ",", 
     "2.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DUB\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DUI\"\>"}], ",", 
     "14.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"ROY\"\>"}], ",", 
     "61.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DUB\"\>", "\[UndirectedEdge]", "\<\"PIS\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ROY\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
     "8.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIO\"\>", "\[UndirectedEdge]", "\<\"VOW\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"DOV\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DIV\"\>", "\[UndirectedEdge]", "\<\"DOT\"\>"}], ",", 
     "35.666666666666664`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
     "35.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OBI\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
     "145.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OFR\"\>", "\[UndirectedEdge]", "\<\"ROY\"\>"}], ",", 
     "41.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
     "50.666666666666664`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"MLO\"\>", "\[UndirectedEdge]", "\<\"VIX\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "46.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DUI\"\>", "\[UndirectedEdge]", "\<\"VAA\"\>"}], ",", 
     "84.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "15.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
     "38.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VOY\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"TUZ\"\>"}], ",", 
     "2.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEG\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "64.33333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OAT\"\>", "\[UndirectedEdge]", "\<\"OST\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"EDW\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "16.666666666666664`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"VET\"\>"}], ",", 
     "78.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VIV\"\>", "\[UndirectedEdge]", "\<\"VOT\"\>"}], ",", 
     "76.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ECH\"\>", "\[UndirectedEdge]", "\<\"ELV\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"EDW\"\>", "\[UndirectedEdge]", "\<\"OFR\"\>"}], ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOT\"\>", "\[UndirectedEdge]", "\<\"EDW\"\>"}], ",", 
     "22.666666666666664`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ASH\"\>", "\[UndirectedEdge]", "\<\"EDW\"\>"}], ",", 
     "64.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"ORB\"\>", "\[UndirectedEdge]", "\<\"VEL\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VAI\"\>", "\[UndirectedEdge]", "\<\"VOR\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"EDW\"\>", "\[UndirectedEdge]", "\<\"OMO\"\>"}], ",", 
     "12.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VET\"\>", "\[UndirectedEdge]", "\<\"VIG\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"DOV\"\>", "\[UndirectedEdge]", "\<\"DOX\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"VEX\"\>", "\[UndirectedEdge]", "\<\"VIV\"\>"}], ",", 
     "98.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"OST\"\>", "\[UndirectedEdge]", "\<\"POW\"\>"}], ",", 
     "98.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7507006720459213`*^9, 3.750700704619867*^9}, 
   3.7507007374421005`*^9, 3.7507020194479403`*^9},
 CellLabel->
  "Out[262]=",ExpressionUUID->"d2a4c57f-cb40-47ce-ad42-3629654d3fc8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{"edgebw", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"broken", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"broken", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{
           RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
     "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mean", " ", 
    RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", "broken", " ",
     "bonds"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{"edgebw", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"maintained", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"maintained", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "&"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{
           RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
     "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mean", " ", 
    RowBox[{"b", "/", "w"}], " ", "centrality", " ", "of", " ", "maintained", 
    " ", "bonds"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.750700743984647*^9, 3.750700844127103*^9}, {
  3.750701209309058*^9, 3.750701249211232*^9}},
 CellLabel->
  "In[263]:=",ExpressionUUID->"a7c3f43e-793f-4f06-8ca0-3ea0dd38f69c"],

Cell[BoxData["71.67676767676768`"], "Output",
 CellChangeTimes->{{3.7507007830572968`*^9, 3.750700844783535*^9}, 
   3.7507020195332947`*^9},
 CellLabel->
  "Out[263]=",ExpressionUUID->"2ac692d1-f66a-4f2d-a70e-4832b209763f"],

Cell[BoxData["52.87972508591065`"], "Output",
 CellChangeTimes->{{3.7507007830572968`*^9, 3.750700844783535*^9}, 
   3.750702019539318*^9},
 CellLabel->
  "Out[264]=",ExpressionUUID->"0c28e359-a7b7-48ee-9c8f-01f3c4eaf4e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Dimensions", "[", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"actualbroken", ",", 
           RowBox[{
            RowBox[{"#", "==", 
             RowBox[{"broken", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], "]"}], 
     "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{
     RowBox[{"Dimensions", "[", "actualbroken", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"%", " ", "broken", " ", "bonds", " ", "correct"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Dimensions", "[", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"actualmaintained", ",", 
           RowBox[{
            RowBox[{"#", "\[Equal]", 
             RowBox[{"maintained", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], "]"}], 
     "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{
     RowBox[{"Dimensions", "[", "actualmaintained", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"%", " ", "maintained", " ", "bonds", " ", "correct"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Dimensions", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"actualbroken", ",", 
             RowBox[{
              RowBox[{"#", "==", 
               RowBox[{"broken", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "broken", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], "]"}], 
       "[", 
       RowBox[{"[", "1", "]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"Dimensions", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{"actualmaintained", ",", 
             RowBox[{
              RowBox[{"#", "\[Equal]", 
               RowBox[{"maintained", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "maintained", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], "]"}], 
       "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"Dimensions", "[", 
      RowBox[{"EdgeList", "[", "g", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"%", " ", "total", " ", "bonds", " ", "correct"}], " ", 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.750702088418413*^9, 
  3.750702356484715*^9}},ExpressionUUID->"a1f8a78e-f627-4b03-a408-\
bee4f4e51bb7"],

Cell[BoxData["0.3508771929824561`"], "Output",
 CellChangeTimes->{
  3.7507021239712267`*^9, {3.750702158558319*^9, 3.7507021931226983`*^9}, {
   3.7507022351292715`*^9, 3.750702273455549*^9}, 3.7507023138999133`*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"a71938c6-cb42-4397-890a-4d77a9e48dc9"],

Cell[BoxData["0.821917808219178`"], "Output",
 CellChangeTimes->{
  3.7507021239712267`*^9, {3.750702158558319*^9, 3.7507021931226983`*^9}, {
   3.7507022351292715`*^9, 3.750702273455549*^9}, 3.750702313915042*^9},
 CellLabel->
  "Out[281]=",ExpressionUUID->"00b42544-13ee-4d83-abae-bcda45bce10c"],

Cell[BoxData["0.6153846153846154`"], "Output",
 CellChangeTimes->{
  3.7507021239712267`*^9, {3.750702158558319*^9, 3.7507021931226983`*^9}, {
   3.7507022351292715`*^9, 3.750702273455549*^9}, 3.7507023139271975`*^9},
 CellLabel->
  "Out[282]=",ExpressionUUID->"2221a49a-1187-432e-a8ef-9634f5325a9c"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figures", "Chapter",
 CellChangeTimes->{{3.7459405253365164`*^9, 3.7459405259395866`*^9}, {
  3.8302460960885468`*^9, 3.830246098880521*^9}, {3.8302461980658417`*^9, 
  3.830246199225092*^9}, {3.830246654565133*^9, 3.830246656872785*^9}, {
  3.830250037374686*^9, 
  3.8302500398217225`*^9}},ExpressionUUID->"5d0109e0-2395-41a8-96ac-\
f15398c0352c"],

Cell[CellGroupData[{

Cell["Load Data (Run First)", "Section",
 CellChangeTimes->{{3.7577848403468804`*^9, 3.7577848408429303`*^9}, {
  3.8302503137345076`*^9, 
  3.8302503278569565`*^9}},ExpressionUUID->"80295b08-cdca-45c6-aa1a-\
81e49d15fff4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottymax", "=", "237"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookmax", "=", "90"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindamax", "=", "75"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgemax", "=", "54"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayomax", "=", "121"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violamax", "=", "52"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguemax", "=", "90"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7613870249864936`*^9, 3.7613870941160955`*^9}},
 CellLabel->
  "In[550]:=",ExpressionUUID->"648758a7-6ba2-44b9-9df4-f41570f8550c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{"<<", "\"\<dotty_despot\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{"<<", "\"\<dotty_democ\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{"<<", "\"\<dotty_comm\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottyrand", "=", 
    RowBox[{"<<", "\"\<dotty_rand\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{"<<", "\"\<linda_despot\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{"<<", "\"\<linda_democ\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{"<<", "\"\<linda_comm\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindarand", "=", 
    RowBox[{"<<", "\"\<linda_rand\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{"<<", "\"\<lodge_despot\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{"<<", "\"\<lodge_democ\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{"<<", "\"\<lodge_comm\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgerand", "=", 
    RowBox[{"<<", "\"\<lodge_rand\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{"<<", "\"\<nyayo_despot\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{"<<", "\"\<nyayo_democ\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{"<<", "\"\<nyayo_comm\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayorand", "=", 
    RowBox[{"<<", "\"\<nyayo_rand\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{"<<", "\"\<hook_despot\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{"<<", "\"\<hook_democ\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{"<<", "\"\<hook_comm\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hookrand", "=", 
    RowBox[{"<<", "\"\<hook_rand\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{"<<", "\"\<viola_despot\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{"<<", "\"\<viola_democ\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{"<<", "\"\<viola_comm\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violarand", "=", 
    RowBox[{"<<", "\"\<viola_rand\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{"<<", "\"\<vogue_despot\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{"<<", "\"\<vogue_democ\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{"<<", "\"\<vogue_comm\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{"<<", "\"\<vogue_rand\>\""}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7577853016172924`*^9, 3.757785535272587*^9}},
 CellLabel->
  "In[557]:=",ExpressionUUID->"ad2fbaf2-cf1e-461e-8d50-ef1bd71a8172"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyperc", "=", "0.44"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookperc", "=", "0.8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindaperc", "=", "0.34"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgeperc", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayoperc", "=", "0.34"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violaperc", "=", "0.38"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vogueperc", "=", "0.34"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7583929037440395`*^9, 3.7583929190306654`*^9}, {
  3.7583929597408967`*^9, 3.7583930828236957`*^9}, {3.788776610516076*^9, 
  3.7887766383744793`*^9}},
 CellLabel->
  "In[585]:=",ExpressionUUID->"ce73dd6b-c5e8-4ed2-8bde-57603e5c2cbd"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottybrok", "=", "0.11"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookbrok", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindabrok", "=", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgebrok", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayobrok", "=", "0.12"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violabrok", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguebrok", "=", "0.16"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyspars", "=", "0.44"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookspars", "=", "1.37"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindaspars", "=", "0.38"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgespars", "=", "0.41"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayospars", "=", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violaspars", "=", "0.49"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguespars", "=", "0.7"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottymain", "=", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookmain", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindamain", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgemain", "=", "0.23"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayomain", "=", "0.11"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violamain", "=", "0.27"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguemain", "=", "0.17"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottybwbrok", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookbwbrok", "=", "0.32"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindabwbrok", "=", "0.52"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgebwbrok", "=", "2.61"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayobwbrok", "=", "0.24"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violabwbrok", "=", "0.59"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguebwbrok", "=", "0.37"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottybwmain", "=", "0.19"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookbwmain", "=", "0.31"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindabwmain", "=", "0.54"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgebwmain", "=", "1.04"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayobwmain", "=", "0.33"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violabwmain", "=", "0.69"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguebwmain", "=", "0.28"}], ";"}]}], "Input",
 CellChangeTimes->{{3.763897622945345*^9, 3.7638976263039293`*^9}, {
   3.763897664735517*^9, 3.7638976955653934`*^9}, {3.78748465510493*^9, 
   3.787484681002672*^9}, {3.787484766682147*^9, 3.7874848218963213`*^9}, {
   3.78748492702669*^9, 3.7874849374864736`*^9}, {3.787485145117247*^9, 
   3.787485349837045*^9}, 3.7874859209423733`*^9, {3.7887767420776176`*^9, 
   3.788776887156046*^9}, {3.8400936435099077`*^9, 3.8400936995996857`*^9}, {
   3.840093788736245*^9, 3.8400938422011623`*^9}},
 CellLabel->
  "In[592]:=",ExpressionUUID->"eb2bdc2f-18bf-4bfc-958a-3fcab2a14f70"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sparsdottyperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.25", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindaperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.29", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgeperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.09", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayoperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolaperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.22", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsvogueperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.23", ",", "100"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7583929037440395`*^9, 3.7583929190306654`*^9}, {
   3.7583929597408967`*^9, 3.7583930828236957`*^9}, {3.7638984957725954`*^9, 
   3.7638985129742694`*^9}, {3.763898618828734*^9, 3.7638986189138565`*^9}, 
   3.7638986611691647`*^9, {3.7638986911989083`*^9, 3.7638986918002443`*^9}, {
   3.7638987871431956`*^9, 3.763898787523153*^9}, {3.7638988187779083`*^9, 
   3.7638988189784207`*^9}, {3.763898850036601*^9, 3.763898850145465*^9}, {
   3.763898890597722*^9, 3.763898890753911*^9}, {3.7638997244973445`*^9, 
   3.7638997513386335`*^9}, {3.763899781379002*^9, 3.7638997844904623`*^9}, {
   3.788776905148724*^9, 3.788776964594522*^9}},
 CellLabel->
  "In[627]:=",ExpressionUUID->"438d28fc-66d5-4e92-8d6b-c9cd37d09754"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sparsdottybrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.09", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.12", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindabrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.16", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgebrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.16", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayobrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.08", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolabrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.2", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguebrok", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.11", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottyspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.12", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.21", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindaspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgespars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.05", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayospars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.15", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolaspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.24", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguespars", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.17", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottymain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.19", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.19", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindamain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgemain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.25", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayomain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.13", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolamain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.29", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguemain", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.18", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottybwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.3", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookbwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.34", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindabwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.59", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgebwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"2.55", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayobwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.41", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolabwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.79", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguebwbrok", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.3", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottybwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.22", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookbwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.31", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindabwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.52", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgebwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1.35", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayobwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.26", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolabwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.61", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsvoguebwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.31", ",", "100"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.763897622945345*^9, 3.7638976263039293`*^9}, {
  3.763897664735517*^9, 3.7638976955653934`*^9}, {3.7638985147787924`*^9, 
  3.763898524827169*^9}, {3.76389863338136*^9, 3.7638986343655043`*^9}, {
  3.76389866803017*^9, 3.7638986689993153`*^9}, {3.7638986998119855`*^9, 
  3.763898701367464*^9}, {3.763898795857239*^9, 3.7638988250125475`*^9}, {
  3.7638988624343185`*^9, 3.763898895794795*^9}, {3.7638997539813795`*^9, 
  3.763899792563949*^9}, {3.7874846934725075`*^9, 3.7874847332830257`*^9}, {
  3.7874849528624496`*^9, 3.7874850218160114`*^9}, {3.787485577675925*^9, 
  3.7874856570123606`*^9}, {3.7874856957921457`*^9, 3.787485756362424*^9}, {
  3.787486186782049*^9, 3.7874862734421067`*^9}, {3.7887769755181212`*^9, 
  3.788777176320466*^9}, {3.8400937589838886`*^9, 3.840093780317397*^9}},
 CellLabel->
  "In[634]:=",ExpressionUUID->"adb22f3b-8ad9-4b76-af2e-dea07742bf5e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sparsdottycorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.62", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookcorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.42", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindacorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.56", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgecorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.79", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayocorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.56", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolacorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.62", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsvoguecorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.63", ",", "100"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7638985410955963`*^9, 3.763898545215225*^9}, {
  3.7638986435213795`*^9, 3.763898643661972*^9}, {3.76389867903468*^9, 
  3.7638986790723963`*^9}, {3.763898715298128*^9, 3.763898716372466*^9}, {
  3.7638988092231245`*^9, 3.7638988322169104`*^9}, {3.7638988812775126`*^9, 
  3.7638989042975817`*^9}, {3.763899769093176*^9, 3.76389980047834*^9}, {
  3.7639002829152403`*^9, 3.763900295821453*^9}, {3.788777194190618*^9, 
  3.7887771996157556`*^9}, {3.7887772671523647`*^9, 3.7887772770488577`*^9}},
 CellLabel->
  "In[669]:=",ExpressionUUID->"72e5aa1c-dbc8-4426-849a-f78fb660d148"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate Figures", "Section",
 CellChangeTimes->{{3.7874843287235236`*^9, 3.7874843335020947`*^9}, {
  3.787489329488254*^9, 3.7874893299883747`*^9}, {3.82359110934995*^9, 
  3.8235911161901836`*^9}, {3.83025065612092*^9, 
  3.8302506571210003`*^9}},ExpressionUUID->"6a77e014-0543-491f-899c-\
11dd4129f28f"],

Cell["\<\
Run this to create functions that will rescale data appropriately\
\>", "Text",
 CellChangeTimes->{{3.8302506661469088`*^9, 
  3.8302506781024923`*^9}},ExpressionUUID->"4d461173-992b-4c7c-bf31-\
5d9dfc50b7af"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "rand_", ",", "spars_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", "-", "spars"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"rand", "-", "spars"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"frev", "[", 
   RowBox[{"x_", ",", "rand_", ",", "spars_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", "-", "rand"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"spars", "-", "rand"}], ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.8235913101397257`*^9, 3.823591313595092*^9}, {
  3.8235913976348*^9, 3.8235914144024315`*^9}, {3.8235943970765347`*^9, 
  3.823594414272317*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"120168b5-c898-4392-87bf-d90881affc25"],

Cell[CellGroupData[{

Cell["Percent Broken", "Subsection",
 CellChangeTimes->{{3.8235925757025185`*^9, 
  3.823592578221815*^9}},ExpressionUUID->"59ca0aa4-e6b8-491a-b1fc-\
d6a5df7b9101"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottynewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"dottydemoc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"dottyrand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsdottyperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"dottycomm", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"dottyrand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsdottyperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"dottydespot", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"dottyrand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsdottyperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottynewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"dottyperc", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"sparsdottyperc", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"hookdemoc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"hookrand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparshookperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"hookcomm", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"hookrand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparshookperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"hookdespot", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"hookrand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparshookperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hooknewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"hookperc", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"sparshookperc", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lindademoc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lindarand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparslindaperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lindacomm", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lindarand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparslindaperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lindadespot", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lindarand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparslindaperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lindaperc", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"sparslindaperc", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lodgedemoc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lodgerand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparslodgeperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lodgecomm", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lodgerand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparslodgeperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lodgedespot", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lodgerand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparslodgeperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgenewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lodgeperc", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"sparslodgeperc", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"nyayodemoc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"nyayorand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsnyayoperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"nyayocomm", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"nyayorand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsnyayoperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"nyayodespot", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"nyayorand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsnyayoperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayonewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"nyayoperc", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"sparsnyayoperc", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"violademoc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"violarand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsviolaperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"violacomm", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"violarand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsviolaperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"violadespot", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"violarand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsviolaperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"violaperc", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"sparsviolaperc", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"voguedemoc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsvogueperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"voguecomm", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsvogueperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"voguedespot", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsvogueperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewobs", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"vogueperc", ",", "100"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"sparsvogueperc", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.823591449009904*^9, 3.8235914956379766`*^9}, {
  3.823591525819866*^9, 3.8235916157503233`*^9}, {3.82359168469874*^9, 
  3.8235917021111393`*^9}, {3.823591773033968*^9, 3.823591837938725*^9}, {
  3.8235918747444067`*^9, 3.823592001058693*^9}},
 CellLabel->
  "In[676]:=",ExpressionUUID->"ff03b58b-4769-4249-9131-9226da887a75"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig3", "=", 
  RowBox[{"Labeled", "[", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "dottynewobs", ",", "hooknewobs", ",", "lindanewobs", ",", 
              "lodgenewobs", ",", "nyayonewobs", ",", "violanewobs", ",", 
              "voguenewobs"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdemoc", ",", "hooknewdemoc", ",", "lindanewdemoc", ",", 
              "lodgenewdemoc", ",", "nyayonewdemoc", ",", "violanewdemoc", 
              ",", "voguenewdemoc"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewcomm", ",", "hooknewcomm", ",", "lindanewcomm", ",", 
              "lodgenewcomm", ",", "nyayonewcomm", ",", "violanewcomm", ",", 
              "voguenewcomm"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdespot", ",", "hooknewdespot", ",", "lindanewdespot", 
              ",", "lodgenewdespot", ",", "nyayonewdespot", ",", 
              "violanewdespot", ",", "voguenewdespot"}], "}"}]}], 
           "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<Outliers\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<MedianMarker\>\"", ",", "1", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Black", ",", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"ChartLabels", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Observed\>\"", ",", "17", ",", "Black"}], "]"}],
                 "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Democracy\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Community\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Despotism\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}]}], "}"}], ",", "None"}], "}"}]}], ",", 
          RowBox[{"ChartLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Dotty\>\"", ",", "\"\<Hook\>\"", ",", "\"\<Linda\>\"", ",", 
             "\"\<Lodge\>\"", ",", "\"\<Nyayo\>\"", ",", "\"\<Viola\>\"", 
             ",", "\"\<Vogue\>\""}], "}"}]}], ",", 
          RowBox[{"BarSpacing", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "2"}], "}"}]}], ",", 
          RowBox[{"ChartStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Gray", ",", "Orange", ",", "Green", ",", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", "Yellow", 
             ",", "Blue", ",", "Red"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"FrameStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.25", ",", "34.75"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dashed"}], "]"}]}]}], "]"}], 
        "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Efficient Non-behavioral\>\"", ",", "12"}], "]"}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"-", "0.1"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Random\>\"", ",", "12"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "1.1"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Gray", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"dottynewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Orange", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"hooknewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Green", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"lindanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Lighter", "[", 
                 RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", 
               RowBox[{"lodgenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Yellow", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", 
               RowBox[{"nyayonewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"6", ",", 
               RowBox[{"violanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"7", ",", 
               RowBox[{"voguenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}]}], 
          "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<   More Efficient                                          \
Less Efficient\>\"", ",", "Italic", ",", "Red", ",", "15"}], "]"}], "]"}], 
        ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Scaled Percent of Broken Bonds\>\"", ",", "21", ",", 
         RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}], "]"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzE8oQwEAx/GX1BMSosSKjVgOLH9LFu9ALGqtiAPKKA17kj/5szH5Vy6I
PHPYzGIk2iKKxQFbHGjsIJm/u+hlWdocWPZ7h1+fy68vv5mWtYYQBJEcHGy8
nq1kh1lquClXCl+Lz2ugTyZug4dpdTTUmh+7uJ/QMAgtBrUKqjzjGtiebpuG
23txS7AzhTRBZuL6Emqs2iv4tc8PX1SxFP+hnXPMl8qDdx1Czh+qpHd2hKXC
snv64LLfrYYfV0cjUJIYvwKVaVs6eLoRa4Q8sccEo8vs27C81HoC7ztTzmCF
N+IJ3jI779DrufiDUV5J5FzQG7JABBsEtnwo812UQbtzQAKPlYp62Cdcb4XM
z5ASWg6W+qGpe2EIFhkCo7Ai41IDu23mSWhz0FPwOYlwQIWz6hvqLXrjPHr9
+l2YR66+LAYNdbk/YbKuNgClB3LOtZZvuZ9hqZwZuguaddKscy1LuQQJImjo
yCyEJTEL1fCXnNuH7rdNzn87BxQL
  "],
 CellLabel->
  "In[704]:=",ExpressionUUID->"ed735b3d-f611-4c3a-be32-697b6c5e8bf0"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
     TemplateBox[{
       GraphicsBox[{{{
           CapForm[None], 
           Directive[
            RGBColor[0.982864, 0.7431472, 0.3262672]], {{}, {{{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{0.5, 0.7644692045806246}, {1.5, 
                    0.7644692045806246}, {1.5, 0.7644692045806246}, {0.5, 
                    0.7644692045806246}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.7644692045806246}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{1.5, 0.7644692045806246}, {0.5, 
                    0.7644692045806246}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1., 0.7644692045806246}, {1., 
                    0.7644692045806246}}, {{1., 0.7644692045806246}, {1., 
                    0.7644692045806246}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1.25, 0.7644692045806246}, {0.75, 
                    0.7644692045806246}}, {{1.25, 0.7644692045806246}, {0.75, 
                    0.7644692045806246}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7644692045806246`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7644692045806246`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7644692045806246`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.7644692045806246`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.7644692045806246`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.7644692045806246}, {
                    Style["75%", Bold], 0.7644692045806246}, {
                    Style["median", Bold], 0.7644692045806246}, {
                    Style["25%", Bold], 0.7644692045806246}, {
                    Style["min", Bold], 0.7644692045806246}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{1.5, 2.4544695071010842`}, {2.5, 
                    2.4544695071010842`}, {2.5, 2.4544695071010842`}, {1.5, 
                    2.4544695071010842`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.4544695071010842`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{2.5, 2.4544695071010842`}, {1.5, 
                    2.4544695071010842`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2., 2.4544695071010842`}, {2., 
                    2.4544695071010842`}}, {{2., 2.4544695071010842`}, {2., 
                    2.4544695071010842`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2.25, 2.4544695071010842`}, {1.75, 
                    2.4544695071010842`}}, {{2.25, 2.4544695071010842`}, {
                    1.75, 2.4544695071010842`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.4544695071010842`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "2.4544695071010842`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "2.4544695071010842`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "2.4544695071010842`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "2.4544695071010842`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.4544695071010842`}, {
                    Style["75%", Bold], 2.4544695071010842`}, {
                    Style["median", Bold], 2.4544695071010842`}, {
                    Style["25%", Bold], 2.4544695071010842`}, {
                    Style["min", Bold], 2.4544695071010842`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{2.5, 0.231596360628619}, {3.5, 
                    0.231596360628619}, {3.5, 0.231596360628619}, {2.5, 
                    0.231596360628619}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.231596360628619}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{3.5, 0.231596360628619}, {2.5, 
                    0.231596360628619}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    LineBox[{{{3., 0.231596360628619}, {3., 
                    0.231596360628619}}, {{3., 0.231596360628619}, {3., 
                    0.231596360628619}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3.25, 0.231596360628619}, {2.75, 
                    0.231596360628619}}, {{3.25, 0.231596360628619}, {2.75, 
                    0.231596360628619}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.231596360628619`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.231596360628619`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.231596360628619`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.231596360628619`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.231596360628619`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.231596360628619}, {
                    Style["75%", Bold], 0.231596360628619}, {
                    Style["median", Bold], 0.231596360628619}, {
                    Style["25%", Bold], 0.231596360628619}, {
                    Style["min", Bold], 0.231596360628619}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{3.5, 0.3910981393651954}, {4.5, 
                    0.3910981393651954}, {4.5, 0.3910981393651954}, {3.5, 
                    0.3910981393651954}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.3910981393651954}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{4.5, 0.3910981393651954}, {3.5, 
                    0.3910981393651954}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4., 0.3910981393651954}, {4., 
                    0.3910981393651954}}, {{4., 0.3910981393651954}, {4., 
                    0.3910981393651954}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4.25, 0.3910981393651954}, {3.75, 
                    0.3910981393651954}}, {{4.25, 0.3910981393651954}, {3.75, 
                    0.3910981393651954}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.3910981393651954`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.3910981393651954`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.3910981393651954`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.3910981393651954`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.3910981393651954`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.3910981393651954}, {
                    Style["75%", Bold], 0.3910981393651954}, {
                    Style["median", Bold], 0.3910981393651954}, {
                    Style["25%", Bold], 0.3910981393651954}, {
                    Style["min", Bold], 0.3910981393651954}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{4.5, 0.28124999999999994`}, {5.5, 
                    0.28124999999999994`}, {5.5, 0.28124999999999994`}, {4.5, 
                    0.28124999999999994`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.28124999999999994`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{5.5, 0.28124999999999994`}, {4.5, 
                    0.28124999999999994`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5., 0.28124999999999994`}, {5., 
                    0.28124999999999994`}}, {{5., 0.28124999999999994`}, {5., 
                    0.28124999999999994`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5.25, 0.28124999999999994`}, {4.75, 
                    0.28124999999999994`}}, {{5.25, 0.28124999999999994`}, {
                    4.75, 0.28124999999999994`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.28124999999999994`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.28124999999999994`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.28124999999999994`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.28124999999999994`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.28124999999999994`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.28124999999999994`}, {
                    Style["75%", Bold], 0.28124999999999994`}, {
                    Style["median", Bold], 0.28124999999999994`}, {
                    Style["25%", Bold], 0.28124999999999994`}, {
                    Style["min", Bold], 0.28124999999999994`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{5.5, 0.5723370429252778}, {6.5, 
                    0.5723370429252778}, {6.5, 0.5723370429252778}, {5.5, 
                    0.5723370429252778}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.5723370429252778}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{6.5, 0.5723370429252778}, {5.5, 
                    0.5723370429252778}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6., 0.5723370429252778}, {6., 
                    0.5723370429252778}}, {{6., 0.5723370429252778}, {6., 
                    0.5723370429252778}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6.25, 0.5723370429252778}, {5.75, 
                    0.5723370429252778}}, {{6.25, 0.5723370429252778}, {5.75, 
                    0.5723370429252778}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.5723370429252778`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5723370429252778`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5723370429252778`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5723370429252778`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5723370429252778`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.5723370429252778}, {
                    Style["75%", Bold], 0.5723370429252778}, {
                    Style["median", Bold], 0.5723370429252778}, {
                    Style["25%", Bold], 0.5723370429252778}, {
                    Style["min", Bold], 0.5723370429252778}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{6.5, 0.4172163588390501}, {7.5, 
                    0.4172163588390501}, {7.5, 0.4172163588390501}, {6.5, 
                    0.4172163588390501}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.4172163588390501}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{7.5, 0.4172163588390501}, {6.5, 
                    0.4172163588390501}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7., 0.4172163588390501}, {7., 
                    0.4172163588390501}}, {{7., 0.4172163588390501}, {7., 
                    0.4172163588390501}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7.25, 0.4172163588390501}, {6.75, 
                    0.4172163588390501}}, {{7.25, 0.4172163588390501}, {6.75, 
                    0.4172163588390501}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.4172163588390501`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4172163588390501`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.4172163588390501`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4172163588390501`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.4172163588390501`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.4172163588390501}, {
                    Style["75%", Bold], 0.4172163588390501}, {
                    Style["median", Bold], 0.4172163588390501}, {
                    Style["25%", Bold], 0.4172163588390501}, {
                    Style["min", Bold], 0.4172163588390501}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{9.5, 0.09285051067780867}, {10.5, 
                    0.09285051067780867}, {10.5, -0.3559269575982665}, {
                    9.5, -0.3559269575982665}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{10.5, -0.0773754255648405}, {
                    9.5, -0.0773754255648405}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10., -0.3559269575982665}, {
                    10., -0.9749303621169909}}, {{10., 0.09285051067780867}, {
                    10., 0.38687712782420275`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10.25, -0.9749303621169909}, {
                    9.75, -0.9749303621169909}}, {{10.25, 
                    0.38687712782420275`}, {9.75, 
                    0.38687712782420275`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.38687712782420275`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.09285051067780867`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.0773754255648405`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3559269575982665`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.9749303621169909`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.38687712782420275`}, {
                    Style["75%", Bold], 0.09285051067780867}, {
                    Style["median", Bold], -0.0773754255648405}, {
                    Style["25%", Bold], -0.3559269575982665}, {
                    Style["min", Bold], -0.9749303621169909}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{10.5, 0.2656641604010023}, {11.5, 
                    0.2656641604010023}, {11.5, -0.08939014202172096}, {
                    10.5, -0.08939014202172096}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.7368421052631575}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.6950710108604842}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.7786131996658308}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.6532999164578108}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -1.1127819548872173`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.945697577276524}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.6950710108604842}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.945697577276524}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -0.945697577276524}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{11.5, 0.14035087719298214`}, {10.5, 
                    0.14035087719298214`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11., -0.08939014202172096}, {
                    11., -0.5697577276524642}}, {{11., 0.2656641604010023}, {
                    11., 0.6833751044277354}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11.25, -0.5697577276524642}, {
                    10.75, -0.5697577276524642}}, {{11.25, 
                    0.6833751044277354}, {10.75, 
                    0.6833751044277354}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6833751044277354`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.2656641604010023`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.14035087719298214`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.08939014202172096`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.1127819548872173`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.6833751044277354}, {
                    Style["75%", Bold], 0.2656641604010023}, {
                    Style["median", Bold], 0.14035087719298214`}, {
                    Style["25%", Bold], -0.08939014202172096}, {
                    Style["min", Bold], -1.1127819548872173`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{11.5, 0.02150537634408616}, {12.5, 
                    0.02150537634408616}, {12.5, -0.5161290322580646}, {
                    11.5, -0.5161290322580646}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{12.5, -0.14392059553349862`}, {
                    11.5, -0.14392059553349862`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12., -0.5161290322580646}, {
                    12., -1.3019023986765925`}}, {{12., 
                    0.02150537634408616}, {12., 0.3523573200992557}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12.25, -1.3019023986765925`}, {
                    11.75, -1.3019023986765925`}}, {{12.25, 
                    0.3523573200992557}, {11.75, 
                    0.3523573200992557}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.3523573200992557`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.02150537634408616`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.14392059553349862`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5161290322580646`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.3019023986765925`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.3523573200992557}, {
                    Style["75%", Bold], 0.02150537634408616}, {
                    Style["median", Bold], -0.14392059553349862`}, {
                    Style["25%", Bold], -0.5161290322580646}, {
                    Style["min", Bold], -1.3019023986765925`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{12.5, 0.1813206858810654}, {13.5, 
                    0.1813206858810654}, {13.5, -0.07406056183874501}, {
                    12.5, -0.07406056183874501}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{13.5, -0.0010944910616563347`}, {
                    12.5, -0.0010944910616563347`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13., -0.07406056183874501}, {
                    13., -0.14702663261583368`}}, {{13., 
                    0.1813206858810654}, {13., 0.4367019336008758}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13.25, -0.14702663261583368`}, {
                    12.75, -0.14702663261583368`}}, {{13.25, 
                    0.4367019336008758}, {12.75, 
                    0.4367019336008758}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.4367019336008758`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.1813206858810654`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.0010944910616563347`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.07406056183874501`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.14702663261583368`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.4367019336008758}, {
                    Style["75%", Bold], 0.1813206858810654}, {
                    Style["median", Bold], -0.0010944910616563347`}, {
                    Style["25%", Bold], -0.07406056183874501}, {
                    Style["min", Bold], -0.14702663261583368`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{13.5, 0.24999999999999975`}, {14.5, 
                    0.24999999999999975`}, {14.5, -0.036989795918367346`}, {
                    13.5, -0.036989795918367346`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.5790816326530612}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.610969387755102}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.8022959183673468}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.610969387755102}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.7385204081632653}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.8022959183673468}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.8660714285714286}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., -1.0573979591836733`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., -1.0255102040816326`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{14.5, 0.12244897959183662`}, {13.5, 
                    0.12244897959183662`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14., -0.036989795918367346`}, {
                    14., -0.35586734693877553`}}, {{14., 
                    0.24999999999999975`}, {14., 0.6007653061224488}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14.25, -0.35586734693877553`}, {
                    13.75, -0.35586734693877553`}}, {{14.25, 
                    0.6007653061224488}, {13.75, 
                    0.6007653061224488}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6007653061224488`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.24999999999999975`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.12244897959183662`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.036989795918367346`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.0573979591836733`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.6007653061224488}, {
                    Style["75%", Bold], 0.24999999999999975`}, {
                    Style["median", Bold], 0.12244897959183662`}, {
                    Style["25%", Bold], -0.036989795918367346`}, {
                    Style["min", Bold], -1.0573979591836733`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{14.5, 0.3656597774244831}, {15.5, 
                    0.3656597774244831}, {15.5, 0.04769475357710649}, {14.5, 
                    0.04769475357710649}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.5882352941176466}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.5484896661367245}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.5882352941176466}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.7074721780604127}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.5882352941176466}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.7074721780604127}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.7074721780604127}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{15.5, 0.18680445151033373`}, {14.5, 
                    0.18680445151033373`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15., 0.04769475357710649}, {
                    15., -0.3497615262321142}}, {{15., 0.3656597774244831}, {
                    15., 0.6438791732909376}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15.25, -0.3497615262321142}, {
                    14.75, -0.3497615262321142}}, {{15.25, 
                    0.6438791732909376}, {14.75, 
                    0.6438791732909376}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6438791732909376`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.3656597774244831`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.18680445151033373`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.04769475357710649`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.7074721780604127`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.6438791732909376}, {
                    Style["75%", Bold], 0.3656597774244831}, {
                    Style["median", Bold], 0.18680445151033373`}, {
                    Style["25%", Bold], 0.04769475357710649}, {
                    Style["min", Bold], -0.7074721780604127}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{15.5, 0.24901055408970973`}, {16.5, 
                    0.24901055408970973`}, {16.5, -0.17974934036939316`}, {
                    15.5, -0.17974934036939316`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., -0.8393799472295513}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{16.5, 0.06761213720316617}, {15.5, 
                    0.06761213720316617}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16., -0.17974934036939316`}, {
                    16., -0.7734168865435356}}, {{16., 
                    0.24901055408970973`}, {16., 0.6777704485488126}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16.25, -0.7734168865435356}, {
                    15.75, -0.7734168865435356}}, {{16.25, 
                    0.6777704485488126}, {15.75, 
                    0.6777704485488126}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6777704485488126`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.24901055408970973`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.06761213720316617`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.17974934036939316`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.8393799472295513`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.6777704485488126}, {
                    Style["75%", Bold], 0.24901055408970973`}, {
                    Style["median", Bold], 0.06761213720316617}, {
                    Style["25%", Bold], -0.17974934036939316`}, {
                    Style["min", Bold], -0.8393799472295513}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{18.5, -0.015475085112968056`}, {
                    19.5, -0.015475085112968056`}, {
                    19.5, -0.4797276385020114}, {
                    18.5, -0.4797276385020114}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{19.5, -0.29402661714639405`}, {
                    18.5, -0.29402661714639405`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19., -0.4797276385020114}, {
                    19., -0.9749303621169909}}, {{
                    19., -0.015475085112968056`}, {19., 
                    0.26307644692045784`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19.25, -0.9749303621169909}, {
                    18.75, -0.9749303621169909}}, {{19.25, 
                    0.26307644692045784`}, {18.75, 
                    0.26307644692045784`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.26307644692045784`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.015475085112968056`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.29402661714639405`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4797276385020114`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.9749303621169909`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.26307644692045784`}, {
                    Style["75%", Bold], -0.015475085112968056`}, {
                    Style["median", Bold], -0.29402661714639405`}, {
                    Style["25%", Bold], -0.4797276385020114}, {
                    Style["min", Bold], -0.9749303621169909}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{19.5, -0.2773600668337509}, {
                    20.5, -0.2773600668337509}, {20.5, -1.071010860484544}, {
                    19.5, -1.071010860484544}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{20.5, -0.4444444444444442}, {
                    19.5, -0.4444444444444442}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20., -1.071010860484544}, {
                    20., -1.2798663324979107`}}, {{
                    20., -0.2773600668337509}, {20., 0.3909774436090222}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20.25, -1.2798663324979107`}, {
                    19.75, -1.2798663324979107`}}, {{20.25, 
                    0.3909774436090222}, {19.75, 
                    0.3909774436090222}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.3909774436090222`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.2773600668337509`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4444444444444442`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.071010860484544`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.2798663324979107`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.3909774436090222}, {
                    Style["75%", Bold], -0.2773600668337509}, {
                    Style["median", Bold], -0.4444444444444442}, {
                    Style["25%", Bold], -1.071010860484544}, {
                    Style["min", Bold], -1.2798663324979107`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{20.5, -0.4954507857733666}, {
                    21.5, -0.4954507857733666}, {
                    21.5, -1.3019023986765925`}, {
                    20.5, -1.3019023986765925`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{21.5, -1.3019023986765925`}, {
                    20.5, -1.3019023986765925`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21., -1.3019023986765925`}, {
                    21., -1.3019023986765925`}}, {{
                    21., -0.4954507857733666}, {
                    21., -0.3507030603804798}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21.25, -1.3019023986765925`}, {
                    20.75, -1.3019023986765925`}}, {{
                    21.25, -0.3507030603804798}, {
                    20.75, -0.3507030603804798}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3507030603804798`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4954507857733666`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.3019023986765925`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.3019023986765925`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.3019023986765925`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.3507030603804798}, {
                    Style["75%", Bold], -0.4954507857733666}, {
                    Style["median", Bold], -1.3019023986765925`}, {
                    Style["25%", Bold], -1.3019023986765925`}, {
                    Style["min", Bold], -1.3019023986765925`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{21.5, -0.0010944910616563347`}, {
                    22.5, -0.0010944910616563347`}, {
                    22.5, -0.11054359722728936`}, {
                    21.5, -0.11054359722728936`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{22.5, -0.0010944910616563347`}, {
                    21.5, -0.0010944910616563347`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22., -0.11054359722728936`}, {
                    22., -0.14702663261583368`}}, {{
                    22., -0.0010944910616563347`}, {22., 
                    0.144837650492521}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22.25, -0.14702663261583368`}, {
                    21.75, -0.14702663261583368`}}, {{22.25, 
                    0.144837650492521}, {21.75, 
                    0.144837650492521}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.144837650492521`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.0010944910616563347`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.0010944910616563347`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.11054359722728936`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.14702663261583368`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.144837650492521}, {
                    Style["75%", Bold], -0.0010944910616563347`}, {
                    Style["median", Bold], -0.0010944910616563347`}, {
                    Style["25%", Bold], -0.11054359722728936`}, {
                    Style["min", Bold], -0.14702663261583368`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{22.5, 0.28188775510204056`}, {23.5, 
                    0.28188775510204056`}, {23.5, -0.2761479591836735}, {
                    22.5, -0.2761479591836735}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -1.2487244897959182`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -1.2487244897959182`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -1.2487244897959182`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -1.2487244897959182`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -1.2487244897959182`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{23.5, 0.058673469387754924`}, {22.5, 
                    0.058673469387754924`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23., -0.2761479591836735}, {
                    23., -1.0892857142857142`}}, {{23., 0.28188775510204056`},
                     {23., 0.4732142857142854}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23.25, -1.0892857142857142`}, {
                    22.75, -1.0892857142857142`}}, {{23.25, 
                    0.4732142857142854}, {22.75, 
                    0.4732142857142854}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.4732142857142854`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.28188775510204056`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.058673469387754924`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.2761479591836735`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.2487244897959182`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.4732142857142854}, {
                    Style["75%", Bold], 0.28188775510204056`}, {
                    Style["median", Bold], 0.058673469387754924`}, {
                    Style["25%", Bold], -0.2761479591836735}, {
                    Style["min", Bold], -1.2487244897959182`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{23.5, 0.2066772655007948}, {24.5, 
                    0.2066772655007948}, {24.5, 0.04769475357710649}, {23.5, 
                    0.04769475357710649}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {24., -0.7074721780604127}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {24., -0.7074721780604127}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {24., -0.7074721780604127}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {24., -0.7074721780604127}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {24., -0.7074721780604127}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {24., -0.7074721780604127}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{24.5, 0.2066772655007948}, {23.5, 
                    0.2066772655007948}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24., 0.04769475357710649}, {
                    24., -0.15103338632750382`}}, {{24., 
                    0.2066772655007948}, {24., 0.4451510333863271}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    LineBox[{{{24.25, -0.15103338632750382`}, {
                    23.75, -0.15103338632750382`}}, {{24.25, 
                    0.4451510333863271}, {23.75, 
                    0.4451510333863271}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.4451510333863271`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.2066772655007948`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.2066772655007948`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.04769475357710649`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.7074721780604127`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.4451510333863271}, {
                    Style["75%", Bold], 0.2066772655007948}, {
                    Style["median", Bold], 0.2066772655007948}, {
                    Style["25%", Bold], 0.04769475357710649}, {
                    Style["min", Bold], -0.7074721780604127}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{24.5, 0.01813984168865433}, {25.5, 
                    0.01813984168865433}, {25.5, -0.31167546174142474`}, {
                    24.5, -0.31167546174142474`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.8393799472295513}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.8393799472295513}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.8393799472295513}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.8393799472295513}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.8393799472295513}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.8393799472295513}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.8393799472295513}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{25.5, -0.0148416886543536}, {
                    24.5, -0.0148416886543536}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25., -0.31167546174142474`}, {
                    25., -0.8063984168865433}}, {{25., 0.01813984168865433}, {
                    25., 0.44689973614775713`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25.25, -0.8063984168865433}, {
                    24.75, -0.8063984168865433}}, {{25.25, 
                    0.44689973614775713`}, {24.75, 
                    0.44689973614775713`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.44689973614775713`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.01813984168865433`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.0148416886543536`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.31167546174142474`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.8393799472295513`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.44689973614775713`}, {
                    Style["75%", Bold], 0.01813984168865433}, {
                    Style["median", Bold], -0.0148416886543536}, {
                    Style["25%", Bold], -0.31167546174142474`}, {
                    Style["min", Bold], -0.8393799472295513}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{27.5, 0.7892293407613737}, {28.5, 
                    0.7892293407613737}, {28.5, 0.4797276385020115}, {27.5, 
                    0.4797276385020115}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{28.5, 0.6654286598576289}, {27.5, 
                    0.6654286598576289}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28., 0.4797276385020115}, {28., 
                    0.015475085112968056`}}, {{28., 0.7892293407613737}, {28.,
                     1.160631383472608}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28.25, 0.015475085112968056`}, {27.75, 
                    0.015475085112968056`}}, {{28.25, 1.160631383472608}, {
                    27.75, 1.160631383472608}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.160631383472608`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7892293407613737`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6654286598576289`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4797276385020115`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.015475085112968056`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.160631383472608}, {
                    Style["75%", Bold], 0.7892293407613737}, {
                    Style["median", Bold], 0.6654286598576289}, {
                    Style["25%", Bold], 0.4797276385020115}, {
                    Style["min", Bold], 0.015475085112968056`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{28.5, 0.829573934837092}, {29.5, 
                    0.829573934837092}, {29.5, 0.5162907268170421}, {28.5, 
                    0.5162907268170421}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{29.5, 0.6833751044277354}, {28.5, 
                    0.6833751044277354}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29., 0.5162907268170421}, {29., 
                    0.18212197159565555`}}, {{29., 0.829573934837092}, {29., 
                    1.2263993316624884`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29.25, 0.18212197159565555`}, {28.75, 
                    0.18212197159565555`}}, {{29.25, 1.2263993316624884`}, {
                    28.75, 1.2263993316624884`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2263993316624884`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.829573934837092`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6833751044277354`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5162907268170421`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.18212197159565555`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2263993316624884`}, {
                    Style["75%", Bold], 0.829573934837092}, {
                    Style["median", Bold], 0.6833751044277354}, {
                    Style["25%", Bold], 0.5162907268170421}, {
                    Style["min", Bold], 0.18212197159565555`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{29.5, 0.3523573200992557}, {30.5, 
                    0.3523573200992557}, {30.5, -0.019851116625310163`}, {
                    29.5, -0.019851116625310163`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{30.5, 0.18693134822167093`}, {29.5, 
                    0.18693134822167093`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30., -0.019851116625310163`}, {
                    30., -0.5574855252274609}}, {{30., 0.3523573200992557}, {
                    30., 0.8899917287014066}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30.25, -0.5574855252274609}, {
                    29.75, -0.5574855252274609}}, {{30.25, 
                    0.8899917287014066}, {29.75, 
                    0.8899917287014066}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8899917287014066`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.3523573200992557`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.18693134822167093`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.019851116625310163`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5574855252274609`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.8899917287014066}, {
                    Style["75%", Bold], 0.3523573200992557}, {
                    Style["median", Bold], 0.18693134822167093`}, {
                    Style["25%", Bold], -0.019851116625310163`}, {
                    Style["min", Bold], -0.5574855252274609}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{30.5, 0.4002188982123315}, {31.5, 
                    0.4002188982123315}, {31.5, 0.03538854432688801}, {30.5, 
                    0.03538854432688801}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{31.5, 0.2542867566581541}, {30.5, 
                    0.2542867566581541}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31., 0.03538854432688801}, {
                    31., -0.14702663261583368`}}, {{31., 
                    0.4002188982123315}, {31., 0.6556001459321418}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31.25, -0.14702663261583368`}, {
                    30.75, -0.14702663261583368`}}, {{31.25, 
                    0.6556001459321418}, {30.75, 
                    0.6556001459321418}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6556001459321418`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4002188982123315`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.2542867566581541`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.03538854432688801`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.14702663261583368`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.6556001459321418}, {
                    Style["75%", Bold], 0.4002188982123315}, {
                    Style["median", Bold], 0.2542867566581541}, {
                    Style["25%", Bold], 0.03538854432688801}, {
                    Style["min", Bold], -0.14702663261583368`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{31.5, 0.9834183673469384}, {32.5, 
                    0.9834183673469384}, {32.5, 0.6964285714285711}, {31.5, 
                    0.6964285714285711}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    32., 0.24999999999999975`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{32.5, 0.8558673469387753}, {31.5, 
                    0.8558673469387753}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32., 0.6964285714285711}, {32., 
                    0.28188775510204056`}}, {{32., 0.9834183673469384}, {32., 
                    1.3341836734693873`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32.25, 0.28188775510204056`}, {31.75, 
                    0.28188775510204056`}}, {{32.25, 1.3341836734693873`}, {
                    31.75, 1.3341836734693873`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.3341836734693873`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9834183673469384`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8558673469387753`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6964285714285711`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.24999999999999975`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.3341836734693873`}, {
                    Style["75%", Bold], 0.9834183673469384}, {
                    Style["median", Bold], 0.8558673469387753}, {
                    Style["25%", Bold], 0.6964285714285711}, {
                    Style["min", Bold], 0.24999999999999975`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{32.5, 0.8028616852146256}, {33.5, 
                    0.8028616852146256}, {33.5, 0.5246422893481711}, {32.5, 
                    0.5246422893481711}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., 0.04769475357710649}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{33.5, 0.6836248012718594}, {32.5, 
                    0.6836248012718594}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33., 0.5246422893481711}, {33., 
                    0.16693163751987267`}}, {{33., 0.8028616852146256}, {33., 
                    1.0413354531001582`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33.25, 0.16693163751987267`}, {32.75, 
                    0.16693163751987267`}}, {{33.25, 1.0413354531001582`}, {
                    32.75, 1.0413354531001582`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.0413354531001582`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8028616852146256`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6836248012718594`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5246422893481711`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.04769475357710649`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.0413354531001582`}, {
                    Style["75%", Bold], 0.8028616852146256}, {
                    Style["median", Bold], 0.6836248012718594}, {
                    Style["25%", Bold], 0.5246422893481711}, {
                    Style["min", Bold], 0.04769475357710649}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{33.5, 0.9086411609498679}, {34.5, 
                    0.9086411609498679}, {34.5, 0.6777704485488126}, {33.5, 
                    0.6777704485488126}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    34., 0.3149736147757256}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    34., 0.18304749340369386`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    34., 0.11708443271767802`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{34.5, 0.8261873350923481}, {33.5, 
                    0.8261873350923481}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34., 0.6777704485488126}, {34., 
                    0.3479551451187333}}, {{34., 0.9086411609498679}, {34., 
                    1.1395118733509235`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34.25, 0.3479551451187333}, {33.75, 
                    0.3479551451187333}}, {{34.25, 1.1395118733509235`}, {
                    33.75, 1.1395118733509235`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.1395118733509235`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9086411609498679`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8261873350923481`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6777704485488126`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.11708443271767802`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.1395118733509235`}, {
                    Style["75%", Bold], 0.9086411609498679}, {
                    Style["median", Bold], 0.8261873350923481}, {
                    Style["25%", Bold], 0.6777704485488126}, {
                    Style["min", Bold], 0.11708443271767802`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}}, {}, {}}}, {{{{{{{{{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, \
{}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}}, {}}, \
{}}, {{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxFz38sFAAUB/Bzdn5E7HJ1UZwzzuXEOQk5nGKHusldKZxDRU0/TSZH2bDO
JmqcmJli1eTHZXa0MSsrP/rDcHXTqDs/SvlxNCfnx9ZVW733tre3zx/v7X3p
564L04gEAkHwp//O6HzCGpEwGkr4V4UzDPfkNnR3pCChJ2EMzNpd+zqrUwW2
VviWfclQg4e16YwB9QS4qSG99a16BvdJwxpZiw4sWou/PS7fAufbaXKEA0Te
f+etOPu/YFiAa4QersrtnWBKaadJaRcZfJkdaPHgOQW892U/ebScCjbqrspD
jjqAsy9tHjRhO4IZlY95q4s08MMYJstWQAenGDLDYvpcwPycKPmz/a7g9ZqK
VfcqN/BJVopqwMwdPFjVs5yfzASTGkv2JKkP4P27s9JTHBa4yLp9IbvVExxr
avJJSfMCc1VaSyupNziHXtPQf4sN1kbIxGSmD7iuMeDj4nt08GhjfGI5B7w0
L8qN4/qCCz701s9toC8a5otJHYfAErMky3aJHzhwrqRyxf4w2KVju6d7CJ3a
xX5KuemP+Uqd5KZeAWDlCRH9ziT6nYanLKsOxP/E2V+Z/CPgNLsr40I9uq92
3whZEQT2tNmVJhZzwVJhH4FrHwx2GuEkNavQY/6LZ54UhGDeTPFZ36BQsHU1
xSBYQBdL+S3b0Tywnjz92aEJnUGr1xp/ob+bWUwVEcLw/nLmlDkRfaE3YtqW
hJYk6mZoVujYau5cKBUdYDu5VOCN7loP15n6oP00Cp2Mg+a0FS7f90N7Hvf4
8SgI7SzL1b/io+uvzeqPRaEd4wRrg9FoBzf6zxEBmvJmaF0rQlc0cwznT6PJ
FXWGb3Fom9QbGyvx6HuRExtZiegd7PBNgxhdQlVs5knQ5kbqljEZ/Ru3Fwx3

               "]]}, Annotation[#, "Charting`Private`Tag$17307#1"]& ], 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7VXD8IWJ4YI9Axh8sF+xMG3NkauP4Hxt1rP32le/
hfODv0TWXp/yC86vEb5XHnSMyQHGr36vYL5ejQPOnxGkpbLlNy+cL9K9lbF7
myCcn21gyTFhpQicL7H9qOCFPnE4///b3Cl2TlJwfmnGT11GA1k4X23yAodP
r+Xh/Gn+Gtr8vopwfsL3Qkf/g0pwvnu555RlMipw/rcZkz6pT1WF8wO0Ey4d
Y1OH849P3f2uJl4Dzmdd1CEWe1UTYX7b46oQI204v5lnw6vSNTpwfiAz450t
8npwvs2l+5zcVfpwfrnijIVHKwzg/Puu7TGCGoZw/pxFFjdeX0bwbS8siozu
M4Lz37wMrgyzMYbz66/snffsB4Kf/v1lC+smEzg/ji2Wc0OcKZxv+axj8ntJ
MzhfadPv3btOIPiJ2wyWipSYI/zXLTeFWc8Czt/iE6xYdxvBP3nPYUvvdEuE
+2JKn2q4W8H5qcI514M+I/gHZ0mfF1xnDefr8AmlxsTYwPlVQQcZbCRt4Xy5
80axqy4h+BfNX4cvqbdD+LcwJsLY2h7O55ku8t33FYLfUuW++reXA5z/WfDh
XakVCH6W/Lz7//8h+Bb8t9/U6zvC+ez/xX/9j0fwAT9m8Jc=
               "]]}, 
             Annotation[#, "Charting`Private`Tag$17307#2"]& ]}}, {}}}, {
        Epilog -> {
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox[
                  "\"Efficient Non-behavioral\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Efficient Non-behavioral", 12]]], TraditionalForm]], {
            3, -0.1}], 
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Random\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Random", 12]]], TraditionalForm]], {1, 1.1}], 
           InsetBox[
            GraphicsBox[{
              GrayLevel[0.5], 
              RectangleBox[{0, 0}, {3, 1}]}], {1, 0.7644692045806246}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0.5, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {2, 2.4544695071010842`}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {3, 0.231596360628619}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0.7777777777777778, 
               NCache[
                Rational[5, 9], 0.5555555555555556], 0.7777777777777778], 
              RectangleBox[{0, 0}, {3, 1}]}], {4, 0.3910981393651954}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {5, 0.28124999999999994`}, {1.5,
             0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 0, 1], 
              RectangleBox[{0, 0}, {3, 1}]}], {6, 0.5723370429252778}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {7, 0.4172163588390501}, {1.5, 
            0.5}, 1.25]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False},
          AxesLabel -> {None, None}, 
         AxesOrigin -> {-1.2000000000000002`, -1.4897209939654763`}, Frame -> 
         True, FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
         GrayLevel[0], FrameTicks -> {{Automatic, Automatic}, {{{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Observed\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Observed", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Democracy\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Democracy", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Community\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Community", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Despotism\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Despotism", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Large, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {{{1., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Observed\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Observed", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            11., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            12., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            13., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            14., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            15., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            16., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            9.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Democracy\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Democracy", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            20., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            21., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            22., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            23., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            24., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            25., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            18.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Community\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Community", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            29., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            30., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            31., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            32., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            33., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            34., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            27.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Despotism\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Despotism", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
           Automatic}}], 
       FormBox[
        FormBox[
         TemplateBox[{
          "\"Dotty\"", "\"Hook\"", "\"Linda\"", "\"Lodge\"", "\"Nyayo\"", 
           "\"Viola\"", "\"Vogue\""}, "SwatchLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #7}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.5185185185185186, 0.37037037037037035`, 
                    0.5185185185185186], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.7777777777777778`", ",", 
                    FractionBox["5", "9"], ",", "0.7777777777777778`"}], 
                    "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], Editable -> False, 
                    Selectable -> False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], "]"}]}], "}"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", "}"}], ",", 
                   RowBox[{"{", 
                    
                    RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, 
                    ",", #7}], "}"}]}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "None", "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic"}], "}"}]}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]}, "Legended", 
      DisplayFunction -> (GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ), 
      InterpretationFunction -> (RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& ), Editable -> True], 
     RotationBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"   More Efficient                                          Less \
Efficient\"", Italic, 
           RGBColor[1, 0, 0], 15, StripOnInput -> False], TextForm]], 
        "InlineText"], 
       Text[
        Style[
        "   More Efficient                                          Less \
Efficient", Italic, 
         RGBColor[1, 0, 0], 15]]], BoxRotation -> 1.5707963267948966`]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 2}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )], 
   RotationBox[
    InterpretationBox[
     Cell[
      BoxData[
       FormBox[
        StyleBox[
        "\"Scaled Percent of Broken Bonds\"", 21, TextAlignment -> Center, 
         StripOnInput -> False], TextForm]], "InlineText"], 
     Text[
      Style["Scaled Percent of Broken Bonds", 21, TextAlignment -> Center]]], 
    BoxRotation -> 1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8235923308961267`*^9, {3.8235924131861086`*^9, 3.8235924292269435`*^9}, {
   3.8235924620030713`*^9, 3.8235925198217907`*^9}, 3.8235926568314123`*^9, {
   3.823592690074173*^9, 3.823592731531687*^9}, 3.8235927706492815`*^9, 
   3.8235930540342207`*^9, 3.8239375890792828`*^9, 3.8239376210305524`*^9, 
   3.8239377632416687`*^9, 3.8249763290591817`*^9, 3.8249768230776973`*^9, 
   3.82497689623542*^9, 3.824977154969181*^9, {3.824977207099616*^9, 
   3.824977224887741*^9}, {3.8249772591071787`*^9, 3.82497732524804*^9}, {
   3.8249773779361453`*^9, 3.8249774072024965`*^9}, {3.8249774431442485`*^9, 
   3.8249774525340877`*^9}, {3.8249774929054556`*^9, 
   3.8249776577399206`*^9}, {3.8249777304992285`*^9, 3.824977801880391*^9}, {
   3.824977831962393*^9, 3.8249779035811367`*^9}, {3.8249780650209646`*^9, 
   3.82497818389285*^9}, {3.8249782855374165`*^9, 3.8249783070478787`*^9}, {
   3.824978380507355*^9, 3.824978397515151*^9}, 3.824978479764208*^9, {
   3.824978578411792*^9, 3.824978637034465*^9}, {3.82497878491242*^9, 
   3.8249788052883673`*^9}, {3.8249788787051687`*^9, 3.82497891016116*^9}, {
   3.824978953926936*^9, 3.824978959471613*^9}, {3.82497899911453*^9, 
   3.824979004710332*^9}, {3.8249796071805296`*^9, 3.8249796767619376`*^9}, 
   3.824979796461603*^9, 3.8249798317056627`*^9, 3.824979879127589*^9, {
   3.8249813016127553`*^9, 3.824981342957742*^9}, 3.824981374964775*^9, {
   3.82498791859247*^9, 3.8249880245283747`*^9}, 3.824988148904545*^9, 
   3.830250464151266*^9, {3.8400943712973895`*^9, 3.840094400474495*^9}, 
   3.840094519045101*^9},
 CellLabel->
  "Out[704]=",ExpressionUUID->"57a16f3b-4e76-4dad-a3f4-f7cfadc06197"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Broken Weight", "Subsection",
 CellChangeTimes->{{3.8235925757025185`*^9, 3.823592578221815*^9}, {
  3.8235933790635824`*^9, 
  3.8235933845943413`*^9}},ExpressionUUID->"acdda333-a033-4b92-92ce-\
c1c54664a340"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottynewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottybrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottycomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottybrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottybrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottynewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"dottybrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"dottyrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", 
        "dottymax"}], "]"}], ",", 
      RowBox[{"sparsdottybrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookcomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hooknewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"hookbrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"hookrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}],
        "]"}], ",", 
      RowBox[{"sparshookbrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindabrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindabrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindabrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lindabrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lindarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", 
        "lindamax"}], "]"}], ",", 
      RowBox[{"sparslindabrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgebrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgebrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgebrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgenewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lodgebrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lodgerand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", 
        "lodgemax"}], "]"}], ",", 
      RowBox[{"sparslodgebrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayobrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayocomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayobrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayobrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayonewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"nyayobrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"nyayorand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", 
        "nyayomax"}], "]"}], ",", 
      RowBox[{"sparsnyayobrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolabrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolabrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolabrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"violabrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"violarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", 
        "violamax"}], "]"}], ",", 
      RowBox[{"sparsviolabrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewobs", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"voguebrok", ",", "100"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.823591449009904*^9, 3.8235914956379766`*^9}, {
  3.823591525819866*^9, 3.8235916157503233`*^9}, {3.82359168469874*^9, 
  3.8235917021111393`*^9}, {3.823591773033968*^9, 3.823591837938725*^9}, {
  3.8235918747444067`*^9, 3.823592001058693*^9}, {3.823593511044263*^9, 
  3.8235935533689365`*^9}, {3.8235936132386136`*^9, 3.8235936950309906`*^9}},
 CellLabel->
  "In[705]:=",ExpressionUUID->"8e6313a5-f09e-4230-b806-3123b1571301"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig4", "=", 
  RowBox[{"Labeled", "[", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "dottynewobs", ",", "hooknewobs", ",", "lindanewobs", ",", 
              "lodgenewobs", ",", "nyayonewobs", ",", "violanewobs", ",", 
              "voguenewobs"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdemoc", ",", "hooknewdemoc", ",", "lindanewdemoc", ",", 
              "lodgenewdemoc", ",", "nyayonewdemoc", ",", "violanewdemoc", 
              ",", "voguenewdemoc"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewcomm", ",", "hooknewcomm", ",", "lindanewcomm", ",", 
              "lodgenewcomm", ",", "nyayonewcomm", ",", "violanewcomm", ",", 
              "voguenewcomm"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdespot", ",", "hooknewdespot", ",", "lindanewdespot", 
              ",", "lodgenewdespot", ",", "nyayonewdespot", ",", 
              "violanewdespot", ",", "voguenewdespot"}], "}"}]}], 
           "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<Outliers\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<MedianMarker\>\"", ",", "1", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Black", ",", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"ChartLabels", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Observed\>\"", ",", "17", ",", "Black"}], "]"}],
                 "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Democracy\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Community\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Despotism\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}]}], "}"}], ",", "None"}], "}"}]}], ",", 
          RowBox[{"ChartLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Dotty\>\"", ",", "\"\<Hook\>\"", ",", "\"\<Linda\>\"", ",", 
             "\"\<Lodge\>\"", ",", "\"\<Nyayo\>\"", ",", "\"\<Viola\>\"", 
             ",", "\"\<Vogue\>\""}], "}"}]}], ",", 
          RowBox[{"BarSpacing", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "2"}], "}"}]}], ",", 
          RowBox[{"ChartStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Gray", ",", "Orange", ",", "Green", ",", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", "Yellow", 
             ",", "Blue", ",", "Red"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"All", ",", "2.5"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.25", ",", "34.75"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dashed"}], "]"}]}]}], "]"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Efficient Non-behavioral\>\"", ",", "12"}], "]"}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"-", "0.1"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Random\>\"", ",", "12"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "1.1"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Gray", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"dottynewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Orange", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"hooknewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Green", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"lindanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Lighter", "[", 
                 RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", 
               RowBox[{"lodgenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Yellow", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", 
               RowBox[{"nyayonewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"6", ",", 
               RowBox[{"violanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"7", ",", 
               RowBox[{"voguenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}]}], 
          "\[IndentingNewLine]", "}"}]}]}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<   More Efficient                                          \
Less Efficient\>\"", ",", "Italic", ",", "Red", ",", "15"}], "]"}], "]"}], 
        ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Scaled Mean Weight\nof Broken Bonds\>\"", ",", "21", ",", 
         RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}], "]"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8235920125253134`*^9, 3.823592065605406*^9}, {
   3.823592110163682*^9, 3.823592257916377*^9}, {3.8235923147544823`*^9, 
   3.82359232692793*^9}, {3.823592405067442*^9, 3.8235924279573603`*^9}, {
   3.8235924601542344`*^9, 3.8235925182234397`*^9}, {3.8235926326470547`*^9, 
   3.823592768222708*^9}, {3.823593046485058*^9, 3.823593052835633*^9}, {
   3.8235937638522778`*^9, 3.82359377539753*^9}, {3.823593821851324*^9, 
   3.823593855042349*^9}, {3.823937790391342*^9, 3.8239377915600967`*^9}, 
   3.8249882234634233`*^9, {3.8382951583097935`*^9, 3.8382951747264714`*^9}, {
   3.8392409482423573`*^9, 3.839240975218647*^9}, {3.839241664376957*^9, 
   3.839241664909464*^9}},
 CellLabel->
  "In[733]:=",ExpressionUUID->"ae6f5424-194d-4876-9a54-3edddb704940"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
     TemplateBox[{
       GraphicsBox[{{{
           CapForm[None], 
           Directive[
            RGBColor[0.982864, 0.7431472, 0.3262672]], {{}, {{{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{0.5, 0.28609716531936347`}, {1.5, 
                    0.28609716531936347`}, {1.5, 0.28609716531936347`}, {0.5, 
                    0.28609716531936347`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.28609716531936347`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{1.5, 0.28609716531936347`}, {0.5, 
                    0.28609716531936347`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1., 0.28609716531936347`}, {1., 
                    0.28609716531936347`}}, {{1., 0.28609716531936347`}, {1., 
                    0.28609716531936347`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1.25, 0.28609716531936347`}, {0.75, 
                    0.28609716531936347`}}, {{1.25, 0.28609716531936347`}, {
                    0.75, 0.28609716531936347`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.28609716531936347`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.28609716531936347`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.28609716531936347`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.28609716531936347`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.28609716531936347`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.28609716531936347`}, {
                    Style["75%", Bold], 0.28609716531936347`}, {
                    Style["median", Bold], 0.28609716531936347`}, {
                    Style["25%", Bold], 0.28609716531936347`}, {
                    Style["min", Bold], 0.28609716531936347`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{1.5, 0.5614856903117206}, {2.5, 
                    0.5614856903117206}, {2.5, 0.5614856903117206}, {1.5, 
                    0.5614856903117206}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.5614856903117206}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{2.5, 0.5614856903117206}, {1.5, 
                    0.5614856903117206}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2., 0.5614856903117206}, {2., 
                    0.5614856903117206}}, {{2., 0.5614856903117206}, {2., 
                    0.5614856903117206}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2.25, 0.5614856903117206}, {1.75, 
                    0.5614856903117206}}, {{2.25, 0.5614856903117206}, {1.75, 
                    0.5614856903117206}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.5614856903117206`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5614856903117206`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5614856903117206`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5614856903117206`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5614856903117206`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.5614856903117206}, {
                    Style["75%", Bold], 0.5614856903117206}, {
                    Style["median", Bold], 0.5614856903117206}, {
                    Style["25%", Bold], 0.5614856903117206}, {
                    Style["min", Bold], 0.5614856903117206}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{2.5, 0.48913862461810087`}, {3.5, 
                    0.48913862461810087`}, {3.5, 0.48913862461810087`}, {2.5, 
                    0.48913862461810087`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.48913862461810087`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{3.5, 0.48913862461810087`}, {2.5, 
                    0.48913862461810087`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3., 0.48913862461810087`}, {3., 
                    0.48913862461810087`}}, {{3., 0.48913862461810087`}, {3., 
                    0.48913862461810087`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3.25, 0.48913862461810087`}, {2.75, 
                    0.48913862461810087`}}, {{3.25, 0.48913862461810087`}, {
                    2.75, 0.48913862461810087`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.48913862461810087`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.48913862461810087`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.48913862461810087`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.48913862461810087`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.48913862461810087`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.48913862461810087`}, {
                    Style["75%", Bold], 0.48913862461810087`}, {
                    Style["median", Bold], 0.48913862461810087`}, {
                    Style["25%", Bold], 0.48913862461810087`}, {
                    Style["min", Bold], 0.48913862461810087`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{3.5, 1.3096455359378378`}, {4.5, 
                    1.3096455359378378`}, {4.5, 1.3096455359378378`}, {3.5, 
                    1.3096455359378378`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.3096455359378378`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{4.5, 1.3096455359378378`}, {3.5, 
                    1.3096455359378378`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4., 1.3096455359378378`}, {4., 
                    1.3096455359378378`}}, {{4., 1.3096455359378378`}, {4., 
                    1.3096455359378378`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4.25, 1.3096455359378378`}, {3.75, 
                    1.3096455359378378`}}, {{4.25, 1.3096455359378378`}, {
                    3.75, 1.3096455359378378`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.3096455359378378`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.3096455359378378`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.3096455359378378`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.3096455359378378`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.3096455359378378`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.3096455359378378`}, {
                    Style["75%", Bold], 1.3096455359378378`}, {
                    Style["median", Bold], 1.3096455359378378`}, {
                    Style["25%", Bold], 1.3096455359378378`}, {
                    Style["min", Bold], 1.3096455359378378`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{4.5, 1.0590706932025862`}, {5.5, 
                    1.0590706932025862`}, {5.5, 1.0590706932025862`}, {4.5, 
                    1.0590706932025862`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.0590706932025862`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{5.5, 1.0590706932025862`}, {4.5, 
                    1.0590706932025862`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5., 1.0590706932025862`}, {5., 
                    1.0590706932025862`}}, {{5., 1.0590706932025862`}, {5., 
                    1.0590706932025862`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5.25, 1.0590706932025862`}, {4.75, 
                    1.0590706932025862`}}, {{5.25, 1.0590706932025862`}, {
                    4.75, 1.0590706932025862`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.0590706932025862`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.0590706932025862`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.0590706932025862`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.0590706932025862`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.0590706932025862`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.0590706932025862`}, {
                    Style["75%", Bold], 1.0590706932025862`}, {
                    Style["median", Bold], 1.0590706932025862`}, {
                    Style["25%", Bold], 1.0590706932025862`}, {
                    Style["min", Bold], 1.0590706932025862`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{5.5, 0.8617111838396985}, {6.5, 
                    0.8617111838396985}, {6.5, 0.8617111838396985}, {5.5, 
                    0.8617111838396985}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.8617111838396985}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{6.5, 0.8617111838396985}, {5.5, 
                    0.8617111838396985}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6., 0.8617111838396985}, {6., 
                    0.8617111838396985}}, {{6., 0.8617111838396985}, {6., 
                    0.8617111838396985}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6.25, 0.8617111838396985}, {5.75, 
                    0.8617111838396985}}, {{6.25, 0.8617111838396985}, {5.75, 
                    0.8617111838396985}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8617111838396985`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8617111838396985`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8617111838396985`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.8617111838396985`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.8617111838396985`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.8617111838396985}, {
                    Style["75%", Bold], 0.8617111838396985}, {
                    Style["median", Bold], 0.8617111838396985}, {
                    Style["25%", Bold], 0.8617111838396985}, {
                    Style["min", Bold], 0.8617111838396985}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{6.5, 0.9368795613619549}, {7.5, 
                    0.9368795613619549}, {7.5, 0.9368795613619549}, {6.5, 
                    0.9368795613619549}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], TraditionalForm]],
                     {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.9368795613619549}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{7.5, 0.9368795613619549}, {6.5, 
                    0.9368795613619549}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7., 0.9368795613619549}, {7., 
                    0.9368795613619549}}, {{7., 0.9368795613619549}, {7., 
                    0.9368795613619549}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7.25, 0.9368795613619549}, {6.75, 
                    0.9368795613619549}}, {{7.25, 0.9368795613619549}, {6.75, 
                    0.9368795613619549}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.9368795613619549`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9368795613619549`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.9368795613619549`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.9368795613619549`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.9368795613619549`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.9368795613619549}, {
                    Style["75%", Bold], 0.9368795613619549}, {
                    Style["median", Bold], 0.9368795613619549}, {
                    Style["25%", Bold], 0.9368795613619549}, {
                    Style["min", Bold], 0.9368795613619549}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{9.5, 0.222329699289406}, {10.5, 
                    0.222329699289406}, {10.5, -0.072396129855193}, {
                    9.5, -0.072396129855193}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 0.9186495477132297}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 0.8477288369009405}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 0.8477288369009405}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {10., 1.126884826268463}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{10.5, 0.058706147180788704`}, {9.5, 
                    0.058706147180788704`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10., -0.072396129855193}, {
                    10., -0.3930406588382433}}, {{10., 0.222329699289406}, {
                    10., 0.5721655887093194}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10.25, -0.3930406588382433}, {
                    9.75, -0.3930406588382433}}, {{10.25, 
                    0.5721655887093194}, {9.75, 
                    0.5721655887093194}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.126884826268463`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.222329699289406`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.058706147180788704`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.072396129855193`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3930406588382433`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.126884826268463}, {
                    Style["75%", Bold], 0.222329699289406}, {
                    Style["median", Bold], 0.058706147180788704`}, {
                    Style["25%", Bold], -0.072396129855193}, {
                    Style["min", Bold], -0.3930406588382433}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{10.5, 0.45591997253535976`}, {11.5, 
                    0.45591997253535976`}, {11.5, 0.04829984432789017}, {10.5,
                     0.04829984432789017}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 1.2893375110861733`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{11.5, 0.20923654710269435`}, {10.5, 
                    0.20923654710269435`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    LineBox[{{{11., 0.04829984432789017}, {
                    11., -0.3281109795237214}}, {{11., 
                    0.45591997253535976`}, {11., 1.0481066219152122`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11.25, -0.3281109795237214}, {
                    10.75, -0.3281109795237214}}, {{11.25, 
                    1.0481066219152122`}, {10.75, 
                    1.0481066219152122`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2893375110861733`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.45591997253535976`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.20923654710269435`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.04829984432789017`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3281109795237214`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2893375110861733`}, {
                    Style["75%", Bold], 0.45591997253535976`}, {
                    Style["median", Bold], 0.20923654710269435`}, {
                    Style["25%", Bold], 0.04829984432789017}, {
                    Style["min", Bold], -0.3281109795237214}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{11.5, 0.6044598489638267}, {12.5, 
                    0.6044598489638267}, {12.5, 0.2181713547899784}, {11.5, 
                    0.2181713547899784}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., -0.4891386246181007}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 1.2962173552379672`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 1.2344927192742547`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {12., 2.28264691488447}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {12., 2.201123810781454}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {12., 2.28264691488447}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{12.5, 0.3617367173402262}, {11.5, 
                    0.3617367173402262}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12., 0.2181713547899784}, {
                    12., -0.27549186903778095`}}, {{12., 
                    0.6044598489638267}, {12., 1.1413234574422353`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12.25, -0.27549186903778095`}, {
                    11.75, -0.27549186903778095`}}, {{12.25, 
                    1.1413234574422353`}, {11.75, 
                    1.1413234574422353`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.28264691488447`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6044598489638267`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.3617367173402262`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.2181713547899784`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4891386246181007`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.28264691488447}, {
                    Style["75%", Bold], 0.6044598489638267}, {
                    Style["median", Bold], 0.3617367173402262}, {
                    Style["25%", Bold], 0.2181713547899784}, {
                    Style["min", Bold], -0.4891386246181007}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{12.5, 0.7340482386614546}, {13.5, 
                    0.7340482386614546}, {13.5, 0.055180063574968755`}, {12.5,
                     0.055180063574968755`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{13.5, 0.35004723275375516`}, {12.5, 
                    0.35004723275375516`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13., 0.055180063574968755`}, {
                    13., -0.5917657606830231}}, {{13., 0.7340482386614546}, {
                    13., 1.2595232993772536`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13.25, -0.5917657606830231}, {
                    12.75, -0.5917657606830231}}, {{13.25, 
                    1.2595232993772536`}, {12.75, 
                    1.2595232993772536`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2595232993772536`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7340482386614546`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.35004723275375516`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.055180063574968755`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5917657606830231`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2595232993772536`}, {
                    Style["75%", Bold], 0.7340482386614546}, {
                    Style["median", Bold], 0.35004723275375516`}, {
                    Style["25%", Bold], 0.055180063574968755`}, {
                    Style["min", Bold], -0.5917657606830231}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{13.5, 0.44814790460201637`}, {14.5, 
                    0.44814790460201637`}, {14.5, 0.19873664928351892`}, {
                    13.5, 0.19873664928351892`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., 0.9038885679533354}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., 0.8723474855856014}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., 4.501050446110991}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., 1.3928649500008476`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., 2.080395581740411}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., 1.3636114394492225`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{14.5, 0.2841268339861964}, {13.5, 
                    0.2841268339861964}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    LineBox[{{{14., 0.19873664928351892`}, {
                    14., -0.05365755218884822}}, {{14., 
                    0.44814790460201637`}, {14., 0.7994087326102167}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14.25, -0.05365755218884822}, {
                    13.75, -0.05365755218884822}}, {{14.25, 
                    0.7994087326102167}, {13.75, 
                    0.7994087326102167}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "4.501050446110991`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.44814790460201637`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.2841268339861964`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.19873664928351892`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.05365755218884822`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 4.501050446110991}, {
                    Style["75%", Bold], 0.44814790460201637`}, {
                    Style["median", Bold], 0.2841268339861964}, {
                    Style["25%", Bold], 0.19873664928351892`}, {
                    Style["min", Bold], -0.05365755218884822}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{14.5, 0.4046594380210705}, {15.5, 
                    0.4046594380210705}, {15.5, 0.035290878255543084`}, {14.5,
                     0.035290878255543084`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.9666631869996615}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 1.0669635778312057`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 1.5052326768994735`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 2.421261125532486}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 1.8780884775993425`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{15.5, 0.24884831057778634`}, {14.5, 
                    0.24884831057778634`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15., 0.035290878255543084`}, {
                    15., -0.32662408306075513`}}, {{15., 
                    0.4046594380210705}, {15., 0.9222327051127213}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15.25, -0.32662408306075513`}, {
                    14.75, -0.32662408306075513`}}, {{15.25, 
                    0.9222327051127213}, {14.75, 
                    0.9222327051127213}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.421261125532486`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4046594380210705`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.24884831057778634`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.035290878255543084`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.32662408306075513`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.421261125532486}, {
                    Style["75%", Bold], 0.4046594380210705}, {
                    Style["median", Bold], 0.24884831057778634`}, {
                    Style["25%", Bold], 0.035290878255543084`}, {
                    Style["min", Bold], -0.32662408306075513`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{15.5, 0.5801082536513926}, {16.5, 
                    0.5801082536513926}, {16.5, 0.06543285825385078}, {15.5, 
                    0.06543285825385078}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.7210824534649247`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.7210824534649247`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.7210824534649247`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.7210824534649247`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.7210824534649247`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {16., 2.310969584692822}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {16., 2.310969584692822}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {16., 2.310969584692822}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {16., 2.310969584692822}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {16., 2.310969584692822}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{16.5, 0.25196988772811557`}, {15.5, 
                    0.25196988772811557`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16., 0.06543285825385078}, {
                    16., -0.17936839465391266`}}, {{16., 
                    0.5801082536513926}, {16., 1.1510234611018302`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16.25, -0.17936839465391266`}, {
                    15.75, -0.17936839465391266`}}, {{16.25, 
                    1.1510234611018302`}, {15.75, 
                    1.1510234611018302`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.310969584692822`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5801082536513926`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.25196988772811557`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.06543285825385078`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.17936839465391266`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.310969584692822}, {
                    Style["75%", Bold], 0.5801082536513926}, {
                    Style["median", Bold], 0.25196988772811557`}, {
                    Style["25%", Bold], 0.06543285825385078}, {
                    Style["min", Bold], -0.17936839465391266`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{18.5, 0.029942842196788846`}, {19.5, 
                    0.029942842196788846`}, {19.5, -0.3930406588382433}, {
                    18.5, -0.3930406588382433}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{19.5, -0.1667436905532526}, {
                    18.5, -0.1667436905532526}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19., -0.3930406588382433}, {
                    19., -0.6838567263857357}}, {{19., 
                    0.029942842196788846`}, {19., 0.34223015345164354`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19.25, -0.6838567263857357}, {
                    18.75, -0.6838567263857357}}, {{19.25, 
                    0.34223015345164354`}, {18.75, 
                    0.34223015345164354`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.34223015345164354`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.029942842196788846`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1667436905532526`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3930406588382433`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6838567263857357`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.34223015345164354`}, {
                    Style["75%", Bold], 0.029942842196788846`}, {
                    Style["median", Bold], -0.1667436905532526}, {
                    Style["25%", Bold], -0.3930406588382433}, {
                    Style["min", Bold], -0.6838567263857357}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{19.5, 0.041591532615683276`}, {20.5, 
                    0.041591532615683276`}, {20.5, -0.16593137576640066`}, {
                    19.5, -0.16593137576640066`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -0.582281456619562}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 1.0813798480077585`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 1.0813798480077585`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 1.0813798480077585`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 1.0813798480077585`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{20.5, -0.035429824080026165`}, {
                    19.5, -0.035429824080026165`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20., -0.16593137576640066`}, {
                    20., -0.42631320931075073`}}, {{20., 
                    0.041591532615683276`}, {20., 0.07486475870822974}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20.25, -0.42631320931075073`}, {
                    19.75, -0.42631320931075073`}}, {{20.25, 
                    0.07486475870822974}, {19.75, 
                    0.07486475870822974}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.0813798480077585`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.041591532615683276`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.035429824080026165`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.16593137576640066`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.582281456619562`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.0813798480077585`}, {
                    Style["75%", Bold], 0.041591532615683276`}, {
                    Style["median", Bold], -0.035429824080026165`}, {
                    Style["25%", Bold], -0.16593137576640066`}, {
                    Style["min", Bold], -0.582281456619562}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{20.5, -0.2581564963262198}, {
                    21.5, -0.2581564963262198}, {21.5, -0.6521848328241343}, {
                    20.5, -0.6521848328241343}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{21.5, -0.4891386246181007}, {
                    20.5, -0.4891386246181007}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21., -0.6521848328241343}, {
                    21., -0.815231041030168}}, {{21., -0.2581564963262198}, {
                    21., 0.13427334793438067`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21.25, -0.815231041030168}, {
                    20.75, -0.815231041030168}}, {{21.25, 
                    0.13427334793438067`}, {20.75, 
                    0.13427334793438067`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.13427334793438067`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.2581564963262198`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4891386246181007`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6521848328241343`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.815231041030168`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.13427334793438067`}, {
                    Style["75%", Bold], -0.2581564963262198}, {
                    Style["median", Bold], -0.4891386246181007}, {
                    Style["25%", Bold], -0.6521848328241343}, {
                    Style["min", Bold], -0.815231041030168}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{21.5, -0.027216913401177475`}, {
                    22.5, -0.027216913401177475`}, {
                    22.5, -0.39774419980334347`}, {
                    21.5, -0.39774419980334347`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{22.5, -0.03395377315394428}, {
                    21.5, -0.03395377315394428}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22., -0.39774419980334347`}, {
                    22., -0.5917657606830231}}, {{
                    22., -0.027216913401177475`}, {22., 
                    0.08730970239585568}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22.25, -0.5917657606830231}, {
                    21.75, -0.5917657606830231}}, {{22.25, 
                    0.08730970239585568}, {21.75, 
                    0.08730970239585568}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.08730970239585568`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.027216913401177475`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.03395377315394428`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.39774419980334347`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5917657606830231`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.08730970239585568}, {
                    Style["75%", Bold], -0.027216913401177475`}, {
                    Style["median", Bold], -0.03395377315394428}, {
                    Style["25%", Bold], -0.39774419980334347`}, {
                    Style["min", Bold], -0.5917657606830231}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{22.5, 0.04643808975883927}, {23.5, 
                    0.04643808975883927}, {23.5, -0.14879505606978483`}, {
                    22.5, -0.14879505606978483`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{23.5, 0.012830589727942716`}, {22.5, 
                    0.012830589727942716`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23., -0.14879505606978483`}, {
                    23., -0.367611314995939}}, {{23., 0.04643808975883927}, {
                    23., 0.18641282994474917`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23.25, -0.367611314995939}, {
                    22.75, -0.367611314995939}}, {{23.25, 
                    0.18641282994474917`}, {22.75, 
                    0.18641282994474917`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.18641282994474917`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.04643808975883927`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.012830589727942716`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.14879505606978483`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.367611314995939`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.18641282994474917`}, {
                    Style["75%", Bold], 0.04643808975883927}, {
                    Style["median", Bold], 0.012830589727942716`}, {
                    Style["25%", Bold], -0.14879505606978483`}, {
                    Style["min", Bold], -0.367611314995939}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{23.5, -0.25514647384752964`}, {
                    24.5, -0.25514647384752964`}, {
                    24.5, -0.4039271174248588}, {
                    23.5, -0.4039271174248588}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., -0.014409886017386332`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., -0.014409886017386332`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., -0.014409886017386332`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{24.5, -0.3654199300306415}, {
                    23.5, -0.3654199300306415}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24., -0.4039271174248588}, {
                    24., -0.41980801263985307`}}, {{
                    24., -0.25514647384752964`}, {
                    24., -0.09846755445213948}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24.25, -0.41980801263985307`}, {
                    23.75, -0.41980801263985307`}}, {{
                    24.25, -0.09846755445213948}, {
                    23.75, -0.09846755445213948}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.014409886017386332`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.25514647384752964`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3654199300306415`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4039271174248588`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.41980801263985307`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.014409886017386332`}, {
                    Style["75%", Bold], -0.25514647384752964`}, {
                    Style["median", Bold], -0.3654199300306415}, {
                    Style["25%", Bold], -0.4039271174248588}, {
                    Style["min", Bold], -0.41980801263985307`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{24.5, 0.020819545808043575`}, {25.5, 
                    0.020819545808043575`}, {25.5, -0.17936839465391266`}, {
                    24.5, -0.17936839465391266`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.7078645574734769}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.7078645574734769}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.7078645574734769}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.7078645574734769}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.7078645574734769}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    25., -0.7078645574734769}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{25.5, -0.05112444453249275}, {
                    24.5, -0.05112444453249275}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25., -0.17936839465391266`}, {
                    25., -0.23694625943439881`}}, {{25., 
                    0.020819545808043575`}, {25., 0.11748172277395921`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25.25, -0.23694625943439881`}, {
                    24.75, -0.23694625943439881`}}, {{25.25, 
                    0.11748172277395921`}, {24.75, 
                    0.11748172277395921`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.11748172277395921`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.020819545808043575`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.05112444453249275`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.17936839465391266`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.7078645574734769`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.11748172277395921`}, {
                    Style["75%", Bold], 0.020819545808043575`}, {
                    Style["median", Bold], -0.05112444453249275}, {
                    Style["25%", Bold], -0.17936839465391266`}, {
                    Style["min", Bold], -0.7078645574734769}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{27.5, 0.886593074414756}, {28.5, 
                    0.886593074414756}, {28.5, 0.611950469941404}, {27.5, 
                    0.611950469941404}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 0.03440408950042972}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 0.1794463168999025}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 0.16801486770385304`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 0.15612616053996203`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 1.3170696308554133`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 1.4450220573945132`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{28.5, 0.7504807281646119}, {27.5, 
                    0.7504807281646119}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28., 0.611950469941404}, {28., 
                    0.2831295611080688}}, {{28., 0.886593074414756}, {28., 
                    1.1196993439166605`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28.25, 0.2831295611080688}, {27.75, 
                    0.2831295611080688}}, {{28.25, 1.1196993439166605`}, {
                    27.75, 1.1196993439166605`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.4450220573945132`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.886593074414756`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7504807281646119`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.611950469941404`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.03440408950042972`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.4450220573945132`}, {
                    Style["75%", Bold], 0.886593074414756}, {
                    Style["median", Bold], 0.7504807281646119}, {
                    Style["25%", Bold], 0.611950469941404}, {
                    Style["min", Bold], 0.03440408950042972}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{28.5, 0.814482758942446}, {29.5, 
                    0.814482758942446}, {29.5, 0.350342401267031}, {28.5, 
                    0.350342401267031}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{29.5, 0.5497145018355839}, {28.5, 
                    0.5497145018355839}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29., 0.350342401267031}, {
                    29., -0.09865898434417798}}, {{29., 0.814482758942446}, {
                    29., 1.2554839380268972`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29.25, -0.09865898434417798}, {
                    28.75, -0.09865898434417798}}, {{29.25, 
                    1.2554839380268972`}, {28.75, 
                    1.2554839380268972`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2554839380268972`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.814482758942446`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5497145018355839`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.350342401267031`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.09865898434417798`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2554839380268972`}, {
                    Style["75%", Bold], 0.814482758942446}, {
                    Style["median", Bold], 0.5497145018355839}, {
                    Style["25%", Bold], 0.350342401267031}, {
                    Style["min", Bold], -0.09865898434417798}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{29.5, 0.8164781738626621}, {30.5, 
                    0.8164781738626621}, {30.5, 0.49423381862453936`}, {29.5, 
                    0.49423381862453936`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., -0.06521848328241338}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., -0.023860420713078107`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 1.436569293923431}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 1.6100813060345818`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {30., 1.8502200148597732`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{30.5, 0.6551851080757694}, {29.5, 
                    0.6551851080757694}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30., 0.49423381862453936`}, {30., 
                    0.16784168491797583`}}, {{30., 0.8164781738626621}, {30., 
                    1.2888414553429324`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30.25, 0.16784168491797583`}, {29.75, 
                    0.16784168491797583`}}, {{30.25, 1.2888414553429324`}, {
                    29.75, 1.2888414553429324`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.8502200148597732`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8164781738626621`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6551851080757694`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.49423381862453936`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.06521848328241338`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.8502200148597732`}, {
                    Style["75%", Bold], 0.8164781738626621}, {
                    Style["median", Bold], 0.6551851080757694}, {
                    Style["25%", Bold], 0.49423381862453936`}, {
                    Style["min", Bold], -0.06521848328241338}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{30.5, 0.5377168972951121}, {31.5, 
                    0.5377168972951121}, {31.5, 0.15660311699574164`}, {30.5, 
                    0.15660311699574164`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 1.1456091253759266`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {31., 2.270052262292252}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{31.5, 0.2179011376033324}, {30.5, 
                    0.2179011376033324}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31., 0.15660311699574164`}, {
                    31., -0.1821646877148104}}, {{31., 0.5377168972951121}, {
                    31., 0.9563646105027545}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31.25, -0.1821646877148104}, {
                    30.75, -0.1821646877148104}}, {{31.25, 
                    0.9563646105027545}, {30.75, 
                    0.9563646105027545}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.270052262292252`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5377168972951121`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.2179011376033324`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.15660311699574164`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1821646877148104`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.270052262292252}, {
                    Style["75%", Bold], 0.5377168972951121}, {
                    Style["median", Bold], 0.2179011376033324}, {
                    Style["25%", Bold], 0.15660311699574164`}, {
                    Style["min", Bold], -0.1821646877148104}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{31.5, 0.8395053335701983}, {32.5, 
                    0.8395053335701983}, {32.5, 0.5952076448629648}, {31.5, 
                    0.5952076448629648}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{32.5, 0.724950422281178}, {31.5, 
                    0.724950422281178}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32., 0.5952076448629648}, {32., 
                    0.3460663295016719}}, {{32., 0.8395053335701983}, {32., 
                    1.098110292414173}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32.25, 0.3460663295016719}, {31.75, 
                    0.3460663295016719}}, {{32.25, 1.098110292414173}, {31.75,
                     1.098110292414173}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.098110292414173`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8395053335701983`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.724950422281178`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5952076448629648`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.3460663295016719`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.098110292414173}, {
                    Style["75%", Bold], 0.8395053335701983}, {
                    Style["median", Bold], 0.724950422281178}, {
                    Style["25%", Bold], 0.5952076448629648}, {
                    Style["min", Bold], 0.3460663295016719}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{32.5, 1.0247802787718425`}, {33.5, 
                    1.0247802787718425`}, {33.5, 0.5903614950140524}, {32.5, 
                    0.5903614950140524}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., 1.776819000866045}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., 1.730787420532728}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{33.5, 0.8450630956191489}, {32.5, 
                    0.8450630956191489}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33., 0.5903614950140524}, {33., 
                    0.042962808311095925`}}, {{33., 1.0247802787718425`}, {
                    33., 1.425828200824501}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33.25, 0.042962808311095925`}, {32.75, 
                    0.042962808311095925`}}, {{33.25, 1.425828200824501}, {
                    32.75, 1.425828200824501}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.776819000866045`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.0247802787718425`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8450630956191489`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5903614950140524`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.042962808311095925`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.776819000866045}, {
                    Style["75%", Bold], 1.0247802787718425`}, {
                    Style["median", Bold], 0.8450630956191489}, {
                    Style["25%", Bold], 0.5903614950140524}, {
                    Style["min", Bold], 0.042962808311095925`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{33.5, 0.9622250953891383}, {34.5, 
                    0.9622250953891383}, {34.5, 0.6142493969519951}, {33.5, 
                    0.6142493969519951}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{34.5, 0.7898178605178663}, {33.5, 
                    0.7898178605178663}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34., 0.6142493969519951}, {34., 
                    0.2511634568757583}}, {{34., 0.9622250953891383}, {34., 
                    1.3516375719692513`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34.25, 0.2511634568757583}, {33.75, 
                    0.2511634568757583}}, {{34.25, 1.3516375719692513`}, {
                    33.75, 1.3516375719692513`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.3516375719692513`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9622250953891383`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7898178605178663`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6142493969519951`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.2511634568757583`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.3516375719692513`}, {
                    Style["75%", Bold], 0.9622250953891383}, {
                    Style["median", Bold], 0.7898178605178663}, {
                    Style["25%", Bold], 0.6142493969519951}, {
                    Style["min", Bold], 0.2511634568757583}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    
                    "Tooltip"]& ]}}}, {}, {}}}}, {}, {}}}, {{{{{{{{{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, \
{}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}}, {}}, \
{}}, {{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxFz38sFAAUB/Bzdn5E7HJ1UZwzzuXEOQk5nGKHusldKZxDRU0/TSZH2bDO
JmqcmJli1eTHZXa0MSsrP/rDcHXTqDs/SvlxNCfnx9ZVW733tre3zx/v7X3p
564L04gEAkHwp//O6HzCGpEwGkr4V4UzDPfkNnR3pCChJ2EMzNpd+zqrUwW2
VviWfclQg4e16YwB9QS4qSG99a16BvdJwxpZiw4sWou/PS7fAufbaXKEA0Te
f+etOPu/YFiAa4QersrtnWBKaadJaRcZfJkdaPHgOQW892U/ebScCjbqrspD
jjqAsy9tHjRhO4IZlY95q4s08MMYJstWQAenGDLDYvpcwPycKPmz/a7g9ZqK
VfcqN/BJVopqwMwdPFjVs5yfzASTGkv2JKkP4P27s9JTHBa4yLp9IbvVExxr
avJJSfMCc1VaSyupNziHXtPQf4sN1kbIxGSmD7iuMeDj4nt08GhjfGI5B7w0
L8qN4/qCCz701s9toC8a5otJHYfAErMky3aJHzhwrqRyxf4w2KVju6d7CJ3a
xX5KuemP+Uqd5KZeAWDlCRH9ziT6nYanLKsOxP/E2V+Z/CPgNLsr40I9uq92
3whZEQT2tNmVJhZzwVJhH4FrHwx2GuEkNavQY/6LZ54UhGDeTPFZ36BQsHU1
xSBYQBdL+S3b0Tywnjz92aEJnUGr1xp/ob+bWUwVEcLw/nLmlDkRfaE3YtqW
hJYk6mZoVujYau5cKBUdYDu5VOCN7loP15n6oP00Cp2Mg+a0FS7f90N7Hvf4
8SgI7SzL1b/io+uvzeqPRaEd4wRrg9FoBzf6zxEBmvJmaF0rQlc0cwznT6PJ
FXWGb3Fom9QbGyvx6HuRExtZiegd7PBNgxhdQlVs5knQ5kbqljEZ/Ru3Fwx3

               "]]}, Annotation[#, "Charting`Private`Tag$19041#1"]& ], 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7VXD8IWJ4YI9Axh8sF+xMG3NkauP4Hxt1rP32le/
hfODv0TWXp/yC86vEb5XHnSMyQHGr36vYL5ejQPOnxGkpbLlNy+cL9K9lbF7
myCcn21gyTFhpQicL7H9qOCFPnE4///b3Cl2TlJwfmnGT11GA1k4X23yAodP
r+Xh/Gn+Gtr8vopwfsL3Qkf/g0pwvnu555RlMipw/rcZkz6pT1WF8wO0Ey4d
Y1OH849P3f2uJl4Dzmdd1CEWe1UTYX7b46oQI204v5lnw6vSNTpwfiAz450t
8npwvs2l+5zcVfpwfrnijIVHKwzg/Puu7TGCGoZw/pxFFjdeX0bwbS8siozu
M4Lz37wMrgyzMYbz66/snffsB4Kf/v1lC+smEzg/ji2Wc0OcKZxv+axj8ntJ
MzhfadPv3btOIPiJ2wyWipSYI/zXLTeFWc8Czt/iE6xYdxvBP3nPYUvvdEuE
+2JKn2q4W8H5qcI514M+I/gHZ0mfF1xnDefr8AmlxsTYwPlVQQcZbCRt4Xy5
80axqy4h+BfNX4cvqbdD+LcwJsLY2h7O55ku8t33FYLfUuW++reXA5z/WfDh
XakVCH6W/Lz7//8h+Bb8t9/U6zvC+ez/xX/9j0fwAT9m8Jc=
               "]]}, 
             Annotation[#, "Charting`Private`Tag$19041#2"]& ]}}, {}}}, {
        Epilog -> {
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox[
                  "\"Efficient Non-behavioral\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Efficient Non-behavioral", 12]]], TraditionalForm]], {
            3, -0.1}], 
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Random\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Random", 12]]], TraditionalForm]], {1, 1.1}], 
           InsetBox[
            GraphicsBox[{
              GrayLevel[0.5], 
              RectangleBox[{0, 0}, {3, 1}]}], {1, 0.28609716531936347`}, {1.5,
             0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0.5, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {2, 0.5614856903117206}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {3, 0.48913862461810087`}, {1.5,
             0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0.7777777777777778, 
               NCache[
                Rational[5, 9], 0.5555555555555556], 0.7777777777777778], 
              RectangleBox[{0, 0}, {3, 1}]}], {4, 1.3096455359378378`}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {5, 1.0590706932025862`}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 0, 1], 
              RectangleBox[{0, 0}, {3, 1}]}], {6, 0.8617111838396985}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {7, 0.9368795613619549}, {1.5, 
            0.5}, 1.25]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False},
          AxesLabel -> {None, None}, 
         AxesOrigin -> {-1.2000000000000002`, -1.081045115387226}, Frame -> 
         True, FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
         GrayLevel[0], FrameTicks -> {{Automatic, Automatic}, {{{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Observed\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Observed", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Democracy\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Democracy", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Community\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Community", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Despotism\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Despotism", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Large, PlotRange -> {All, 2.5}, 
         PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {{{1., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Observed\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Observed", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            11., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            12., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            13., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            14., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            15., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            16., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            9.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Democracy\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Democracy", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            20., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            21., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            22., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            23., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            24., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            25., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            18.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Community\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Community", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            29., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            30., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            31., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            32., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            33., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            34., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            27.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Despotism\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Despotism", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
           Automatic}}], 
       FormBox[
        FormBox[
         TemplateBox[{
          "\"Dotty\"", "\"Hook\"", "\"Linda\"", "\"Lodge\"", "\"Nyayo\"", 
           "\"Viola\"", "\"Vogue\""}, "SwatchLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #7}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.5185185185185186, 0.37037037037037035`, 
                    0.5185185185185186], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.7777777777777778`", ",", 
                    FractionBox["5", "9"], ",", "0.7777777777777778`"}], 
                    "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], Editable -> False, 
                    Selectable -> False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], "]"}]}], "}"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", "}"}], ",", 
                   RowBox[{"{", 
                    
                    RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, 
                    ",", #7}], "}"}]}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "None", "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic"}], "}"}]}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]}, "Legended", 
      DisplayFunction -> (GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ), 
      InterpretationFunction -> (RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& ), Editable -> True], 
     RotationBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"   More Efficient                                          Less \
Efficient\"", Italic, 
           RGBColor[1, 0, 0], 15, StripOnInput -> False], TextForm]], 
        "InlineText"], 
       Text[
        Style[
        "   More Efficient                                          Less \
Efficient", Italic, 
         RGBColor[1, 0, 0], 15]]], BoxRotation -> 1.5707963267948966`]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 2}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )], 
   RotationBox[
    InterpretationBox[
     Cell[
      BoxData[
       FormBox[
        StyleBox[
        "\"Scaled Mean Weight\\nof Broken Bonds\"", 21, TextAlignment -> 
         Center, StripOnInput -> False], TextForm]], "InlineText"], 
     Text[
      Style[
      "Scaled Mean Weight\nof Broken Bonds", 21, TextAlignment -> Center]]], 
    BoxRotation -> 1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8235923308961267`*^9, {3.8235924131861086`*^9, 3.8235924292269435`*^9}, {
   3.8235924620030713`*^9, 3.8235925198217907`*^9}, 3.8235926568314123`*^9, {
   3.823592690074173*^9, 3.823592731531687*^9}, 3.8235927706492815`*^9, 
   3.8235930540342207`*^9, 3.823593706526876*^9, {3.8235937711941338`*^9, 
   3.823593776723172*^9}, {3.8235938429564257`*^9, 3.82359385668573*^9}, 
   3.82393779318495*^9, 3.824988232890164*^9, {3.840094372449966*^9, 
   3.840094401478868*^9}, 3.840094520010007*^9},
 CellLabel->
  "Out[733]=",ExpressionUUID->"5f9dbc99-f3f2-4718-88a8-8422a4fa03f3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sparsity", "Subsection",
 CellChangeTimes->{{3.8235925757025185`*^9, 3.823592578221815*^9}, {
  3.8235933790635824`*^9, 3.8235933845943413`*^9}, {3.823593945273777*^9, 
  3.8235939479084578`*^9}},ExpressionUUID->"1bbd635b-9153-427d-b2ed-\
d5d42e2b2d45"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{"<<", "\"\<dotty_despot_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{"<<", "\"\<dotty_democ_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{"<<", "\"\<dotty_comm_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottyrand", "=", 
    RowBox[{"<<", "\"\<dotty_rand_sparsity\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{"<<", "\"\<linda_despot_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{"<<", "\"\<linda_democ_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{"<<", "\"\<linda_comm_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindarand", "=", 
    RowBox[{"<<", "\"\<linda_rand_sparsity\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{"<<", "\"\<lodge_despot_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{"<<", "\"\<lodge_democ_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{"<<", "\"\<lodge_comm_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgerand", "=", 
    RowBox[{"<<", "\"\<lodge_rand_sparsity\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{"<<", "\"\<nyayo_despot_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{"<<", "\"\<nyayo_democ_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{"<<", "\"\<nyayo_comm_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayorand", "=", 
    RowBox[{"<<", "\"\<nyayo_rand_sparsity\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{"<<", "\"\<hook_despot_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{"<<", "\"\<hook_democ_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{"<<", "\"\<hook_comm_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hookrand", "=", 
    RowBox[{"<<", "\"\<hook_rand_sparsity\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{"<<", "\"\<viola_despot_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{"<<", "\"\<viola_democ_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{"<<", "\"\<viola_comm_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violarand", "=", 
    RowBox[{"<<", "\"\<viola_rand_sparsity\>\""}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{"<<", "\"\<vogue_despot_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{"<<", "\"\<vogue_democ_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{"<<", "\"\<vogue_comm_sparsity\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{"<<", "\"\<vogue_rand_sparsity\>\""}]}], ";"}]}], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"abcde9e7-1ea6-43c1-92ac-cd8d2fe64731"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottynewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"dottydemoc", "/", "dottymax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"dottyrand", "/", "dottymax"}], "]"}], ",", 
     RowBox[{"29.57", "/", "dottymax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"dottycomm", "/", "dottymax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"dottyrand", "/", "dottymax"}], "]"}], ",", 
     RowBox[{"29.57", "/", "dottymax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"dottydespot", "/", "dottymax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"dottyrand", "/", "dottymax"}], "]"}], ",", 
     RowBox[{"29.57", "/", "dottymax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottynewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"dottyspars", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"dottyrand", "/", "dottymax"}], "]"}], ",", 
      RowBox[{"29.57", "/", "dottymax"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"hookdemoc", "/", "hookmax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"hookrand", "/", "hookmax"}], "]"}], ",", 
     RowBox[{"19.06", "/", "hookmax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"hookcomm", "/", "hookmax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"hookrand", "/", "hookmax"}], "]"}], ",", 
     RowBox[{"19.06", "/", "hookmax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"hookdespot", "/", "hookmax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"hookrand", "/", "hookmax"}], "]"}], ",", 
     RowBox[{"19.06", "/", "hookmax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hooknewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"hookspars", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"hookrand", "/", "hookmax"}], "]"}], ",", 
      RowBox[{"19.06", "/", "hookmax"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lindademoc", "/", "lindamax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lindarand", "/", "lindamax"}], "]"}], ",", 
     RowBox[{"20.95", "/", "lindamax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lindacomm", "/", "lindamax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lindarand", "/", "lindamax"}], "]"}], ",", 
     RowBox[{"20.95", "/", "lindamax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lindadespot", "/", "lindamax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lindarand", "/", "lindamax"}], "]"}], ",", 
     RowBox[{"20.95", "/", "lindamax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lindaspars", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"lindarand", "/", "lindamax"}], "]"}], ",", 
      RowBox[{"20.95", "/", "lindamax"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lodgedemoc", "/", "lodgemax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lodgerand", "/", "lodgemax"}], "]"}], ",", 
     RowBox[{"2.68", "/", "lodgemax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lodgecomm", "/", "lodgemax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lodgerand", "/", "lodgemax"}], "]"}], ",", 
     RowBox[{"2.68", "/", "lodgemax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"lodgedespot", "/", "lodgemax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"lodgerand", "/", "lodgemax"}], "]"}], ",", 
     RowBox[{"2.68", "/", "lodgemax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgenewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lodgespars", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"lodgerand", "/", "lodgemax"}], "]"}], ",", 
      RowBox[{"2.68", "/", "lodgemax"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"nyayodemoc", "/", "nyayomax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"nyayorand", "/", "nyayomax"}], "]"}], ",", 
     RowBox[{"18.73", "/", "nyayomax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"nyayocomm", "/", "nyayomax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"nyayorand", "/", "nyayomax"}], "]"}], ",", 
     RowBox[{"18.73", "/", "nyayomax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"nyayodespot", "/", "nyayomax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"nyayorand", "/", "nyayomax"}], "]"}], ",", 
     RowBox[{"18.73", "/", "nyayomax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayonewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"nyayospars", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"nyayorand", "/", "nyayomax"}], "]"}], ",", 
      RowBox[{"18.73", "/", "nyayomax"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"violademoc", "/", "violamax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"violarand", "/", "violamax"}], "]"}], ",", 
     RowBox[{"12.35", "/", "violamax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"violacomm", "/", "violamax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"violarand", "/", "violamax"}], "]"}], ",", 
     RowBox[{"12.35", "/", "violamax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"violadespot", "/", "violamax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"violarand", "/", "violamax"}], "]"}], ",", 
     RowBox[{"12.35", "/", "violamax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"violaspars", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"violarand", "/", "violamax"}], "]"}], ",", 
      RowBox[{"12.35", "/", "violamax"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"voguedemoc", "/", "voguemax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "/", "voguemax"}], "]"}], ",", 
     RowBox[{"15.59", "/", "voguemax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"voguecomm", "/", "voguemax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "/", "voguemax"}], "]"}], ",", 
     RowBox[{"15.59", "/", "voguemax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"voguedespot", "/", "voguemax"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "/", "voguemax"}], "]"}], ",", 
     RowBox[{"15.59", "/", "voguemax"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewobs", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"voguespars", ",", "100"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"voguerand", "/", "voguemax"}], "]"}], ",", 
     RowBox[{"15.59", "/", "voguemax"}]}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[30]:=",ExpressionUUID->"def859f4-ff2b-4fda-8c07-aa2510f4fdbb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figs7", "=", 
  RowBox[{"Labeled", "[", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "dottynewobs", ",", "hooknewobs", ",", "lindanewobs", ",", 
              "lodgenewobs", ",", "nyayonewobs", ",", "violanewobs", ",", 
              "voguenewobs"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdemoc", ",", "hooknewdemoc", ",", "lindanewdemoc", ",", 
              "lodgenewdemoc", ",", "nyayonewdemoc", ",", "violanewdemoc", 
              ",", "voguenewdemoc"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewcomm", ",", "hooknewcomm", ",", "lindanewcomm", ",", 
              "lodgenewcomm", ",", "nyayonewcomm", ",", "violanewcomm", ",", 
              "voguenewcomm"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdespot", ",", "hooknewdespot", ",", "lindanewdespot", 
              ",", "lodgenewdespot", ",", "nyayonewdespot", ",", 
              "violanewdespot", ",", "voguenewdespot"}], "}"}]}], 
           "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<Outliers\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<MedianMarker\>\"", ",", "1", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Black", ",", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"ChartLabels", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Observed\>\"", ",", "17", ",", "Black"}], "]"}],
                 "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Democracy\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Community\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Despotism\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}]}], "}"}], ",", "None"}], "}"}]}], ",", 
          RowBox[{"ChartLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Dotty\>\"", ",", "\"\<Hook\>\"", ",", "\"\<Linda\>\"", ",", 
             "\"\<Lodge\>\"", ",", "\"\<Nyayo\>\"", ",", "\"\<Viola\>\"", 
             ",", "\"\<Vogue\>\""}], "}"}]}], ",", 
          RowBox[{"BarSpacing", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "2"}], "}"}]}], ",", 
          RowBox[{"ChartStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Gray", ",", "Orange", ",", "Green", ",", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", "Yellow", 
             ",", "Blue", ",", "Red"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"FrameStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.25", ",", "34.75"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dashed"}], "]"}]}]}], "]"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Efficient Non-behavioral\>\"", ",", "12"}], "]"}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"-", "0.1"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Random\>\"", ",", "12"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "1.1"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Gray", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"dottynewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Orange", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"hooknewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Green", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"lindanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Lighter", "[", 
                 RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", 
               RowBox[{"lodgenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Yellow", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", 
               RowBox[{"nyayonewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"6", ",", 
               RowBox[{"violanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"7", ",", 
               RowBox[{"voguenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}]}], 
          "\[IndentingNewLine]", "}"}]}]}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<   More Efficient                                          \
Less Efficient\>\"", ",", "Italic", ",", "Red", ",", "15"}], "]"}], "]"}], 
        ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Scaled Sparsity\>\"", ",", "21", ",", 
         RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}], "]"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8235920125253134`*^9, 3.823592065605406*^9}, {
   3.823592110163682*^9, 3.823592257916377*^9}, {3.8235923147544823`*^9, 
   3.82359232692793*^9}, {3.823592405067442*^9, 3.8235924279573603`*^9}, {
   3.8235924601542344`*^9, 3.8235925182234397`*^9}, {3.8235926326470547`*^9, 
   3.823592768222708*^9}, {3.823593046485058*^9, 3.823593052835633*^9}, {
   3.8235937638522778`*^9, 3.82359377539753*^9}, {3.823593821851324*^9, 
   3.823593855042349*^9}, {3.823594025025442*^9, 3.8235940489083385`*^9}, {
   3.823958810136651*^9, 3.8239588123945274`*^9}, 3.824988274878929*^9, {
   3.83924158334317*^9, 3.839241607162958*^9}, {3.8400947073704433`*^9, 
   3.840094707834696*^9}},ExpressionUUID->"93cc6893-42f0-442f-bb47-\
a6fd4c9b77a0"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
     TemplateBox[{
       GraphicsBox[{{{
           CapForm[None], 
           Directive[
            RGBColor[0.982864, 0.7431472, 0.3262672]], {{}, {{{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{0.5, 0.9310516033032665}, {1.5, 
                    0.9310516033032665}, {1.5, 0.9310516033032665}, {0.5, 
                    0.9310516033032665}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.9310516033032665}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{1.5, 0.9310516033032665}, {0.5, 
                    0.9310516033032665}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1., 0.9310516033032665}, {1., 
                    0.9310516033032665}}, {{1., 0.9310516033032665}, {1., 
                    0.9310516033032665}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1.25, 0.9310516033032665}, {0.75, 
                    0.9310516033032665}}, {{1.25, 0.9310516033032665}, {0.75, 
                    0.9310516033032665}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.9310516033032665`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9310516033032665`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.9310516033032665`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.9310516033032665`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.9310516033032665`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.9310516033032665}, {
                    Style["75%", Bold], 0.9310516033032665}, {
                    Style["median", Bold], 0.9310516033032665}, {
                    Style["25%", Bold], 0.9310516033032665}, {
                    Style["min", Bold], 0.9310516033032665}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{1.5, 2.8457742340695984`}, {2.5, 
                    2.8457742340695984`}, {2.5, 2.8457742340695984`}, {1.5, 
                    2.8457742340695984`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 2.8457742340695984`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{2.5, 2.8457742340695984`}, {1.5, 
                    2.8457742340695984`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2., 2.8457742340695984`}, {2., 
                    2.8457742340695984`}}, {{2., 2.8457742340695984`}, {2., 
                    2.8457742340695984`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2.25, 2.8457742340695984`}, {1.75, 
                    2.8457742340695984`}}, {{2.25, 2.8457742340695984`}, {
                    1.75, 2.8457742340695984`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.8457742340695984`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "2.8457742340695984`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "2.8457742340695984`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "2.8457742340695984`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "2.8457742340695984`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.8457742340695984`}, {
                    Style["75%", Bold], 2.8457742340695984`}, {
                    Style["median", Bold], 2.8457742340695984`}, {
                    Style["25%", Bold], 2.8457742340695984`}, {
                    Style["min", Bold], 2.8457742340695984`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{2.5, 0.19054341504511257`}, {3.5, 
                    0.19054341504511257`}, {3.5, 0.19054341504511257`}, {2.5, 
                    0.19054341504511257`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.19054341504511257`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{3.5, 0.19054341504511257`}, {2.5, 
                    0.19054341504511257`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3., 0.19054341504511257`}, {3., 
                    0.19054341504511257`}}, {{3., 0.19054341504511257`}, {3., 
                    0.19054341504511257`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3.25, 0.19054341504511257`}, {2.75, 
                    0.19054341504511257`}}, {{3.25, 0.19054341504511257`}, {
                    2.75, 0.19054341504511257`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.19054341504511257`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.19054341504511257`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.19054341504511257`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.19054341504511257`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.19054341504511257`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.19054341504511257`}, {
                    Style["75%", Bold], 0.19054341504511257`}, {
                    Style["median", Bold], 0.19054341504511257`}, {
                    Style["25%", Bold], 0.19054341504511257`}, {
                    Style["min", Bold], 0.19054341504511257`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{3.5, 0.8285028211559801}, {4.5, 
                    0.8285028211559801}, {4.5, 0.8285028211559801}, {3.5, 
                    0.8285028211559801}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 0.8285028211559801}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{4.5, 0.8285028211559801}, {3.5, 
                    0.8285028211559801}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4., 0.8285028211559801}, {4., 
                    0.8285028211559801}}, {{4., 0.8285028211559801}, {4., 
                    0.8285028211559801}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4.25, 0.8285028211559801}, {3.75, 
                    0.8285028211559801}}, {{4.25, 0.8285028211559801}, {3.75, 
                    0.8285028211559801}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8285028211559801`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8285028211559801`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8285028211559801`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.8285028211559801`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.8285028211559801`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.8285028211559801}, {
                    Style["75%", Bold], 0.8285028211559801}, {
                    Style["median", Bold], 0.8285028211559801}, {
                    Style["25%", Bold], 0.8285028211559801}, {
                    Style["min", Bold], 0.8285028211559801}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{4.5, 0.8776159025037409}, {5.5, 
                    0.8776159025037409}, {5.5, 0.8776159025037409}, {4.5, 
                    0.8776159025037409}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 0.8776159025037409}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{5.5, 0.8776159025037409}, {4.5, 
                    0.8776159025037409}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5., 0.8776159025037409}, {5., 
                    0.8776159025037409}}, {{5., 0.8776159025037409}, {5., 
                    0.8776159025037409}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5.25, 0.8776159025037409}, {4.75, 
                    0.8776159025037409}}, {{5.25, 0.8776159025037409}, {4.75, 
                    0.8776159025037409}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8776159025037409`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8776159025037409`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8776159025037409`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.8776159025037409`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.8776159025037409`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.8776159025037409}, {
                    Style["75%", Bold], 0.8776159025037409}, {
                    Style["median", Bold], 0.8776159025037409}, {
                    Style["25%", Bold], 0.8776159025037409}, {
                    Style["min", Bold], 0.8776159025037409}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{5.5, 0.4265111089304966}, {6.5, 
                    0.4265111089304966}, {6.5, 0.4265111089304966}, {5.5, 
                    0.4265111089304966}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.4265111089304966}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{6.5, 0.4265111089304966}, {5.5, 
                    0.4265111089304966}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6., 0.4265111089304966}, {6., 
                    0.4265111089304966}}, {{6., 0.4265111089304966}, {6., 
                    0.4265111089304966}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6.25, 0.4265111089304966}, {5.75, 
                    0.4265111089304966}}, {{6.25, 0.4265111089304966}, {5.75, 
                    0.4265111089304966}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.4265111089304966`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4265111089304966`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.4265111089304966`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4265111089304966`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.4265111089304966`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.4265111089304966}, {
                    Style["75%", Bold], 0.4265111089304966}, {
                    Style["median", Bold], 0.4265111089304966}, {
                    Style["25%", Bold], 0.4265111089304966}, {
                    Style["min", Bold], 0.4265111089304966}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{6.5, 1.2217666559785036`}, {7.5, 
                    1.2217666559785036`}, {7.5, 1.2217666559785036`}, {6.5, 
                    1.2217666559785036`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 1.2217666559785036`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{7.5, 1.2217666559785036`}, {6.5, 
                    1.2217666559785036`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7., 1.2217666559785036`}, {7., 
                    1.2217666559785036`}}, {{7., 1.2217666559785036`}, {7., 
                    1.2217666559785036`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7.25, 1.2217666559785036`}, {6.75, 
                    1.2217666559785036`}}, {{7.25, 1.2217666559785036`}, {
                    6.75, 1.2217666559785036`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2217666559785036`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.2217666559785036`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.2217666559785036`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.2217666559785036`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.2217666559785036`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2217666559785036`}, {
                    Style["75%", Bold], 1.2217666559785036`}, {
                    Style["median", Bold], 1.2217666559785036`}, {
                    Style["25%", Bold], 1.2217666559785036`}, {
                    Style["min", Bold], 1.2217666559785036`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{9.5, 0.3957720508278524}, {10.5, 
                    0.3957720508278524}, {10.5, 0.010741034822514827`}, {9.5, 
                    0.010741034822514827`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 1.3076595467087637`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 1.006489505931149}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 1.052184270738787}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 1.1693290314274591`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 0.9794880539993628}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 1.32457254407263}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 1.3232373074386403`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    10., 1.4349521058157557`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {10., 1.6160992091603208`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{10.5, 0.17609100729052546`}, {9.5, 
                    0.17609100729052546`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10., 0.010741034822514827`}, {
                    10., -0.18157437906744198`}}, {{10., 
                    0.3957720508278524}, {10., 0.8714822462722182}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10.25, -0.18157437906744198`}, {
                    9.75, -0.18157437906744198`}}, {{10.25, 
                    0.8714822462722182}, {9.75, 
                    0.8714822462722182}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.6160992091603208`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.3957720508278524`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.17609100729052546`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.010741034822514827`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.18157437906744198`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.6160992091603208`}, {
                    Style["75%", Bold], 0.3957720508278524}, {
                    Style["median", Bold], 0.17609100729052546`}, {
                    Style["25%", Bold], 0.010741034822514827`}, {
                    Style["min", Bold], -0.18157437906744198`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{10.5, 0.46744898551808983`}, {11.5, 
                    0.46744898551808983`}, {11.5, 0.1886103486150072}, {10.5, 
                    0.1886103486150072}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 0.8992690260001208}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 0.9421693611809747}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 1.0812704479795017`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 0.926569239297028}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 1.2882970654810473`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 0.9641070325802753}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 1.2132214789145528`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {11., 1.7728758515011487`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{11.5, 0.281601700157597}, {10.5, 
                    0.281601700157597}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11., 0.1886103486150072}, {
                    11., -0.08353865268853573}}, {{11., 
                    0.46744898551808983`}, {11., 0.8685562860411002}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11.25, -0.08353865268853573}, {
                    10.75, -0.08353865268853573}}, {{11.25, 
                    0.8685562860411002}, {10.75, 
                    0.8685562860411002}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.7728758515011487`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.46744898551808983`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.281601700157597`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.1886103486150072`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.08353865268853573`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.7728758515011487`}, {
                    Style["75%", Bold], 0.46744898551808983`}, {
                    Style["median", Bold], 0.281601700157597}, {
                    Style["25%", Bold], 0.1886103486150072}, {
                    Style["min", Bold], -0.08353865268853573}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{11.5, 0.31131245917382244`}, {12.5, 
                    0.31131245917382244`}, {12.5, 0.06468562542521832}, {11.5,
                     0.06468562542521832}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 0.8782663368966779}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 1.036000952000248}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 0.786149321676193}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{12.5, 0.1587751101084638}, {11.5, 
                    0.1587751101084638}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12., 0.06468562542521832}, {
                    12., -0.3015885840780258}}, {{12., 
                    0.31131245917382244`}, {12., 0.6574378757516798}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12.25, -0.3015885840780258}, {
                    11.75, -0.3015885840780258}}, {{12.25, 
                    0.6574378757516798}, {11.75, 
                    0.6574378757516798}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.036000952000248`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.31131245917382244`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.1587751101084638`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.06468562542521832`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3015885840780258`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.036000952000248}, {
                    Style["75%", Bold], 0.31131245917382244`}, {
                    Style["median", Bold], 0.1587751101084638}, {
                    Style["25%", Bold], 0.06468562542521832}, {
                    Style["min", Bold], -0.3015885840780258}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{12.5, 0.2507410759128282}, {13.5, 
                    0.2507410759128282}, {13.5, 0.06582852885757029}, {12.5, 
                    0.06582852885757029}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    13., 0.6451479659087161}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    13., 0.6096690852494159}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {13., 0.8225423692052176}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{13.5, 0.12139099017579591`}, {12.5, 
                    0.12139099017579591`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13., 0.06582852885757029}, {
                    13., -0.002341606123513828}}, {{13., 
                    0.2507410759128282}, {13., 0.5245197716670954}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13.25, -0.002341606123513828}, {
                    12.75, -0.002341606123513828}}, {{13.25, 
                    0.5245197716670954}, {12.75, 
                    0.5245197716670954}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8225423692052176`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.2507410759128282`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.12139099017579591`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.06582852885757029`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.002341606123513828`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.8225423692052176}, {
                    Style["75%", Bold], 0.2507410759128282}, {
                    Style["median", Bold], 0.12139099017579591`}, {
                    Style["25%", Bold], 0.06582852885757029}, {
                    Style["min", Bold], -0.002341606123513828}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{13.5, 0.4571194479972225}, {14.5, 
                    0.4571194479972225}, {14.5, 0.20383678278066378`}, {13.5, 
                    0.20383678278066378`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., 0.9150829335060352}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., 1.0749516560158245`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., 0.9594517860087519}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., 1.1714363035217332`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., 1.8123197285609773`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., 1.3119376697803364`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14., 1.2305947735253555`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{14.5, 0.2849654800299498}, {13.5, 
                    0.2849654800299498}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14., 0.20383678278066378`}, {14., 
                    0.010675414814290043`}}, {{14., 0.4571194479972225}, {14.,
                     0.8235281585004287}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14.25, 0.010675414814290043`}, {13.75, 
                    0.010675414814290043`}}, {{14.25, 0.8235281585004287}, {
                    13.75, 0.8235281585004287}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.8123197285609773`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4571194479972225`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.2849654800299498`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.20383678278066378`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.010675414814290043`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.8123197285609773`}, {
                    Style["75%", Bold], 0.4571194479972225}, {
                    Style["median", Bold], 0.2849654800299498}, {
                    Style["25%", Bold], 0.20383678278066378`}, {
                    Style["min", Bold], 0.010675414814290043`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{14.5, 0.40658776695456084`}, {15.5, 
                    0.40658776695456084`}, {15.5, 0.18643329127714836`}, {
                    14.5, 0.18643329127714836`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.8765187679087004}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.995625703634404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.9213772242209785}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.9144164292759697}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.9501485099936808}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.7926025177383184}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.9550210664551868}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 0.8397038968662102}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{15.5, 0.31346779902355626`}, {14.5, 
                    0.31346779902355626`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15., 0.18643329127714836`}, {
                    15., -0.07633671789692821}}, {{15., 
                    0.40658776695456084`}, {15., 0.71626579984139}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15.25, -0.07633671789692821}, {
                    14.75, -0.07633671789692821}}, {{15.25, 
                    0.71626579984139}, {14.75, 0.71626579984139}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.995625703634404`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.40658776695456084`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.31346779902355626`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.18643329127714836`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.07633671789692821`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.995625703634404}, {
                    Style["75%", Bold], 0.40658776695456084`}, {
                    Style["median", Bold], 0.31346779902355626`}, {
                    Style["25%", Bold], 0.18643329127714836`}, {
                    Style["min", Bold], -0.07633671789692821}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{15.5, 0.5102219419925698}, {16.5, 
                    0.5102219419925698}, {16.5, 0.11293087935454825`}, {15.5, 
                    0.11293087935454825`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.1702261937984362`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.475173928363836}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.2063045173244835`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.1297301163712403`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 1.5825498912389775`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{16.5, 0.24961536695351336`}, {15.5, 
                    0.24961536695351336`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16., 0.11293087935454825`}, {
                    16., -0.09251512961322143}}, {{16., 0.5102219419925698}, {
                    16., 1.0735878272108095`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16.25, -0.09251512961322143}, {
                    15.75, -0.09251512961322143}}, {{16.25, 
                    1.0735878272108095`}, {15.75, 
                    1.0735878272108095`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.5825498912389775`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5102219419925698`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.24961536695351336`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.11293087935454825`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.09251512961322143`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.5825498912389775`}, {
                    Style["75%", Bold], 0.5102219419925698}, {
                    Style["median", Bold], 0.24961536695351336`}, {
                    Style["25%", Bold], 0.11293087935454825`}, {
                    Style["min", Bold], -0.09251512961322143}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{18.5, 0.08547294773044309}, {19.5, 
                    0.08547294773044309}, {19.5, -0.09766217460250654}, {
                    18.5, -0.09766217460250654}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{19.5, 0.004171872683086988}, {18.5, 
                    0.004171872683086988}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19., -0.09766217460250654}, {
                    19., -0.2438854219869485}}, {{19., 0.08547294773044309}, {
                    19., 0.3247028446535485}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19.25, -0.2438854219869485}, {
                    18.75, -0.2438854219869485}}, {{19.25, 
                    0.3247028446535485}, {18.75, 
                    0.3247028446535485}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.3247028446535485`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.08547294773044309`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.004171872683086988`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.09766217460250654`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.2438854219869485`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.3247028446535485}, {
                    Style["75%", Bold], 0.08547294773044309}, {
                    Style["median", Bold], 0.004171872683086988}, {
                    Style["25%", Bold], -0.09766217460250654}, {
                    Style["min", Bold], -0.2438854219869485}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{19.5, 0.29598306251936063`}, {20.5, 
                    0.29598306251936063`}, {20.5, 0.07855636376185035}, {19.5,
                     0.07855636376185035}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 0.7518478741968223}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{20.5, 0.1291755092498656}, {19.5, 
                    0.1291755092498656}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20., 0.07855636376185035}, {
                    20., -0.08353865268853573}}, {{20., 
                    0.29598306251936063`}, {20., 0.5307161464918746}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20.25, -0.08353865268853573}, {
                    19.75, -0.08353865268853573}}, {{20.25, 
                    0.5307161464918746}, {19.75, 
                    0.5307161464918746}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7518478741968223`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.29598306251936063`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.1291755092498656`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.07855636376185035`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.08353865268853573`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.7518478741968223}, {
                    Style["75%", Bold], 0.29598306251936063`}, {
                    Style["median", Bold], 0.1291755092498656}, {
                    Style["25%", Bold], 0.07855636376185035}, {
                    Style["min", Bold], -0.08353865268853573}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{20.5, -0.0029443794819332624`}, {
                    21.5, -0.0029443794819332624`}, {
                    21.5, -0.3520636609111682}, {
                    20.5, -0.3520636609111682}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{21.5, -0.3015885840780258}, {
                    20.5, -0.3015885840780258}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21., -0.3520636609111682}, {
                    21., -0.3520636609111682}}, {{
                    21., -0.0029443794819332624`}, {21., 
                    0.177924645836827}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21.25, -0.3520636609111682}, {
                    20.75, -0.3520636609111682}}, {{21.25, 
                    0.177924645836827}, {20.75, 
                    0.177924645836827}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.177924645836827`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.0029443794819332624`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3015885840780258`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3520636609111682`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3520636609111682`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.177924645836827}, {
                    Style["75%", Bold], -0.0029443794819332624`}, {
                    Style["median", Bold], -0.3015885840780258}, {
                    Style["25%", Bold], -0.3520636609111682}, {
                    Style["min", Bold], -0.3520636609111682}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{21.5, 0.061875167869819704`}, {22.5, 
                    0.061875167869819704`}, {22.5, 0.0001792617128048837}, {
                    21.5, 0.0001792617128048837}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.2690718309201333}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.2690718309201333}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.2690718309201333}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.2690718309201333}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.2690718309201333}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{22.5, 0.0001792617128048837}, {21.5, 
                    0.0001792617128048837}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22., 0.0001792617128048837}, {
                    22., -0.002341606123513828}}, {{22., 
                    0.061875167869819704`}, {22., 0.1380728869473323}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22.25, -0.002341606123513828}, {
                    21.75, -0.002341606123513828}}, {{22.25, 
                    0.1380728869473323}, {21.75, 
                    0.1380728869473323}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.2690718309201333`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.061875167869819704`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.0001792617128048837`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.0001792617128048837`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.002341606123513828`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.2690718309201333}, {
                    Style["75%", Bold], 0.061875167869819704`}, {
                    Style["median", Bold], 0.0001792617128048837}, {
                    Style["25%", Bold], 0.0001792617128048837}, {
                    Style["min", Bold], -0.002341606123513828}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{22.5, 0.4218609276424994}, {23.5, 
                    0.4218609276424994}, {23.5, 0.13334600845816547`}, {22.5, 
                    0.13334600845816547`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{23.5, 0.20926604496281442`}, {22.5, 
                    0.20926604496281442`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23., 0.13334600845816547`}, {
                    23., -0.19906825156218996`}}, {{23., 
                    0.4218609276424994}, {23., 0.7770465034975824}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23.25, -0.19906825156218996`}, {
                    22.75, -0.19906825156218996`}}, {{23.25, 
                    0.7770465034975824}, {22.75, 
                    0.7770465034975824}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7770465034975824`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4218609276424994`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.20926604496281442`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.13334600845816547`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.19906825156218996`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.7770465034975824}, {
                    Style["75%", Bold], 0.4218609276424994}, {
                    Style["median", Bold], 0.20926604496281442`}, {
                    Style["25%", Bold], 0.13334600845816547`}, {
                    Style["min", Bold], -0.19906825156218996`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{23.5, 0.29722594415186937`}, {24.5, 
                    0.29722594415186937`}, {24.5, 0.02302521778868544}, {23.5,
                     0.02302521778868544}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{24.5, 0.15604674411336059`}, {23.5, 
                    0.15604674411336059`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24., 0.02302521778868544}, {
                    24., -0.07633671789692821}}, {{24., 
                    0.29722594415186937`}, {24., 0.5043095937658766}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24.25, -0.07633671789692821}, {
                    23.75, -0.07633671789692821}}, {{24.25, 
                    0.5043095937658766}, {23.75, 
                    0.5043095937658766}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.5043095937658766`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.29722594415186937`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.15604674411336059`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.02302521778868544`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.07633671789692821`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.5043095937658766}, {
                    Style["75%", Bold], 0.29722594415186937`}, {
                    Style["median", Bold], 0.15604674411336059`}, {
                    Style["25%", Bold], 0.02302521778868544}, {
                    Style["min", Bold], -0.07633671789692821}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{24.5, 0.1644062651934795}, {25.5, 
                    0.1644062651934795}, {25.5, 0.028973102668366616`}, {24.5,
                     0.028973102668366616`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {25., 0.8094429585379626}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{25.5, 0.06408858239544568}, {24.5, 
                    0.06408858239544568}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25., 0.028973102668366616`}, {
                    25., -0.14405559179328908`}}, {{25., 
                    0.1644062651934795}, {25., 0.34042475269934686`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25.25, -0.14405559179328908`}, {
                    24.75, -0.14405559179328908`}}, {{25.25, 
                    0.34042475269934686`}, {24.75, 
                    0.34042475269934686`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8094429585379626`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.1644062651934795`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.06408858239544568`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.028973102668366616`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.14405559179328908`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.8094429585379626}, {
                    Style["75%", Bold], 0.1644062651934795}, {
                    Style["median", Bold], 0.06408858239544568}, {
                    Style["25%", Bold], 0.028973102668366616`}, {
                    Style["min", Bold], -0.14405559179328908`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{27.5, 0.897000101944016}, {28.5, 
                    0.897000101944016}, {28.5, 0.5542893658867302}, {27.5, 
                    0.5542893658867302}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 1.7134143967787268`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 1.4179867462309486`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {28., 2.35359491000048}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {28., 3.2223888798495994`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{28.5, 0.7180413030829333}, {27.5, 
                    0.7180413030829333}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28., 0.5542893658867302}, {28., 
                    0.20076618028664997`}}, {{28., 0.897000101944016}, {28., 
                    1.3549426322182714`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28.25, 0.20076618028664997`}, {27.75, 
                    0.20076618028664997`}}, {{28.25, 1.3549426322182714`}, {
                    27.75, 1.3549426322182714`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "3.2223888798495994`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.897000101944016`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7180413030829333`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5542893658867302`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.20076618028664997`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 3.2223888798495994`}, {
                    Style["75%", Bold], 0.897000101944016}, {
                    Style["median", Bold], 0.7180413030829333}, {
                    Style["25%", Bold], 0.5542893658867302}, {
                    Style["min", Bold], 0.20076618028664997`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{28.5, 0.7699830158869108}, {29.5, 
                    0.7699830158869108}, {29.5, 0.5121910017546876}, {28.5, 
                    0.5121910017546876}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    29., 1.3213723238984543`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    29., 1.1598619711069615`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 1.7592257448526951`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{29.5, 0.6110108914827778}, {28.5, 
                    0.6110108914827778}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29., 0.5121910017546876}, {29., 
                    0.22700127356378286`}}, {{29., 0.7699830158869108}, {29., 
                    1.1153957146006355`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29.25, 0.22700127356378286`}, {28.75, 
                    0.22700127356378286`}}, {{29.25, 1.1153957146006355`}, {
                    28.75, 1.1153957146006355`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.7592257448526951`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7699830158869108`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6110108914827778`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5121910017546876`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.22700127356378286`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.7592257448526951`}, {
                    Style["75%", Bold], 0.7699830158869108}, {
                    Style["median", Bold], 0.6110108914827778}, {
                    Style["25%", Bold], 0.5121910017546876}, {
                    Style["min", Bold], 0.22700127356378286`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{29.5, 0.5222078570703732}, {30.5, 
                    0.5222078570703732}, {30.5, 0.3147481576809523}, {29.5, 
                    0.3147481576809523}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 0.9001065143725567}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 0.857936097616662}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 0.9855258751671054}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{30.5, 0.43981945238773695`}, {29.5, 
                    0.43981945238773695`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30., 0.3147481576809523}, {30., 
                    0.08959326137882777}}, {{30., 0.5222078570703732}, {30., 
                    0.8232845567748619}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30.25, 0.08959326137882777}, {29.75, 
                    0.08959326137882777}}, {{30.25, 0.8232845567748619}, {
                    29.75, 0.8232845567748619}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.9855258751671054`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5222078570703732`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.43981945238773695`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.3147481576809523`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.08959326137882777`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.9855258751671054}, {
                    Style["75%", Bold], 0.5222078570703732}, {
                    Style["median", Bold], 0.43981945238773695`}, {
                    Style["25%", Bold], 0.3147481576809523}, {
                    Style["min", Bold], 0.08959326137882777}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{30.5, 0.7846982298352974}, {31.5, 
                    0.7846982298352974}, {31.5, 0.46278651931991277`}, {30.5, 
                    0.46278651931991277`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 1.6793573371273194`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 1.370691075391407}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 1.5341473470003262`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 1.3273561568718328`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{31.5, 0.6588326770201607}, {30.5, 
                    0.6588326770201607}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31., 0.46278651931991277`}, {31., 
                    0.0774858753599118}}, {{31., 0.7846982298352974}, {31., 
                    1.0886339741499698`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31.25, 0.0774858753599118}, {30.75, 
                    0.0774858753599118}}, {{31.25, 1.0886339741499698`}, {
                    30.75, 1.0886339741499698`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.6793573371273194`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7846982298352974`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6588326770201607`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.46278651931991277`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.0774858753599118`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.6793573371273194`}, {
                    Style["75%", Bold], 0.7846982298352974}, {
                    Style["median", Bold], 0.6588326770201607}, {
                    Style["25%", Bold], 0.46278651931991277`}, {
                    Style["min", Bold], 0.0774858753599118}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{31.5, 1.0595281977648803`}, {32.5, 
                    1.0595281977648803`}, {32.5, 0.6669887005362976}, {31.5, 
                    0.6669887005362976}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    32., 1.8603859854389209`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{32.5, 0.8102857953556785}, {31.5, 
                    0.8102857953556785}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32., 0.6669887005362976}, {32., 
                    0.4285259519545017}}, {{32., 1.0595281977648803`}, {32., 
                    1.5140624422927138`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32.25, 0.4285259519545017}, {31.75, 
                    0.4285259519545017}}, {{32.25, 1.5140624422927138`}, {
                    31.75, 1.5140624422927138`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.8603859854389209`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.0595281977648803`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8102857953556785`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6669887005362976`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.4285259519545017`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.8603859854389209`}, {
                    Style["75%", Bold], 1.0595281977648803`}, {
                    Style["median", Bold], 0.8102857953556785}, {
                    Style["25%", Bold], 0.6669887005362976}, {
                    Style["min", Bold], 0.4285259519545017}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{32.5, 0.9744620745591758}, {33.5, 
                    0.9744620745591758}, {33.5, 0.6657130265532647}, {32.5, 
                    0.6657130265532647}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., 1.5559696967076004`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., 1.4731362368619974`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{33.5, 0.8010566114279399}, {32.5, 
                    0.8010566114279399}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33., 0.6657130265532647}, {33., 
                    0.3230218313010191}}, {{33., 0.9744620745591758}, {33., 
                    1.391926962503563}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33.25, 0.3230218313010191}, {32.75, 
                    0.3230218313010191}}, {{33.25, 1.391926962503563}, {32.75,
                     1.391926962503563}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.5559696967076004`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9744620745591758`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8010566114279399`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6657130265532647`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.3230218313010191`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.5559696967076004`}, {
                    Style["75%", Bold], 0.9744620745591758}, {
                    Style["median", Bold], 0.8010566114279399}, {
                    Style["25%", Bold], 0.6657130265532647}, {
                    Style["min", Bold], 0.3230218313010191}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{33.5, 0.9472523371765721}, {34.5, 
                    0.9472523371765721}, {34.5, 0.6467789018373078}, {33.5, 
                    0.6467789018373078}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    34., 1.479468966878842}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    34., 1.4536987357888085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    34., 1.7457613548091915`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{34.5, 0.7741692259373507}, {33.5, 
                    0.7741692259373507}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34., 0.6467789018373078}, {34., 
                    0.3355570423823405}}, {{34., 0.9472523371765721}, {34., 
                    1.28718339643782}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34.25, 0.3355570423823405}, {33.75, 
                    0.3355570423823405}}, {{34.25, 1.28718339643782}, {33.75, 
                    1.28718339643782}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.7457613548091915`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9472523371765721`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7741692259373507`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6467789018373078`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.3355570423823405`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.7457613548091915`}, {
                    Style["75%", Bold], 0.9472523371765721}, {
                    Style["median", Bold], 0.7741692259373507}, {
                    Style["25%", Bold], 0.6467789018373078}, {
                    Style["min", Bold], 0.3355570423823405}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}}, {}, {}}}, {{{{{{{{{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, \
{}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}}, {}}, \
{}}, {{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxFz38sFAAUB/Bzdn5E7HJ1UZwzzuXEOQk5nGKHusldKZxDRU0/TSZH2bDO
JmqcmJli1eTHZXa0MSsrP/rDcHXTqDs/SvlxNCfnx9ZVW733tre3zx/v7X3p
564L04gEAkHwp//O6HzCGpEwGkr4V4UzDPfkNnR3pCChJ2EMzNpd+zqrUwW2
VviWfclQg4e16YwB9QS4qSG99a16BvdJwxpZiw4sWou/PS7fAufbaXKEA0Te
f+etOPu/YFiAa4QersrtnWBKaadJaRcZfJkdaPHgOQW892U/ebScCjbqrspD
jjqAsy9tHjRhO4IZlY95q4s08MMYJstWQAenGDLDYvpcwPycKPmz/a7g9ZqK
VfcqN/BJVopqwMwdPFjVs5yfzASTGkv2JKkP4P27s9JTHBa4yLp9IbvVExxr
avJJSfMCc1VaSyupNziHXtPQf4sN1kbIxGSmD7iuMeDj4nt08GhjfGI5B7w0
L8qN4/qCCz701s9toC8a5otJHYfAErMky3aJHzhwrqRyxf4w2KVju6d7CJ3a
xX5KuemP+Uqd5KZeAWDlCRH9ziT6nYanLKsOxP/E2V+Z/CPgNLsr40I9uq92
3whZEQT2tNmVJhZzwVJhH4FrHwx2GuEkNavQY/6LZ54UhGDeTPFZ36BQsHU1
xSBYQBdL+S3b0Tywnjz92aEJnUGr1xp/ob+bWUwVEcLw/nLmlDkRfaE3YtqW
hJYk6mZoVujYau5cKBUdYDu5VOCN7loP15n6oP00Cp2Mg+a0FS7f90N7Hvf4
8SgI7SzL1b/io+uvzeqPRaEd4wRrg9FoBzf6zxEBmvJmaF0rQlc0cwznT6PJ
FXWGb3Fom9QbGyvx6HuRExtZiegd7PBNgxhdQlVs5knQ5kbqljEZ/Ru3Fwx3

               "]]}, Annotation[#, "Charting`Private`Tag$3176#1"]& ], 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7VXD8IWJ4YI9Axh8sF+xMG3NkauP4Hxt1rP32le/
hfODv0TWXp/yC86vEb5XHnSMyQHGr36vYL5ejQPOnxGkpbLlNy+cL9K9lbF7
myCcn21gyTFhpQicL7H9qOCFPnE4///b3Cl2TlJwfmnGT11GA1k4X23yAodP
r+Xh/Gn+Gtr8vopwfsL3Qkf/g0pwvnu555RlMipw/rcZkz6pT1WF8wO0Ey4d
Y1OH849P3f2uJl4Dzmdd1CEWe1UTYX7b46oQI204v5lnw6vSNTpwfiAz450t
8npwvs2l+5zcVfpwfrnijIVHKwzg/Puu7TGCGoZw/pxFFjdeX0bwbS8siozu
M4Lz37wMrgyzMYbz66/snffsB4Kf/v1lC+smEzg/ji2Wc0OcKZxv+axj8ntJ
MzhfadPv3btOIPiJ2wyWipSYI/zXLTeFWc8Czt/iE6xYdxvBP3nPYUvvdEuE
+2JKn2q4W8H5qcI514M+I/gHZ0mfF1xnDefr8AmlxsTYwPlVQQcZbCRt4Xy5
80axqy4h+BfNX4cvqbdD+LcwJsLY2h7O55ku8t33FYLfUuW++reXA5z/WfDh
XakVCH6W/Lz7//8h+Bb8t9/U6zvC+ez/xX/9j0fwAT9m8Jc=
               "]]}, 
             Annotation[#, "Charting`Private`Tag$3176#2"]& ]}}, {}}}, {Epilog -> {
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox[
                  "\"Efficient Non-behavioral\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Efficient Non-behavioral", 12]]], TraditionalForm]], {
            3, -0.1}], 
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Random\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Random", 12]]], TraditionalForm]], {1, 1.1}], 
           InsetBox[
            GraphicsBox[{
              GrayLevel[0.5], 
              RectangleBox[{0, 0}, {3, 1}]}], {1, 0.9310516033032665}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0.5, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {2, 2.8457742340695984`}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {3, 0.19054341504511257`}, {1.5,
             0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0.7777777777777778, 
               NCache[
                Rational[5, 9], 0.5555555555555556], 0.7777777777777778], 
              RectangleBox[{0, 0}, {3, 1}]}], {4, 0.8285028211559801}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {5, 0.8776159025037409}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 0, 1], 
              RectangleBox[{0, 0}, {3, 1}]}], {6, 0.4265111089304966}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {7, 1.2217666559785036`}, {1.5, 
            0.5}, 1.25]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False},
          AxesLabel -> {None, None}, 
         AxesOrigin -> {-1.2000000000000002`, -0.5307862879492066}, Frame -> 
         True, FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
         GrayLevel[0], FrameTicks -> {{Automatic, Automatic}, {{{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Observed\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Observed", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Democracy\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Democracy", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Community\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Community", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Despotism\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Despotism", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Large, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {{{1., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Observed\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Observed", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            11., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            12., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            13., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            14., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            15., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            16., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            9.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Democracy\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Democracy", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            20., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            21., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            22., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            23., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            24., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            25., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            18.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Community\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Community", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            29., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            30., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            31., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            32., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            33., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            34., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            27.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Despotism\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Despotism", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
           Automatic}}], 
       FormBox[
        FormBox[
         TemplateBox[{
          "\"Dotty\"", "\"Hook\"", "\"Linda\"", "\"Lodge\"", "\"Nyayo\"", 
           "\"Viola\"", "\"Vogue\""}, "SwatchLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #7}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.5185185185185186, 0.37037037037037035`, 
                    0.5185185185185186], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.7777777777777778`", ",", 
                    FractionBox["5", "9"], ",", "0.7777777777777778`"}], 
                    "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], Editable -> False, 
                    Selectable -> False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], "]"}]}], "}"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", "}"}], ",", 
                   RowBox[{"{", 
                    
                    RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, 
                    ",", #7}], "}"}]}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "None", "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic"}], "}"}]}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]}, "Legended", 
      DisplayFunction -> (GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ), 
      InterpretationFunction -> (RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& ), Editable -> True], 
     RotationBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"   More Efficient                                          Less \
Efficient\"", Italic, 
           RGBColor[1, 0, 0], 15, StripOnInput -> False], TextForm]], 
        "InlineText"], 
       Text[
        Style[
        "   More Efficient                                          Less \
Efficient", Italic, 
         RGBColor[1, 0, 0], 15]]], BoxRotation -> 1.5707963267948966`]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 2}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )], 
   RotationBox[
    InterpretationBox[
     Cell[
      BoxData[
       FormBox[
        StyleBox[
        "\"Scaled Sparsity\"", 21, TextAlignment -> Center, StripOnInput -> 
         False], TextForm]], "InlineText"], 
     Text[
      Style["Scaled Sparsity", 21, TextAlignment -> Center]]], BoxRotation -> 
    1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8235923308961267`*^9, {3.8235924131861086`*^9, 3.8235924292269435`*^9}, {
   3.8235924620030713`*^9, 3.8235925198217907`*^9}, 3.8235926568314123`*^9, {
   3.823592690074173*^9, 3.823592731531687*^9}, 3.8235927706492815`*^9, 
   3.8235930540342207`*^9, 3.823593706526876*^9, {3.8235937711941338`*^9, 
   3.823593776723172*^9}, {3.8235938429564257`*^9, 3.82359385668573*^9}, {
   3.82359403239396*^9, 3.8235940502272625`*^9}, {3.8239588051438437`*^9, 
   3.823958819959555*^9}, 3.8249882779406495`*^9, 3.840094101096265*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"847fe089-76cf-443f-b1e4-940addfcee29"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Maintained Weight", "Subsection",
 CellChangeTimes->{{3.8235925757025185`*^9, 3.823592578221815*^9}, {
  3.8235933790635824`*^9, 3.8235933845943413`*^9}, {3.8235941397534943`*^9, 
  3.823594140919758*^9}},ExpressionUUID->"6d5b07d0-7149-4e26-b56d-\
4285fad188ba"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottynewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottymain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottycomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottymain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottymain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottynewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"dottymain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"dottyrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", 
        "dottymax"}], "]"}], ",", 
      RowBox[{"sparsdottymain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookcomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hooknewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"hookmain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"hookrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}],
        "]"}], ",", 
      RowBox[{"sparshookmain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindamain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindamain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindamain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindanewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lindamain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lindarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", 
        "lindamax"}], "]"}], ",", 
      RowBox[{"sparslindamain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgemain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgemain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgemain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgenewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lodgemain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lodgerand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", 
        "lodgemax"}], "]"}], ",", 
      RowBox[{"sparslodgemain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayomain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayocomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayomain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayomain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayonewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"nyayomain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"nyayorand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", 
        "nyayomax"}], "]"}], ",", 
      RowBox[{"sparsnyayomain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolamain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolamain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolamain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violanewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"violamain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"violarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", 
        "violamax"}], "]"}], ",", 
      RowBox[{"sparsviolamain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguemain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguemain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguemain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewobs", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"voguemain", ",", "100"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguemain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.823591449009904*^9, 3.8235914956379766`*^9}, {
  3.823591525819866*^9, 3.8235916157503233`*^9}, {3.82359168469874*^9, 
  3.8235917021111393`*^9}, {3.823591773033968*^9, 3.823591837938725*^9}, {
  3.8235918747444067`*^9, 3.823592001058693*^9}, {3.823593511044263*^9, 
  3.8235935533689365`*^9}, {3.8235936132386136`*^9, 3.8235936950309906`*^9}, {
  3.8235941509928536`*^9, 3.823594183741576*^9}, {3.8235944233975563`*^9, 
  3.823594429564615*^9}},
 CellLabel->
  "In[734]:=",ExpressionUUID->"6175c3a5-b31d-4227-b6b6-95a3b3dd3aac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figs8", "=", 
  RowBox[{"Labeled", "[", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "dottynewobs", ",", "hooknewobs", ",", "lindanewobs", ",", 
              "lodgenewobs", ",", "nyayonewobs", ",", "violanewobs", ",", 
              "voguenewobs"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdemoc", ",", "hooknewdemoc", ",", "lindanewdemoc", ",", 
              "lodgenewdemoc", ",", "nyayonewdemoc", ",", "violanewdemoc", 
              ",", "voguenewdemoc"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewcomm", ",", "hooknewcomm", ",", "lindanewcomm", ",", 
              "lodgenewcomm", ",", "nyayonewcomm", ",", "violanewcomm", ",", 
              "voguenewcomm"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdespot", ",", "hooknewdespot", ",", "lindanewdespot", 
              ",", "lodgenewdespot", ",", "nyayonewdespot", ",", 
              "violanewdespot", ",", "voguenewdespot"}], "}"}]}], 
           "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<Outliers\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<MedianMarker\>\"", ",", "1", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Black", ",", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"ChartLabels", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Observed\>\"", ",", "17", ",", "Black"}], "]"}],
                 "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Democracy\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Community\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Despotism\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}]}], "}"}], ",", "None"}], "}"}]}], ",", 
          RowBox[{"ChartLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Dotty\>\"", ",", "\"\<Hook\>\"", ",", "\"\<Linda\>\"", ",", 
             "\"\<Lodge\>\"", ",", "\"\<Nyayo\>\"", ",", "\"\<Viola\>\"", 
             ",", "\"\<Vogue\>\""}], "}"}]}], ",", 
          RowBox[{"BarSpacing", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "2"}], "}"}]}], ",", 
          RowBox[{"ChartStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Gray", ",", "Orange", ",", "Green", ",", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", "Yellow", 
             ",", "Blue", ",", "Red"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"All", ",", "All"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.25", ",", "34.75"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dashed"}], "]"}]}]}], "]"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Efficient Non-behavioral\>\"", ",", "12"}], "]"}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", "1.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Random\>\"", ",", "12"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"-", "0.1"}]}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Gray", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"dottynewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Orange", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"hooknewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Green", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"lindanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Lighter", "[", 
                 RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", 
               RowBox[{"lodgenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Yellow", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", 
               RowBox[{"nyayonewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"6", ",", 
               RowBox[{"violanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"7", ",", 
               RowBox[{"voguenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}]}], 
          "\[IndentingNewLine]", "}"}]}]}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<   Less Efficient                                          \
More Efficient\>\"", ",", "Italic", ",", "Red", ",", "15"}], "]"}], "]"}], 
        ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<Scaled Mean Weight\nof Maintained Bonds\>\"", ",", "21", ",", 
         RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}], "]"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8235920125253134`*^9, 3.823592065605406*^9}, {
   3.823592110163682*^9, 3.823592257916377*^9}, {3.8235923147544823`*^9, 
   3.82359232692793*^9}, {3.823592405067442*^9, 3.8235924279573603`*^9}, {
   3.8235924601542344`*^9, 3.8235925182234397`*^9}, {3.8235926326470547`*^9, 
   3.823592768222708*^9}, {3.823593046485058*^9, 3.823593052835633*^9}, {
   3.8235937638522778`*^9, 3.82359377539753*^9}, {3.823593821851324*^9, 
   3.823593855042349*^9}, {3.8235941979176807`*^9, 3.8235941991407948`*^9}, {
   3.8235944458627462`*^9, 3.823594450459326*^9}, {3.8239588650989056`*^9, 
   3.8239588667361717`*^9}, 3.824988318187912*^9, {3.824989538281108*^9, 
   3.8249895415276833`*^9}, {3.825518481469056*^9, 3.8255184829863157`*^9}, {
   3.8392410236315455`*^9, 3.8392410435294356`*^9}, {3.8392411036909266`*^9, 
   3.8392411126549077`*^9}, {3.83924167823108*^9, 3.839241678785463*^9}, {
   3.8400947187151055`*^9, 
   3.840094718978096*^9}},ExpressionUUID->"ab375daa-291d-42ff-9154-\
b4f7baff0951"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
     TemplateBox[{
       GraphicsBox[{{{
           CapForm[None], 
           Directive[
            RGBColor[0.982864, 0.7431472, 0.3262672]], {{}, {{{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{0.5, 1.3453838614036993`}, {1.5, 
                    1.3453838614036993`}, {1.5, 1.3453838614036993`}, {0.5, 
                    1.3453838614036993`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.3453838614036993`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{1.5, 1.3453838614036993`}, {0.5, 
                    1.3453838614036993`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1., 1.3453838614036993`}, {1., 
                    1.3453838614036993`}}, {{1., 1.3453838614036993`}, {1., 
                    1.3453838614036993`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1.25, 1.3453838614036993`}, {0.75, 
                    1.3453838614036993`}}, {{1.25, 1.3453838614036993`}, {
                    0.75, 1.3453838614036993`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.3453838614036993`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.3453838614036993`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.3453838614036993`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.3453838614036993`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.3453838614036993`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.3453838614036993`}, {
                    Style["75%", Bold], 1.3453838614036993`}, {
                    Style["median", Bold], 1.3453838614036993`}, {
                    Style["25%", Bold], 1.3453838614036993`}, {
                    Style["min", Bold], 1.3453838614036993`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{1.5, 5.126732085165458}, {2.5, 
                    5.126732085165458}, {2.5, 5.126732085165458}, {1.5, 
                    5.126732085165458}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 5.126732085165458}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{2.5, 5.126732085165458}, {1.5, 
                    5.126732085165458}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2., 5.126732085165458}, {2., 
                    5.126732085165458}}, {{2., 5.126732085165458}, {2., 
                    5.126732085165458}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2.25, 5.126732085165458}, {1.75, 
                    5.126732085165458}}, {{2.25, 5.126732085165458}, {1.75, 
                    5.126732085165458}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "5.126732085165458`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "5.126732085165458`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "5.126732085165458`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "5.126732085165458`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "5.126732085165458`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 5.126732085165458}, {
                    Style["75%", Bold], 5.126732085165458}, {
                    Style["median", Bold], 5.126732085165458}, {
                    Style["25%", Bold], 5.126732085165458}, {
                    Style["min", Bold], 5.126732085165458}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{2.5, 0.45802712664913353`}, {3.5, 
                    0.45802712664913353`}, {3.5, 0.45802712664913353`}, {2.5, 
                    0.45802712664913353`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 0.45802712664913353`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{3.5, 0.45802712664913353`}, {2.5, 
                    0.45802712664913353`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3., 0.45802712664913353`}, {3., 
                    0.45802712664913353`}}, {{3., 0.45802712664913353`}, {3., 
                    0.45802712664913353`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3.25, 0.45802712664913353`}, {2.75, 
                    0.45802712664913353`}}, {{3.25, 0.45802712664913353`}, {
                    2.75, 0.45802712664913353`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.45802712664913353`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.45802712664913353`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.45802712664913353`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.45802712664913353`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.45802712664913353`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.45802712664913353`}, {
                    Style["75%", Bold], 0.45802712664913353`}, {
                    Style["median", Bold], 0.45802712664913353`}, {
                    Style["25%", Bold], 0.45802712664913353`}, {
                    Style["min", Bold], 0.45802712664913353`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{3.5, -0.8872662446977547}, {
                    4.5, -0.8872662446977547}, {4.5, -0.8872662446977547}, {
                    3.5, -0.8872662446977547}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -0.8872662446977547}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{4.5, -0.8872662446977547}, {
                    3.5, -0.8872662446977547}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4., -0.8872662446977547}, {
                    4., -0.8872662446977547}}, {{4., -0.8872662446977547}, {
                    4., -0.8872662446977547}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4.25, -0.8872662446977547}, {
                    3.75, -0.8872662446977547}}, {{
                    4.25, -0.8872662446977547}, {
                    3.75, -0.8872662446977547}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.8872662446977547`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.8872662446977547`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.8872662446977547`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.8872662446977547`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.8872662446977547`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.8872662446977547}, {
                    Style["75%", Bold], -0.8872662446977547}, {
                    Style["median", Bold], -0.8872662446977547}, {
                    Style["25%", Bold], -0.8872662446977547}, {
                    Style["min", Bold], -0.8872662446977547}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{4.5, -0.3975911225605511}, {
                    5.5, -0.3975911225605511}, {5.5, -0.3975911225605511}, {
                    4.5, -0.3975911225605511}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.3975911225605511}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{5.5, -0.3975911225605511}, {
                    4.5, -0.3975911225605511}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5., -0.3975911225605511}, {
                    5., -0.3975911225605511}}, {{5., -0.3975911225605511}, {
                    5., -0.3975911225605511}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5.25, -0.3975911225605511}, {
                    4.75, -0.3975911225605511}}, {{
                    5.25, -0.3975911225605511}, {
                    4.75, -0.3975911225605511}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3975911225605511`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3975911225605511`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3975911225605511`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3975911225605511`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3975911225605511`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.3975911225605511}, {
                    Style["75%", Bold], -0.3975911225605511}, {
                    Style["median", Bold], -0.3975911225605511}, {
                    Style["25%", Bold], -0.3975911225605511}, {
                    Style["min", Bold], -0.3975911225605511}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{5.5, 0.09955443258503255}, {6.5, 
                    0.09955443258503255}, {6.5, 0.09955443258503255}, {5.5, 
                    0.09955443258503255}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 0.09955443258503255}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{6.5, 0.09955443258503255}, {5.5, 
                    0.09955443258503255}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6., 0.09955443258503255}, {6., 
                    0.09955443258503255}}, {{6., 0.09955443258503255}, {6., 
                    0.09955443258503255}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6.25, 0.09955443258503255}, {5.75, 
                    0.09955443258503255}}, {{6.25, 0.09955443258503255}, {
                    5.75, 0.09955443258503255}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.09955443258503255`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.09955443258503255`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.09955443258503255`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.09955443258503255`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.09955443258503255`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.09955443258503255}, {
                    Style["75%", Bold], 0.09955443258503255}, {
                    Style["median", Bold], 0.09955443258503255}, {
                    Style["25%", Bold], 0.09955443258503255}, {
                    Style["min", Bold], 0.09955443258503255}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{6.5, 0.36826497408304876`}, {7.5, 
                    0.36826497408304876`}, {7.5, 0.36826497408304876`}, {6.5, 
                    0.36826497408304876`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7., 0.36826497408304876`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{7.5, 0.36826497408304876`}, {6.5, 
                    0.36826497408304876`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7., 0.36826497408304876`}, {7., 
                    0.36826497408304876`}}, {{7., 0.36826497408304876`}, {7., 
                    0.36826497408304876`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{7.25, 0.36826497408304876`}, {6.75, 
                    0.36826497408304876`}}, {{7.25, 0.36826497408304876`}, {
                    6.75, 0.36826497408304876`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.36826497408304876`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.36826497408304876`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.36826497408304876`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.36826497408304876`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.36826497408304876`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.36826497408304876`}, {
                    Style["75%", Bold], 0.36826497408304876`}, {
                    Style["median", Bold], 0.36826497408304876`}, {
                    Style["25%", Bold], 0.36826497408304876`}, {
                    Style["min", Bold], 0.36826497408304876`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{9.5, 0.8460951381844796}, {10.5, 
                    0.8460951381844796}, {10.5, 0.41929100306012335`}, {9.5, 
                    0.41929100306012335`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{10.5, 0.6365897748888422}, {9.5, 
                    0.6365897748888422}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10., 0.41929100306012335`}, {
                    10., -0.019974248341863596`}}, {{10., 
                    0.8460951381844796}, {10., 1.3608142647426573`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10.25, -0.019974248341863596`}, {
                    9.75, -0.019974248341863596`}}, {{10.25, 
                    1.3608142647426573`}, {9.75, 
                    1.3608142647426573`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.3608142647426573`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8460951381844796`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6365897748888422`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.41929100306012335`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.019974248341863596`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.3608142647426573`}, {
                    Style["75%", Bold], 0.8460951381844796}, {
                    Style["median", Bold], 0.6365897748888422}, {
                    Style["25%", Bold], 0.41929100306012335`}, {
                    Style["min", Bold], -0.019974248341863596`}}, 
                    Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{10.5, 1.413373609398339}, {11.5, 
                    1.413373609398339}, {11.5, 0.6562662481835622}, {10.5, 
                    0.6562662481835622}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{11.5, 1.0178200057147553`}, {10.5, 
                    1.0178200057147553`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11., 0.6562662481835622}, {
                    11., -0.06065580455107336}}, {{11., 1.413373609398339}, {
                    11., 2.1310302751934964`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11.25, -0.06065580455107336}, {
                    10.75, -0.06065580455107336}}, {{11.25, 
                    2.1310302751934964`}, {10.75, 
                    2.1310302751934964`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.1310302751934964`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.413373609398339`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.0178200057147553`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6562662481835622`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.06065580455107336`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.1310302751934964`}, {
                    Style["75%", Bold], 1.413373609398339}, {
                    Style["median", Bold], 1.0178200057147553`}, {
                    Style["25%", Bold], 0.6562662481835622}, {
                    Style["min", Bold], -0.06065580455107336}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{11.5, 0.6410309540143619}, {12.5, 
                    0.6410309540143619}, {12.5, 0.2597157322094341}, {11.5, 
                    0.2597157322094341}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{12.5, 0.4248176308465277}, {11.5, 
                    0.4248176308465277}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12., 0.2597157322094341}, {
                    12., -0.1657529728679005}}, {{12., 0.6410309540143619}, {
                    12., 1.1123006854690987`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12.25, -0.1657529728679005}, {
                    11.75, -0.1657529728679005}}, {{12.25, 
                    1.1123006854690987`}, {11.75, 
                    1.1123006854690987`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.1123006854690987`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6410309540143619`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.4248176308465277`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.2597157322094341`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1657529728679005`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.1123006854690987`}, {
                    Style["75%", Bold], 0.6410309540143619}, {
                    Style["median", Bold], 0.4248176308465277}, {
                    Style["25%", Bold], 0.2597157322094341}, {
                    Style["min", Bold], -0.1657529728679005}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{12.5, 0.8505006446976129}, {13.5, 
                    0.8505006446976129}, {13.5, 0.030464227388119235`}, {12.5,
                     0.030464227388119235`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    13., 2.3730111568568315`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{13.5, 0.32517765674122173`}, {12.5, 
                    0.32517765674122173`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13., 0.030464227388119235`}, {
                    13., -0.4342432153101381}}, {{13., 0.8505006446976129}, {
                    13., 2.0715610229328596`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13.25, -0.4342432153101381}, {
                    12.75, -0.4342432153101381}}, {{13.25, 
                    2.0715610229328596`}, {12.75, 
                    2.0715610229328596`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.3730111568568315`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8505006446976129`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.32517765674122173`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.030464227388119235`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4342432153101381`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.3730111568568315`}, {
                    Style["75%", Bold], 0.8505006446976129}, {
                    Style["median", Bold], 0.32517765674122173`}, {
                    Style["25%", Bold], 0.030464227388119235`}, {
                    Style["min", Bold], -0.4342432153101381}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{13.5, 1.0242358634892015`}, {14.5, 
                    1.0242358634892015`}, {14.5, 0.6471484412657046}, {13.5, 
                    0.6471484412657046}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.46444183057529415`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.12384806797637608`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.28565863059849067`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.23931058037631875`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{14.5, 0.8550114918535243}, {13.5, 
                    0.8550114918535243}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14., 0.6471484412657046}, {14., 
                    0.08877862310955151}}, {{14., 1.0242358634892015`}, {14., 
                    1.5614202425689443`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14.25, 0.08877862310955151}, {13.75, 
                    0.08877862310955151}}, {{14.25, 1.5614202425689443`}, {
                    13.75, 1.5614202425689443`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.5614202425689443`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.0242358634892015`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8550114918535243`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6471484412657046`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.46444183057529415`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.5614202425689443`}, {
                    Style["75%", Bold], 1.0242358634892015`}, {
                    Style["median", Bold], 0.8550114918535243}, {
                    Style["25%", Bold], 0.6471484412657046}, {
                    Style["min", Bold], -0.46444183057529415`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{14.5, 1.2075112578122154`}, {15.5, 
                    1.2075112578122154`}, {15.5, 0.6164642131901045}, {14.5, 
                    0.6164642131901045}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.27521892857806607`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., -0.4174596432109247}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 2.325655974249818}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{15.5, 0.930734956352697}, {14.5, 
                    0.930734956352697}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15., 0.6164642131901045}, {
                    15., -0.11842673418737022`}}, {{15., 
                    1.2075112578122154`}, {15., 1.8398386542235785`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15.25, -0.11842673418737022`}, {
                    14.75, -0.11842673418737022`}}, {{15.25, 
                    1.8398386542235785`}, {14.75, 
                    1.8398386542235785`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.325655974249818`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.2075112578122154`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.930734956352697`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6164642131901045`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4174596432109247`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.325655974249818}, {
                    Style["75%", Bold], 1.2075112578122154`}, {
                    Style["median", Bold], 0.930734956352697}, {
                    Style["25%", Bold], 0.6164642131901045}, {
                    Style["min", Bold], -0.4174596432109247}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{15.5, 1.121782279861177}, {16.5, 
                    1.121782279861177}, {16.5, 0.30385956213835175`}, {15.5, 
                    0.30385956213835175`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{16.5, 0.8437471051265442}, {15.5, 
                    0.8437471051265442}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16., 0.30385956213835175`}, {
                    16., -0.17073830491031447`}}, {{16., 1.121782279861177}, {
                    16., 2.30246604108804}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16.25, -0.17073830491031447`}, {
                    15.75, -0.17073830491031447`}}, {{16.25, 
                    2.30246604108804}, {15.75, 2.30246604108804}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.30246604108804`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.121782279861177`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8437471051265442`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.30385956213835175`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.17073830491031447`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.30246604108804}, {
                    Style["75%", Bold], 1.121782279861177}, {
                    Style["median", Bold], 0.8437471051265442}, {
                    Style["25%", Bold], 0.30385956213835175`}, {
                    Style["min", Bold], -0.17073830491031447`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{18.5, 0.836951242684498}, {19.5, 
                    0.836951242684498}, {19.5, 0.4526811659717113}, {18.5, 
                    0.4526811659717113}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{19.5, 0.6717800810758094}, {18.5, 
                    0.6717800810758094}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19., 0.4526811659717113}, {
                    19., -0.005288119410296183}}, {{19., 0.836951242684498}, {
                    19., 1.2385140308709075`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19.25, -0.005288119410296183}, {
                    18.75, -0.005288119410296183}}, {{19.25, 
                    1.2385140308709075`}, {18.75, 
                    1.2385140308709075`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2385140308709075`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.836951242684498`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6717800810758094`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4526811659717113`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.005288119410296183`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2385140308709075`}, {
                    Style["75%", Bold], 0.836951242684498}, {
                    Style["median", Bold], 0.6717800810758094}, {
                    Style["25%", Bold], 0.4526811659717113}, {
                    Style["min", Bold], -0.005288119410296183}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{19.5, 0.8762708193160278}, {20.5, 
                    0.8762708193160278}, {20.5, 0.26074413893861376`}, {19.5, 
                    0.26074413893861376`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 2.117201719705289}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{20.5, 0.7066574156162568}, {19.5, 
                    0.7066574156162568}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20., 0.26074413893861376`}, {20., 
                    0.016275032986353143`}}, {{20., 0.8762708193160278}, {20.,
                     1.6567164205533957`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20.25, 0.016275032986353143`}, {19.75, 
                    0.016275032986353143`}}, {{20.25, 1.6567164205533957`}, {
                    19.75, 1.6567164205533957`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.117201719705289`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8762708193160278`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7066574156162568`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.26074413893861376`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.016275032986353143`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.117201719705289}, {
                    Style["75%", Bold], 0.8762708193160278}, {
                    Style["median", Bold], 0.7066574156162568}, {
                    Style["25%", Bold], 0.26074413893861376`}, {
                    Style["min", Bold], 0.016275032986353143`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{20.5, 0.5426533623449139}, {21.5, 
                    0.5426533623449139}, {21.5, 0.013707023271396548`}, {20.5,
                     0.013707023271396548`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{21.5, 0.020217207936272}, {20.5, 
                    0.020217207936272}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21., 0.013707023271396548`}, {21., 
                    0.013707023271396548`}}, {{21., 0.5426533623449139}, {21.,
                     0.7495428388302823}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21.25, 0.013707023271396548`}, {20.75, 
                    0.013707023271396548`}}, {{21.25, 0.7495428388302823}, {
                    20.75, 0.7495428388302823}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7495428388302823`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5426533623449139`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.020217207936272`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.013707023271396548`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.013707023271396548`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.7495428388302823}, {
                    Style["75%", Bold], 0.5426533623449139}, {
                    Style["median", Bold], 0.020217207936272}, {
                    Style["25%", Bold], 0.013707023271396548`}, {
                    Style["min", Bold], 0.013707023271396548`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{21.5, 0.5846180851834021}, {22.5, 
                    0.5846180851834021}, {22.5, 0.3173950214490167}, {21.5, 
                    0.3173950214490167}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    22., 1.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 1.873734372545256}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 1.873734372545256}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 1.873734372545256}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 1.873734372545256}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 1.873734372545256}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 1.873734372545256}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{22.5, 0.5846180851834021}, {21.5, 
                    0.5846180851834021}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22., 0.3173950214490167}, {22., 
                    0.045613223835179566`}}, {{22., 0.5846180851834021}, {22.,
                     0.8835020836606313}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22.25, 0.045613223835179566`}, {21.75, 
                    0.045613223835179566`}}, {{22.25, 0.8835020836606313}, {
                    21.75, 0.8835020836606313}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.873734372545256`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5846180851834021`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5846180851834021`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.3173950214490167`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.045613223835179566`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.873734372545256}, {
                    Style["75%", Bold], 0.5846180851834021}, {
                    Style["median", Bold], 0.5846180851834021}, {
                    Style["25%", Bold], 0.3173950214490167}, {
                    Style["min", Bold], 0.045613223835179566`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{22.5, 1.4331377445952116`}, {23.5, 
                    1.4331377445952116`}, {23.5, 0.7810501365917525}, {22.5, 
                    0.7810501365917525}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{23.5, 0.9696298275943919}, {22.5, 
                    0.9696298275943919}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23., 0.7810501365917525}, {23., 
                    0.10843324940102751`}}, {{23., 1.4331377445952116`}, {23.,
                     1.6908926971683629`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23.25, 0.10843324940102751`}, {22.75, 
                    0.10843324940102751`}}, {{23.25, 1.6908926971683629`}, {
                    22.75, 1.6908926971683629`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.6908926971683629`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.4331377445952116`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.9696298275943919`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.7810501365917525`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.10843324940102751`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.6908926971683629`}, {
                    Style["75%", Bold], 1.4331377445952116`}, {
                    Style["median", Bold], 0.9696298275943919}, {
                    Style["25%", Bold], 0.7810501365917525}, {
                    Style["min", Bold], 0.10843324940102751`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{23.5, 1.7432671991383926`}, {24.5, 
                    1.7432671991383926`}, {24.5, 1.2150317772931287`}, {23.5, 
                    1.2150317772931287`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 0.12395461841533398`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 0.12395461841533398`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 0.12395461841533398`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 0.12395461841533398`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 0.12395461841533398`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 0.12395461841533398`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{24.5, 1.6633459949299636`}, {23.5, 
                    1.6633459949299636`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24., 1.2150317772931287`}, {24., 
                    0.8254333697267263}}, {{24., 1.7432671991383926`}, {24., 
                    2.114012785327497}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24.25, 0.8254333697267263}, {23.75, 
                    0.8254333697267263}}, {{24.25, 2.114012785327497}, {23.75,
                     2.114012785327497}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.114012785327497`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.7432671991383926`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.6633459949299636`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.2150317772931287`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.12395461841533398`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.114012785327497}, {
                    Style["75%", Bold], 1.7432671991383926`}, {
                    Style["median", Bold], 1.6633459949299636`}, {
                    Style["25%", Bold], 1.2150317772931287`}, {
                    Style["min", Bold], 0.12395461841533398`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{24.5, 1.1356534637424665`}, {25.5, 
                    1.1356534637424665`}, {25.5, 0.5444631785904979}, {24.5, 
                    0.5444631785904979}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{25.5, 0.9397456956007476}, {24.5, 
                    0.9397456956007476}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25., 0.5444631785904979}, {
                    25., -0.00855942734109838}}, {{25., 
                    1.1356534637424665`}, {25., 1.93590374209919}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25.25, -0.00855942734109838}, {
                    24.75, -0.00855942734109838}}, {{25.25, 
                    1.93590374209919}, {24.75, 1.93590374209919}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.93590374209919`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.1356534637424665`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.9397456956007476`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5444631785904979`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.00855942734109838`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.93590374209919}, {
                    Style["75%", Bold], 1.1356534637424665`}, {
                    Style["median", Bold], 0.9397456956007476}, {
                    Style["25%", Bold], 0.5444631785904979}, {
                    Style["min", Bold], -0.00855942734109838}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{27.5, 0.6568402590518757}, {28.5, 
                    0.6568402590518757}, {28.5, 0.17466506009616056`}, {27.5, 
                    0.17466506009616056`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., -0.6340776227551975}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 1.4528609068826974`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{28.5, 0.43494494626669933`}, {27.5, 
                    0.43494494626669933`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28., 0.17466506009616056`}, {
                    28., -0.5298220670240782}}, {{28., 0.6568402590518757}, {
                    28., 1.1875672158719068`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28.25, -0.5298220670240782}, {
                    27.75, -0.5298220670240782}}, {{28.25, 
                    1.1875672158719068`}, {27.75, 
                    1.1875672158719068`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.4528609068826974`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6568402590518757`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.43494494626669933`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.17466506009616056`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6340776227551975`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.4528609068826974`}, {
                    Style["75%", Bold], 0.6568402590518757}, {
                    Style["median", Bold], 0.43494494626669933`}, {
                    Style["25%", Bold], 0.17466506009616056`}, {
                    Style["min", Bold], -0.6340776227551975}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{28.5, 1.5509127353379273`}, {29.5, 
                    1.5509127353379273`}, {29.5, 0.462359373773538}, {28.5, 
                    0.462359373773538}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{29.5, 1.0806987984185314`}, {28.5, 
                    1.0806987984185314`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29., 0.462359373773538}, {
                    29., -0.4785117221227709}}, {{29., 1.5509127353379273`}, {
                    29., 2.7170555826644742`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29.25, -0.4785117221227709}, {
                    28.75, -0.4785117221227709}}, {{29.25, 
                    2.7170555826644742`}, {28.75, 
                    2.7170555826644742`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.7170555826644742`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.5509127353379273`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.0806987984185314`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.462359373773538`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4785117221227709`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.7170555826644742`}, {
                    Style["75%", Bold], 1.5509127353379273`}, {
                    Style["median", Bold], 1.0806987984185314`}, {
                    Style["25%", Bold], 0.462359373773538}, {
                    Style["min", Bold], -0.4785117221227709}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{29.5, 0.579081821395306}, {30.5, 
                    0.579081821395306}, {30.5, 0.16058725210776548`}, {29.5, 
                    0.16058725210776548`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., -0.483801288818371}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., -0.49803738027318034`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., -0.5491391296612262}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 1.3061143080963227`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 1.3053368300568255`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{30.5, 0.38014361744167624`}, {29.5, 
                    0.38014361744167624`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30., 0.16058725210776548`}, {
                    30., -0.23449376707697298`}}, {{30., 0.579081821395306}, {
                    30., 1.2025555183230507`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30.25, -0.23449376707697298`}, {
                    29.75, -0.23449376707697298`}}, {{30.25, 
                    1.2025555183230507`}, {29.75, 
                    1.2025555183230507`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.3061143080963227`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.579081821395306`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.38014361744167624`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.16058725210776548`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5491391296612262`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.3061143080963227`}, {
                    Style["75%", Bold], 0.579081821395306}, {
                    Style["median", Bold], 0.38014361744167624`}, {
                    Style["25%", Bold], 0.16058725210776548`}, {
                    Style["min", Bold], -0.5491391296612262}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{30.5, 1.5032538665395458`}, {31.5, 
                    1.5032538665395458`}, {31.5, 0.14409694118015565`}, {30.5,
                     0.14409694118015565`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 3.621203117635773}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{31.5, 0.8253059829847504}, {30.5, 
                    0.8253059829847504}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31., 0.14409694118015565`}, {
                    31., -0.7335999455263045}}, {{31., 1.5032538665395458`}, {
                    31., 3.1552114522782984`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31.25, -0.7335999455263045}, {
                    30.75, -0.7335999455263045}}, {{31.25, 
                    3.1552114522782984`}, {30.75, 
                    3.1552114522782984`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "3.621203117635773`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.5032538665395458`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8253059829847504`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.14409694118015565`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.7335999455263045`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 3.621203117635773}, {
                    Style["75%", Bold], 1.5032538665395458`}, {
                    Style["median", Bold], 0.8253059829847504}, {
                    Style["25%", Bold], 0.14409694118015565`}, {
                    Style["min", Bold], -0.7335999455263045}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{31.5, 0.8726538479181678}, {32.5, 
                    0.8726538479181678}, {32.5, 0.37955918829709184`}, {31.5, 
                    0.37955918829709184`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{32.5, 0.6499978411115892}, {31.5, 
                    0.6499978411115892}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32., 0.37955918829709184`}, {
                    32., -0.18897299790345973`}}, {{32., 
                    0.8726538479181678}, {32., 1.562631695655415}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32.25, -0.18897299790345973`}, {
                    31.75, -0.18897299790345973`}}, {{32.25, 
                    1.562631695655415}, {31.75, 
                    1.562631695655415}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.562631695655415`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8726538479181678`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6499978411115892`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.37955918829709184`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.18897299790345973`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.562631695655415}, {
                    Style["75%", Bold], 0.8726538479181678}, {
                    Style["median", Bold], 0.6499978411115892}, {
                    Style["25%", Bold], 0.37955918829709184`}, {
                    Style["min", Bold], -0.18897299790345973`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{32.5, 0.9993209309446365}, {33.5, 
                    0.9993209309446365}, {33.5, -0.03554507471761361}, {
                    32.5, -0.03554507471761361}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., -1.6025698807478224`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{33.5, 0.36186194351952194`}, {32.5, 
                    0.36186194351952194`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33., -0.03554507471761361}, {
                    33., -1.0714577115772228`}}, {{33., 0.9993209309446365}, {
                    33., 1.9004455674149725`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33.25, -1.0714577115772228`}, {
                    32.75, -1.0714577115772228`}}, {{33.25, 
                    1.9004455674149725`}, {32.75, 
                    1.9004455674149725`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.9004455674149725`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9993209309446365`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.36186194351952194`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.03554507471761361`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.6025698807478224`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.9004455674149725`}, {
                    Style["75%", Bold], 0.9993209309446365}, {
                    Style["median", Bold], 0.36186194351952194`}, {
                    Style["25%", Bold], -0.03554507471761361}, {
                    Style["min", Bold], -1.6025698807478224`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{33.5, 0.9342701544381263}, {34.5, 
                    0.9342701544381263}, {34.5, 0.06790801882004818}, {33.5, 
                    0.06790801882004818}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{34.5, 0.5366006019040561}, {33.5, 
                    0.5366006019040561}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34., 0.06790801882004818}, {
                    34., -0.9719784315949309}}, {{34., 0.9342701544381263}, {
                    34., 2.227778807431818}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{34.25, -0.9719784315949309}, {
                    33.75, -0.9719784315949309}}, {{34.25, 
                    2.227778807431818}, {33.75, 
                    2.227778807431818}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.227778807431818`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.9342701544381263`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5366006019040561`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.06790801882004818`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.9719784315949309`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.227778807431818}, {
                    Style["75%", Bold], 0.9342701544381263}, {
                    Style["median", Bold], 0.5366006019040561}, {
                    Style["25%", Bold], 0.06790801882004818}, {
                    Style["min", Bold], -0.9719784315949309}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}}}, {}, {}}}}, {}, {}}}, {{{{{{{{{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, \
{}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}}, {}}, \
{}}, {{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxFz38sFAAUB/Bzdn5E7HJ1UZwzzuXEOQk5nGKHusldKZxDRU0/TSZH2bDO
JmqcmJli1eTHZXa0MSsrP/rDcHXTqDs/SvlxNCfnx9ZVW733tre3zx/v7X3p
564L04gEAkHwp//O6HzCGpEwGkr4V4UzDPfkNnR3pCChJ2EMzNpd+zqrUwW2
VviWfclQg4e16YwB9QS4qSG99a16BvdJwxpZiw4sWou/PS7fAufbaXKEA0Te
f+etOPu/YFiAa4QersrtnWBKaadJaRcZfJkdaPHgOQW892U/ebScCjbqrspD
jjqAsy9tHjRhO4IZlY95q4s08MMYJstWQAenGDLDYvpcwPycKPmz/a7g9ZqK
VfcqN/BJVopqwMwdPFjVs5yfzASTGkv2JKkP4P27s9JTHBa4yLp9IbvVExxr
avJJSfMCc1VaSyupNziHXtPQf4sN1kbIxGSmD7iuMeDj4nt08GhjfGI5B7w0
L8qN4/qCCz701s9toC8a5otJHYfAErMky3aJHzhwrqRyxf4w2KVju6d7CJ3a
xX5KuemP+Uqd5KZeAWDlCRH9ziT6nYanLKsOxP/E2V+Z/CPgNLsr40I9uq92
3whZEQT2tNmVJhZzwVJhH4FrHwx2GuEkNavQY/6LZ54UhGDeTPFZ36BQsHU1
xSBYQBdL+S3b0Tywnjz92aEJnUGr1xp/ob+bWUwVEcLw/nLmlDkRfaE3YtqW
hJYk6mZoVujYau5cKBUdYDu5VOCN7loP15n6oP00Cp2Mg+a0FS7f90N7Hvf4
8SgI7SzL1b/io+uvzeqPRaEd4wRrg9FoBzf6zxEBmvJmaF0rQlc0cwznT6PJ
FXWGb3Fom9QbGyvx6HuRExtZiegd7PBNgxhdQlVs5knQ5kbqljEZ/Ru3Fwx3

               "]]}, Annotation[#, "Charting`Private`Tag$20802#1"]& ], 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7VXD8IWJ4YI9Axh8sF+xMG3NkauP4Hxt1rP32le/
hfODv0TWXp/yC86vEb5XHnSMyQHGr36vYL5ejQPOnxGkpbLlNy+cL9K9lbF7
myCcn21gyTFhpQicL7H9qOCFPnE4///b3Cl2TlJwfmnGT11GA1k4X23yAodP
r+Xh/Gn+Gtr8vopwfsL3Qkf/g0pwvnu555RlMipw/rcZkz6pT1WF8wO0Ey4d
Y1OH849P3f2uJl4Dzmdd1CEWe1UTYX7b46oQI204v5lnw6vSNTpwfiAz450t
8npwvs2l+5zcVfpwfrnijIVHKwzg/Puu7TGCGoZw/pxFFjdeX0bwbS8siozu
M4Lz37wMrgyzMYbz66/snffsB4Kf/v1lC+smEzg/ji2Wc0OcKZxv+axj8ntJ
MzhfadPv3btOIPiJ2wyWipSYI/zXLTeFWc8Czt/iE6xYdxvBP3nPYUvvdEuE
+2JKn2q4W8H5qcI514M+I/gHZ0mfF1xnDefr8AmlxsTYwPlVQQcZbCRt4Xy5
80axqy4h+BfNX4cvqbdD+LcwJsLY2h7O55ku8t33FYLfUuW++reXA5z/WfDh
XakVCH6W/Lz7//8h+Bb8t9/U6zvC+ez/xX/9j0fwAT9m8Jc=
               "]]}, 
             Annotation[#, "Charting`Private`Tag$20802#2"]& ]}}, {}}}, {
        Epilog -> {
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox[
                  "\"Efficient Non-behavioral\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Efficient Non-behavioral", 12]]], TraditionalForm]], {
            3, 1.1}], 
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Random\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Random", 12]]], TraditionalForm]], {1, -0.1}], 
           InsetBox[
            GraphicsBox[{
              GrayLevel[0.5], 
              RectangleBox[{0, 0}, {3, 1}]}], {1, 1.3453838614036993`}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0.5, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {2, 5.126732085165458}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {3, 0.45802712664913353`}, {1.5,
             0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0.7777777777777778, 
               NCache[
                Rational[5, 9], 0.5555555555555556], 0.7777777777777778], 
              RectangleBox[{0, 0}, {3, 1}]}], {4, -0.8872662446977547}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {5, -0.3975911225605511}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 0, 1], 
              RectangleBox[{0, 0}, {3, 1}]}], {6, 0.09955443258503255}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {7, 0.36826497408304876`}, {1.5,
             0.5}, 1.25]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False},
          AxesLabel -> {None, None}, 
         AxesOrigin -> {-1.2000000000000002`, -1.9390349790434864`}, Frame -> 
         True, FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
         GrayLevel[0], FrameTicks -> {{Automatic, Automatic}, {{{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Observed\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Observed", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Democracy\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Democracy", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Community\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Community", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Despotism\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Despotism", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Large, PlotRange -> {All, All}, 
         PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {{{1., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Observed\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Observed", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            11., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            12., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            13., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            14., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            15., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            16., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            9.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Democracy\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Democracy", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            20., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            21., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            22., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            23., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            24., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            25., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            18.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Community\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Community", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            29., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            30., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            31., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            32., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            33., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            34., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            27.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Despotism\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Despotism", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
           Automatic}}], 
       FormBox[
        FormBox[
         TemplateBox[{
          "\"Dotty\"", "\"Hook\"", "\"Linda\"", "\"Lodge\"", "\"Nyayo\"", 
           "\"Viola\"", "\"Vogue\""}, "SwatchLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #7}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.5185185185185186, 0.37037037037037035`, 
                    0.5185185185185186], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.7777777777777778`", ",", 
                    FractionBox["5", "9"], ",", "0.7777777777777778`"}], 
                    "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], Editable -> False, 
                    Selectable -> False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], "]"}]}], "}"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", "}"}], ",", 
                   RowBox[{"{", 
                    
                    RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, 
                    ",", #7}], "}"}]}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "None", "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic"}], "}"}]}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]}, "Legended", 
      DisplayFunction -> (GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ), 
      InterpretationFunction -> (RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& ), Editable -> True], 
     RotationBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"   Less Efficient                                          More \
Efficient\"", Italic, 
           RGBColor[1, 0, 0], 15, StripOnInput -> False], TextForm]], 
        "InlineText"], 
       Text[
        Style[
        "   Less Efficient                                          More \
Efficient", Italic, 
         RGBColor[1, 0, 0], 15]]], BoxRotation -> 1.5707963267948966`]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 2}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )], 
   RotationBox[
    InterpretationBox[
     Cell[
      BoxData[
       FormBox[
        StyleBox[
        "\"Scaled Mean Weight\\nof Maintained Bonds\"", 21, TextAlignment -> 
         Center, StripOnInput -> False], TextForm]], "InlineText"], 
     Text[
      Style[
      "Scaled Mean Weight\nof Maintained Bonds", 21, TextAlignment -> 
       Center]]], BoxRotation -> 1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{3.840094375489888*^9, 3.8400944077604065`*^9, 
  3.840094523953452*^9},
 CellLabel->
  "Out[762]=",ExpressionUUID->"96c0ceaa-1f0a-4aa1-8a01-405b6e206413"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Betweenness Centrality Broken", "Subsection",
 CellChangeTimes->{{3.8235925757025185`*^9, 3.823592578221815*^9}, {
   3.8235933790635824`*^9, 3.8235933845943413`*^9}, {3.8235941397534943`*^9, 
   3.823594140919758*^9}, {3.8235945857975097`*^9, 3.8235945982351165`*^9}, 
   3.840094567731363*^9, 
   3.84009462379199*^9},ExpressionUUID->"354b6efa-39fe-4897-8d06-\
269d8da03583"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottynewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottybwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottycomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottybwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}],
       "]"}], ",", 
     RowBox[{"sparsdottybwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottynewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"dottybwbrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"dottyrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", 
        "dottymax"}], "]"}], ",", 
      RowBox[{"sparsdottybwbrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookbwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookcomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookbwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}], 
      "]"}], ",", 
     RowBox[{"sparshookbwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hooknewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"hookbwbrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"hookrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}],
        "]"}], ",", 
      RowBox[{"sparshookbwbrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindabwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindabwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}],
       "]"}], ",", 
     RowBox[{"sparslindabwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindanewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lindabwbrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lindarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", 
        "lindamax"}], "]"}], ",", 
      RowBox[{"sparslindabwbrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgebwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgebwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}],
       "]"}], ",", 
     RowBox[{"sparslodgebwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgenewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lodgebwbrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lodgerand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", 
        "lodgemax"}], "]"}], ",", 
      RowBox[{"sparslodgebwbrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayobwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayocomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayobwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}],
       "]"}], ",", 
     RowBox[{"sparsnyayobwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayonewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"nyayobwbrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"nyayorand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", 
        "nyayomax"}], "]"}], ",", 
      RowBox[{"sparsnyayobwbrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolabwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolabwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}],
       "]"}], ",", 
     RowBox[{"sparsviolabwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violanewobs", "=", 
    RowBox[{"frev", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"violabwbrok", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"violarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", 
        "violamax"}], "]"}], ",", 
      RowBox[{"sparsviolabwbrok", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewobs", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"voguebwbrok", ",", "100"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}],
       "]"}], ",", 
     RowBox[{"sparsvoguebwbrok", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.823591449009904*^9, 3.8235914956379766`*^9}, {
  3.823591525819866*^9, 3.8235916157503233`*^9}, {3.82359168469874*^9, 
  3.8235917021111393`*^9}, {3.823591773033968*^9, 3.823591837938725*^9}, {
  3.8235918747444067`*^9, 3.823592001058693*^9}, {3.823593511044263*^9, 
  3.8235935533689365`*^9}, {3.8235936132386136`*^9, 3.8235936950309906`*^9}, {
  3.8235941509928536`*^9, 3.823594183741576*^9}, {3.8235944233975563`*^9, 
  3.823594429564615*^9}, {3.823594625982317*^9, 3.8235946642220116`*^9}, {
  3.8235948584656563`*^9, 3.823594879797306*^9}},
 CellLabel->
  "In[763]:=",ExpressionUUID->"456c60b0-5ca8-4773-9292-3e75eb99d1a8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figs9", "=", 
  RowBox[{"Labeled", "[", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "dottynewobs", ",", "hooknewobs", ",", "lindanewobs", ",", 
              "lodgenewobs", ",", "nyayonewobs", ",", "violanewobs", ",", 
              "Null"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdemoc", ",", "hooknewdemoc", ",", "lindanewdemoc", ",", 
              "lodgenewdemoc", ",", "nyayonewdemoc", ",", "violanewdemoc", 
              ",", "Null"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewcomm", ",", "hooknewcomm", ",", "lindanewcomm", ",", 
              "lodgenewcomm", ",", "nyayonewcomm", ",", "violanewcomm", ",", 
              "Null"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdespot", ",", "hooknewdespot", ",", "lindanewdespot", 
              ",", "lodgenewdespot", ",", "nyayonewdespot", ",", 
              "violanewdespot", ",", "Null"}], "}"}]}], "\[IndentingNewLine]",
            "}"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<Outliers\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<MedianMarker\>\"", ",", "1", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Black", ",", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"ChartLabels", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Observed\>\"", ",", "17", ",", "Black"}], "]"}],
                 "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Democracy\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Community\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Despotism\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}]}], "}"}], ",", "None"}], "}"}]}], ",", 
          RowBox[{"ChartLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Dotty\>\"", ",", "\"\<Hook\>\"", ",", "\"\<Linda\>\"", ",", 
             "\"\<Lodge\>\"", ",", "\"\<Nyayo\>\"", ",", "\"\<Viola\>\""}], 
            "}"}]}], ",", 
          RowBox[{"BarSpacing", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "2"}], "}"}]}], ",", 
          RowBox[{"ChartStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Gray", ",", "Orange", ",", "Green", ",", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", "Yellow", 
             ",", "Blue"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"All", ",", "11"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.25", ",", "34.75"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dashed"}], "]"}]}]}], "]"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Efficient Non-behavioral\>\"", ",", "12"}], "]"}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Random\>\"", ",", "12"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"-", "0.5"}]}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Gray", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"dottynewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Orange", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"hooknewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Green", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"lindanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Lighter", "[", 
                 RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", 
               RowBox[{"lodgenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Yellow", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", 
               RowBox[{"nyayonewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"6", ",", 
               RowBox[{"violanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}]}], 
          "\[IndentingNewLine]", "}"}]}]}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<   Less Efficient                                          \
More Efficient\>\"", ",", "Italic", ",", "Red", ",", "15"}], "]"}], "]"}], 
        ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<Scaled Mean Betweenness\nCentrality of Broken Bonds\>\"", ",", 
         "21", ",", 
         RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}], "]"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8235920125253134`*^9, 3.823592065605406*^9}, {
   3.823592110163682*^9, 3.823592257916377*^9}, {3.8235923147544823`*^9, 
   3.82359232692793*^9}, {3.823592405067442*^9, 3.8235924279573603`*^9}, {
   3.8235924601542344`*^9, 3.8235925182234397`*^9}, {3.8235926326470547`*^9, 
   3.823592768222708*^9}, {3.823593046485058*^9, 3.823593052835633*^9}, {
   3.8235937638522778`*^9, 3.82359377539753*^9}, {3.823593821851324*^9, 
   3.823593855042349*^9}, {3.8235941979176807`*^9, 3.8235941991407948`*^9}, {
   3.8235944458627462`*^9, 3.823594450459326*^9}, {3.823594681625139*^9, 
   3.823594694429593*^9}, 3.8235950213109226`*^9, {3.8235950627639313`*^9, 
   3.8235950945633583`*^9}, {3.823595152424226*^9, 3.8235951568219056`*^9}, {
   3.823958937011573*^9, 3.8239589424460025`*^9}, 3.824988364271651*^9, {
   3.8249895804217834`*^9, 3.824989597968215*^9}, {3.8255185160895615`*^9, 
   3.8255185174917107`*^9}, {3.8255185658478327`*^9, 
   3.8255186429232254`*^9}, {3.8392411915539618`*^9, 
   3.8392412452968273`*^9}, {3.8392416973842793`*^9, 3.839241697970162*^9}, {
   3.8400947270173197`*^9, 
   3.8400947273458977`*^9}},ExpressionUUID->"8f764c8a-fe7d-465f-a9ea-\
dd935029b539"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
     TemplateBox[{
       GraphicsBox[{{{
           CapForm[None], 
           Directive[
            RGBColor[0.982864, 0.7431472, 0.3262672]], {{}, {{{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{0.5, 1.}, {1.5, 1.}, {1.5, 1.}, {0.5, 
                    1.}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 1.}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{1.5, 1.}, {0.5, 1.}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    LineBox[{{{1., 1.}, {1., 1.}}, {{1., 1.}, {1., 1.}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1.25, 1.}, {0.75, 1.}}, {{1.25, 1.}, {0.75, 
                    1.}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], "1.`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], "1.`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], "1.`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], "1.`"}},
                     GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}},
                     AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.}, {
                    Style["75%", Bold], 1.}, {
                    Style["median", Bold], 1.}, {
                    Style["25%", Bold], 1.}, {
                    Style["min", Bold], 1.}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{1.5, -0.1620266005521285}, {
                    2.5, -0.1620266005521285}, {2.5, -0.1620266005521285}, {
                    1.5, -0.1620266005521285}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., -0.1620266005521285}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{2.5, -0.1620266005521285}, {
                    1.5, -0.1620266005521285}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2., -0.1620266005521285}, {
                    2., -0.1620266005521285}}, {{2., -0.1620266005521285}, {
                    2., -0.1620266005521285}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2.25, -0.1620266005521285}, {
                    1.75, -0.1620266005521285}}, {{
                    2.25, -0.1620266005521285}, {
                    1.75, -0.1620266005521285}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1620266005521285`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1620266005521285`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1620266005521285`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1620266005521285`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.1620266005521285`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.1620266005521285}, {
                    Style["75%", Bold], -0.1620266005521285}, {
                    Style["median", Bold], -0.1620266005521285}, {
                    Style["25%", Bold], -0.1620266005521285}, {
                    Style["min", Bold], -0.1620266005521285}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{2.5, -0.6126947224789424}, {
                    3.5, -0.6126947224789424}, {3.5, -0.6126947224789424}, {
                    2.5, -0.6126947224789424}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., -0.6126947224789424}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{3.5, -0.6126947224789424}, {
                    2.5, -0.6126947224789424}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3., -0.6126947224789424}, {
                    3., -0.6126947224789424}}, {{3., -0.6126947224789424}, {
                    3., -0.6126947224789424}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3.25, -0.6126947224789424}, {
                    2.75, -0.6126947224789424}}, {{
                    3.25, -0.6126947224789424}, {
                    2.75, -0.6126947224789424}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6126947224789424`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6126947224789424`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6126947224789424`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6126947224789424`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6126947224789424`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.6126947224789424}, {
                    Style["75%", Bold], -0.6126947224789424}, {
                    Style["median", Bold], -0.6126947224789424}, {
                    Style["25%", Bold], -0.6126947224789424}, {
                    Style["min", Bold], -0.6126947224789424}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{3.5, 1.0556003025763658`}, {4.5, 
                    1.0556003025763658`}, {4.5, 1.0556003025763658`}, {3.5, 
                    1.0556003025763658`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., 1.0556003025763658`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{4.5, 1.0556003025763658`}, {3.5, 
                    1.0556003025763658`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4., 1.0556003025763658`}, {4., 
                    1.0556003025763658`}}, {{4., 1.0556003025763658`}, {4., 
                    1.0556003025763658`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4.25, 1.0556003025763658`}, {3.75, 
                    1.0556003025763658`}}, {{4.25, 1.0556003025763658`}, {
                    3.75, 1.0556003025763658`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.0556003025763658`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.0556003025763658`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.0556003025763658`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.0556003025763658`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.0556003025763658`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.0556003025763658`}, {
                    Style["75%", Bold], 1.0556003025763658`}, {
                    Style["median", Bold], 1.0556003025763658`}, {
                    Style["25%", Bold], 1.0556003025763658`}, {
                    Style["min", Bold], 1.0556003025763658`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{4.5, -0.48913843033559723`}, {
                    5.5, -0.48913843033559723`}, {
                    5.5, -0.48913843033559723`}, {
                    4.5, -0.48913843033559723`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., -0.48913843033559723`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{5.5, -0.48913843033559723`}, {
                    4.5, -0.48913843033559723`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5., -0.48913843033559723`}, {
                    5., -0.48913843033559723`}}, {{
                    5., -0.48913843033559723`}, {
                    5., -0.48913843033559723`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5.25, -0.48913843033559723`}, {
                    4.75, -0.48913843033559723`}}, {{
                    5.25, -0.48913843033559723`}, {
                    4.75, -0.48913843033559723`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.48913843033559723`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.48913843033559723`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.48913843033559723`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.48913843033559723`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.48913843033559723`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.48913843033559723`}, {
                    Style["75%", Bold], -0.48913843033559723`}, {
                    Style["median", Bold], -0.48913843033559723`}, {
                    Style["25%", Bold], -0.48913843033559723`}, {
                    Style["min", Bold], -0.48913843033559723`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{5.5, -0.42488882973207565`}, {
                    6.5, -0.42488882973207565`}, {
                    6.5, -0.42488882973207565`}, {
                    5.5, -0.42488882973207565`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., -0.42488882973207565`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{6.5, -0.42488882973207565`}, {
                    5.5, -0.42488882973207565`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6., -0.42488882973207565`}, {
                    6., -0.42488882973207565`}}, {{
                    6., -0.42488882973207565`}, {
                    6., -0.42488882973207565`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6.25, -0.42488882973207565`}, {
                    5.75, -0.42488882973207565`}}, {{
                    6.25, -0.42488882973207565`}, {
                    5.75, -0.42488882973207565`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.42488882973207565`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.42488882973207565`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.42488882973207565`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.42488882973207565`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.42488882973207565`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -0.42488882973207565`}, {
                    Style["75%", Bold], -0.42488882973207565`}, {
                    Style["median", Bold], -0.42488882973207565`}, {
                    Style["25%", Bold], -0.42488882973207565`}, {
                    Style["min", Bold], -0.42488882973207565`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{9.5, 1.7296268707856646`}, {10.5, 
                    1.7296268707856646`}, {10.5, 0.23016385114274646`}, {9.5, 
                    0.23016385114274646`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{10.5, 0.7148754206222624}, {9.5, 
                    0.7148754206222624}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10., 0.23016385114274646`}, {
                    10., -0.9675495574015042}}, {{10., 1.7296268707856646`}, {
                    10., 3.2407233850675943`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10.25, -0.9675495574015042}, {
                    9.75, -0.9675495574015042}}, {{10.25, 
                    3.2407233850675943`}, {9.75, 
                    3.2407233850675943`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "3.2407233850675943`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.7296268707856646`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7148754206222624`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.23016385114274646`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.9675495574015042`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 3.2407233850675943`}, {
                    Style["75%", Bold], 1.7296268707856646`}, {
                    Style["median", Bold], 0.7148754206222624}, {
                    Style["25%", Bold], 0.23016385114274646`}, {
                    Style["min", Bold], -0.9675495574015042}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{10.5, 3.680358093224034}, {11.5, 
                    3.680358093224034}, {11.5, 1.0609978676526293`}, {10.5, 
                    1.0609978676526293`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., -2.934268860873171}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    11., 8.18734971452612}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{11.5, 2.326973663477723}, {10.5, 
                    2.326973663477723}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11., 1.0609978676526293`}, {
                    11., -2.44530693847912}}, {{11., 3.680358093224034}, {11.,
                     6.786958683091499}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11.25, -2.44530693847912}, {
                    10.75, -2.44530693847912}}, {{11.25, 6.786958683091499}, {
                    10.75, 6.786958683091499}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "8.18734971452612`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "3.680358093224034`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "2.326973663477723`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.0609978676526293`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "2.934268860873171`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 8.18734971452612}, {
                    Style["75%", Bold], 3.680358093224034}, {
                    Style["median", Bold], 2.326973663477723}, {
                    Style["25%", Bold], 1.0609978676526293`}, {
                    Style["min", Bold], -2.934268860873171}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{11.5, 2.0992653822611578`}, {12.5, 
                    2.0992653822611578`}, {12.5, -0.38331250523877325`}, {
                    11.5, -0.38331250523877325`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 6.409331086677493}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 7.944460947817491}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {12., 23.244947838638137`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {12., 11.367323215936068`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {12., 23.244947838638137`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{12.5, 0.6408920141781606}, {11.5, 
                    0.6408920141781606}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12., -0.38331250523877325`}, {
                    12., -3.713749426928249}}, {{12., 2.0992653822611578`}, {
                    12., 5.560159453358827}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12.25, -3.713749426928249}, {
                    11.75, -3.713749426928249}}, {{12.25, 
                    5.560159453358827}, {11.75, 
                    5.560159453358827}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "23.244947838638137`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "2.0992653822611578`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6408920141781606`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.38331250523877325`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.713749426928249`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 23.244947838638137`}, {
                    Style["75%", Bold], 2.0992653822611578`}, {
                    Style["median", Bold], 0.6408920141781606}, {
                    Style["25%", Bold], -0.38331250523877325`}, {
                    Style["min", Bold], -3.713749426928249}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{12.5, 1.3951615219582902`}, {13.5, 
                    1.3951615219582902`}, {13.5, 0.16636947415278686`}, {12.5,
                     0.16636947415278686`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{13.5, 0.818097775521766}, {12.5, 
                    0.818097775521766}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13., 0.16636947415278686`}, {
                    13., -0.6765893708984384}}, {{13., 1.3951615219582902`}, {
                    13., 3.115900403600588}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13.25, -0.6765893708984384}, {
                    12.75, -0.6765893708984384}}, {{13.25, 
                    3.115900403600588}, {12.75, 
                    3.115900403600588}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "3.115900403600588`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.3951615219582902`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.818097775521766`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.16636947415278686`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6765893708984384`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 3.115900403600588}, {
                    Style["75%", Bold], 1.3951615219582902`}, {
                    Style["median", Bold], 0.818097775521766}, {
                    Style["25%", Bold], 0.16636947415278686`}, {
                    Style["min", Bold], -0.6765893708984384}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{13.5, 0.7251070042351782}, {14.5, 
                    0.7251070042351782}, {14.5, 0.2928815131792332}, {13.5, 
                    0.2928815131792332}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.41822099300580357`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., -0.4913819828722464}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    14., 1.8517118927028833`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{14.5, 0.5140773911490659}, {13.5, 
                    0.5140773911490659}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14., 0.2928815131792332}, {
                    14., -0.24967265751335196`}}, {{14., 
                    0.7251070042351782}, {14., 1.3178083475533924`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14.25, -0.24967265751335196`}, {
                    13.75, -0.24967265751335196`}}, {{14.25, 
                    1.3178083475533924`}, {13.75, 
                    1.3178083475533924`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.8517118927028833`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7251070042351782`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5140773911490659`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.2928815131792332`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4913819828722464`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.8517118927028833`}, {
                    Style["75%", Bold], 0.7251070042351782}, {
                    Style["median", Bold], 0.5140773911490659}, {
                    Style["25%", Bold], 0.2928815131792332}, {
                    Style["min", Bold], -0.4913819828722464}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{14.5, 1.3325004764523112`}, {15.5, 
                    1.3325004764523112`}, {15.5, 0.23045979181249954`}, {14.5,
                     0.23045979181249954`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 4.140235767063381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 4.140235767063381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    15., 4.140235767063381}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{15.5, 0.7160150495704001}, {14.5, 
                    0.7160150495704001}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15., 0.23045979181249954`}, {
                    15., -0.6093936653768698}}, {{15., 1.3325004764523112`}, {
                    15., 2.2511786064337347`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15.25, -0.6093936653768698}, {
                    14.75, -0.6093936653768698}}, {{15.25, 
                    2.2511786064337347`}, {14.75, 
                    2.2511786064337347`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "4.140235767063381`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.3325004764523112`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7160150495704001`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.23045979181249954`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6093936653768698`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 4.140235767063381}, {
                    Style["75%", Bold], 1.3325004764523112`}, {
                    Style["median", Bold], 0.7160150495704001}, {
                    Style["25%", Bold], 0.23045979181249954`}, {
                    Style["min", Bold], -0.6093936653768698}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{18.5, 2.8535431838112224`}, {19.5, 
                    2.8535431838112224`}, {19.5, 0.19783152794786893`}, {18.5,
                     0.19783152794786893`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{19.5, 1.6893366146732867`}, {18.5, 
                    1.6893366146732867`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19., 0.19783152794786893`}, {
                    19., -0.7639667474188592}}, {{19., 2.8535431838112224`}, {
                    19., 3.2105961120884774`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19.25, -0.7639667474188592}, {
                    18.75, -0.7639667474188592}}, {{19.25, 
                    3.2105961120884774`}, {18.75, 
                    3.2105961120884774`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "3.2105961120884774`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "2.8535431838112224`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.6893366146732867`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.19783152794786893`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.7639667474188592`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 3.2105961120884774`}, {
                    Style["75%", Bold], 2.8535431838112224`}, {
                    Style["median", Bold], 1.6893366146732867`}, {
                    Style["25%", Bold], 0.19783152794786893`}, {
                    Style["min", Bold], -0.7639667474188592}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{19.5, 4.8153858809374315`}, {20.5, 
                    4.8153858809374315`}, {20.5, 0.8585893554883642}, {19.5, 
                    0.8585893554883642}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., 16.321535918391014`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 27.726611812698934`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 27.726611812698934`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 19.979767809018085`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 27.726611812698934`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., 27.726611812698934`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{20.5, 4.088304141534728}, {19.5, 
                    4.088304141534728}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20., 0.8585893554883642}, {
                    20., -1.4854457845142741`}}, {{20., 
                    4.8153858809374315`}, {20., 5.187183067222485}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20.25, -1.4854457845142741`}, {
                    19.75, -1.4854457845142741`}}, {{20.25, 
                    5.187183067222485}, {19.75, 
                    5.187183067222485}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "27.726611812698934`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "4.8153858809374315`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "4.088304141534728`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.8585893554883642`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.4854457845142741`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 27.726611812698934`}, {
                    Style["75%", Bold], 4.8153858809374315`}, {
                    Style["median", Bold], 4.088304141534728}, {
                    Style["25%", Bold], 0.8585893554883642}, {
                    Style["min", Bold], -1.4854457845142741`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{20.5, 11.367323215936068`}, {21.5, 
                    11.367323215936068`}, {21.5, 1.8191465257035906`}, {20.5, 
                    1.8191465257035906`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{21.5, 11.367323215936068`}, {20.5, 
                    11.367323215936068`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21., 1.8191465257035906`}, {21., 
                    1.4430480006810296`}}, {{21., 11.367323215936068`}, {21., 
                    11.367323215936068`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21.25, 1.4430480006810296`}, {20.75, 
                    1.4430480006810296`}}, {{21.25, 11.367323215936068`}, {
                    20.75, 11.367323215936068`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "11.367323215936068`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "11.367323215936068`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "11.367323215936068`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.8191465257035906`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.4430480006810296`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 11.367323215936068`}, {
                    Style["75%", Bold], 11.367323215936068`}, {
                    Style["median", Bold], 11.367323215936068`}, {
                    Style["25%", Bold], 1.8191465257035906`}, {
                    Style["min", Bold], 1.4430480006810296`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{21.5, 1.4970850096590727`}, {22.5, 
                    1.4970850096590727`}, {22.5, 0.9708270017346227}, {21.5, 
                    0.9708270017346227}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{22.5, 0.999427980426169}, {21.5, 
                    0.999427980426169}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22., 0.9708270017346227}, {22., 
                    0.30891863773026795`}}, {{22., 1.4970850096590727`}, {22.,
                     1.8219921275950377`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22.25, 0.30891863773026795`}, {21.75, 
                    0.30891863773026795`}}, {{22.25, 1.8219921275950377`}, {
                    21.75, 1.8219921275950377`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.8219921275950377`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.4970850096590727`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.999427980426169`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.9708270017346227`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.30891863773026795`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.8219921275950377`}, {
                    Style["75%", Bold], 1.4970850096590727`}, {
                    Style["median", Bold], 0.999427980426169}, {
                    Style["25%", Bold], 0.9708270017346227}, {
                    Style["min", Bold], 0.30891863773026795`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{22.5, 1.008698735188124}, {23.5, 
                    1.008698735188124}, {23.5, 0.6280906558147041}, {22.5, 
                    0.6280906558147041}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.0542246530567608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.0542246530567608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.18038186256437708`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.0542246530567608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.0542246530567608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.0542246530567608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.0244100014069407}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.0542246530567608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., -0.008757309290785305}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{23.5, 0.7312990668139281}, {22.5, 
                    0.7312990668139281}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23., 0.6280906558147041}, {23., 
                    0.1248591543930638}}, {{23., 1.008698735188124}, {23., 
                    1.2676532344164946`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23.25, 0.1248591543930638}, {22.75, 
                    0.1248591543930638}}, {{23.25, 1.2676532344164946`}, {
                    22.75, 1.2676532344164946`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2676532344164946`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.008698735188124`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7312990668139281`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6280906558147041`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.18038186256437708`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2676532344164946`}, {
                    Style["75%", Bold], 1.008698735188124}, {
                    Style["median", Bold], 0.7312990668139281}, {
                    Style["25%", Bold], 0.6280906558147041}, {
                    Style["min", Bold], -0.18038186256437708`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{23.5, 1.733803695153934}, {24.5, 
                    1.733803695153934}, {24.5, 0.7321483017186337}, {23.5, 
                    0.7321483017186337}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 4.140235767063381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 4.140235767063381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 4.140235767063381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 4.140235767063381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 4.140235767063381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    24., 4.140235767063381}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{24.5, 1.3306472797198792`}, {23.5, 
                    1.3306472797198792`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24., 0.7321483017186337}, {24., 
                    0.435524809759985}}, {{24., 1.733803695153934}, {24., 
                    2.1117481969586893`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24.25, 0.435524809759985}, {23.75, 
                    0.435524809759985}}, {{24.25, 2.1117481969586893`}, {
                    23.75, 2.1117481969586893`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "4.140235767063381`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.733803695153934`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.3306472797198792`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.7321483017186337`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.435524809759985`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 4.140235767063381}, {
                    Style["75%", Bold], 1.733803695153934}, {
                    Style["median", Bold], 1.3306472797198792`}, {
                    Style["25%", Bold], 0.7321483017186337}, {
                    Style["min", Bold], 0.435524809759985}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{27.5, 0.5257492893766771}, {28.5, 
                    0.5257492893766771}, {28.5, 0.06101859023066001}, {27.5, 
                    0.06101859023066001}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., -0.6912337435105292}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 1.34941288436285}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    28., 1.298657722268556}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{28.5, 0.2557991851981165}, {27.5, 
                    0.2557991851981165}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28., 0.06101859023066001}, {
                    28., -0.42009203877183093`}}, {{28., 
                    0.5257492893766771}, {28., 1.065219337409109}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28.25, -0.42009203877183093`}, {
                    27.75, -0.42009203877183093`}}, {{28.25, 
                    1.065219337409109}, {27.75, 
                    1.065219337409109}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.34941288436285`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5257492893766771`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.2557991851981165`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.06101859023066001`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6912337435105292`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.34941288436285}, {
                    Style["75%", Bold], 0.5257492893766771}, {
                    Style["median", Bold], 0.2557991851981165}, {
                    Style["25%", Bold], 0.06101859023066001}, {
                    Style["min", Bold], -0.6912337435105292}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{28.5, 1.9586897507838565`}, {29.5, 
                    1.9586897507838565`}, {29.5, -0.434609718898861}, {
                    28.5, -0.434609718898861}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    29., 6.481968083160268}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{29.5, 0.8396199324193871}, {28.5, 
                    0.8396199324193871}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29., -0.434609718898861}, {
                    29., -3.097219717502317}}, {{29., 1.9586897507838565`}, {
                    29., 5.038823028498539}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29.25, -3.097219717502317}, {
                    28.75, -3.097219717502317}}, {{29.25, 
                    5.038823028498539}, {28.75, 
                    5.038823028498539}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "6.481968083160268`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.9586897507838565`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8396199324193871`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.434609718898861`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.097219717502317`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 6.481968083160268}, {
                    Style["75%", Bold], 1.9586897507838565`}, {
                    Style["median", Bold], 0.8396199324193871}, {
                    Style["25%", Bold], -0.434609718898861}, {
                    Style["min", Bold], -3.097219717502317}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{29.5, 2.6934399309029766`}, {30.5, 
                    2.6934399309029766`}, {30.5, 0.17012848272963987`}, {29.5,
                     0.17012848272963987`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    30., 6.759624008853373}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{30.5, 1.4992966985901623`}, {29.5, 
                    1.4992966985901623`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30., 0.17012848272963987`}, {
                    30., -2.0655728508383504`}}, {{30., 
                    2.6934399309029766`}, {30., 5.818266106331101}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30.25, -2.0655728508383504`}, {
                    29.75, -2.0655728508383504`}}, {{30.25, 
                    5.818266106331101}, {29.75, 
                    5.818266106331101}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "6.759624008853373`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "2.6934399309029766`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.4992966985901623`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.17012848272963987`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "2.0655728508383504`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 6.759624008853373}, {
                    Style["75%", Bold], 2.6934399309029766`}, {
                    Style["median", Bold], 1.4992966985901623`}, {
                    Style["25%", Bold], 0.17012848272963987`}, {
                    Style["min", Bold], -2.0655728508383504`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{30.5, 0.5122630749271693}, {31.5, 
                    0.5122630749271693}, {31.5, -0.10794991273106075`}, {
                    30.5, -0.10794991273106075`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{31.5, 0.12642662909516486`}, {30.5, 
                    0.12642662909516486`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31., -0.10794991273106075`}, {
                    31., -0.5324404382930455}}, {{31., 0.5122630749271693}, {
                    31., 1.0209887182090274`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31.25, -0.5324404382930455}, {
                    30.75, -0.5324404382930455}}, {{31.25, 
                    1.0209887182090274`}, {30.75, 
                    1.0209887182090274`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.0209887182090274`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5122630749271693`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.12642662909516486`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.10794991273106075`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5324404382930455`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.0209887182090274`}, {
                    Style["75%", Bold], 0.5122630749271693}, {
                    Style["median", Bold], 0.12642662909516486`}, {
                    Style["25%", Bold], -0.10794991273106075`}, {
                    Style["min", Bold], -0.5324404382930455}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{31.5, 0.2887093014255834}, {32.5, 
                    0.2887093014255834}, {32.5, -0.007086282102208554}, {
                    31.5, -0.007086282102208554}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{32.5, 0.1454325779784273}, {31.5, 
                    0.1454325779784273}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32., -0.007086282102208554}, {
                    32., -0.295071135915463}}, {{32., 0.2887093014255834}, {
                    32., 0.6170373215131111}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32.25, -0.295071135915463}, {
                    31.75, -0.295071135915463}}, {{32.25, 
                    0.6170373215131111}, {31.75, 
                    0.6170373215131111}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6170373215131111`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.2887093014255834`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.1454325779784273`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.007086282102208554`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.295071135915463`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.6170373215131111}, {
                    Style["75%", Bold], 0.2887093014255834}, {
                    Style["median", Bold], 0.1454325779784273}, {
                    Style["25%", Bold], -0.007086282102208554}, {
                    Style["min", Bold], -0.295071135915463}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{32.5, 0.7944797620822145}, {33.5, 
                    0.7944797620822145}, {33.5, -0.031781746930706074`}, {
                    32.5, -0.031781746930706074`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., 2.069884475999683}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{33.5, 0.35247039225547266`}, {32.5, 
                    0.35247039225547266`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33., -0.031781746930706074`}, {
                    33., -1.0090019108946786`}}, {{33., 0.7944797620822145}, {
                    33., 1.989044187251252}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33.25, -1.0090019108946786`}, {
                    32.75, -1.0090019108946786`}}, {{33.25, 
                    1.989044187251252}, {32.75, 
                    1.989044187251252}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.069884475999683`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7944797620822145`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.35247039225547266`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.031781746930706074`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.0090019108946786`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.069884475999683}, {
                    Style["75%", Bold], 0.7944797620822145}, {
                    Style["median", Bold], 0.35247039225547266`}, {
                    Style["25%", Bold], -0.031781746930706074`}, {
                    Style["min", Bold], -1.0090019108946786`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}}, {}, {}}}, {{{{{{{{{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {}}, {}}, \
{}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {}}, {}}, {}}, {}}}}, {}}, {}}, {{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxFz38sFAAUB/Bzdn5E7HJ1UZwzzuXEOQk5nGKHusldKZxDRU0/TSZH2bDO
JmqcmJli1eTHZXa0MSsrP/rDcHXTqDs/SvlxNCfnx9ZVW733tre3zx/v7X3p
564L04gEAkHwp//O6HzCGpEwGkr4V4UzDPfkNnR3pCChJ2EMzNpd+zqrUwW2
VviWfclQg4e16YwB9QS4qSG99a16BvdJwxpZiw4sWou/PS7fAufbaXKEA0Te
f+etOPu/YFiAa4QersrtnWBKaadJaRcZfJkdaPHgOQW892U/ebScCjbqrspD
jjqAsy9tHjRhO4IZlY95q4s08MMYJstWQAenGDLDYvpcwPycKPmz/a7g9ZqK
VfcqN/BJVopqwMwdPFjVs5yfzASTGkv2JKkP4P27s9JTHBa4yLp9IbvVExxr
avJJSfMCc1VaSyupNziHXtPQf4sN1kbIxGSmD7iuMeDj4nt08GhjfGI5B7w0
L8qN4/qCCz701s9toC8a5otJHYfAErMky3aJHzhwrqRyxf4w2KVju6d7CJ3a
xX5KuemP+Uqd5KZeAWDlCRH9ziT6nYanLKsOxP/E2V+Z/CPgNLsr40I9uq92
3whZEQT2tNmVJhZzwVJhH4FrHwx2GuEkNavQY/6LZ54UhGDeTPFZ36BQsHU1
xSBYQBdL+S3b0Tywnjz92aEJnUGr1xp/ob+bWUwVEcLw/nLmlDkRfaE3YtqW
hJYk6mZoVujYau5cKBUdYDu5VOCN7loP15n6oP00Cp2Mg+a0FS7f90N7Hvf4
8SgI7SzL1b/io+uvzeqPRaEd4wRrg9FoBzf6zxEBmvJmaF0rQlc0cwznT6PJ
FXWGb3Fom9QbGyvx6HuRExtZiegd7PBNgxhdQlVs5knQ5kbqljEZ/Ru3Fwx3

               "]]}, Annotation[#, "Charting`Private`Tag$22507#1"]& ], 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7VXD8IWJ4YI9Axh8sF+xMG3NkauP4Hxt1rP32le/
hfODv0TWXp/yC86vEb5XHnSMyQHGr36vYL5ejQPOnxGkpbLlNy+cL9K9lbF7
myCcn21gyTFhpQicL7H9qOCFPnE4///b3Cl2TlJwfmnGT11GA1k4X23yAodP
r+Xh/Gn+Gtr8vopwfsL3Qkf/g0pwvnu555RlMipw/rcZkz6pT1WF8wO0Ey4d
Y1OH849P3f2uJl4Dzmdd1CEWe1UTYX7b46oQI204v5lnw6vSNTpwfiAz450t
8npwvs2l+5zcVfpwfrnijIVHKwzg/Puu7TGCGoZw/pxFFjdeX0bwbS8siozu
M4Lz37wMrgyzMYbz66/snffsB4Kf/v1lC+smEzg/ji2Wc0OcKZxv+axj8ntJ
MzhfadPv3btOIPiJ2wyWipSYI/zXLTeFWc8Czt/iE6xYdxvBP3nPYUvvdEuE
+2JKn2q4W8H5qcI514M+I/gHZ0mfF1xnDefr8AmlxsTYwPlVQQcZbCRt4Xy5
80axqy4h+BfNX4cvqbdD+LcwJsLY2h7O55ku8t33FYLfUuW++reXA5z/WfDh
XakVCH6W/Lz7//8h+Bb8t9/U6zvC+ez/xX/9j0fwAT9m8Jc=
               "]]}, 
             Annotation[#, "Charting`Private`Tag$22507#2"]& ]}}, {}}}, {
        Epilog -> {
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox[
                  "\"Efficient Non-behavioral\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Efficient Non-behavioral", 12]]], TraditionalForm]], {
            3, 1.5}], 
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Random\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Random", 12]]], TraditionalForm]], {1, -0.5}], 
           InsetBox[
            GraphicsBox[{
              GrayLevel[0.5], 
              RectangleBox[{0, 0}, {3, 1}]}], {1, 1.}, {1.5, 0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0.5, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {2, -0.1620266005521285}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {3, -0.6126947224789424}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0.7777777777777778, 
               NCache[
                Rational[5, 9], 0.5555555555555556], 0.7777777777777778], 
              RectangleBox[{0, 0}, {3, 1}]}], {4, 1.0556003025763658`}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {5, -0.48913843033559723`}, {
            1.5, 0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 0, 1], 
              RectangleBox[{0, 0}, {3, 1}]}], {6, -0.42488882973207565`}, {
            1.5, 0.5}, 1.25]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False},
          AxesLabel -> {None, None}, 
         AxesOrigin -> {-1.2000000000000002`, -5.285767488909609}, Frame -> 
         True, FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
         GrayLevel[0], FrameTicks -> {{Automatic, Automatic}, {{{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Observed\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Observed", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Democracy\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Democracy", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Community\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Community", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Despotism\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Despotism", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Large, PlotRange -> {All, 11}, 
         PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {{{1., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Observed\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Observed", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            11., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            12., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            13., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            14., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            15., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            16., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            9.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Democracy\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Democracy", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            20., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            21., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            22., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            23., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            24., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            25., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            18.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Community\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Community", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            29., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            30., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            31., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            32., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            33., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            34., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            27.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Despotism\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Despotism", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
           Automatic}}], 
       FormBox[
        FormBox[
         TemplateBox[{
          "\"Dotty\"", "\"Hook\"", "\"Linda\"", "\"Lodge\"", "\"Nyayo\"", 
           "\"Viola\""}, "SwatchLegend", DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.5185185185185186, 0.37037037037037035`, 
                    0.5185185185185186], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.7777777777777778`", ",", 
                    FractionBox["5", "9"], ",", "0.7777777777777778`"}], 
                    "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], Editable -> False, 
                    Selectable -> False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], 
                    "}"}]}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "None", "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic", ",", "Automatic", ",", "Automatic"}], 
                    "}"}]}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]}, "Legended", 
      DisplayFunction -> (GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ), 
      InterpretationFunction -> (RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& ), Editable -> True], 
     RotationBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"   Less Efficient                                          More \
Efficient\"", Italic, 
           RGBColor[1, 0, 0], 15, StripOnInput -> False], TextForm]], 
        "InlineText"], 
       Text[
        Style[
        "   Less Efficient                                          More \
Efficient", Italic, 
         RGBColor[1, 0, 0], 15]]], BoxRotation -> 1.5707963267948966`]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 2}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )], 
   RotationBox[
    InterpretationBox[
     Cell[
      BoxData[
       FormBox[
        StyleBox[
        "\"Scaled Mean Betweenness\\nCentrality of Broken Bonds\"", 21, 
         TextAlignment -> Center, StripOnInput -> False], TextForm]], 
      "InlineText"], 
     Text[
      Style[
      "Scaled Mean Betweenness\nCentrality of Broken Bonds", 21, 
       TextAlignment -> Center]]], BoxRotation -> 1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8400943766206913`*^9, 3.8400944085922904`*^9, 
  3.840094524824814*^9},
 CellLabel->
  "Out[791]=",ExpressionUUID->"7ceaa755-9d51-4dee-a9a1-c01f133b3aea"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Betweenness Centrality Maintained", "Subsection",
 CellChangeTimes->{{3.8235925757025185`*^9, 3.823592578221815*^9}, {
  3.8235933790635824`*^9, 3.8235933845943413`*^9}, {3.8235941397534943`*^9, 
  3.823594140919758*^9}, {3.8235945857975097`*^9, 3.8235945982351165`*^9}, {
  3.823595173461299*^9, 
  3.823595174926857*^9}},ExpressionUUID->"23c73765-3918-4e15-9393-\
27a1aca294fb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottynewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "dottymax"}], "]"}], ",", 
     RowBox[{"sparsdottybwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottycomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "dottymax"}], "]"}], ",", 
     RowBox[{"sparsdottybwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottynewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dottydespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"dottyrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "dottymax"}], "]"}], ",", 
     RowBox[{"sparsdottybwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dottynewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"dottybwmain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"dottyrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
        "dottymax"}], "]"}], ",", 
      RowBox[{"sparsdottybwmain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}],
       "]"}], ",", 
     RowBox[{"sparshookbwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookcomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}],
       "]"}], ",", 
     RowBox[{"sparshookbwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hooknewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hookdespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}], 
     ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"hookrand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}],
       "]"}], ",", 
     RowBox[{"sparshookbwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hooknewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"hookbwmain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"hookrand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
        "hookmax"}], "]"}], ",", 
      RowBox[{"sparshookbwmain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "lindamax"}], "]"}], ",", 
     RowBox[{"sparslindabwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "lindamax"}], "]"}], ",", 
     RowBox[{"sparslindabwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lindadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lindarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "lindamax"}], "]"}], ",", 
     RowBox[{"sparslindabwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lindanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lindabwmain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lindarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
        "lindamax"}], "]"}], ",", 
      RowBox[{"sparslindabwmain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "lodgemax"}], "]"}], ",", 
     RowBox[{"sparslodgebwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "lodgemax"}], "]"}], ",", 
     RowBox[{"sparslodgebwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgenewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"lodgedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"lodgerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "lodgemax"}], "]"}], ",", 
     RowBox[{"sparslodgebwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lodgenewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"lodgebwmain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"lodgerand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
        "lodgemax"}], "]"}], ",", 
      RowBox[{"sparslodgebwmain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "nyayomax"}], "]"}], ",", 
     RowBox[{"sparsnyayobwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayocomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "nyayomax"}], "]"}], ",", 
     RowBox[{"sparsnyayobwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayonewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nyayodespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"nyayorand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "nyayomax"}], "]"}], ",", 
     RowBox[{"sparsnyayobwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nyayonewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"nyayobwmain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"nyayorand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
        "nyayomax"}], "]"}], ",", 
      RowBox[{"sparsnyayobwmain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdemoc", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violademoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "violamax"}], "]"}], ",", 
     RowBox[{"sparsviolabwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewcomm", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violacomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "violamax"}], "]"}], ",", 
     RowBox[{"sparsviolabwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violanewdespot", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"violadespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"violarand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "violamax"}], "]"}], ",", 
     RowBox[{"sparsviolabwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"violanewobs", "=", 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"violabwmain", ",", "100"}], "]"}], ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"violarand", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
        "violamax"}], "]"}], ",", 
      RowBox[{"sparsviolabwmain", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdemoc", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedemoc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "voguemax"}], "]"}], ",", 
     RowBox[{"sparsvoguebwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewcomm", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguecomm", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "voguemax"}], "]"}], ",", 
     RowBox[{"sparsvoguebwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewdespot", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"voguedespot", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}],
      ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "voguemax"}], "]"}], ",", 
     RowBox[{"sparsvoguebwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguenewobs", "=", 
   RowBox[{"frev", "[", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"voguebwmain", ",", "100"}], "]"}], ",", 
     RowBox[{"Mean", "[", 
      RowBox[{
       RowBox[{"voguerand", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", 
       "voguemax"}], "]"}], ",", 
     RowBox[{"sparsvoguebwmain", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.823591449009904*^9, 3.8235914956379766`*^9}, {
  3.823591525819866*^9, 3.8235916157503233`*^9}, {3.82359168469874*^9, 
  3.8235917021111393`*^9}, {3.823591773033968*^9, 3.823591837938725*^9}, {
  3.8235918747444067`*^9, 3.823592001058693*^9}, {3.823593511044263*^9, 
  3.8235935533689365`*^9}, {3.8235936132386136`*^9, 3.8235936950309906`*^9}, {
  3.8235941509928536`*^9, 3.823594183741576*^9}, {3.8235944233975563`*^9, 
  3.823594429564615*^9}, {3.823594625982317*^9, 3.8235946642220116`*^9}, {
  3.8235948584656563`*^9, 3.823594879797306*^9}, {3.823595187568231*^9, 
  3.823595202329975*^9}, {3.8235952375662136`*^9, 3.8235952630738487`*^9}, {
  3.8235954968015027`*^9, 3.8235955040052414`*^9}},
 CellLabel->
  "In[792]:=",ExpressionUUID->"23d75262-479f-41f9-ac33-6daa0aa751a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figs10", "=", 
  RowBox[{"Labeled", "[", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "dottynewobs", ",", "hooknewobs", ",", "lindanewobs", ",", 
              "lodgenewobs", ",", "nyayonewobs", ",", "violanewobs", ",", 
              "Null"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdemoc", ",", "hooknewdemoc", ",", "lindanewdemoc", ",", 
              "lodgenewdemoc", ",", "nyayonewdemoc", ",", "violanewdemoc", 
              ",", "Null"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewcomm", ",", "hooknewcomm", ",", "lindanewcomm", ",", 
              "lodgenewcomm", ",", "nyayonewcomm", ",", "violanewcomm", ",", 
              "Null"}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "dottynewdespot", ",", "hooknewdespot", ",", "lindanewdespot", 
              ",", "lodgenewdespot", ",", "nyayonewdespot", ",", 
              "violanewdespot", ",", "Null"}], "}"}]}], "\[IndentingNewLine]",
            "}"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<Outliers\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<MedianMarker\>\"", ",", "1", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Black", ",", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"ChartLabels", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Observed\>\"", ",", "17", ",", "Black"}], "]"}],
                 "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Democracy\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Community\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<Despotism\>\"", ",", "17", ",", "Black"}], 
                 "]"}], "]"}]}], "}"}], ",", "None"}], "}"}]}], ",", 
          RowBox[{"ChartLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Dotty\>\"", ",", "\"\<Hook\>\"", ",", "\"\<Linda\>\"", ",", 
             "\"\<Lodge\>\"", ",", "\"\<Nyayo\>\"", ",", "\"\<Viola\>\""}], 
            "}"}]}], ",", 
          RowBox[{"BarSpacing", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "2"}], "}"}]}], ",", 
          RowBox[{"ChartStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Gray", ",", "Orange", ",", "Green", ",", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", "Yellow", 
             ",", "Blue"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
          RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10"}], ",", "9"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.25", ",", "34.75"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dashed"}], "]"}]}]}], "]"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Efficient Non-behavioral\>\"", ",", "12"}], "]"}],
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"-", "0.5"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Random\>\"", ",", "12"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "1.5"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Gray", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"dottynewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Orange", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"hooknewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Green", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"lindanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Lighter", "[", 
                 RowBox[{"Lighter", "[", "Purple", "]"}], "]"}], ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", 
               RowBox[{"lodgenewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Yellow", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", 
               RowBox[{"nyayonewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"6", ",", 
               RowBox[{"violanewobs", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.5", ",", "0.5"}], "}"}], ",", "1.25"}], "]"}]}], 
          "\[IndentingNewLine]", "}"}]}]}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<   More Efficient                                          \
Less Efficient\>\"", ",", "Italic", ",", "Red", ",", "15"}], "]"}], "]"}], 
        ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<Scaled Mean Betweenness\nCentrality of Maintained Bonds\>\"", 
         ",", "21", ",", 
         RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}], "]"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8235920125253134`*^9, 3.823592065605406*^9}, {
   3.823592110163682*^9, 3.823592257916377*^9}, {3.8235923147544823`*^9, 
   3.82359232692793*^9}, {3.823592405067442*^9, 3.8235924279573603`*^9}, {
   3.8235924601542344`*^9, 3.8235925182234397`*^9}, {3.8235926326470547`*^9, 
   3.823592768222708*^9}, {3.823593046485058*^9, 3.823593052835633*^9}, {
   3.8235937638522778`*^9, 3.82359377539753*^9}, {3.823593821851324*^9, 
   3.823593855042349*^9}, {3.8235941979176807`*^9, 3.8235941991407948`*^9}, {
   3.8235944458627462`*^9, 3.823594450459326*^9}, {3.823594681625139*^9, 
   3.823594694429593*^9}, 3.8235950213109226`*^9, {3.8235950627639313`*^9, 
   3.8235950945633583`*^9}, {3.823595152424226*^9, 3.8235951568219056`*^9}, {
   3.8235952245512915`*^9, 3.8235952258899612`*^9}, {3.8235952793437405`*^9, 
   3.823595281125951*^9}, {3.823595517749529*^9, 3.823595571204408*^9}, {
   3.8239590085547667`*^9, 3.823959012347769*^9}, 3.8249884017181187`*^9, {
   3.8249897066584363`*^9, 3.824989721823682*^9}, {3.8255186681444798`*^9, 
   3.8255187292650084`*^9}, {3.839241269377059*^9, 3.8392412909173317`*^9}, {
   3.8392417119571967`*^9, 3.83924171249621*^9}, {3.8400947388747454`*^9, 
   3.8400947395409718`*^9}},ExpressionUUID->"db7bef6e-6f41-4567-af93-\
d9d1a2a6b758"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
     TemplateBox[{
       GraphicsBox[{{{
           CapForm[None], 
           Directive[
            RGBColor[0.982864, 0.7431472, 0.3262672]], {{}, {{{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{0.5, -1.0940764948197255`}, {
                    1.5, -1.0940764948197255`}, {1.5, -1.0940764948197255`}, {
                    0.5, -1.0940764948197255`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., -1.0940764948197255`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{1.5, -1.0940764948197255`}, {
                    0.5, -1.0940764948197255`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1., -1.0940764948197255`}, {
                    1., -1.0940764948197255`}}, {{1., -1.0940764948197255`}, {
                    1., -1.0940764948197255`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1.25, -1.0940764948197255`}, {
                    0.75, -1.0940764948197255`}}, {{
                    1.25, -1.0940764948197255`}, {
                    0.75, -1.0940764948197255`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.0940764948197255`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.0940764948197255`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.0940764948197255`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.0940764948197255`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.0940764948197255`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -1.0940764948197255`}, {
                    Style["75%", Bold], -1.0940764948197255`}, {
                    Style["median", Bold], -1.0940764948197255`}, {
                    Style["25%", Bold], -1.0940764948197255`}, {
                    Style["min", Bold], -1.0940764948197255`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{1.5, 0.}, {2.5, 0.}, {2.5, 0.}, {1.5, 
                    0.}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2., 0.}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{2.5, 0.}, {1.5, 0.}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    LineBox[{{{2., 0.}, {2., 0.}}, {{2., 0.}, {2., 0.}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2.25, 0.}, {1.75, 0.}}, {{2.25, 0.}, {1.75, 
                    0.}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], "0.`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], "0.`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}},
                     GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}},
                     AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.}, {
                    Style["75%", Bold], 0.}, {
                    Style["median", Bold], 0.}, {
                    Style["25%", Bold], 0.}, {
                    Style["min", Bold], 0.}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{2.5, 1.350720756376404}, {3.5, 
                    1.350720756376404}, {3.5, 1.350720756376404}, {2.5, 
                    1.350720756376404}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3., 1.350720756376404}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{3.5, 1.350720756376404}, {2.5, 
                    1.350720756376404}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    LineBox[{{{3., 1.350720756376404}, {3., 
                    1.350720756376404}}, {{3., 1.350720756376404}, {3., 
                    1.350720756376404}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3.25, 1.350720756376404}, {2.75, 
                    1.350720756376404}}, {{3.25, 1.350720756376404}, {2.75, 
                    1.350720756376404}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.350720756376404`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.350720756376404`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.350720756376404`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.350720756376404`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.350720756376404`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.350720756376404}, {
                    Style["75%", Bold], 1.350720756376404}, {
                    Style["median", Bold], 1.350720756376404}, {
                    Style["25%", Bold], 1.350720756376404}, {
                    Style["min", Bold], 1.350720756376404}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{3.5, -3.6795072091547882`}, {
                    4.5, -3.6795072091547882`}, {4.5, -3.6795072091547882`}, {
                    3.5, -3.6795072091547882`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4., -3.6795072091547882`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{4.5, -3.6795072091547882`}, {
                    3.5, -3.6795072091547882`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4., -3.6795072091547882`}, {
                    4., -3.6795072091547882`}}, {{4., -3.6795072091547882`}, {
                    4., -3.6795072091547882`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4.25, -3.6795072091547882`}, {
                    3.75, -3.6795072091547882`}}, {{
                    4.25, -3.6795072091547882`}, {
                    3.75, -3.6795072091547882`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.6795072091547882`"}]}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.6795072091547882`"}]}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.6795072091547882`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.6795072091547882`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.6795072091547882`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], -3.6795072091547882`}, {
                    Style["75%", Bold], -3.6795072091547882`}, {
                    Style["median", Bold], -3.6795072091547882`}, {
                    Style["25%", Bold], -3.6795072091547882`}, {
                    Style["min", Bold], -3.6795072091547882`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{4.5, 1.3416816644649612`}, {5.5, 
                    1.3416816644649612`}, {5.5, 1.3416816644649612`}, {4.5, 
                    1.3416816644649612`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5., 1.3416816644649612`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{5.5, 1.3416816644649612`}, {4.5, 
                    1.3416816644649612`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5., 1.3416816644649612`}, {5., 
                    1.3416816644649612`}}, {{5., 1.3416816644649612`}, {5., 
                    1.3416816644649612`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5.25, 1.3416816644649612`}, {4.75, 
                    1.3416816644649612`}}, {{5.25, 1.3416816644649612`}, {
                    4.75, 1.3416816644649612`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.3416816644649612`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.3416816644649612`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.3416816644649612`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.3416816644649612`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.3416816644649612`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.3416816644649612`}, {
                    Style["75%", Bold], 1.3416816644649612`}, {
                    Style["median", Bold], 1.3416816644649612`}, {
                    Style["25%", Bold], 1.3416816644649612`}, {
                    Style["min", Bold], 1.3416816644649612`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{5.5, 1.7348941628301084`}, {6.5, 
                    1.7348941628301084`}, {6.5, 1.7348941628301084`}, {5.5, 
                    1.7348941628301084`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6., 1.7348941628301084`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{6.5, 1.7348941628301084`}, {5.5, 
                    1.7348941628301084`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6., 1.7348941628301084`}, {6., 
                    1.7348941628301084`}}, {{6., 1.7348941628301084`}, {6., 
                    1.7348941628301084`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{6.25, 1.7348941628301084`}, {5.75, 
                    1.7348941628301084`}}, {{6.25, 1.7348941628301084`}, {
                    5.75, 1.7348941628301084`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.7348941628301084`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.7348941628301084`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.7348941628301084`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "1.7348941628301084`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "1.7348941628301084`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.7348941628301084`}, {
                    Style["75%", Bold], 1.7348941628301084`}, {
                    Style["median", Bold], 1.7348941628301084`}, {
                    Style["25%", Bold], 1.7348941628301084`}, {
                    Style["min", Bold], 1.7348941628301084`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{9.5, 0.7999378441428769}, {10.5, 
                    0.7999378441428769}, {10.5, -0.08709918167782361}, {
                    9.5, -0.08709918167782361}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{10.5, 0.5278879772380967}, {9.5, 
                    0.5278879772380967}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10., -0.08709918167782361}, {
                    10., -0.6165400594342776}}, {{10., 0.7999378441428769}, {
                    10., 1.5263612379153972`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10.25, -0.6165400594342776}, {
                    9.75, -0.6165400594342776}}, {{10.25, 
                    1.5263612379153972`}, {9.75, 
                    1.5263612379153972`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.5263612379153972`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7999378441428769`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5278879772380967`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.08709918167782361`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6165400594342776`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.5263612379153972`}, {
                    Style["75%", Bold], 0.7999378441428769}, {
                    Style["median", Bold], 0.5278879772380967}, {
                    Style["25%", Bold], -0.08709918167782361}, {
                    Style["min", Bold], -0.6165400594342776}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{10.5, 0.3406457842536992}, {11.5, 
                    0.3406457842536992}, {11.5, -3.395147765985871}, {
                    10.5, -3.395147765985871}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{11.5, -1.7209740624479148`}, {
                    10.5, -1.7209740624479148`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11., -3.395147765985871}, {
                    11., -7.8254885723537955`}}, {{11., 0.3406457842536992}, {
                    11., 5.563166642402299}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11.25, -7.8254885723537955`}, {
                    10.75, -7.8254885723537955`}}, {{11.25, 
                    5.563166642402299}, {10.75, 
                    5.563166642402299}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "5.563166642402299`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.3406457842536992`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.7209740624479148`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.395147765985871`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "7.8254885723537955`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 5.563166642402299}, {
                    Style["75%", Bold], 0.3406457842536992}, {
                    Style["median", Bold], -1.7209740624479148`}, {
                    Style["25%", Bold], -3.395147765985871}, {
                    Style["min", Bold], -7.8254885723537955`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{11.5, 1.7762642858114432`}, {12.5, 
                    1.7762642858114432`}, {12.5, -0.22871130576827337`}, {
                    11.5, -0.22871130576827337`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 5.332475084844012}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    12., 4.938349432042822}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{12.5, 0.7429002426282365}, {11.5, 
                    0.7429002426282365}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12., -0.22871130576827337`}, {
                    12., -2.701441512752797}}, {{12., 1.7762642858114432`}, {
                    12., 3.8691879200919215`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12.25, -2.701441512752797}, {
                    11.75, -2.701441512752797}}, {{12.25, 
                    3.8691879200919215`}, {11.75, 
                    3.8691879200919215`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "5.332475084844012`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.7762642858114432`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7429002426282365`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.22871130576827337`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "2.701441512752797`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 5.332475084844012}, {
                    Style["75%", Bold], 1.7762642858114432`}, {
                    Style["median", Bold], 0.7429002426282365}, {
                    Style["25%", Bold], -0.22871130576827337`}, {
                    Style["min", Bold], -2.701441512752797}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{12.5, 0.8707592191502209}, {13.5, 
                    0.8707592191502209}, {13.5, 0.02536191900437534}, {12.5, 
                    0.02536191900437534}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    13., -1.9402636581347348`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    13., -2.403706066400404}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    13., 2.2906643702666116`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    13., 2.1600669561726535`}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {13., -2.8663121303787067`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {13., 3.501508010064454}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{13.5, 0.3566808063615325}, {12.5, 
                    0.3566808063615325}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13., 0.02536191900437534}, {
                    13., -1.1398371026823626`}}, {{13., 0.8707592191502209}, {
                    13., 1.9602457761381773`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{13.25, -1.1398371026823626`}, {
                    12.75, -1.1398371026823626`}}, {{13.25, 
                    1.9602457761381773`}, {12.75, 
                    1.9602457761381773`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "3.501508010064454`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8707592191502209`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.3566808063615325`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.02536191900437534`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "2.8663121303787067`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 3.501508010064454}, {
                    Style["75%", Bold], 0.8707592191502209}, {
                    Style["median", Bold], 0.3566808063615325}, {
                    Style["25%", Bold], 0.02536191900437534}, {
                    Style["min", Bold], -2.8663121303787067`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{13.5, 0.6702129845462264}, {14.5, 
                    0.6702129845462264}, {14.5, 0.26319669822595615`}, {13.5, 
                    0.26319669822595615`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{14.5, 0.43016107899182343`}, {13.5, 
                    0.43016107899182343`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14., 0.26319669822595615`}, {
                    14., -0.20513053311932394`}}, {{14., 
                    0.6702129845462264}, {14., 1.2634877024810125`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{14.25, -0.20513053311932394`}, {
                    13.75, -0.20513053311932394`}}, {{14.25, 
                    1.2634877024810125`}, {13.75, 
                    1.2634877024810125`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.2634877024810125`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6702129845462264`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.43016107899182343`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.26319669822595615`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.20513053311932394`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.2634877024810125`}, {
                    Style["75%", Bold], 0.6702129845462264}, {
                    Style["median", Bold], 0.43016107899182343`}, {
                    Style["25%", Bold], 0.26319669822595615`}, {
                    Style["min", Bold], -0.20513053311932394`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{14.5, 0.7252356568844041}, {15.5, 
                    0.7252356568844041}, {15.5, -0.4898656027306987}, {
                    14.5, -0.4898656027306987}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{15.5, 0.23539816720408396`}, {14.5, 
                    0.23539816720408396`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15., -0.4898656027306987}, {
                    15., -1.599253005080467}}, {{15., 0.7252356568844041}, {
                    15., 1.7594532949428197`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15.25, -1.599253005080467}, {
                    14.75, -1.599253005080467}}, {{15.25, 
                    1.7594532949428197`}, {14.75, 
                    1.7594532949428197`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.7594532949428197`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7252356568844041`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.23539816720408396`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.4898656027306987`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.599253005080467`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.7594532949428197`}, {
                    Style["75%", Bold], 0.7252356568844041}, {
                    Style["median", Bold], 0.23539816720408396`}, {
                    Style["25%", Bold], -0.4898656027306987}, {
                    Style["min", Bold], -1.599253005080467}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{18.5, 0.7999378441428779}, {19.5, 
                    0.7999378441428779}, {19.5, -0.3642228899274178}, {
                    18.5, -0.3642228899274178}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{19.5, 0.5645050999096771}, {18.5, 
                    0.5645050999096771}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19., -0.3642228899274178}, {
                    19., -0.579115276138365}}, {{19., 0.7999378441428779}, {
                    19., 1.1880356704179755`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19.25, -0.579115276138365}, {
                    18.75, -0.579115276138365}}, {{19.25, 
                    1.1880356704179755`}, {18.75, 
                    1.1880356704179755`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.1880356704179755`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7999378441428779`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5645050999096771`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3642228899274178`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.579115276138365`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.1880356704179755`}, {
                    Style["75%", Bold], 0.7999378441428779}, {
                    Style["median", Bold], 0.5645050999096771}, {
                    Style["25%", Bold], -0.3642228899274178}, {
                    Style["min", Bold], -0.579115276138365}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{19.5, 1.022305800898718}, {20.5, 
                    1.022305800898718}, {20.5, -0.3566510754224495}, {
                    19.5, -0.3566510754224495}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -4.196143989147659}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -4.305847099975043}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -4.305847099975043}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -4.305847099975043}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    20., -4.305847099975043}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., -5.212235607115983}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., -4.871943280847157}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., -4.871943280847157}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., -5.786839096144807}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., -4.759427269742146}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {20., -5.90568413287448}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{20.5, 0.5258784042836563}, {19.5, 
                    0.5258784042836563}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20., -0.3566510754224495}, {
                    20., -1.4073439575925086`}}, {{20., 1.022305800898718}, {
                    20., 2.0721698711840455`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{20.25, -1.4073439575925086`}, {
                    19.75, -1.4073439575925086`}}, {{20.25, 
                    2.0721698711840455`}, {19.75, 
                    2.0721698711840455`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.0721698711840455`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.022305800898718`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5258784042836563`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.3566510754224495`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "5.90568413287448`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.0721698711840455`}, {
                    Style["75%", Bold], 1.022305800898718}, {
                    Style["median", Bold], 0.5258784042836563}, {
                    Style["25%", Bold], -0.3566510754224495}, {
                    Style["min", Bold], -5.90568413287448}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{20.5, 1.1276287395574784`}, {21.5, 
                    1.1276287395574784`}, {21.5, -0.12279279603421174`}, {
                    20.5, -0.12279279603421174`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{21.5, 1.1276287395574711`}, {20.5, 
                    1.1276287395574711`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21., -0.12279279603421174`}, {
                    21., -0.6097990783172899}}, {{21., 1.1276287395574784`}, {
                    21., 1.1276287395574784`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{21.25, -0.6097990783172899}, {
                    20.75, -0.6097990783172899}}, {{21.25, 
                    1.1276287395574784`}, {20.75, 
                    1.1276287395574784`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.1276287395574784`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.1276287395574784`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "1.1276287395574711`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.12279279603421174`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.6097990783172899`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.1276287395574784`}, {
                    Style["75%", Bold], 1.1276287395574784`}, {
                    Style["median", Bold], 1.1276287395574711`}, {
                    Style["25%", Bold], -0.12279279603421174`}, {
                    Style["min", Bold], -0.6097990783172899}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{21.5, 0.7766383197339841}, {22.5, 
                    0.7766383197339841}, {22.5, -0.017656330498130937`}, {
                    21.5, -0.017656330498130937`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., -2.8663121303787067`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., -2.8663121303787067`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., -2.8663121303787067`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., -2.8663121303787067`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., -2.8663121303787067`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., -2.8663121303787067`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{22.5, 0.3516852768606705}, {21.5, 
                    0.3516852768606705}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22., -0.017656330498130937`}, {
                    22., -0.4327851144125972}}, {{22., 0.7766383197339841}, {
                    22., 0.8707592191502209}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22.25, -0.4327851144125972}, {
                    21.75, -0.4327851144125972}}, {{22.25, 
                    0.8707592191502209}, {21.75, 
                    0.8707592191502209}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8707592191502209`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7766383197339841`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.3516852768606705`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.017656330498130937`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "2.8663121303787067`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.8707592191502209}, {
                    Style["75%", Bold], 0.7766383197339841}, {
                    Style["median", Bold], 0.3516852768606705}, {
                    Style["25%", Bold], -0.017656330498130937`}, {
                    Style["min", Bold], -2.8663121303787067`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{22.5, 0.4596992585652041}, {23.5, 
                    0.4596992585652041}, {23.5, 0.014417994418508641`}, {22.5,
                     0.014417994418508641`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{23.5, 0.3436415168038389}, {22.5, 
                    0.3436415168038389}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23., 0.014417994418508641`}, {
                    23., -0.5403775587463657}}, {{23., 0.4596992585652041}, {
                    23., 1.1088278218718681`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23.25, -0.5403775587463657}, {
                    22.75, -0.5403775587463657}}, {{23.25, 
                    1.1088278218718681`}, {22.75, 
                    1.1088278218718681`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.1088278218718681`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4596992585652041`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.3436415168038389`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.014417994418508641`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5403775587463657`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.1088278218718681`}, {
                    Style["75%", Bold], 0.4596992585652041}, {
                    Style["median", Bold], 0.3436415168038389}, {
                    Style["25%", Bold], 0.014417994418508641`}, {
                    Style["min", Bold], -0.5403775587463657}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{23.5, 0.3470784246534423}, {24.5, 
                    0.3470784246534423}, {24.5, -1.1495585270635602`}, {
                    23.5, -1.1495585270635602`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{24.5, -0.5654659968593152}, {
                    23.5, -0.5654659968593152}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24., -1.1495585270635602`}, {
                    24., -1.7952398929579767`}}, {{24., 0.3470784246534423}, {
                    24., 0.671247839879965}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24.25, -1.7952398929579767`}, {
                    23.75, -1.7952398929579767`}}, {{24.25, 
                    0.671247839879965}, {23.75, 
                    0.671247839879965}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.671247839879965`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.3470784246534423`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5654659968593152`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.1495585270635602`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.7952398929579767`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 0.671247839879965}, {
                    Style["75%", Bold], 0.3470784246534423}, {
                    Style["median", Bold], -0.5654659968593152}, {
                    Style["25%", Bold], -1.1495585270635602`}, {
                    Style["min", Bold], -1.7952398929579767`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}, {{{}, {{}, {{
                  Directive[
                   GrayLevel[0.5]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{27.5, 0.8690066763212559}, {28.5, 
                    0.8690066763212559}, {28.5, 0.1825282092569038}, {27.5, 
                    0.1825282092569038}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{28.5, 0.5670442987610902}, {27.5, 
                    0.5670442987610902}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28., 0.1825282092569038}, {
                    28., -0.5466198057371597}}, {{28., 0.8690066763212559}, {
                    28., 1.8816514149069041`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{28.25, -0.5466198057371597}, {
                    27.75, -0.5466198057371597}}, {{28.25, 
                    1.8816514149069041`}, {27.75, 
                    1.8816514149069041`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.8816514149069041`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8690066763212559`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5670442987610902`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.1825282092569038`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5466198057371597`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.8816514149069041`}, {
                    Style["75%", Bold], 0.8690066763212559}, {
                    Style["median", Bold], 0.5670442987610902}, {
                    Style["25%", Bold], 0.1825282092569038}, {
                    Style["min", Bold], -0.5466198057371597}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 0.5, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{28.5, 2.236012179562607}, {29.5, 
                    2.236012179562607}, {29.5, -3.4918601064188124`}, {
                    28.5, -3.4918601064188124`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    29., -12.980355177898886`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    29., 12.314877415443911`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{29.5, -0.9281257390947046}, {
                    28.5, -0.9281257390947046}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29., -3.4918601064188124`}, {
                    29., -10.750904861084194`}}, {{29., 2.236012179562607}, {
                    29., 9.48322446930105}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29.25, -10.750904861084194`}, {
                    28.75, -10.750904861084194`}}, {{29.25, 
                    9.48322446930105}, {28.75, 9.48322446930105}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "12.314877415443911`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "2.236012179562607`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.9281257390947046`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.4918601064188124`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "12.980355177898886`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 12.314877415443911`}, {
                    Style["75%", Bold], 2.236012179562607}, {
                    Style["median", Bold], -0.9281257390947046}, {
                    Style["25%", Bold], -3.4918601064188124`}, {
                    Style["min", Bold], -12.980355177898886`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{29.5, 0.8916522640131785}, {30.5, 
                    0.8916522640131785}, {30.5, -2.815380781357704}, {
                    29.5, -2.815380781357704}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{30.5, -0.5114121344817548}, {
                    29.5, -0.5114121344817548}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30., -2.815380781357704}, {
                    30., -6.090942487728128}}, {{30., 0.8916522640131785}, {
                    30., 4.238261573341069}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30.25, -6.090942487728128}, {
                    29.75, -6.090942487728128}}, {{30.25, 
                    4.238261573341069}, {29.75, 
                    4.238261573341069}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "4.238261573341069`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.8916522640131785`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.5114121344817548`"}]}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "2.815380781357704`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "6.090942487728128`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 4.238261573341069}, {
                    Style["75%", Bold], 0.8916522640131785}, {
                    Style["median", Bold], -0.5114121344817548}, {
                    Style["25%", Bold], -2.815380781357704}, {
                    Style["min", Bold], -6.090942487728128}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    PolygonBox[{{30.5, 1.5564561840307811`}, {31.5, 
                    1.5564561840307811`}, {31.5, 0.689383071118932}, {30.5, 
                    0.689383071118932}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., -1.0594518965427777`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., -1.0166980001401074`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., -0.9695767702339381}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., -0.8472418033461679}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., -1.7100696587350228`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., -0.7452575973097046}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 3.145231843784472}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 3.175312259347801}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {31., -1.9318267638666116`}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{31.5, 0.8808991833582196}, {30.5, 
                    0.8808991833582196}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31., 0.689383071118932}, {
                    31., -0.5510782686522181}}, {{31., 1.5564561840307811`}, {
                    31., 2.5183177860916004`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31.25, -0.5510782686522181}, {
                    30.75, -0.5510782686522181}}, {{31.25, 
                    2.5183177860916004`}, {30.75, 
                    2.5183177860916004`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "3.175312259347801`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.5564561840307811`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.8808991833582196`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.689383071118932`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "1.9318267638666116`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 3.175312259347801}, {
                    Style["75%", Bold], 1.5564561840307811`}, {
                    Style["median", Bold], 0.8808991833582196}, {
                    Style["25%", Bold], 0.689383071118932}, {
                    Style["min", Bold], -1.9318267638666116`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[1, 1, 0]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{31.5, 1.0159108575580489`}, {32.5, 
                    1.0159108575580489`}, {32.5, 0.496211573490344}, {31.5, 
                    0.496211573490344}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{32.5, 0.7074172398948447}, {31.5, 
                    0.7074172398948447}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32., 0.496211573490344}, {
                    32., -0.12285108248675665`}}, {{32., 
                    1.0159108575580489`}, {32., 1.6652380568706637`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32.25, -0.12285108248675665`}, {
                    31.75, -0.12285108248675665`}}, {{32.25, 
                    1.6652380568706637`}, {31.75, 
                    1.6652380568706637`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "1.6652380568706637`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.0159108575580489`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7074172398948447`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.496211573490344`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.12285108248675665`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 1.6652380568706637`}, {
                    Style["75%", Bold], 1.0159108575580489`}, {
                    Style["median", Bold], 0.7074172398948447}, {
                    Style["25%", Bold], 0.496211573490344}, {
                    Style["min", Bold], -0.12285108248675665`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
                  Directive[
                   RGBColor[0, 0, 1]], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{32.5, 1.0629742272458795`}, {33.5, 
                    1.0629742272458795`}, {33.5, -0.654511845589736}, {
                    32.5, -0.654511845589736}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., -3.244585717985154}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{33.5, 0.2560332098249449}, {32.5, 
                    0.2560332098249449}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33., -0.654511845589736}, {
                    33., -1.9847921908094075`}}, {{33., 
                    1.0629742272458795`}, {33., 2.6838960980534186`}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33.25, -1.9847921908094075`}, {
                    32.75, -1.9847921908094075`}}, {{33.25, 
                    2.6838960980534186`}, {32.75, 
                    2.6838960980534186`}}}]}, {}}]}], 
                    "DelayedMouseEffectStyle"], 
                    StyleBox[
                    TagBox[
                    GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "2.6838960980534186`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "1.0629742272458795`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.2560332098249449`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "0.654511845589736`"}]}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    RowBox[{"-", "3.244585717985154`"}]}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                   Annotation[#, 
                    Style[
                    Grid[{{
                    Style["max", Bold], 2.6838960980534186`}, {
                    Style["75%", Bold], 1.0629742272458795`}, {
                    Style["median", Bold], 0.2560332098249449}, {
                    Style["25%", Bold], -0.654511845589736}, {
                    Style["min", Bold], -3.244585717985154}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                    Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                    "Tooltip"]& ]}, {}}}, {}, {}}}}, {}, {}}}, {{{{{{{{{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {}}, {}}, \
{}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {}}, {}}, {}}, {}}}}, {}}, {}}, {{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxFz38sFAAUB/Bzdn5E7HJ1UZwzzuXEOQk5nGKHusldKZxDRU0/TSZH2bDO
JmqcmJli1eTHZXa0MSsrP/rDcHXTqDs/SvlxNCfnx9ZVW733tre3zx/v7X3p
564L04gEAkHwp//O6HzCGpEwGkr4V4UzDPfkNnR3pCChJ2EMzNpd+zqrUwW2
VviWfclQg4e16YwB9QS4qSG99a16BvdJwxpZiw4sWou/PS7fAufbaXKEA0Te
f+etOPu/YFiAa4QersrtnWBKaadJaRcZfJkdaPHgOQW892U/ebScCjbqrspD
jjqAsy9tHjRhO4IZlY95q4s08MMYJstWQAenGDLDYvpcwPycKPmz/a7g9ZqK
VfcqN/BJVopqwMwdPFjVs5yfzASTGkv2JKkP4P27s9JTHBa4yLp9IbvVExxr
avJJSfMCc1VaSyupNziHXtPQf4sN1kbIxGSmD7iuMeDj4nt08GhjfGI5B7w0
L8qN4/qCCz701s9toC8a5otJHYfAErMky3aJHzhwrqRyxf4w2KVju6d7CJ3a
xX5KuemP+Uqd5KZeAWDlCRH9ziT6nYanLKsOxP/E2V+Z/CPgNLsr40I9uq92
3whZEQT2tNmVJhZzwVJhH4FrHwx2GuEkNavQY/6LZ54UhGDeTPFZ36BQsHU1
xSBYQBdL+S3b0Tywnjz92aEJnUGr1xp/ob+bWUwVEcLw/nLmlDkRfaE3YtqW
hJYk6mZoVujYau5cKBUdYDu5VOCN7loP15n6oP00Cp2Mg+a0FS7f90N7Hvf4
8SgI7SzL1b/io+uvzeqPRaEd4wRrg9FoBzf6zxEBmvJmaF0rQlc0cwznT6PJ
FXWGb3Fom9QbGyvx6HuRExtZiegd7PBNgxhdQlVs5knQ5kbqljEZ/Ru3Fwx3

               "]]}, Annotation[#, "Charting`Private`Tag$24029#1"]& ], 
            TagBox[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[1.6], 
               GrayLevel[0], 
               Dashing[{Small, Small}]], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7VXD8IWJ4YI9Axh8sF+xMG3NkauP4Hxt1rP32le/
hfODv0TWXp/yC86vEb5XHnSMyQHGr36vYL5ejQPOnxGkpbLlNy+cL9K9lbF7
myCcn21gyTFhpQicL7H9qOCFPnE4///b3Cl2TlJwfmnGT11GA1k4X23yAodP
r+Xh/Gn+Gtr8vopwfsL3Qkf/g0pwvnu555RlMipw/rcZkz6pT1WF8wO0Ey4d
Y1OH849P3f2uJl4Dzmdd1CEWe1UTYX7b46oQI204v5lnw6vSNTpwfiAz450t
8npwvs2l+5zcVfpwfrnijIVHKwzg/Puu7TGCGoZw/pxFFjdeX0bwbS8siozu
M4Lz37wMrgyzMYbz66/snffsB4Kf/v1lC+smEzg/ji2Wc0OcKZxv+axj8ntJ
MzhfadPv3btOIPiJ2wyWipSYI/zXLTeFWc8Czt/iE6xYdxvBP3nPYUvvdEuE
+2JKn2q4W8H5qcI514M+I/gHZ0mfF1xnDefr8AmlxsTYwPlVQQcZbCRt4Xy5
80axqy4h+BfNX4cvqbdD+LcwJsLY2h7O55ku8t33FYLfUuW++reXA5z/WfDh
XakVCH6W/Lz7//8h+Bb8t9/U6zvC+ez/xX/9j0fwAT9m8Jc=
               "]]}, 
             Annotation[#, "Charting`Private`Tag$24029#2"]& ]}}, {}}}, {
        Epilog -> {
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox[
                  "\"Efficient Non-behavioral\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Efficient Non-behavioral", 12]]], TraditionalForm]], {
            3, -0.5}], 
           InsetBox[
            BoxData[
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Random\"", 12, StripOnInput -> False], 
                  TextForm]], "InlineText"], 
               Text[
                Style["Random", 12]]], TraditionalForm]], {1, 1.5}], 
           InsetBox[
            GraphicsBox[{
              GrayLevel[0.5], 
              RectangleBox[{0, 0}, {3, 1}]}], {1, -1.0940764948197255`}, {1.5,
             0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 0.5, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {2, 0.}, {1.5, 0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {3, 1.350720756376404}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0.7777777777777778, 
               NCache[
                Rational[5, 9], 0.5555555555555556], 0.7777777777777778], 
              RectangleBox[{0, 0}, {3, 1}]}], {4, -3.6795072091547882`}, {1.5,
             0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[1, 1, 0], 
              RectangleBox[{0, 0}, {3, 1}]}], {5, 1.3416816644649612`}, {1.5, 
            0.5}, 1.25], 
           InsetBox[
            GraphicsBox[{
              RGBColor[0, 0, 1], 
              RectangleBox[{0, 0}, {3, 1}]}], {6, 1.7348941628301084`}, {1.5, 
            0.5}, 1.25]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False},
          AxesLabel -> {None, None}, 
         AxesOrigin -> {-1.2000000000000002`, -14.245116807566026`}, Frame -> 
         True, FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
         GrayLevel[0], FrameTicks -> {{Automatic, Automatic}, {{{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Observed\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Observed", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Democracy\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Democracy", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Community\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Community", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
              FormBox[
               InterpretationBox[
                Cell[
                 BoxData[
                  FormBox[
                   StyleBox["\"Despotism\"", 17, 
                    GrayLevel[0], StripOnInput -> False], TextForm]], 
                 "InlineText"], 
                Text[
                 Style["Despotism", 17, 
                  GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             2., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             3., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             4., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             5., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             6., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             7., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             11., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             12., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             13., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             14., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             15., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             16., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             9.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             20., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             21., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             22., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             23., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             24., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             25., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             18.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {28., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             29., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             30., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             31., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             32., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             33., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             34., 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
             27.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {0.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
              FormBox[
               TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Large, PlotRange -> {-10, 9}, 
         PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {{{1., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {7.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {4., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Observed\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Observed", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {10., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            11., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            12., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            13., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            14., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            15., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            16., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            9.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {16.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {13., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Democracy\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Democracy", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {19., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            20., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            21., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            22., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            23., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            24., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            25., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            18.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {25.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Community\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Community", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {28., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            29., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            30., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            31., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            32., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            33., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            34., 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
            27.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
             FormBox[
              InterpretationBox[
               Cell[
                BoxData[
                 FormBox[
                  StyleBox["\"Despotism\"", 17, 
                   GrayLevel[0], StripOnInput -> False], TextForm]], 
                "InlineText"], 
               Text[
                Style["Despotism", 17, 
                 GrayLevel[0]]]], TraditionalForm], {0, 0}}, {0.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {34.5, 
             FormBox[
              TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
           Automatic}}], 
       FormBox[
        FormBox[
         TemplateBox[{
          "\"Dotty\"", "\"Hook\"", "\"Linda\"", "\"Lodge\"", "\"Nyayo\"", 
           "\"Viola\""}, "SwatchLegend", DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.7777777777777778, 
                    NCache[
                    Rational[5, 9], 0.5555555555555556], 0.7777777777777778]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.5185185185185186, 0.37037037037037035`, 
                    0.5185185185185186], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.7777777777777778`", ",", 
                    FractionBox["5", "9"], ",", "0.7777777777777778`"}], 
                    "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.7777777777777778, 
                    Rational[5, 9], 0.7777777777777778], Editable -> False, 
                    Selectable -> False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], 
                    "}"}]}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "None", "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic", ",", "Automatic", ",", "Automatic"}], 
                    "}"}]}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]}, "Legended", 
      DisplayFunction -> (GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ), 
      InterpretationFunction -> (RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& ), Editable -> True], 
     RotationBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"   More Efficient                                          Less \
Efficient\"", Italic, 
           RGBColor[1, 0, 0], 15, StripOnInput -> False], TextForm]], 
        "InlineText"], 
       Text[
        Style[
        "   More Efficient                                          Less \
Efficient", Italic, 
         RGBColor[1, 0, 0], 15]]], BoxRotation -> 1.5707963267948966`]}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 2}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )], 
   RotationBox[
    InterpretationBox[
     Cell[
      BoxData[
       FormBox[
        StyleBox[
        "\"Scaled Mean Betweenness\\nCentrality of Maintained Bonds\"", 21, 
         TextAlignment -> Center, StripOnInput -> False], TextForm]], 
      "InlineText"], 
     Text[
      Style[
      "Scaled Mean Betweenness\nCentrality of Maintained Bonds", 21, 
       TextAlignment -> Center]]], BoxRotation -> 1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8400943775880556`*^9, 3.8400944094635715`*^9, 
  3.8400945256815376`*^9},
 CellLabel->
  "Out[820]=",ExpressionUUID->"a41c19f6-313c-4f00-9d69-abd2c9a0fdfb"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Percent Correct", "Subsection",
 CellChangeTimes->{{3.8235925757025185`*^9, 3.823592578221815*^9}, {
  3.8235933790635824`*^9, 3.8235933845943413`*^9}, {3.8235941397534943`*^9, 
  3.823594140919758*^9}, {3.8235945857975097`*^9, 3.8235945982351165`*^9}, {
  3.823595173461299*^9, 3.823595174926857*^9}, {3.830250622668856*^9, 
  3.8302506249415455`*^9}},ExpressionUUID->"9e598715-7ccc-4eda-bbba-\
15f20942b62f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure5", "=", 
  RowBox[{"Labeled", "[", 
   RowBox[{
    RowBox[{"BoxWhiskerChart", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"sparsdottycorr", ",", 
          RowBox[{"dottydemoc", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"dottycomm", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"dottydespot", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"dottyrand", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"sparshookcorr", ",", 
          RowBox[{"hookdemoc", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"hookcomm", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"hookdespot", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"hookrand", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"sparslindacorr", ",", 
          RowBox[{"lindademoc", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"lindacomm", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"lindadespot", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"lindarand", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"sparslodgecorr", ",", 
          RowBox[{"lodgedemoc", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"lodgecomm", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"lodgedespot", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"lodgerand", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"sparsnyayocorr", ",", 
          RowBox[{"nyayodemoc", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"nyayocomm", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"nyayodespot", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"nyayorand", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"sparsviolacorr", ",", 
          RowBox[{"violademoc", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"violacomm", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"violadespot", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"violarand", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"sparsvoguecorr", ",", 
          RowBox[{"voguedemoc", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"voguecomm", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"voguedespot", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}], ",", 
          RowBox[{"voguerand", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], "}"}]}], 
       "}"}], "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Outliers\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<MedianMarker\>\"", ",", "1", ",", 
          RowBox[{"Directive", "[", 
           RowBox[{"Black", ",", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
      RowBox[{"ChartLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Sparsest Cut\>\"", ",", "\"\<Democracy\>\"", ",", 
         "\"\<Community\>\"", ",", "\"\<Despotism\>\"", ",", 
         "\"\<Random\>\""}], "}"}]}], ",", 
      RowBox[{"ChartLabels", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Dotty\>\"", ",", "Black", ",", "18"}], "]"}], "]"}],
            ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Hook\>\"", ",", "Black", ",", "18"}], "]"}], "]"}], 
           ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Linda\>\"", ",", "Black", ",", "18"}], "]"}], "]"}],
            ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Lodge\>\"", ",", "Black", ",", "18"}], "]"}], "]"}],
            ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Nyayo\>\"", ",", "Black", ",", "18"}], "]"}], "]"}],
            ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Viola\>\"", ",", "Black", ",", "18"}], "]"}], "]"}],
            ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Vogue\>\"", ",", "Black", ",", "18"}], "]"}], 
            "]"}]}], "}"}], ",", "None"}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ChartStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Blue", ",", "Green", ",", "Red", ",", "Gray"}],
         "}"}]}], ",", 
      RowBox[{"BarSpacing", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"None", ",", "2"}], "}"}]}], ",", 
      RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Black", ",", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"sparsdottycorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "0.6"}], "}"}], ",", "1.25"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Black", ",", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", 
             RowBox[{"sparshookcorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "0.55"}], "}"}], ",", "1.25"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Black", ",", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"15", ",", 
             RowBox[{"sparslindacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "0.575"}], "}"}], ",", "1.25"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Black", ",", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"22", ",", 
             RowBox[{"sparslodgecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "0.6"}], "}"}], ",", "1.25"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Black", ",", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"29", ",", 
             RowBox[{"sparsnyayocorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "0.575"}], "}"}], ",", "1.25"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Black", ",", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"36", ",", 
             RowBox[{"sparsviolacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "0.6"}], "}"}], ",", "1.25"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Black", ",", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"43", ",", 
             RowBox[{"sparsvoguecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.7", ",", "0.575"}], "}"}], ",", "1.25"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"Text", "[", "\"\<Percent Correct\>\"", "]"}], ",", "21"}], 
       "]"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", "Left"}], "]"}]}]], "Input",
 CellLabel->
  "In[821]:=",ExpressionUUID->"e0b21f40-7859-4990-bde8-9a98c1bddb09"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
     GraphicsBox[{{
        CapForm[None], 
        Directive[
         RGBColor[0.982864, 0.7431472, 0.3262672]], {{}, {{{{}, {{}, {{
               Directive[
                GrayLevel[0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{0.5, 0.62}, {1.5, 0.62}, {1.5, 0.62}, {0.5, 
                    0.62}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1., 0.62}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{1.5, 0.62}, {0.5, 0.62}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1., 0.62}, {1., 0.62}}, {{1., 0.62}, {1., 
                    0.62}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{1.25, 0.62}, {0.75, 0.62}}, {{1.25, 0.62}, {
                    0.75, 0.62}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.62`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.62}, {
                    Style["75%", Bold], 0.62}, {
                    Style["median", Bold], 0.62}, {
                    Style["25%", Bold], 0.62}, {
                    Style["min", Bold], 0.62}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 0, 1]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{1.5, 0.6461538461538462}, {2.5, 
                    0.6461538461538462}, {2.5, 0.5615384615384615}, {1.5, 
                    0.5615384615384615}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{2.5, 0.5961538461538461}, {1.5, 
                    0.5961538461538461}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2., 0.5615384615384615}, {2., 
                    0.49230769230769234`}}, {{2., 0.6461538461538462}, {2., 
                    0.7384615384615385}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{2.25, 0.49230769230769234`}, {1.75, 
                    0.49230769230769234`}}, {{2.25, 0.7384615384615385}, {
                    1.75, 0.7384615384615385}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7384615384615385`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6461538461538462`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5961538461538461`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5615384615384615`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.49230769230769234`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7384615384615385}, {
                    Style["75%", Bold], 0.6461538461538462}, {
                    Style["median", Bold], 0.5961538461538461}, {
                    Style["25%", Bold], 0.5615384615384615}, {
                    Style["min", Bold], 0.49230769230769234`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 1, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{2.5, 0.7153846153846154}, {3.5, 
                    0.7153846153846154}, {3.5, 0.5538461538461539}, {2.5, 
                    0.5538461538461539}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{3.5, 0.5923076923076923}, {2.5, 
                    0.5923076923076923}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3., 0.5538461538461539}, {3., 
                    0.5307692307692308}}, {{3., 0.7153846153846154}, {3., 
                    0.7153846153846154}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{3.25, 0.5307692307692308}, {2.75, 
                    0.5307692307692308}}, {{3.25, 0.7153846153846154}, {2.75, 
                    0.7153846153846154}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7153846153846154`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7153846153846154`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5923076923076923`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5538461538461539`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5307692307692308`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7153846153846154}, {
                    Style["75%", Bold], 0.7153846153846154}, {
                    Style["median", Bold], 0.5923076923076923}, {
                    Style["25%", Bold], 0.5538461538461539}, {
                    Style["min", Bold], 0.5307692307692308}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[1, 0, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{3.5, 0.5615384615384615}, {4.5, 
                    0.5615384615384615}, {4.5, 0.49230769230769234`}, {3.5, 
                    0.49230769230769234`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{4.5, 0.5384615384615384}, {3.5, 
                    0.5384615384615384}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4., 0.49230769230769234`}, {4., 
                    0.43846153846153846`}}, {{4., 0.5615384615384615}, {4., 
                    0.6384615384615384}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{4.25, 0.43846153846153846`}, {3.75, 
                    0.43846153846153846`}}, {{4.25, 0.6384615384615384}, {
                    3.75, 0.6384615384615384}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6384615384615384`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5615384615384615`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5384615384615384`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.49230769230769234`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.43846153846153846`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6384615384615384}, {
                    Style["75%", Bold], 0.5615384615384615}, {
                    Style["median", Bold], 0.5384615384615384}, {
                    Style["25%", Bold], 0.49230769230769234`}, {
                    Style["min", Bold], 0.43846153846153846`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                GrayLevel[0.5]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{4.5, 0.5230769230769231}, {5.5, 
                    0.5230769230769231}, {5.5, 0.46923076923076923`}, {4.5, 
                    0.46923076923076923`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5., 0.6076923076923076}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5., 0.6538461538461539}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{5.5, 0.49615384615384617`}, {4.5, 
                    0.49615384615384617`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5., 0.46923076923076923`}, {5., 
                    0.3923076923076923}}, {{5., 0.5230769230769231}, {5., 
                    0.5923076923076923}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{5.25, 0.3923076923076923}, {4.75, 
                    0.3923076923076923}}, {{5.25, 0.5923076923076923}, {4.75, 
                    0.5923076923076923}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6538461538461539`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5230769230769231`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.49615384615384617`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.46923076923076923`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.3923076923076923`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6538461538461539}, {
                    Style["75%", Bold], 0.5230769230769231}, {
                    Style["median", Bold], 0.49615384615384617`}, {
                    Style["25%", Bold], 0.46923076923076923`}, {
                    Style["min", Bold], 0.3923076923076923}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                 "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
               Directive[
                GrayLevel[0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{7.5, 0.42}, {8.5, 0.42}, {8.5, 0.42}, {7.5, 
                    0.42}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8., 0.42}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{8.5, 0.42}, {7.5, 0.42}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{8., 0.42}, {8., 0.42}}, {{8., 0.42}, {8., 
                    0.42}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{8.25, 0.42}, {7.75, 0.42}}, {{8.25, 0.42}, {
                    7.75, 0.42}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.42`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.42`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.42`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.42`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.42`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.42}, {
                    Style["75%", Bold], 0.42}, {
                    Style["median", Bold], 0.42}, {
                    Style["25%", Bold], 0.42}, {
                    Style["min", Bold], 0.42}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 0, 1]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{8.5, 0.4247787610619469}, {9.5, 
                    0.4247787610619469}, {9.5, 0.35398230088495575`}, {8.5, 
                    0.35398230088495575`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    9., 0.23008849557522124`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    9., 0.23008849557522124`}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{9.5, 0.38495575221238937`}, {8.5, 
                    0.38495575221238937`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{9., 0.35398230088495575`}, {9., 
                    0.24778761061946902`}}, {{9., 0.4247787610619469}, {9., 
                    0.5132743362831859}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{9.25, 0.24778761061946902`}, {8.75, 
                    0.24778761061946902`}}, {{9.25, 0.5132743362831859}, {
                    8.75, 0.5132743362831859}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.5132743362831859`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.4247787610619469`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.38495575221238937`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.35398230088495575`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.23008849557522124`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.5132743362831859}, {
                    Style["75%", Bold], 0.4247787610619469}, {
                    Style["median", Bold], 0.38495575221238937`}, {
                    Style["25%", Bold], 0.35398230088495575`}, {
                    Style["min", Bold], 0.23008849557522124`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 1, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{9.5, 0.3893805309734513}, {10.5, 
                    0.3893805309734513}, {10.5, 0.25663716814159293`}, {9.5, 
                    0.25663716814159293`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{10.5, 0.35398230088495575`}, {9.5, 
                    0.35398230088495575`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10., 0.25663716814159293`}, {10., 
                    0.19469026548672566`}}, {{10., 0.3893805309734513}, {10., 
                    0.5132743362831859}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{10.25, 0.19469026548672566`}, {9.75, 
                    0.19469026548672566`}}, {{10.25, 0.5132743362831859}, {
                    9.75, 0.5132743362831859}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.5132743362831859`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.3893805309734513`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.35398230088495575`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.25663716814159293`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.19469026548672566`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.5132743362831859}, {
                    Style["75%", Bold], 0.3893805309734513}, {
                    Style["median", Bold], 0.35398230088495575`}, {
                    Style["25%", Bold], 0.25663716814159293`}, {
                    Style["min", Bold], 0.19469026548672566`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[1, 0, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{10.5, 0.5221238938053098}, {11.5, 
                    0.5221238938053098}, {11.5, 0.45132743362831856`}, {10.5, 
                    0.45132743362831856`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{11.5, 0.48672566371681414`}, {10.5, 
                    0.48672566371681414`}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11., 0.45132743362831856`}, {11., 
                    0.40707964601769914`}}, {{11., 0.5221238938053098}, {11., 
                    0.6017699115044248}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{11.25, 0.40707964601769914`}, {10.75, 
                    0.40707964601769914`}}, {{11.25, 0.6017699115044248}, {
                    10.75, 0.6017699115044248}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6017699115044248`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5221238938053098`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.48672566371681414`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.45132743362831856`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.40707964601769914`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6017699115044248}, {
                    Style["75%", Bold], 0.5221238938053098}, {
                    Style["median", Bold], 0.48672566371681414`}, {
                    Style["25%", Bold], 0.45132743362831856`}, {
                    Style["min", Bold], 0.40707964601769914`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                GrayLevel[0.5]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{11.5, 0.5309734513274337}, {12.5, 
                    0.5309734513274337}, {12.5, 0.46017699115044247`}, {11.5, 
                    0.46017699115044247`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{12.5, 0.5}, {11.5, 0.5}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12., 0.46017699115044247`}, {12., 
                    0.3893805309734513}}, {{12., 0.5309734513274337}, {12., 
                    0.5929203539823009}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{12.25, 0.3893805309734513}, {11.75, 
                    0.3893805309734513}}, {{12.25, 0.5929203539823009}, {
                    11.75, 0.5929203539823009}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.5929203539823009`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5309734513274337`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.46017699115044247`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.3893805309734513`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.5929203539823009}, {
                    Style["75%", Bold], 0.5309734513274337}, {
                    Style["median", Bold], 0.5}, {
                    Style["25%", Bold], 0.46017699115044247`}, {
                    Style["min", Bold], 0.3893805309734513}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                 "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
               Directive[
                GrayLevel[0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{14.5, 0.56}, {15.5, 0.56}, {15.5, 0.56}, {
                    14.5, 0.56}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {15., 0.56}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{15.5, 0.56}, {14.5, 0.56}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15., 0.56}, {15., 0.56}}, {{15., 0.56}, {15., 
                    0.56}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{15.25, 0.56}, {14.75, 0.56}}, {{15.25, 0.56}, {
                    14.75, 0.56}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.56`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.56}, {
                    Style["75%", Bold], 0.56}, {
                    Style["median", Bold], 0.56}, {
                    Style["25%", Bold], 0.56}, {
                    Style["min", Bold], 0.56}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 0, 1]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{15.5, 0.6428571428571429}, {16.5, 
                    0.6428571428571429}, {16.5, 0.5892857142857143}, {15.5, 
                    0.5892857142857143}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    16., 0.7321428571428571}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{16.5, 0.6116071428571428}, {15.5, 
                    0.6116071428571428}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16., 0.5892857142857143}, {16., 
                    0.5267857142857143}}, {{16., 0.6428571428571429}, {16., 
                    0.7232142857142857}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{16.25, 0.5267857142857143}, {15.75, 
                    0.5267857142857143}}, {{16.25, 0.7232142857142857}, {
                    15.75, 0.7232142857142857}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7321428571428571`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6428571428571429`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6116071428571428`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5892857142857143`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5267857142857143`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7321428571428571}, {
                    Style["75%", Bold], 0.6428571428571429}, {
                    Style["median", Bold], 0.6116071428571428}, {
                    Style["25%", Bold], 0.5892857142857143}, {
                    Style["min", Bold], 0.5267857142857143}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 1, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{16.5, 0.6919642857142858}, {17.5, 
                    0.6919642857142858}, {17.5, 0.6607142857142857}, {16.5, 
                    0.6607142857142857}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    17., 0.6071428571428571}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    17., 0.6071428571428571}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    17., 0.6071428571428571}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    17., 0.6071428571428571}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    17., 0.6071428571428571}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    17., 0.6071428571428571}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    17., 0.6071428571428571}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{17.5, 0.6607142857142857}, {16.5, 
                    0.6607142857142857}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{17., 0.6607142857142857}, {17., 
                    0.6607142857142857}}, {{17., 0.6919642857142858}, {17., 
                    0.7053571428571429}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{17.25, 0.6607142857142857}, {16.75, 
                    0.6607142857142857}}, {{17.25, 0.7053571428571429}, {
                    16.75, 0.7053571428571429}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7053571428571429`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6919642857142858`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6607142857142857`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6607142857142857`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.6071428571428571`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7053571428571429}, {
                    Style["75%", Bold], 0.6919642857142858}, {
                    Style["median", Bold], 0.6607142857142857}, {
                    Style["25%", Bold], 0.6607142857142857}, {
                    Style["min", Bold], 0.6071428571428571}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[1, 0, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{17.5, 0.5982142857142857}, {18.5, 
                    0.5982142857142857}, {18.5, 0.5178571428571429}, {17.5, 
                    0.5178571428571429}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    18., 0.7321428571428571}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{18.5, 0.5535714285714286}, {17.5, 
                    0.5535714285714286}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{18., 0.5178571428571429}, {18., 
                    0.42857142857142855`}}, {{18., 0.5982142857142857}, {18., 
                    0.6964285714285714}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{18.25, 0.42857142857142855`}, {17.75, 
                    0.42857142857142855`}}, {{18.25, 0.6964285714285714}, {
                    17.75, 0.6964285714285714}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7321428571428571`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5982142857142857`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5535714285714286`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5178571428571429`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.42857142857142855`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7321428571428571}, {
                    Style["75%", Bold], 0.5982142857142857}, {
                    Style["median", Bold], 0.5535714285714286}, {
                    Style["25%", Bold], 0.5178571428571429}, {
                    Style["min", Bold], 0.42857142857142855`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                GrayLevel[0.5]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{18.5, 0.5357142857142857}, {19.5, 
                    0.5357142857142857}, {19.5, 0.4642857142857143}, {18.5, 
                    0.4642857142857143}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{19.5, 0.5089285714285714}, {18.5, 
                    0.5089285714285714}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19., 0.4642857142857143}, {19., 0.375}}, {{19.,
                     0.5357142857142857}, {19., 0.625}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{19.25, 0.375}, {18.75, 0.375}}, {{19.25, 
                    0.625}, {18.75, 0.625}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.625`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5357142857142857`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5089285714285714`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4642857142857143`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.375`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.625}, {
                    Style["75%", Bold], 0.5357142857142857}, {
                    Style["median", Bold], 0.5089285714285714}, {
                    Style["25%", Bold], 0.4642857142857143}, {
                    Style["min", Bold], 0.375}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                 "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
               Directive[
                GrayLevel[0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{21.5, 0.79}, {22.5, 0.79}, {22.5, 0.79}, {
                    21.5, 0.79}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {22., 0.79}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{22.5, 0.79}, {21.5, 0.79}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22., 0.79}, {22., 0.79}}, {{22., 0.79}, {22., 
                    0.79}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{22.25, 0.79}, {21.75, 0.79}}, {{22.25, 0.79}, {
                    21.75, 0.79}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.79`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.79`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.79`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.79`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.79`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.79}, {
                    Style["75%", Bold], 0.79}, {
                    Style["median", Bold], 0.79}, {
                    Style["25%", Bold], 0.79}, {
                    Style["min", Bold], 0.79}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 0, 1]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{22.5, 0.7611940298507462}, {23.5, 
                    0.7611940298507462}, {23.5, 0.6716417910447762}, {22.5, 
                    0.6716417910447762}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    23., 0.5074626865671642}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{23.5, 0.7313432835820896}, {22.5, 
                    0.7313432835820896}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23., 0.6716417910447762}, {23., 
                    0.582089552238806}}, {{23., 0.7611940298507462}, {23., 
                    0.8805970149253731}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{23.25, 0.582089552238806}, {22.75, 
                    0.582089552238806}}, {{23.25, 0.8805970149253731}, {22.75,
                     0.8805970149253731}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8805970149253731`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7611940298507462`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7313432835820896`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6716417910447762`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5074626865671642`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.8805970149253731}, {
                    Style["75%", Bold], 0.7611940298507462}, {
                    Style["median", Bold], 0.7313432835820896}, {
                    Style["25%", Bold], 0.6716417910447762}, {
                    Style["min", Bold], 0.5074626865671642}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 1, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{23.5, 0.7910447761194029}, {24.5, 
                    0.7910447761194029}, {24.5, 0.746268656716418}, {23.5, 
                    0.746268656716418}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{24.5, 0.7761194029850746}, {23.5, 
                    0.7761194029850746}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24., 0.746268656716418}, {24., 
                    0.7313432835820896}}, {{24., 0.7910447761194029}, {24., 
                    0.835820895522388}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{24.25, 0.7313432835820896}, {23.75, 
                    0.7313432835820896}}, {{24.25, 0.835820895522388}, {23.75,
                     0.835820895522388}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.835820895522388`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7910447761194029`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.7761194029850746`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.746268656716418`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.7313432835820896`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.835820895522388}, {
                    Style["75%", Bold], 0.7910447761194029}, {
                    Style["median", Bold], 0.7761194029850746}, {
                    Style["25%", Bold], 0.746268656716418}, {
                    Style["min", Bold], 0.7313432835820896}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[1, 0, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{24.5, 0.7313432835820896}, {25.5, 
                    0.7313432835820896}, {25.5, 0.6343283582089552}, {24.5, 
                    0.6343283582089552}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{25.5, 0.6716417910447762}, {24.5, 
                    0.6716417910447762}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25., 0.6343283582089552}, {25., 
                    0.5671641791044776}}, {{25., 0.7313432835820896}, {25., 
                    0.8059701492537313}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{25.25, 0.5671641791044776}, {24.75, 
                    0.5671641791044776}}, {{25.25, 0.8059701492537313}, {
                    24.75, 0.8059701492537313}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.8059701492537313`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.7313432835820896`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6716417910447762`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.6343283582089552`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5671641791044776`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.8059701492537313}, {
                    Style["75%", Bold], 0.7313432835820896}, {
                    Style["median", Bold], 0.6716417910447762}, {
                    Style["25%", Bold], 0.6343283582089552}, {
                    Style["min", Bold], 0.5671641791044776}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                GrayLevel[0.5]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{25.5, 0.5447761194029851}, {26.5, 
                    0.5447761194029851}, {26.5, 0.4626865671641791}, {25.5, 
                    0.4626865671641791}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    26., 0.7014925373134329}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    26., 0.6716417910447762}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{26.5, 0.5074626865671642}, {25.5, 
                    0.5074626865671642}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{26., 0.4626865671641791}, {26., 
                    0.40298507462686567`}}, {{26., 0.5447761194029851}, {26., 
                    0.6567164179104478}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{26.25, 0.40298507462686567`}, {25.75, 
                    0.40298507462686567`}}, {{26.25, 0.6567164179104478}, {
                    25.75, 0.6567164179104478}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7014925373134329`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5447761194029851`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5074626865671642`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4626865671641791`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.40298507462686567`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7014925373134329}, {
                    Style["75%", Bold], 0.5447761194029851}, {
                    Style["median", Bold], 0.5074626865671642}, {
                    Style["25%", Bold], 0.4626865671641791}, {
                    Style["min", Bold], 0.40298507462686567`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                 "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
               Directive[
                GrayLevel[0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{28.5, 0.56}, {29.5, 0.56}, {29.5, 0.56}, {
                    28.5, 0.56}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {29., 0.56}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{29.5, 0.56}, {28.5, 0.56}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29., 0.56}, {29., 0.56}}, {{29., 0.56}, {29., 
                    0.56}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{29.25, 0.56}, {28.75, 0.56}}, {{29.25, 0.56}, {
                    28.75, 0.56}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.56`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.56`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.56}, {
                    Style["75%", Bold], 0.56}, {
                    Style["median", Bold], 0.56}, {
                    Style["25%", Bold], 0.56}, {
                    Style["min", Bold], 0.56}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 0, 1]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{29.5, 0.5952380952380952}, {30.5, 
                    0.5952380952380952}, {30.5, 0.5306122448979592}, {29.5, 
                    0.5306122448979592}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{30.5, 0.564625850340136}, {29.5, 
                    0.564625850340136}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30., 0.5306122448979592}, {30., 
                    0.46938775510204084`}}, {{30., 0.5952380952380952}, {30., 
                    0.6598639455782312}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{30.25, 0.46938775510204084`}, {29.75, 
                    0.46938775510204084`}}, {{30.25, 0.6598639455782312}, {
                    29.75, 0.6598639455782312}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6598639455782312`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5952380952380952`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.564625850340136`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5306122448979592`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.46938775510204084`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6598639455782312}, {
                    Style["75%", Bold], 0.5952380952380952}, {
                    Style["median", Bold], 0.564625850340136}, {
                    Style["25%", Bold], 0.5306122448979592}, {
                    Style["min", Bold], 0.46938775510204084`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 1, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{30.5, 0.5918367346938775}, {31.5, 
                    0.5918367346938775}, {31.5, 0.5442176870748299}, {30.5, 
                    0.5442176870748299}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 0.6802721088435374}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 0.6802721088435374}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 0.6666666666666666}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 0.6802721088435374}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 0.6802721088435374}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 0.6802721088435374}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    31., 0.6666666666666666}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{31.5, 0.5680272108843537}, {30.5, 
                    0.5680272108843537}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31., 0.5442176870748299}, {31., 
                    0.48299319727891155`}}, {{31., 0.5918367346938775}, {31., 
                    0.6394557823129252}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{31.25, 0.48299319727891155`}, {30.75, 
                    0.48299319727891155`}}, {{31.25, 0.6394557823129252}, {
                    30.75, 0.6394557823129252}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6802721088435374`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5918367346938775`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5680272108843537`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5442176870748299`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.48299319727891155`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6802721088435374}, {
                    Style["75%", Bold], 0.5918367346938775}, {
                    Style["median", Bold], 0.5680272108843537}, {
                    Style["25%", Bold], 0.5442176870748299}, {
                    Style["min", Bold], 0.48299319727891155`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[1, 0, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{31.5, 0.5306122448979592}, {32.5, 
                    0.5306122448979592}, {32.5, 0.46258503401360546`}, {31.5, 
                    0.46258503401360546`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{32.5, 0.5034013605442177}, {31.5, 
                    0.5034013605442177}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32., 0.46258503401360546`}, {32., 
                    0.4013605442176871}}, {{32., 0.5306122448979592}, {32., 
                    0.5782312925170068}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{32.25, 0.4013605442176871}, {31.75, 
                    0.4013605442176871}}, {{32.25, 0.5782312925170068}, {
                    31.75, 0.5782312925170068}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.5782312925170068`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5306122448979592`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5034013605442177`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.46258503401360546`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.4013605442176871`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.5782312925170068}, {
                    Style["75%", Bold], 0.5306122448979592}, {
                    Style["median", Bold], 0.5034013605442177}, {
                    Style["25%", Bold], 0.46258503401360546`}, {
                    Style["min", Bold], 0.4013605442176871}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                GrayLevel[0.5]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{32.5, 0.5374149659863946}, {33.5, 
                    0.5374149659863946}, {33.5, 0.47619047619047616`}, {32.5, 
                    0.47619047619047616`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    33., 0.6394557823129252}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{33.5, 0.5034013605442177}, {32.5, 
                    0.5034013605442177}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33., 0.47619047619047616`}, {33., 
                    0.40816326530612246`}}, {{33., 0.5374149659863946}, {33., 
                    0.6190476190476191}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{33.25, 0.40816326530612246`}, {32.75, 
                    0.40816326530612246`}}, {{33.25, 0.6190476190476191}, {
                    32.75, 0.6190476190476191}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6394557823129252`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5374149659863946`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5034013605442177`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.47619047619047616`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.40816326530612246`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6394557823129252}, {
                    Style["75%", Bold], 0.5374149659863946}, {
                    Style["median", Bold], 0.5034013605442177}, {
                    Style["25%", Bold], 0.47619047619047616`}, {
                    Style["min", Bold], 0.40816326530612246`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                 "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
               Directive[
                GrayLevel[0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{35.5, 0.62}, {36.5, 0.62}, {36.5, 0.62}, {
                    35.5, 0.62}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {36., 0.62}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{36.5, 0.62}, {35.5, 0.62}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{36., 0.62}, {36., 0.62}}, {{36., 0.62}, {36., 
                    0.62}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{36.25, 0.62}, {35.75, 0.62}}, {{36.25, 0.62}, {
                    35.75, 0.62}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.62`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.62`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.62}, {
                    Style["75%", Bold], 0.62}, {
                    Style["median", Bold], 0.62}, {
                    Style["25%", Bold], 0.62}, {
                    Style["min", Bold], 0.62}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 0, 1]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{36.5, 0.6111111111111112}, {37.5, 
                    0.6111111111111112}, {37.5, 0.5444444444444444}, {36.5, 
                    0.5444444444444444}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{37.5, 0.5777777777777777}, {36.5, 
                    0.5777777777777777}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{37., 0.5444444444444444}, {37., 
                    0.4444444444444444}}, {{37., 0.6111111111111112}, {37., 
                    0.6666666666666666}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{37.25, 0.4444444444444444}, {36.75, 
                    0.4444444444444444}}, {{37.25, 0.6666666666666666}, {
                    36.75, 0.6666666666666666}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6666666666666666`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6111111111111112`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5777777777777777`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5444444444444444`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.4444444444444444`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6666666666666666}, {
                    Style["75%", Bold], 0.6111111111111112}, {
                    Style["median", Bold], 0.5777777777777777}, {
                    Style["25%", Bold], 0.5444444444444444}, {
                    Style["min", Bold], 0.4444444444444444}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 1, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{37.5, 0.5666666666666667}, {38.5, 
                    0.5666666666666667}, {38.5, 0.5555555555555556}, {37.5, 
                    0.5555555555555556}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.5222222222222223}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.5222222222222223}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.5222222222222223}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6111111111111112}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6222222222222222}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6111111111111112}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6111111111111112}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6111111111111112}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6111111111111112}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6111111111111112}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6222222222222222}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6111111111111112}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {38., 0.6}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{38.5, 0.5666666666666667}, {37.5, 
                    0.5666666666666667}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{38., 0.5555555555555556}, {38., 
                    0.5444444444444444}}, {{38., 0.5666666666666667}, {38., 
                    0.5777777777777777}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{38.25, 0.5444444444444444}, {37.75, 
                    0.5444444444444444}}, {{38.25, 0.5777777777777777}, {
                    37.75, 0.5777777777777777}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6222222222222222`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5666666666666667`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5666666666666667`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5555555555555556`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5222222222222223`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6222222222222222}, {
                    Style["75%", Bold], 0.5666666666666667}, {
                    Style["median", Bold], 0.5666666666666667}, {
                    Style["25%", Bold], 0.5555555555555556}, {
                    Style["min", Bold], 0.5222222222222223}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[1, 0, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{38.5, 0.5555555555555556}, {39.5, 
                    0.5555555555555556}, {39.5, 0.4888888888888889}, {38.5, 
                    0.4888888888888889}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    39., 0.37777777777777777`}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    39., 0.7111111111111111}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{39.5, 0.5222222222222223}, {38.5, 
                    0.5222222222222223}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{39., 0.4888888888888889}, {39., 
                    0.4222222222222222}}, {{39., 0.5555555555555556}, {39., 
                    0.6555555555555556}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{39.25, 0.4222222222222222}, {38.75, 
                    0.4222222222222222}}, {{39.25, 0.6555555555555556}, {
                    38.75, 0.6555555555555556}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7111111111111111`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5555555555555556`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5222222222222223`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4888888888888889`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.37777777777777777`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7111111111111111}, {
                    Style["75%", Bold], 0.5555555555555556}, {
                    Style["median", Bold], 0.5222222222222223}, {
                    Style["25%", Bold], 0.4888888888888889}, {
                    Style["min", Bold], 0.37777777777777777`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                GrayLevel[0.5]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{39.5, 0.5333333333333333}, {40.5, 
                    0.5333333333333333}, {40.5, 0.45555555555555555`}, {39.5, 
                    0.45555555555555555`}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{40.5, 0.4888888888888889}, {39.5, 
                    0.4888888888888889}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{40., 0.45555555555555555`}, {40., 
                    0.36666666666666664`}}, {{40., 0.5333333333333333}, {40., 
                    0.6333333333333333}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{40.25, 0.36666666666666664`}, {39.75, 
                    0.36666666666666664`}}, {{40.25, 0.6333333333333333}, {
                    39.75, 0.6333333333333333}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6333333333333333`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5333333333333333`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.4888888888888889`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.45555555555555555`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.36666666666666664`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6333333333333333}, {
                    Style["75%", Bold], 0.5333333333333333}, {
                    Style["median", Bold], 0.4888888888888889}, {
                    Style["25%", Bold], 0.45555555555555555`}, {
                    Style["min", Bold], 0.36666666666666664`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                 "Tooltip"]& ]}}}, {}, {}}}, {{{}, {{}, {{
               Directive[
                GrayLevel[0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{42.5, 0.63}, {43.5, 0.63}, {43.5, 0.63}, {
                    42.5, 0.63}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {43., 0.63}]}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{43.5, 0.63}, {42.5, 0.63}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{43., 0.63}, {43., 0.63}}, {{43., 0.63}, {43., 
                    0.63}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{43.25, 0.63}, {42.75, 0.63}}, {{43.25, 0.63}, {
                    42.75, 0.63}}}]}, {}}]}], "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.63`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.63`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.63`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.63`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.63`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.63}, {
                    Style["75%", Bold], 0.63}, {
                    Style["median", Bold], 0.63}, {
                    Style["25%", Bold], 0.63}, {
                    Style["min", Bold], 0.63}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 0, 1]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{43.5, 0.6260869565217392}, {44.5, 
                    0.6260869565217392}, {44.5, 0.5565217391304348}, {43.5, 
                    0.5565217391304348}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    44., 0.7391304347826086}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{44.5, 0.6}, {43.5, 0.6}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{44., 0.5565217391304348}, {44., 
                    0.46956521739130436`}}, {{44., 0.6260869565217392}, {44., 
                    0.7217391304347827}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{44.25, 0.46956521739130436`}, {43.75, 
                    0.46956521739130436`}}, {{44.25, 0.7217391304347827}, {
                    43.75, 0.7217391304347827}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7391304347826086`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6260869565217392`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5565217391304348`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.46956521739130436`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7391304347826086}, {
                    Style["75%", Bold], 0.6260869565217392}, {
                    Style["median", Bold], 0.6}, {
                    Style["25%", Bold], 0.5565217391304348}, {
                    Style["min", Bold], 0.46956521739130436`}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[0, 1, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{44.5, 0.6434782608695652}, {45.5, 
                    0.6434782608695652}, {45.5, 0.5739130434782609}, {44.5, 
                    0.5739130434782609}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    45., 0.7739130434782608}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    LineBox[{{45.5, 0.6}, {44.5, 0.6}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{45., 0.5739130434782609}, {45., 
                    0.5565217391304348}}, {{45., 0.6434782608695652}, {45., 
                    0.7304347826086957}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{45.25, 0.5565217391304348}, {44.75, 
                    0.5565217391304348}}, {{45.25, 0.7304347826086957}, {
                    44.75, 0.7304347826086957}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.7739130434782608`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.6434782608695652`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.6`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.5739130434782609`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.5565217391304348`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.7739130434782608}, {
                    Style["75%", Bold], 0.6434782608695652}, {
                    Style["median", Bold], 0.6}, {
                    Style["25%", Bold], 0.5739130434782609}, {
                    Style["min", Bold], 0.5565217391304348}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                RGBColor[1, 0, 0]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{45.5, 0.5391304347826087}, {46.5, 
                    0.5391304347826087}, {46.5, 0.4782608695652174}, {45.5, 
                    0.4782608695652174}}], {}, {{}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{46.5, 0.5043478260869565}, {45.5, 
                    0.5043478260869565}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{46., 0.4782608695652174}, {46., 
                    0.391304347826087}}, {{46., 0.5391304347826087}, {46., 
                    0.6260869565217392}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{46.25, 0.391304347826087}, {45.75, 
                    0.391304347826087}}, {{46.25, 0.6260869565217392}, {45.75,
                     0.6260869565217392}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6260869565217392`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5391304347826087`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5043478260869565`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.4782608695652174`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.391304347826087`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6260869565217392}, {
                    Style["75%", Bold], 0.5391304347826087}, {
                    Style["median", Bold], 0.5043478260869565}, {
                    Style["25%", Bold], 0.4782608695652174}, {
                    Style["min", Bold], 0.391304347826087}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], "Tooltip"]& ]}, {
               Directive[
                GrayLevel[0.5]], 
               TagBox[
                TooltipBox[
                 TagBox[
                  DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    GraphicsGroupBox[{Antialiasing -> False, 
                    
                    PolygonBox[{{46.5, 0.5391304347826087}, {47.5, 
                    0.5391304347826087}, {47.5, 0.46956521739130436`}, {46.5, 
                    0.46956521739130436`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    47., 0.6782608695652174}]}, {}}, {}, {
                    GrayLevel[0], 
                    Directive[
                    GrayLevel[0], 
                    Thickness[Large]], 
                    
                    LineBox[{{47.5, 0.5043478260869565}, {46.5, 
                    0.5043478260869565}}]}, {}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{47., 0.46956521739130436`}, {47., 0.4}}, {{47.,
                     0.5391304347826087}, {47., 0.6347826086956522}}}]}, {
                    GrayLevel[0], 
                    GrayLevel[0.5], 
                    
                    LineBox[{{{47.25, 0.4}, {46.75, 0.4}}, {{47.25, 
                    0.6347826086956522}, {46.75, 
                    0.6347826086956522}}}]}, {}}]}], 
                  "DelayedMouseEffectStyle"], 
                 StyleBox[
                  TagBox[
                   GridBox[{{
                    StyleBox["\"max\"", Bold, StripOnInput -> False], 
                    "0.6782608695652174`"}, {
                    StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                    "0.5391304347826087`"}, {
                    StyleBox["\"median\"", Bold, StripOnInput -> False], 
                    "0.5043478260869565`"}, {
                    StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                    "0.46956521739130436`"}, {
                    StyleBox["\"min\"", Bold, StripOnInput -> False], 
                    "0.4`"}}, 
                    GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                    AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                    GridBoxFrame -> {
                    "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}},
                     GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
                Annotation[#, 
                 Style[
                  Grid[{{
                    Style["max", Bold], 0.6782608695652174}, {
                    Style["75%", Bold], 0.5391304347826087}, {
                    Style["median", Bold], 0.5043478260869565}, {
                    Style["25%", Bold], 0.46956521739130436`}, {
                    Style["min", Bold], 0.4}}, Dividers -> {{
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                   Frame -> GrayLevel[0], BaseStyle -> Directive[
                    AbsoluteThickness[1], 
                    Dashing[{}]]], {}], 
                 "Tooltip"]& ]}}}, {}, {}}}}, {}, {}}}, {{{{{{{{{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, \
{}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, \
{}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, {{{{{{{{}, {}}, {}}, {{{}, {}}, \
{}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}}, \
{{{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}}, {}}, {}}, {}}}}, {}}, {}}, {
      DisplayFunction -> Identity, AspectRatio -> 
       NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
       AxesLabel -> {None, None}, AxesOrigin -> {-1.85, 0.16039492801479327`},
        Epilog -> {
         InsetBox[
          GraphicsBox[{
            GrayLevel[0], 
            RectangleBox[{0, 0}, {3, 1}]}], {1, 0.62}, {1.7, 0.6}, 1.25], 
         InsetBox[
          GraphicsBox[{
            GrayLevel[0], 
            RectangleBox[{0, 0}, {3, 1}]}], {8, 0.42}, {1.7, 0.55}, 1.25], 
         InsetBox[
          GraphicsBox[{
            GrayLevel[0], 
            RectangleBox[{0, 0}, {3, 1}]}], {15, 0.56}, {1.7, 0.575}, 1.25], 
         InsetBox[
          GraphicsBox[{
            GrayLevel[0], 
            RectangleBox[{0, 0}, {3, 1}]}], {22, 0.79}, {1.7, 0.6}, 1.25], 
         InsetBox[
          GraphicsBox[{
            GrayLevel[0], 
            RectangleBox[{0, 0}, {3, 1}]}], {29, 0.56}, {1.7, 0.575}, 1.25], 
         InsetBox[
          GraphicsBox[{
            GrayLevel[0], 
            RectangleBox[{0, 0}, {3, 1}]}], {36, 0.62}, {1.7, 0.6}, 1.25], 
         InsetBox[
          GraphicsBox[{
            GrayLevel[0], 
            RectangleBox[{0, 0}, {3, 1}]}], {43, 0.63}, {1.7, 0.575}, 1.25]}, 
       Frame -> True, FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
       GrayLevel[0], FrameTicks -> {{Automatic, Automatic}, {{{1., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {0.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {5.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {3., 
            FormBox[
             InterpretationBox[
              Cell[
               BoxData[
                FormBox[
                 StyleBox["\"Dotty\"", 
                  GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
               "InlineText"], 
              Text[
               Style["Dotty", 
                GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {8., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {9., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {10., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {11., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {12., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {12.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
            FormBox[
             InterpretationBox[
              Cell[
               BoxData[
                FormBox[
                 StyleBox["\"Hook\"", 
                  GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
               "InlineText"], 
              Text[
               Style["Hook", 
                GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {15., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {16., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {17., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {18., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {19., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           14.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {17., 
            FormBox[
             InterpretationBox[
              Cell[
               BoxData[
                FormBox[
                 StyleBox["\"Linda\"", 
                  GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
               "InlineText"], 
              Text[
               Style["Linda", 
                GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {22., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {23., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {24., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {25., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {26., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           21.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {26.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {24., 
            FormBox[
             InterpretationBox[
              Cell[
               BoxData[
                FormBox[
                 StyleBox["\"Lodge\"", 
                  GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
               "InlineText"], 
              Text[
               Style["Lodge", 
                GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {29., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {30., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {31., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {32., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {33., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           28.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {33.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
            FormBox[
             InterpretationBox[
              Cell[
               BoxData[
                FormBox[
                 StyleBox["\"Nyayo\"", 
                  GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
               "InlineText"], 
              Text[
               Style["Nyayo", 
                GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {36., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {37., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {38., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {39., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {40., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           35.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {40.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {38., 
            FormBox[
             InterpretationBox[
              Cell[
               BoxData[
                FormBox[
                 StyleBox["\"Viola\"", 
                  GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
               "InlineText"], 
              Text[
               Style["Viola", 
                GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {43., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {44., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {45., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {46., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {47., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           42.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {47.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {45., 
            FormBox[
             InterpretationBox[
              Cell[
               BoxData[
                FormBox[
                 StyleBox["\"Vogue\"", 
                  GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
               "InlineText"], 
              Text[
               Style["Vogue", 
                GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {0.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {47.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {0.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {5.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {8., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {9., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {10., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {11., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {12., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {12.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {15., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {16., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {17., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {18., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {19., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           14.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {22., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {23., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {24., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {25., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {26., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           21.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {26.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {29., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {30., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {31., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {32., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {33., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           28.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {33.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {36., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {37., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {38., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {39., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {40., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           35.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {40.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {43., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {44., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {45., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {46., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {47., 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
           42.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {47.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {0.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {47.5, 
            FormBox[
             TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Large, PlotRangePadding -> {{
          Scaled[0.05], 
          Scaled[0.05]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {{{1., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {3., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {4., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {5., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {0.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {5.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {3., 
           FormBox[
            InterpretationBox[
             Cell[
              BoxData[
               FormBox[
                StyleBox["\"Dotty\"", 
                 GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
              "InlineText"], 
             Text[
              Style["Dotty", 
               GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {8., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {9., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {10., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {11., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {12., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {7.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {12.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {10., 
           FormBox[
            InterpretationBox[
             Cell[
              BoxData[
               FormBox[
                StyleBox["\"Hook\"", 
                 GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
              "InlineText"], 
             Text[
              Style["Hook", 
               GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {15., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {16., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {17., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {18., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {19., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {14.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {19.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {17., 
           FormBox[
            InterpretationBox[
             Cell[
              BoxData[
               FormBox[
                StyleBox["\"Linda\"", 
                 GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
              "InlineText"], 
             Text[
              Style["Linda", 
               GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {22., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {23., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {24., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {25., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {26., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {21.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {26.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {24., 
           FormBox[
            InterpretationBox[
             Cell[
              BoxData[
               FormBox[
                StyleBox["\"Lodge\"", 
                 GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
              "InlineText"], 
             Text[
              Style["Lodge", 
               GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {29., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {30., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {31., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {32., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {33., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {28.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {33.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {31., 
           FormBox[
            InterpretationBox[
             Cell[
              BoxData[
               FormBox[
                StyleBox["\"Nyayo\"", 
                 GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
              "InlineText"], 
             Text[
              Style["Nyayo", 
               GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {36., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {37., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {38., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {39., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {40., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {35.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {40.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {38., 
           FormBox[
            InterpretationBox[
             Cell[
              BoxData[
               FormBox[
                StyleBox["\"Viola\"", 
                 GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
              "InlineText"], 
             Text[
              Style["Viola", 
               GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {43., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {44., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {45., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {46., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {47., 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {42.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {47.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {45., 
           FormBox[
            InterpretationBox[
             Cell[
              BoxData[
               FormBox[
                StyleBox["\"Vogue\"", 
                 GrayLevel[0], 18, StripOnInput -> False], TextForm]], 
              "InlineText"], 
             Text[
              Style["Vogue", 
               GrayLevel[0], 18]]], TraditionalForm], {0, 0}}, {0.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {47.5, 
           FormBox[
            TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
         Automatic}}], 
     FormBox[
      FormBox[
       TemplateBox[{
        "\"Sparsest Cut\"", "\"Democracy\"", "\"Community\"", "\"Despotism\"",
          "\"Random\""}, "SwatchLegend", DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.33333333333333337`], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    "]"}]}], "}"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}]}], 
               "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", "None", "}"}], ",", 
                   RowBox[{"{", 
                    
                    RowBox[{
                    "Automatic", ",", "Automatic", ",", "Automatic", ",", 
                    "Automatic", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]}, "Legended", 
    DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& ), Editable -> True], 
   RotationBox[
    StyleBox[
     InterpretationBox[
      Cell[
       BoxData[
        FormBox["\"Percent Correct\"", TextForm]], "InlineText"], 
      Text["Percent Correct"]], 21, StripOnInput -> False], BoxRotation -> 
    1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{3.830250627386326*^9, 3.840094378596182*^9, 
  3.840094410416728*^9, 3.8400945266095533`*^9},
 CellLabel->
  "Out[821]=",ExpressionUUID->"0dded28c-1067-4e13-9ff4-c8084faac368"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ANOVA", "Chapter",
 CellChangeTimes->{{3.7459405253365164`*^9, 3.7459405259395866`*^9}, {
  3.8302460960885468`*^9, 3.830246098880521*^9}, {3.8302461980658417`*^9, 
  3.830246199225092*^9}, {3.830246654565133*^9, 3.830246656872785*^9}, {
  3.830250037374686*^9, 3.8302500398217225`*^9}, {3.8441829806991005`*^9, 
  3.8441829809774685`*^9}},ExpressionUUID->"9eaa2181-da55-4171-be2e-\
c193a911db7c"],

Cell[CellGroupData[{

Cell["Setup (run first)", "Section",
 CellChangeTimes->{{3.8432027026704082`*^9, 3.8432027039500303`*^9}, {
  3.8441830111932793`*^9, 
  3.844183032686734*^9}},ExpressionUUID->"3f6a1489-4de5-4aa9-baf8-\
934498c74466"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottymax", "=", "237"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookmax", "=", "90"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindamax", "=", "75"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgemax", "=", "54"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayomax", "=", "121"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violamax", "=", "52"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguemax", "=", "90"}], ";"}]}], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"10c66275-188c-4f0f-8c20-222c9e2003ea"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyperc", "=", "0.44"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookperc", "=", "0.8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindaperc", "=", "0.34"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgeperc", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayoperc", "=", "0.34"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violaperc", "=", "0.38"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vogueperc", "=", "0.34"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7583929037440395`*^9, 3.7583929190306654`*^9}, {
  3.7583929597408967`*^9, 3.7583930828236957`*^9}, {3.788776610516076*^9, 
  3.7887766383744793`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"803e56a5-f9c7-4290-8237-80df9fedbf8c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottybrok", "=", "0.11"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookbrok", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindabrok", "=", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgebrok", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayobrok", "=", "0.12"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violabrok", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguebrok", "=", "0.16"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyspars", "=", "0.44"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookspars", "=", "1.37"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindaspars", "=", "0.38"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgespars", "=", "0.41"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayospars", "=", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violaspars", "=", "0.49"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguespars", "=", "0.7"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottymain", "=", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookmain", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindamain", "=", "0.26"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgemain", "=", "0.23"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayomain", "=", "0.11"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violamain", "=", "0.27"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguemain", "=", "0.17"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottybwbrok", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookbwbrok", "=", "0.32"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindabwbrok", "=", "0.52"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgebwbrok", "=", "2.61"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayobwbrok", "=", "0.24"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violabwbrok", "=", "0.59"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"voguebwbrok", "=", "0.37"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottybwmain", "=", "0.19"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookbwmain", "=", "0.31"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindabwmain", "=", "0.54"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgebwmain", "=", "1.04"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayobwmain", "=", "0.33"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violabwmain", "=", "0.69"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguebwmain", "=", "0.28"}], ";"}]}], "Input",
 CellChangeTimes->{{3.763897622945345*^9, 3.7638976263039293`*^9}, {
   3.763897664735517*^9, 3.7638976955653934`*^9}, {3.78748465510493*^9, 
   3.787484681002672*^9}, {3.787484766682147*^9, 3.7874848218963213`*^9}, {
   3.78748492702669*^9, 3.7874849374864736`*^9}, {3.787485145117247*^9, 
   3.787485349837045*^9}, 3.7874859209423733`*^9, {3.7887767420776176`*^9, 
   3.788776887156046*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"827eb6e2-a777-4e0a-88ea-90425622b836"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sparsdottyperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.25", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindaperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.29", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgeperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.09", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayoperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolaperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.22", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsvogueperc", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.23", ",", "100"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7583929037440395`*^9, 3.7583929190306654`*^9}, {
   3.7583929597408967`*^9, 3.7583930828236957`*^9}, {3.7638984957725954`*^9, 
   3.7638985129742694`*^9}, {3.763898618828734*^9, 3.7638986189138565`*^9}, 
   3.7638986611691647`*^9, {3.7638986911989083`*^9, 3.7638986918002443`*^9}, {
   3.7638987871431956`*^9, 3.763898787523153*^9}, {3.7638988187779083`*^9, 
   3.7638988189784207`*^9}, {3.763898850036601*^9, 3.763898850145465*^9}, {
   3.763898890597722*^9, 3.763898890753911*^9}, {3.7638997244973445`*^9, 
   3.7638997513386335`*^9}, {3.763899781379002*^9, 3.7638997844904623`*^9}, {
   3.788776905148724*^9, 3.788776964594522*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"cb0c870f-e700-4532-b36a-9c9a917482d8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sparsdottybrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.09", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.12", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindabrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.16", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgebrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.16", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayobrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.08", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolabrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.2", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguebrok", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.11", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottyspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.12", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.21", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindaspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgespars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.05", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayospars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.15", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolaspars", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.24", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguespars", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.17", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottymain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.19", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.19", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindamain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.28", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgemain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.25", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayomain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.13", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolamain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.29", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguemain", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.18", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottybwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.3", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookbwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.34", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindabwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.59", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgebwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"2.55", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayobwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.41", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolabwbrok", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.79", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sparsvoguebwbrok", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0.3", ",", "100"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsdottybwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.22", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookbwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.31", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindabwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.52", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgebwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1.35", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayobwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.26", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolabwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.61", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsvoguebwmain", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.31", ",", "100"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.763897622945345*^9, 3.7638976263039293`*^9}, {
  3.763897664735517*^9, 3.7638976955653934`*^9}, {3.7638985147787924`*^9, 
  3.763898524827169*^9}, {3.76389863338136*^9, 3.7638986343655043`*^9}, {
  3.76389866803017*^9, 3.7638986689993153`*^9}, {3.7638986998119855`*^9, 
  3.763898701367464*^9}, {3.763898795857239*^9, 3.7638988250125475`*^9}, {
  3.7638988624343185`*^9, 3.763898895794795*^9}, {3.7638997539813795`*^9, 
  3.763899792563949*^9}, {3.7874846934725075`*^9, 3.7874847332830257`*^9}, {
  3.7874849528624496`*^9, 3.7874850218160114`*^9}, {3.787485577675925*^9, 
  3.7874856570123606`*^9}, {3.7874856957921457`*^9, 3.787485756362424*^9}, {
  3.787486186782049*^9, 3.7874862734421067`*^9}, {3.7887769755181212`*^9, 
  3.788777176320466*^9}, {3.8406163063284454`*^9, 3.8406163351273794`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"e818e5b7-fd59-4d26-bf61-35686eabe07b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sparsdottycorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.62", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparshookcorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.42", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslindacorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.56", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparslodgecorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.79", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsnyayocorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.56", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsviolacorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.62", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sparsvoguecorr", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.63", ",", "100"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7638985410955963`*^9, 3.763898545215225*^9}, {
  3.7638986435213795`*^9, 3.763898643661972*^9}, {3.76389867903468*^9, 
  3.7638986790723963`*^9}, {3.763898715298128*^9, 3.763898716372466*^9}, {
  3.7638988092231245`*^9, 3.7638988322169104`*^9}, {3.7638988812775126`*^9, 
  3.7638989042975817`*^9}, {3.763899769093176*^9, 3.76389980047834*^9}, {
  3.7639002829152403`*^9, 3.763900295821453*^9}, {3.788777194190618*^9, 
  3.7887771996157556`*^9}, {3.7887772671523647`*^9, 3.7887772770488577`*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"5581d965-c4d8-4527-b3e2-aa73d185edde"]
}, Closed]],

Cell[CellGroupData[{

Cell["Percent broken", "Section",
 CellChangeTimes->{{3.8426911378347073`*^9, 
  3.842691140154275*^9}},ExpressionUUID->"82528df6-bf3a-4ebe-9020-\
15cae5650a42"],

Cell[CellGroupData[{

Cell["Democ vs Comm", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019462315826`*^9}},ExpressionUUID->"a24b2f50-d922-4f7d-b553-\
a9fd8206fae9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}},
 CellLabel->
  "In[1050]:=",ExpressionUUID->"2226f7b7-99c0-4aa3-a295-efe78e257b6d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}},
 CellLabel->
  "In[1064]:=",ExpressionUUID->"a32a81b0-b061-4920-9415-3db3858e4b15"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1065]:=",ExpressionUUID->"beeb4d1c-6b15-4f18-bd1e-16aff1584893"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "1.6378024965472449`", "1.6378024965472449`", 
      "242.65218640542835`", "1.539952503554386`*^-50"},
     {"Group", "6", "4.4411490911518765`", "0.7401915151919793`", 
      "109.66468172977261`", "3.0258287591804503`*^-113"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.0768830774282527`", 
      "0.1794805129047088`", "26.59132524544847`", "4.251676291097445`*^-30"},
     {"\<\"Error\"\>", "1386", "9.354930173271661`", "0.006749588869604374`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "16.510764838399034`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.843205080227227*^9},
 CellLabel->
  "Out[1066]=",ExpressionUUID->"2fe06e83-847b-48d2-aca6-fc780dfab109"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1067]:=",ExpressionUUID->"b310d7cc-297e-4c17-899d-ee6913514459"],

Cell[BoxData["0.09919604043649224`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432050802600307`*^9},
 CellLabel->
  "Out[1067]=",ExpressionUUID->"591feb17-6ebc-465a-afc3-34e206f3c28e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201954481023*^9}},ExpressionUUID->"f3e654e3-f9d0-45e3-a064-\
e129b4afcaff"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8432021228532553`*^9, 
  3.843202128323515*^9}},
 CellLabel->
  "In[1068]:=",ExpressionUUID->"dfc43227-2639-4414-b616-9fd935c839be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.8432021307129765`*^9},
 CellLabel->
  "In[1082]:=",ExpressionUUID->"2b815279-e48e-47b4-a483-4000d541125d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1083]:=",ExpressionUUID->"84e48865-68df-4af8-bcd5-01da7bcb55e6"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "7.436292594537605`", "7.436292594537605`", 
      "1485.4261798689488`", "1.7949614603759868`*^-221"},
     {"Group", "6", "6.982834294123144`", "1.1638057156871906`", 
      "232.47437568994238`", "1.6275304087947084`*^-205"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.7653109366602848`", 
      "0.12755182277671412`", "25.478935159398063`", 
      "7.910277107322786`*^-29"},
     {"\<\"Error\"\>", "1386", "6.93854846219179`", "0.005006167721639098`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "22.122986287512823`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432021385871325`*^9, 3.8432050804933667`*^9},
 CellLabel->
  "Out[1084]=",ExpressionUUID->"e6a7ffdc-7174-4dc0-a815-5ca4fb7512d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1085]:=",ExpressionUUID->"9bdea369-8926-42f0-8b49-1f9e589a637d"],

Cell[BoxData["0.33613421343279376`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432021514854956`*^9, 
  3.843205080530811*^9},
 CellLabel->
  "Out[1085]=",ExpressionUUID->"c3808926-88c6-4b51-bb36-5600be7946c6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201958219412*^9}},ExpressionUUID->"6200f16e-4d48-4f83-80fd-\
5554d0737246"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.843202191807497*^9, 
  3.843202195013982*^9}},
 CellLabel->
  "In[1086]:=",ExpressionUUID->"a92c7091-fbe8-448e-a58f-61f897be163a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"rand", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.84320219723689*^9},
 CellLabel->
  "In[1100]:=",ExpressionUUID->"8be4a3b3-c9f7-4653-bcb6-28d9fab528b3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1101]:=",ExpressionUUID->"be82ebb2-b974-4c90-8ec7-66fa38d083e4"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1141.203613477121`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1102, 146, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202201809596*^9, 3.843205080775011*^9},
 CellLabel->
  "During evaluation of \
In[1101]:=",ExpressionUUID->"65da0f36-603b-4385-8d64-210869aa07f4"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "24.58704205500709`", "24.58704205500709`", 
      "5768.846236951041`", "0.`"},
     {"Group", "6", "1.1151627219280407`", "0.18586045365467344`", 
      "43.60835175963858`", "5.560768354843329`*^-49"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.249351884701337`", 
      "0.2082253141168895`", "48.855808563459995`", 
      "1.3483730362761227`*^-54"},
     {"\<\"Error\"\>", "1386", "5.9071847105168445`", "0.004262038030675934`",
       "", ""},
     {"\<\"Total\"\>", "1399", "32.85874137215331`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022018345222`*^9, 3.8432050807791367`*^9},
 CellLabel->
  "Out[1102]=",ExpressionUUID->"cfc82caa-6f0d-4894-bc57-b6cf64226967"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1103]:=",ExpressionUUID->"db25142b-de8c-4d71-9d98-14d48ea080fb"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1141.203613477121`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1103, 147, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.8432050808258057`*^9},
 CellLabel->
  "During evaluation of \
In[1103]:=",ExpressionUUID->"28b6417d-a0e4-4def-8ecb-cf3705ec5d02"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1141.203613477121`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1103, 148, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.8432050808721595`*^9},
 CellLabel->
  "During evaluation of \
In[1103]:=",ExpressionUUID->"31fb81d2-e8e3-423e-95c0-27f6878baf9d"],

Cell[BoxData["0.7482648765069191`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202202592086*^9, 
  3.843205080875922*^9},
 CellLabel->
  "Out[1103]=",ExpressionUUID->"c6430930-d0a6-49b1-aca8-0da35a1f8620"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019666710215`*^9}},ExpressionUUID->"866e0dc4-d504-4116-ad6e-\
62f4780a57a4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.843202246062847*^9, 
  3.843202249973429*^9}},
 CellLabel->
  "In[1104]:=",ExpressionUUID->"6c4201f8-9d99-4437-8d44-a18ebd3aa0b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "despot"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.843202251821741*^9},
 CellLabel->
  "In[1118]:=",ExpressionUUID->"a9721332-7f08-4f75-a726-f25cb1b525dc"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1119]:=",ExpressionUUID->"d642f264-bf41-41f8-8c35-a954093585c9"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"795.0416735449313`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1120, 149, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.8432050811429405`*^9},
 CellLabel->
  "During evaluation of \
In[1119]:=",ExpressionUUID->"a34234de-364c-49c8-b552-4b423b8f4352"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "16.05383106786491`", "16.05383106786491`", 
      "2956.2799669502997`", "0.`"},
     {"Group", "6", "7.404991725150001`", "1.2341652875250002`", 
      "227.26899890699138`", "3.990579461597006`*^-202"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.1606098603965407`", 
      "0.19343497673275678`", "35.620653051919746`", 
      "3.0251952438283403`*^-40"},
     {"\<\"Error\"\>", "1386", "7.526557061175267`", "0.005430416350054305`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "32.14598971458672`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022568375087`*^9, 3.843205081147541*^9},
 CellLabel->
  "Out[1120]=",ExpressionUUID->"f0655799-61e4-4cbb-a4b7-7acfdd6f0a74"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1121]:=",ExpressionUUID->"babaf00a-6784-4978-93ac-493ade891d3d"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"795.0416735449313`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1121, 150, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.84320508120485*^9},
 CellLabel->
  "During evaluation of \
In[1121]:=",ExpressionUUID->"7cb6d78b-dfc0-4d0d-b842-f9783e89703e"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"795.0416735449313`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1121, 151, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.8432050812496247`*^9},
 CellLabel->
  "During evaluation of \
In[1121]:=",ExpressionUUID->"ecfe6b4e-4ff4-4030-ba1a-181648c3f3b0"],

Cell[BoxData["0.499403851317113`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202258467805*^9, 
  3.8432050812623243`*^9},
 CellLabel->
  "Out[1121]=",ExpressionUUID->"0909c7ea-07eb-4d27-b51b-89e51566093f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 
  3.8426911900556355`*^9}},ExpressionUUID->"7d5f5194-10e9-4a47-b15b-\
c20f6daa9571"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}},
 CellLabel->
  "In[1122]:=",ExpressionUUID->"8d0503a8-f1df-447c-937f-04c12d5f4f7f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}},
 CellLabel->
  "In[1136]:=",ExpressionUUID->"b00e43f0-9801-4238-b096-8c88384ee22b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}},
 CellLabel->
  "In[1139]:=",ExpressionUUID->"c3edfa1b-bf42-4873-83fc-f6d112b3482f"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1351.4461595342834`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1140, 152, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8427057863575764`*^9, 3.8427083448470335`*^9, 
  3.8432050815648546`*^9},
 CellLabel->
  "During evaluation of \
In[1139]:=",ExpressionUUID->"43be0afd-7fc9-44d4-a9ba-1cfbd6beaec8"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "38.916372254774714`", "38.916372254774714`", 
      "8304.308952009811`", "0.`"},
     {"Group", "6", "1.4837102477911799`", "0.24728504129852996`", 
      "52.767800881068695`", "1.0145384026485714`*^-58"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.6982607136013144`", 
      "0.2830434522668857`", "60.39823699597993`", "1.2996971858218256`*^-66"},
     {"\<\"Error\"\>", "1386", "6.495193309500321`", "0.004686286659091141`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "48.59353652566753`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.8427057863696804`*^9, 3.8427083448571405`*^9, 
  3.843205081569571*^9},
 CellLabel->
  "Out[1140]=",ExpressionUUID->"a31692f1-6913-426f-96ca-a32fba43854e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1144]:=",ExpressionUUID->"eb72e3f3-ea79-402a-b9aa-daf86b5dd31d"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1351.4461595342834`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1144, 157, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.843205081887616*^9},
 CellLabel->
  "During evaluation of \
In[1144]:=",ExpressionUUID->"9e71b09b-541b-4eb6-be97-34150da60f9b"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1351.4461595342834`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1144, 158, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432050819318657`*^9},
 CellLabel->
  "During evaluation of \
In[1144]:=",ExpressionUUID->"2b0fd691-20af-4e64-b850-6ed9c7a7c1e0"],

Cell[BoxData["0.8008549086403446`"], "Output",
 CellChangeTimes->{3.8427083710778227`*^9, 3.8432050819383526`*^9},
 CellLabel->
  "Out[1144]=",ExpressionUUID->"44d4148d-a8f0-49ed-8592-1f6874c083b6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Despot vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201977267528*^9}},ExpressionUUID->"54c604f4-d331-45aa-a8ef-\
48ccda23c3b8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "3"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8432022831561136`*^9, 
  3.843202302232575*^9}},
 CellLabel->
  "In[1145]:=",ExpressionUUID->"3a3c3d0a-9732-4b0e-b557-c1cc11925d18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}, {3.8432022876973305`*^9, 
  3.843202303651292*^9}},
 CellLabel->
  "In[1159]:=",ExpressionUUID->"8c03584e-cbde-458e-9192-1e29b926db51"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1160]:=",ExpressionUUID->"5af0cded-62ac-449a-9910-d046e43c8396"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "4.979929630558356`", "4.979929630558356`", 
      "1692.2042858333539`", "2.053242398963896`*^-242"},
     {"Group", "6", "2.562069407317754`", "0.4270115678862923`", 
      "145.10060560767124`", "7.152280300990083`*^-143"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "2.850014616278038`", 
      "0.4750024360463397`", "161.40813579503862`", 
      "1.365042784304753`*^-155"},
     {"\<\"Error\"\>", "1386", "4.078811598420452`", "0.002942865511125867`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "14.470825252574599`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432023088851333`*^9, 3.843205082177127*^9},
 CellLabel->
  "Out[1161]=",ExpressionUUID->"db68a12c-eddb-4b99-87e3-6bcd507d7177"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1162]:=",ExpressionUUID->"90ce35fb-9804-4144-952f-d905af618d83"],

Cell[BoxData["0.3441358418499556`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432023097395687`*^9, 
  3.8432050822029114`*^9},
 CellLabel->
  "Out[1162]=",ExpressionUUID->"dae79822-e00e-44ab-8c3c-5836fab0a8e6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ENBNB", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}},ExpressionUUID->"44d86a1f-cb6d-4bf6-a186-\
bb31baf574f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgeperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgeperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayoperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayoperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvogueperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvogueperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}},
 CellLabel->
  "In[1163]:=",ExpressionUUID->"17cac955-2a56-4e9b-b0b1-51502c80a36a"],

Cell[BoxData["44.142857142857146`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.843205082235772*^9},
 CellLabel->
  "Out[1163]=",ExpressionUUID->"30f98919-6dd2-4642-944a-a658585fb6dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgeperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgeperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayoperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayoperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvogueperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvogueperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}},
 CellLabel->
  "In[1164]:=",ExpressionUUID->"04741389-819c-4175-b1fb-5b9c575defeb"],

Cell[BoxData["69.14285714285714`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.8432050822716594`*^9},
 CellLabel->
  "Out[1164]=",ExpressionUUID->"1f5ac3f2-388c-4495-a13e-d189457ac3bc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgeperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgeperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayoperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayoperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvogueperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvogueperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}},
 CellLabel->
  "In[1165]:=",ExpressionUUID->"57ce5257-8776-41d6-a5d8-286cd9b31249"],

Cell[BoxData["7.428571428571429`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843205082301335*^9},
 CellLabel->
  "Out[1165]=",ExpressionUUID->"c5e2c6bd-d8d5-488f-8f01-57a781aed836"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgeperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgeperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayoperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayoperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvogueperc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvogueperc", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}},
 CellLabel->
  "In[1166]:=",ExpressionUUID->"74e8a600-b56b-4ca2-b496-4796ff5efa20"],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.843205082341547*^9},
 CellLabel->
  "Out[1166]=",ExpressionUUID->"5d13fe4d-fec5-4196-bc8f-32d6d3032435"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Observed", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}, {3.843203236007986*^9, 
  3.843203240657067*^9}},ExpressionUUID->"ac5701bf-4abb-4d56-a571-\
1ac04a865f9c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", "dottyperc", "}"}]}], "]"}], "]"}], ",", 
         "dottyperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", "hookperc", "}"}]}], "]"}], "]"}], ",", "hookperc"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", "lindaperc", "}"}]}], "]"}], "]"}], ",", 
         "lindaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", "lodgeperc", "}"}]}], "]"}], "]"}], ",", 
         "lodgeperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", "nyayoperc", "}"}]}], "]"}], "]"}], ",", 
         "nyayoperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", "violaperc", "}"}]}], "]"}], "]"}], ",", 
         "violaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", "vogueperc", "}"}]}], "]"}], "]"}], ",", 
         "vogueperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203270647889*^9, 3.843203394525511*^9}, {
  3.843203426549635*^9, 3.8432034349978504`*^9}},
 CellLabel->
  "In[1167]:=",ExpressionUUID->"fdb8ef29-f4f9-40a0-a069-0bfd102a8900"],

Cell[BoxData["94.85714285714286`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.84320343951612*^9, 3.84320508237358*^9},
 CellLabel->
  "Out[1167]=",ExpressionUUID->"7c278b23-4b41-4efb-a8eb-752e2df37905"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", "dottyperc", "}"}]}], "]"}], "]"}], ",", 
         "dottyperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", "hookperc", "}"}]}], "]"}], "]"}], ",", "hookperc"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", "lindaperc", "}"}]}], "]"}], "]"}], ",", 
         "lindaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", "lodgeperc", "}"}]}], "]"}], "]"}], ",", 
         "lodgeperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", "nyayoperc", "}"}]}], "]"}], "]"}], ",", 
         "nyayoperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", "violaperc", "}"}]}], "]"}], "]"}], ",", 
         "violaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", "vogueperc", "}"}]}], "]"}], "]"}], ",", 
         "vogueperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.8432032875222225`*^9, 3.8432034131343436`*^9}},
 CellLabel->
  "In[1168]:=",ExpressionUUID->"09341d21-05a3-4eb4-ad4b-880c0b91deab"],

Cell[BoxData["96.14285714285714`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203440824523*^9, 
  3.8432050824139347`*^9},
 CellLabel->
  "Out[1168]=",ExpressionUUID->"5e19a329-1736-4343-b267-5a852b3ec135"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", "dottyperc", "}"}]}], "]"}], "]"}], ",", 
         "dottyperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", "hookperc", "}"}]}], "]"}], "]"}], ",", "hookperc"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", "lindaperc", "}"}]}], "]"}], "]"}], ",", 
         "lindaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", "lodgeperc", "}"}]}], "]"}], "]"}], ",", 
         "lodgeperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", "nyayoperc", "}"}]}], "]"}], "]"}], ",", 
         "nyayoperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", "violaperc", "}"}]}], "]"}], "]"}], ",", 
         "violaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", "vogueperc", "}"}]}], "]"}], "]"}], ",", 
         "vogueperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.843203289198624*^9, 3.8432034145093603`*^9}},
 CellLabel->
  "In[1169]:=",ExpressionUUID->"9ecad051-5543-404f-af19-ed251f9234e8"],

Cell[BoxData["48.714285714285715`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203442360874*^9, 
  3.8432050824438725`*^9},
 CellLabel->
  "Out[1169]=",ExpressionUUID->"8ccdc56d-176b-426e-8f15-e21e48d2c3f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", "dottyperc", "}"}]}], "]"}], "]"}], ",", 
         "dottyperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", "hookperc", "}"}]}], "]"}], "]"}], ",", "hookperc"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", "lindaperc", "}"}]}], "]"}], "]"}], ",", 
         "lindaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", "lodgeperc", "}"}]}], "]"}], "]"}], ",", 
         "lodgeperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", "nyayoperc", "}"}]}], "]"}], "]"}], ",", 
         "nyayoperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", "violaperc", "}"}]}], "]"}], "]"}], ",", 
         "violaperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", "vogueperc", "}"}]}], "]"}], "]"}], ",", 
         "vogueperc"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432032904995956`*^9, 3.8432034170680695`*^9}},
 CellLabel->
  "In[1170]:=",ExpressionUUID->"2d3e6176-dd14-4930-aec8-58d8844eba4b"],

Cell[BoxData["15.714285714285714`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.8432034435089273`*^9, 
  3.8432050824739823`*^9},
 CellLabel->
  "Out[1170]=",ExpressionUUID->"ad819e1f-a744-4f5d-bded-5f1579400b61"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Broken weight", "Section",
 CellChangeTimes->{{3.8426911378347073`*^9, 3.842691140154275*^9}, {
  3.8426911743027434`*^9, 3.8426911753528943`*^9}, {3.8426924162320967`*^9, 
  3.84269241943659*^9}, {3.843203942370325*^9, 
  3.8432039442497854`*^9}},ExpressionUUID->"6fd8a6ab-ecb9-447c-b9c2-\
07aaa1d4c896"],

Cell[CellGroupData[{

Cell["Democ vs Comm", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019462315826`*^9}},ExpressionUUID->"b8607921-9a5d-4731-bcf9-\
9a6139ad7e48"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203980528944*^9, 
  3.8432039831177483`*^9}, {3.8432042522874093`*^9, 3.8432042523183775`*^9}},
 CellLabel->
  "In[1174]:=",ExpressionUUID->"46d121df-5c0b-401a-a867-8ff065b7b72f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}},
 CellLabel->
  "In[1188]:=",ExpressionUUID->"00daa271-f29e-4332-8db0-b0dd7a931a53"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1189]:=",ExpressionUUID->"6a07d9a4-79b0-41f9-b239-9986ec061da9"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1001.4381442326847`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1190, 159, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781115415*^9, 3.8432040596715755`*^9, 
  3.8432050998879824`*^9},
 CellLabel->
  "During evaluation of \
In[1189]:=",ExpressionUUID->"38f863fc-61e5-420b-8041-c3625b3e6c53"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.3999424364284363`", "0.3999424364284363`", 
      "851.9818258134869`", "2.145415364444793`*^-146"},
     {"Group", "6", "2.1571101156609243`", "0.359518352610154`", 
      "765.8679714150923`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.12910669244582973`", 
      "0.021517782074304954`", "45.8384947164851`", 
      "2.2221887852248286`*^-51"},
     {"\<\"Error\"\>", "1386", "0.6506244618076662`", 
      "0.00046942601862024977`", "", ""},
     {"\<\"Total\"\>", "1399", "3.3367837063428563`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432037811187725`*^9, 3.8432040596762934`*^9, 3.843205099891268*^9},
 CellLabel->
  "Out[1190]=",ExpressionUUID->"767aaefc-5829-44b1-896c-ebd8fefd4c92"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1191]:=",ExpressionUUID->"babd5bfd-dcf1-4d3a-aa2b-e5063dce0872"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1001.4381442326847`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1191, 160, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.8432040597355533`*^9, 
  3.8432050999365225`*^9},
 CellLabel->
  "During evaluation of \
In[1191]:=",ExpressionUUID->"8176a149-890f-48ad-a9c4-8085b4b4bfbd"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1001.4381442326847`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1191, 161, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.8432040597355533`*^9, 
  3.8432050999807115`*^9},
 CellLabel->
  "During evaluation of \
In[1191]:=",ExpressionUUID->"81ea14ba-62d6-4220-a590-a62ef12a6535"],

Cell[BoxData["0.11985866379897205`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432037812119827`*^9, 
  3.843204059793107*^9, 3.843205099985297*^9},
 CellLabel->
  "Out[1191]=",ExpressionUUID->"1c7f5021-9c47-4210-87a1-c1ddac50627e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201954481023*^9}},ExpressionUUID->"7eed36c5-1ef7-47a9-a327-\
1a70fb0c40a0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036025518847`*^9, 
  3.8432036088187733`*^9}, {3.8432039834035654`*^9, 3.8432039859699593`*^9}, {
  3.843204252321314*^9, 3.8432042523476353`*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"75b24d9c-d166-4779-a8b9-79a8d85d624a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.8432021307129765`*^9},
 CellLabel->
  "In[1206]:=",ExpressionUUID->"ab5e6ef2-1cee-457a-b12c-3c51d108928a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1207]:=",ExpressionUUID->"427a568a-68b6-4522-bc35-d0fea51f824e"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1080.4011099862412`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1208, 162, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816017094`*^9, 3.843204060078776*^9, 
  3.843205100275423*^9},
 CellLabel->
  "During evaluation of \
In[1207]:=",ExpressionUUID->"4e830ea6-3b82-4465-8c97-31c0ed97c7ab"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.1588473945270783`", "0.1588473945270783`", 
      "284.4835801387462`", "3.3583627019641126`*^-58"},
     {"Group", "6", "2.9692449920159123`", "0.4948741653359854`", 
      "886.2819229241808`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.07330053185023822`", 
      "0.012216755308373035`", "21.879277895316942`", 
      "1.0814099343518075`*^-24"},
     {"\<\"Error\"\>", "1386", "0.773902271291561`", "0.0005583710471079084`",
       "", ""},
     {"\<\"Total\"\>", "1399", "3.9752951896847897`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432021385871325`*^9, 3.8432037816047707`*^9, 3.84320406008261*^9, 
  3.8432051002811613`*^9},
 CellLabel->
  "Out[1208]=",ExpressionUUID->"5390f762-0946-466d-9641-b4606c44da9f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1209]:=",ExpressionUUID->"21738282-1713-4ad8-8817-18ab49635992"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1080.4011099862412`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1209, 163, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843204060146611*^9, 
  3.843205100350895*^9},
 CellLabel->
  "During evaluation of \
In[1209]:=",ExpressionUUID->"a61e8532-1800-4c35-b529-5aa7f3648830"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1080.4011099862412`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1209, 164, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843204060146611*^9, 
  3.8432051003990717`*^9},
 CellLabel->
  "During evaluation of \
In[1209]:=",ExpressionUUID->"ecae75a1-6465-4afc-880d-837ab57a8176"],

Cell[BoxData["0.03995864129518233`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432021514854956`*^9, 
  3.8432037816956253`*^9, 3.843204060198579*^9, 3.8432051004039707`*^9},
 CellLabel->
  "Out[1209]=",ExpressionUUID->"f56500f3-775f-43a5-8d84-12e822bc9951"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201958219412*^9}},ExpressionUUID->"0183bf53-21b6-4736-ba03-\
8566da8d4d1b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203614394541*^9, 
  3.8432036198484077`*^9}, {3.8432039862824287`*^9, 3.8432039888734045`*^9}, {
  3.8432042523502293`*^9, 3.843204252375916*^9}},
 CellLabel->
  "In[1210]:=",ExpressionUUID->"52bf2f87-679a-4022-8ad4-1a4c379f6424"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"rand", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.84320219723689*^9},
 CellLabel->
  "In[1224]:=",ExpressionUUID->"e0c01c6c-da00-45df-bbca-1eedb7de9044"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1225]:=",ExpressionUUID->"6c22daf2-d54e-4505-b445-4e75b33d4e0f"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1159.5515781149036`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1226, 165, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202201809596*^9, 3.843203781945182*^9, 
  3.8432040604594784`*^9, 3.843205100779928*^9},
 CellLabel->
  "During evaluation of \
In[1225]:=",ExpressionUUID->"7ba82d08-c530-48a3-9b36-cbeb6620ae4f"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.6425653586574143`", "0.6425653586574143`", 
      "1211.3516888469662`", "2.940059746177886`*^-191"},
     {"Group", "6", "3.2513530288704016`", "0.5418921714784002`", 
      "1021.5645587630928`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.055486179185540774`", 
      "0.009247696530923461`", "17.433577238095182`", 
      "1.5617629279223873`*^-19"},
     {"\<\"Error\"\>", "1386", "0.7352081111530013`", 
      "0.0005304531826500731`", "", ""},
     {"\<\"Total\"\>", "1399", "4.684612677866358`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022018345222`*^9, 3.8432037819495487`*^9, 3.8432040604630113`*^9, 
  3.8432051008325267`*^9},
 CellLabel->
  "Out[1226]=",ExpressionUUID->"27c2f51f-3f12-466c-87c1-e5ebcfab056f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1227]:=",ExpressionUUID->"e014eead-2f49-4d9c-ab89-dd2ddce2dfa1"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1159.5515781149036`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1227, 166, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.8432040605179405`*^9, 3.8432051010021915`*^9},
 CellLabel->
  "During evaluation of \
In[1227]:=",ExpressionUUID->"41579fdc-ec6d-43b9-8acf-31ce90478931"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1159.5515781149036`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1227, 167, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.8432040605179405`*^9, 3.8432051011456947`*^9},
 CellLabel->
  "During evaluation of \
In[1227]:=",ExpressionUUID->"9c89289a-3df8-49a1-92f2-332f9623fb7f"],

Cell[BoxData["0.1371650983427888`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202202592086*^9, 
  3.8432037820797253`*^9, 3.8432040605685787`*^9, 3.84320510116291*^9},
 CellLabel->
  "Out[1227]=",ExpressionUUID->"46b5830b-cd2f-49a9-908a-047557ec5b20"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019666710215`*^9}},ExpressionUUID->"d669129f-2791-4484-a2e6-\
dc3cd0269d6e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036301775594`*^9, 
  3.8432036348632784`*^9}, {3.843203989206848*^9, 3.8432039918422127`*^9}, {
  3.843204252379531*^9, 3.8432042524051247`*^9}},
 CellLabel->
  "In[1228]:=",ExpressionUUID->"ef40e02b-9ffb-48ed-bd63-8447054a57cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "despot"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.843202251821741*^9},
 CellLabel->
  "In[1242]:=",ExpressionUUID->"caaf67ea-5b2c-44c4-8a66-5601937ce3db"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1243]:=",ExpressionUUID->"4f38c0c0-064b-4b99-917b-f02d34c11387"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"905.6353193453858`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1244, 168, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.843203782358631*^9, 
  3.843204060872214*^9, 3.8432051015203333`*^9},
 CellLabel->
  "During evaluation of \
In[1243]:=",ExpressionUUID->"cf72e55e-3ce7-46f2-9fb5-18ee323ce996"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1277.7079777070685`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1244, 169, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.843203782358631*^9, 
  3.843204060872214*^9, 3.843205101568457*^9},
 CellLabel->
  "During evaluation of \
In[1243]:=",ExpressionUUID->"b98fcd71-bfa7-4c16-bc85-48a7bb5449f3"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "1.062892257005891`", "1.062892257005891`", 
      "3707.3624144547643`", "0.`"},
     {"Group", "6", "2.158080724026585`", "0.35968012067109745`", 
      "1254.5623056459901`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.18276256669568713`", 
      "0.03046042778261452`", "106.24580652002328`", 
      "3.14704652871765`*^-110"},
     {"\<\"Error\"\>", "1386", "0.3973630046165372`", 
      "0.0002866976945285261`", "", ""},
     {"\<\"Total\"\>", "1399", "3.8010985523447003`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022568375087`*^9, 3.8432037823623514`*^9, 3.8432040609230413`*^9, 
  3.8432051015817394`*^9},
 CellLabel->
  "Out[1244]=",ExpressionUUID->"1ed32726-70f3-4742-9ad0-d6ba78b0d11e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1245]:=",ExpressionUUID->"c656f880-8428-43bf-98b6-d7be4e7585e6"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"905.6353193453858`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1245, 170, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.8432040609736433`*^9, 3.843205101695016*^9},
 CellLabel->
  "During evaluation of \
In[1245]:=",ExpressionUUID->"62b43fff-8cf7-4aa2-b62e-ec7040664779"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1277.7079777070685`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1245, 171, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.8432040609736433`*^9, 3.8432051017466993`*^9},
 CellLabel->
  "During evaluation of \
In[1245]:=",ExpressionUUID->"cbf22075-34a2-4205-a18c-6d7840800e0f"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"905.6353193453858`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1245, 172, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.8432040609736433`*^9, 3.843205101819469*^9},
 CellLabel->
  "During evaluation of \
In[1245]:=",ExpressionUUID->"3c0ddb87-0e6a-426a-b3e8-76092c874dff"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"", 2, 1245, 173, 21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.8432040609736433`*^9, 3.8432051018810062`*^9},
 CellLabel->
  "During evaluation of \
In[1245]:=",ExpressionUUID->"b87069f2-a05a-4045-b4c8-fc8515dc5422"],

Cell[BoxData["0.2796276503670887`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202258467805*^9, 
  3.8432037825058584`*^9, 3.8432040611167035`*^9, 3.843205101894786*^9},
 CellLabel->
  "Out[1245]=",ExpressionUUID->"3b757814-accc-4dc0-a1c1-a8b0faf76a2e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 
  3.8426911900556355`*^9}},ExpressionUUID->"7cbac9cf-d899-4a21-8228-\
14a254e51a5f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203644202664*^9, 
  3.843203647744932*^9}, {3.8432039924328346`*^9, 3.843203995369296*^9}, {
  3.843204252407686*^9, 3.8432042524336433`*^9}},
 CellLabel->
  "In[1246]:=",ExpressionUUID->"607688ec-d287-4298-bc1f-042d3d71630c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}},
 CellLabel->
  "In[1260]:=",ExpressionUUID->"ec1d0ab2-a240-4e60-8de4-1febb8d19a8b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}},
 CellLabel->
  "In[1261]:=",ExpressionUUID->"5e7527c2-a70b-4058-b97b-cdb2854da719"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1325.3687584144175`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1262, 174, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8427057863575764`*^9, 3.8427083448470335`*^9, 
  3.8432037828131795`*^9, 3.843204061442011*^9, 3.84320510224588*^9},
 CellLabel->
  "During evaluation of \
In[1261]:=",ExpressionUUID->"23ab235c-d1f6-4fe3-aa41-aa46bdbab956"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1399.0248620227685`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1262, 175, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8427057863575764`*^9, 3.8427083448470335`*^9, 
  3.8432037828131795`*^9, 3.843204061442011*^9, 3.8432051023178434`*^9},
 CellLabel->
  "During evaluation of \
In[1261]:=",ExpressionUUID->"0da5b90b-44a1-419a-ab68-0360e13f2d82"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "2.0563897509484828`", "2.0563897509484828`", 
      "7946.483890907333`", "0.`"},
     {"Group", "6", "2.3894582035906944`", "0.3982430339317824`", 
      "1538.926097227107`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.21567877132136992`", 
      "0.03594646188689499`", "138.9075102069411`", 
      "6.733031702047116`*^-138"},
     {"\<\"Error\"\>", "1386", "0.35866884447797764`", 
      "0.00025877983007069094`", "", ""},
     {"\<\"Total\"\>", "1399", "5.020195570338524`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.8427057863696804`*^9, 3.8427083448571405`*^9, 
  3.8432037828171196`*^9, 3.843204061482339*^9, 3.8432051023377943`*^9},
 CellLabel->
  "Out[1262]=",ExpressionUUID->"c465a2dc-8722-431f-a078-4f43a91ae8e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1263]:=",ExpressionUUID->"75fc13ca-79ff-41ad-b730-a13d4e00a7a2"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1325.3687584144175`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1263, 176, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432040618574305`*^9, 3.843205102415557*^9},
 CellLabel->
  "During evaluation of \
In[1263]:=",ExpressionUUID->"df6ceb48-be6e-48c0-b3d3-2c91b713ac97"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1399.0248620227685`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1263, 177, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432040618574305`*^9, 3.8432051024637666`*^9},
 CellLabel->
  "During evaluation of \
In[1263]:=",ExpressionUUID->"349f23fb-8694-4471-a4b6-f66485f323fd"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1325.3687584144175`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1263, 178, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432040618574305`*^9, 3.8432051025436506`*^9},
 CellLabel->
  "During evaluation of \
In[1263]:=",ExpressionUUID->"7b2fb63e-1073-41ff-9aec-2b00f1f88f2c"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"", 2, 1263, 179, 21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432040618574305`*^9, 3.84320510260847*^9},
 CellLabel->
  "During evaluation of \
In[1263]:=",ExpressionUUID->"89a236a8-18cd-4080-9d39-a8880b07103e"],

Cell[BoxData["0.40962343441329624`"], "Output",
 CellChangeTimes->{3.8427083710778227`*^9, 3.8432037832366447`*^9, 
  3.8432040620152874`*^9, 3.84320510262411*^9},
 CellLabel->
  "Out[1263]=",ExpressionUUID->"9ebbe920-53ab-44e0-a022-aa7968c2d91d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Despot vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201977267528*^9}},ExpressionUUID->"a29db68a-92a0-4450-ae4b-\
ffc5c2990b88"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "5"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036576648865`*^9, 
  3.843203692894718*^9}, {3.8432039961853*^9, 3.843204002289308*^9}, {
  3.843204252435141*^9, 3.8432042524619403`*^9}},
 CellLabel->
  "In[1264]:=",ExpressionUUID->"4ed53566-ee2c-4c2e-8676-f3383f1a1a11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}, {3.8432022876973305`*^9, 
  3.843202303651292*^9}},
 CellLabel->
  "In[1278]:=",ExpressionUUID->"5ee8e238-9ca7-4c72-8c93-fbc189080caa"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1279]:=",ExpressionUUID->"fe052f03-1f37-44cd-87ad-f9883f7884fd"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1416.5402788480803`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1280, 180, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037835063195`*^9, 3.8432040622994504`*^9, 
  3.8432051030158896`*^9},
 CellLabel->
  "During evaluation of \
In[1279]:=",ExpressionUUID->"2f64b0ad-c810-4608-b28b-02d46f682261"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.16244535797222426`", "0.16244535797222426`", 
      "467.16636436553586`", "1.6088341606018837`*^-89"},
     {"Group", "6", "3.3052991867664616`", "0.5508831977944102`", 
      "1584.2502606179655`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.05616650390499833`", 
      "0.009361083984166388`", "26.920951303214256`", 
      "1.7911540453511184`*^-30"},
     {"\<\"Error\"\>", "1386", "0.4819466539618723`", 
      "0.0003477248585583494`", "", ""},
     {"\<\"Total\"\>", "1399", "4.005857702605557`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432023088851333`*^9, 3.843203783510552*^9, 3.8432040623032837`*^9, 
  3.84320510302011*^9},
 CellLabel->
  "Out[1280]=",ExpressionUUID->"c80b5a0d-4d29-403d-a503-1783073d0a03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1281]:=",ExpressionUUID->"bcc07c46-4c47-4019-9789-c114bbac23b9"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1416.5402788480803`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1281, 181, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432040623537564`*^9, 
  3.8432051030869927`*^9},
 CellLabel->
  "During evaluation of \
In[1281]:=",ExpressionUUID->"fe8615a2-a75c-4b8b-8d89-7d0321263856"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1416.5402788480803`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1281, 182, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432040623537564`*^9, 
  3.8432051031438446`*^9},
 CellLabel->
  "During evaluation of \
In[1281]:=",ExpressionUUID->"2a7df637-dd11-4269-8df1-3e8cc0da8620"],

Cell[BoxData["0.04055195417115387`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432023097395687`*^9, 
  3.843203783603136*^9, 3.843204062410838*^9, 3.8432051031596293`*^9},
 CellLabel->
  "Out[1281]=",ExpressionUUID->"28d5351e-3bc4-4dfd-9ead-414b4db37306"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ENBNB", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}},ExpressionUUID->"4b5fac04-6115-4998-be25-\
6eabe31bc38f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203735607335*^9, 3.843203737916168*^9}, {
  3.843204015783373*^9, 3.8432040182527013`*^9}},
 CellLabel->
  "In[1282]:=",ExpressionUUID->"9141d6bc-6821-49eb-a59b-f9c29b0b6ce9"],

Cell[BoxData["17.571428571428573`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.8432037836415243`*^9, 3.8432040624584074`*^9, 
   3.8432051031988916`*^9},
 CellLabel->
  "Out[1282]=",ExpressionUUID->"85c2b506-7ac9-47b1-b6fd-56138db1d67f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.843203738342523*^9, 3.84320374056324*^9}, {
  3.843204018352154*^9, 3.8432040206978917`*^9}},
 CellLabel->
  "In[1283]:=",ExpressionUUID->"6f160f58-a0fb-428f-aaef-88155c17dd49"],

Cell[BoxData["75.14285714285714`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203783685481*^9, 
  3.843204062506754*^9, 3.8432051032464895`*^9},
 CellLabel->
  "Out[1283]=",ExpressionUUID->"57679797-dc3f-40d8-b8c8-fa17a63fb96a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.8432037408350058`*^9, 3.8432037431439867`*^9}, {3.8432040208017015`*^9, 
  3.8432040230621047`*^9}},
 CellLabel->
  "In[1284]:=",ExpressionUUID->"a8ce0b74-01b8-4479-be11-d188a53516a5"],

Cell[BoxData["1.5714285714285714`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203783723936*^9, 
  3.843204062547219*^9, 3.8432051032975445`*^9},
 CellLabel->
  "Out[1284]=",ExpressionUUID->"874fb916-7a0c-45de-87a6-f70a8cb4e6d9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432037434342103`*^9, 3.843203748665327*^9}, {3.8432040231618757`*^9, 
  3.843204025577409*^9}},
 CellLabel->
  "In[1285]:=",ExpressionUUID->"c448d111-3389-4a89-ae62-ce1f2e42a1c9"],

Cell[BoxData["0.14285714285714285`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.843203783768177*^9, 
  3.8432040625962534`*^9, 3.843205103337387*^9},
 CellLabel->
  "Out[1285]=",ExpressionUUID->"a393b13c-9308-425e-9561-dbe73284a632"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Observed", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}, {3.843203236007986*^9, 
  3.843203240657067*^9}},ExpressionUUID->"f8377e85-df8d-4544-89bc-\
b29a5efb85cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", "dottybrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", "hookbrok", "}"}]}], "]"}], "]"}], ",", "hookbrok"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", "lindabrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", "lodgebrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", "nyayobrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", "violabrok", "}"}]}], "]"}], "]"}], ",", 
         "violabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", "voguebrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203270647889*^9, 3.843203394525511*^9}, {
  3.843203426549635*^9, 3.8432034349978504`*^9}, {3.8432037505175543`*^9, 
  3.843203752748629*^9}, {3.843204025692028*^9, 3.8432040289889507`*^9}},
 CellLabel->
  "In[1286]:=",ExpressionUUID->"3c2fb0b0-2af3-4d7d-919c-acdff70d393f"],

Cell[BoxData["87.28571428571429`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.84320343951612*^9, 3.843203783794284*^9, 
   3.8432040626653185`*^9, 3.843205103376046*^9},
 CellLabel->
  "Out[1286]=",ExpressionUUID->"9550839f-8bea-4228-b0a4-97dd97604be3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", "dottybrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", "hookbrok", "}"}]}], "]"}], "]"}], ",", "hookbrok"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", "lindabrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", "lodgebrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", "nyayobrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", "violabrok", "}"}]}], "]"}], "]"}], ",", 
         "violabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", "voguebrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.8432032875222225`*^9, 3.8432034131343436`*^9}, {
  3.843203753009065*^9, 3.8432037553109555`*^9}, {3.843204029100901*^9, 
  3.8432040317037697`*^9}},
 CellLabel->
  "In[1287]:=",ExpressionUUID->"826202ec-b3ef-4b2f-9cc4-73f74ff55a9d"],

Cell[BoxData["99.`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203440824523*^9, 
  3.843203783827556*^9, 3.8432040627216268`*^9, 3.84320510341608*^9},
 CellLabel->
  "Out[1287]=",ExpressionUUID->"55faa6b7-aa1a-4684-8c56-3ecbe617d420"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", "dottybrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", "hookbrok", "}"}]}], "]"}], "]"}], ",", "hookbrok"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", "lindabrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", "lodgebrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", "nyayobrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", "violabrok", "}"}]}], "]"}], "]"}], ",", 
         "violabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", "voguebrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.843203289198624*^9, 3.8432034145093603`*^9}, {3.843203755618435*^9, 
  3.8432037591618032`*^9}, {3.843204031814435*^9, 3.8432040357055902`*^9}},
 CellLabel->
  "In[1288]:=",ExpressionUUID->"abc76313-e58e-420c-ae91-ea5fed98246d"],

Cell[BoxData["57.285714285714285`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203442360874*^9, 
  3.843203783861021*^9, 3.843204062770681*^9, 3.84320510345544*^9},
 CellLabel->
  "Out[1288]=",ExpressionUUID->"203d2a36-182c-4245-bb68-d823928c4f58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", "dottybrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", "hookbrok", "}"}]}], "]"}], "]"}], ",", "hookbrok"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", "lindabrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", "lodgebrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", "nyayobrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", "violabrok", "}"}]}], "]"}], "]"}], ",", 
         "violabrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", "voguebrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432032904995956`*^9, 3.8432034170680695`*^9}, {3.8432037603835554`*^9, 
  3.843203766456238*^9}, {3.843204035811023*^9, 3.8432040414265823`*^9}},
 CellLabel->
  "In[1289]:=",ExpressionUUID->"8db9fb93-7bc4-4e04-b348-273fbc4ab1d1"],

Cell[BoxData["31.142857142857142`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.8432034435089273`*^9, 
  3.843203783892887*^9, 3.8432040628136387`*^9, 3.8432051034967923`*^9},
 CellLabel->
  "Out[1289]=",ExpressionUUID->"1b3b62ad-25a3-482e-8a58-3b1de3e12cbb"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sparsity", "Section",
 CellChangeTimes->{{3.8426911378347073`*^9, 3.842691140154275*^9}, {
  3.8426911743027434`*^9, 3.8426911753528943`*^9}, {3.8426924162320967`*^9, 
  3.84269241943659*^9}, {3.843203942370325*^9, 3.8432039442497854`*^9}, {
  3.843204221247733*^9, 
  3.8432042245057187`*^9}},ExpressionUUID->"1afa430f-d4cb-4300-a7ac-\
c8cbd5989025"],

Cell[CellGroupData[{

Cell["Democ vs Comm", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019462315826`*^9}},ExpressionUUID->"086c431e-ad17-4dd5-bc75-\
1c1551c9f3a5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203980528944*^9, 
  3.8432039831177483`*^9}, {3.8432042524644904`*^9, 3.8432042758839254`*^9}},
 CellLabel->
  "In[1290]:=",ExpressionUUID->"37382c14-b908-4a8a-a5de-f772378027ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}},
 CellLabel->
  "In[1304]:=",ExpressionUUID->"335d24cd-97d6-4841-9473-5a6789473643"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1305]:=",ExpressionUUID->"750b690f-6025-4fa6-9796-f94758b35e1b"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "3.772129844904722`", "3.772129844904722`", 
      "385.2720847343292`", "6.939710289058436`*^-76"},
     {"Group", "6", "12.491839782388794`", "2.081973297064799`", 
      "212.64543520548415`", "2.1481076636814037`*^-192"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.9842818420895867`", 
      "0.33071364034826445`", "33.777928890534604`", 
      "3.3760066549706645`*^-38"},
     {"\<\"Error\"\>", "1386", "13.570077283546555`", "0.00979082055089939`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "31.81832875292966`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432037811187725`*^9, 3.8432040596762934`*^9, 3.843204352567854*^9, 
  3.8432051038203244`*^9},
 CellLabel->
  "Out[1306]=",ExpressionUUID->"7b1e7943-cecc-483b-ba0a-a627068da680"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1307]:=",ExpressionUUID->"a1a26a16-ae02-4262-9d86-7e6ce580bd5c"],

Cell[BoxData["0.11855210480083447`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432037812119827`*^9, 
  3.843204059793107*^9, 3.843204352604148*^9, 3.843205103863496*^9},
 CellLabel->
  "Out[1307]=",ExpressionUUID->"4a436cf4-da26-49ea-a451-955d3bef2582"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201954481023*^9}},ExpressionUUID->"7a250fed-2a99-4286-96a6-\
ca11da8ad216"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036025518847`*^9, 
  3.8432036088187733`*^9}, {3.8432039834035654`*^9, 3.8432039859699593`*^9}, {
  3.8432042524999557`*^9, 3.8432042791298656`*^9}},
 CellLabel->
  "In[1308]:=",ExpressionUUID->"ad846edc-60cf-4311-8c77-41e2f312c7fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.8432021307129765`*^9},
 CellLabel->
  "In[1322]:=",ExpressionUUID->"99d219a8-e307-43b9-90d7-7f7af0db56dd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1323]:=",ExpressionUUID->"3a2d8858-a962-4738-943d-1501a8198557"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "8.994695598462002`", "8.994695598462002`", 
      "727.093219782247`", "4.318566351844227`*^-129"},
     {"Group", "6", "17.51754102179206`", "2.9195901702986764`", 
      "236.0073438983352`", "8.560790605815727`*^-208"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.3672219420633525`", 
      "0.2278703236772254`", "18.420074978816032`", 
      "1.1075520335450036`*^-20"},
     {"\<\"Error\"\>", "1386", "17.14587312917304`", "0.012370759833458181`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "45.02533169149045`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432021385871325`*^9, 3.8432037816047707`*^9, 3.84320406008261*^9, 
  3.8432043528481073`*^9, 3.843205104185618*^9},
 CellLabel->
  "Out[1324]=",ExpressionUUID->"7a880297-a162-4de9-80f4-5ee32c03dd4a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1325]:=",ExpressionUUID->"9d848bc9-c77b-41c9-9d04-bc7e4b7ca07c"],

Cell[BoxData["0.19976966877429916`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432021514854956`*^9, 
  3.8432037816956253`*^9, 3.843204060198579*^9, 3.8432043528783045`*^9, 
  3.8432051042428865`*^9},
 CellLabel->
  "Out[1325]=",ExpressionUUID->"bafde0a4-7c4e-4844-97ae-3a3e77b7d9a1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201958219412*^9}},ExpressionUUID->"b969e70f-40f1-4128-b0ba-\
50cb87fede9a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203614394541*^9, 
  3.8432036198484077`*^9}, {3.8432039862824287`*^9, 3.8432039888734045`*^9}, {
  3.8432042525331907`*^9, 3.843204281900442*^9}},
 CellLabel->
  "In[1326]:=",ExpressionUUID->"bbcb7466-0b91-4d87-903d-2053d8da51c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"rand", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.84320219723689*^9},
 CellLabel->
  "In[1340]:=",ExpressionUUID->"9fa78455-a13b-43df-82bb-c844036da895"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1341]:=",ExpressionUUID->"1e9d04f0-df87-4173-bbca-bffc3b1ef814"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "29.405802536513015`", "29.405802536513015`", 
      "2441.275077970055`", "5.34332094161013`*^-308"},
     {"Group", "6", "22.35708440681332`", "3.726180734468887`", 
      "309.3482026812842`", "1.377262766257471`*^-251"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.6312391783669327`", 
      "0.27187319639448876`", "22.57096224127159`", 
      "1.7224949989004386`*^-25"},
     {"\<\"Error\"\>", "1386", "16.694735748294466`", "0.012045263887658345`",
       "", ""},
     {"\<\"Total\"\>", "1399", "70.08886186998774`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022018345222`*^9, 3.8432037819495487`*^9, 3.8432040604630113`*^9, 
  3.843204353147248*^9, 3.84320510465829*^9},
 CellLabel->
  "Out[1342]=",ExpressionUUID->"0c0fe6f0-0567-4ab0-807b-a438256c767d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1343]:=",ExpressionUUID->"201e580f-c07f-468c-80b7-08fdf685cf55"],

Cell[BoxData["0.4195502930417061`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202202592086*^9, 
  3.8432037820797253`*^9, 3.8432040605685787`*^9, 3.8432043532204537`*^9, 
  3.8432051047271137`*^9},
 CellLabel->
  "Out[1343]=",ExpressionUUID->"acd079c6-c78f-4e4e-987f-8a7a2febabfe"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019666710215`*^9}},ExpressionUUID->"2970f22c-469a-4cf5-9f68-\
7cbbec2b2d95"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036301775594`*^9, 
  3.8432036348632784`*^9}, {3.843203989206848*^9, 3.8432039918422127`*^9}, {
  3.8432042525652647`*^9, 3.8432042847819242`*^9}},
 CellLabel->
  "In[1344]:=",ExpressionUUID->"7855a84e-32b5-41b6-9b5b-0bff0a9811e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "despot"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.843202251821741*^9},
 CellLabel->
  "In[1358]:=",ExpressionUUID->"f60ddfd0-22a0-4ef2-a514-8dfa93ea458c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1359]:=",ExpressionUUID->"30eb37c7-6b17-4261-8fee-ba4daaa0623a"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"811.9344740399549`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1360, 183, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.843203782358631*^9, 
  3.843204060872214*^9, 3.8432043534946246`*^9, 3.843205105168726*^9},
 CellLabel->
  "During evaluation of \
In[1359]:=",ExpressionUUID->"f68f9e67-f2cf-487b-8f7d-323d9addafe8"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "24.416573889198794`", "24.416573889198794`", 
      "3063.393536855678`", "0.`"},
     {"Group", "6", "12.738977988079412`", "2.1231629980132354`", 
      "266.3798711203333`", "1.045205511963312`*^-226"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.681067521814029`", 
      "0.2801779203023381`", "35.15215665059108`", "1.0004640759352101`*^-39"},
     {"\<\"Error\"\>", "1386", "11.047020568295942`", "0.007970433310458833`",
       "", ""},
     {"\<\"Total\"\>", "1399", "49.88363996738818`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022568375087`*^9, 3.8432037823623514`*^9, 3.8432040609230413`*^9, 
  3.8432043534977818`*^9, 3.8432051051782913`*^9},
 CellLabel->
  "Out[1360]=",ExpressionUUID->"4e95d4b4-083e-4d46-8c59-49f0faddae56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1361]:=",ExpressionUUID->"476aaae8-3c52-4fef-8e75-96de72afea63"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"811.9344740399549`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1361, 184, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.8432040609736433`*^9, 3.8432043535913124`*^9, 3.8432051052701063`*^9},
 CellLabel->
  "During evaluation of \
In[1361]:=",ExpressionUUID->"cd1e34bf-0cac-433c-ab7d-38829e0e69b7"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"811.9344740399549`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1361, 185, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.8432040609736433`*^9, 3.8432043535913124`*^9, 3.8432051053360043`*^9},
 CellLabel->
  "During evaluation of \
In[1361]:=",ExpressionUUID->"7ad1dfa4-3667-4de1-990e-15098741c627"],

Cell[BoxData["0.48947057402309296`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202258467805*^9, 
  3.8432037825058584`*^9, 3.8432040611167035`*^9, 3.843204353643487*^9, 
  3.843205105353758*^9},
 CellLabel->
  "Out[1361]=",ExpressionUUID->"479e0e68-c716-4fd4-9ecf-1b1a4adea263"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 
  3.8426911900556355`*^9}},ExpressionUUID->"61ca2f04-f3dc-4007-8039-\
0f4c43712b1d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203644202664*^9, 
  3.843203647744932*^9}, {3.8432039924328346`*^9, 3.843203995369296*^9}, {
  3.843204252600499*^9, 3.8432042526235266`*^9}, {3.843204284887599*^9, 
  3.8432042878039317`*^9}},
 CellLabel->
  "In[1362]:=",ExpressionUUID->"55a36cc1-b746-4aad-b5a4-5f010e1d90ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}},
 CellLabel->
  "In[1376]:=",ExpressionUUID->"92488bdc-32de-4b77-8e0f-0d8f88058876"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}},
 CellLabel->
  "In[1377]:=",ExpressionUUID->"8d83c436-89b3-486b-b067-e6d214858fce"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1259.0699147381763`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1378, 186, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8427057863575764`*^9, 3.8427083448470335`*^9, 
  3.8432037828131795`*^9, 3.843204061442011*^9, 3.8432043538907194`*^9, 
  3.8432051057283134`*^9},
 CellLabel->
  "During evaluation of \
In[1377]:=",ExpressionUUID->"1a397661-9b1e-464e-b8b8-67047d522b6a"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "54.24188313728075`", "54.24188313728075`", 
      "7095.137677390271`", "0.`"},
     {"Group", "6", "14.735001074794809`", "2.4558335124658015`", 
      "321.23657726989677`", "4.008428161592898`*^-258"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "4.788605056423478`", 
      "0.7981008427372462`", "104.39599497920089`", 
      "1.3894154112784257`*^-108"},
     {"\<\"Error\"\>", "1386", "10.595883187417373`", "0.007644937364658999`",
       "", ""},
     {"\<\"Total\"\>", "1399", "84.36137245591641`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.8427057863696804`*^9, 3.8427083448571405`*^9, 
  3.8432037828171196`*^9, 3.843204061482339*^9, 3.8432043538942337`*^9, 
  3.8432051057316313`*^9},
 CellLabel->
  "Out[1378]=",ExpressionUUID->"29e056be-0585-46bb-9d30-f26f210a317f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1379]:=",ExpressionUUID->"810773b4-71f3-4162-8a8c-a07b33f7b91f"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1259.0699147381763`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1379, 187, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432040618574305`*^9, 3.843204353942898*^9, 3.84320510581011*^9},
 CellLabel->
  "During evaluation of \
In[1379]:=",ExpressionUUID->"8548f1ce-8ccb-449f-9007-a0eeb8fdb6ff"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1259.0699147381763`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1379, 188, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432040618574305`*^9, 3.843204353942898*^9, 3.843205105883343*^9},
 CellLabel->
  "During evaluation of \
In[1379]:=",ExpressionUUID->"12284c59-ca95-4c89-b2df-62a061360734"],

Cell[BoxData["0.642970610342135`"], "Output",
 CellChangeTimes->{3.8427083710778227`*^9, 3.8432037832366447`*^9, 
  3.8432040620152874`*^9, 3.843204353992631*^9, 3.8432051058907785`*^9},
 CellLabel->
  "Out[1379]=",ExpressionUUID->"5a8a3e0d-aa05-4a39-9f2d-ee30dc4130e0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Despot vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201977267528*^9}},ExpressionUUID->"4852c954-1725-4a78-9a0c-\
cf9386207e55"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "8"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036576648865`*^9, 
  3.843203692894718*^9}, {3.8432039961853*^9, 3.843204002289308*^9}, {
  3.843204252636797*^9, 3.8432042526609464`*^9}, {3.8432042879031305`*^9, 
  3.843204291338702*^9}},
 CellLabel->
  "In[1380]:=",ExpressionUUID->"e236a285-e1ae-4c6d-96e6-fec56e3c03cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}, {3.8432022876973305`*^9, 
  3.843202303651292*^9}},
 CellLabel->
  "In[1394]:=",ExpressionUUID->"baaac07d-19cf-4c5a-a486-cda7465aa4dc"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1395]:=",ExpressionUUID->"3bb9ec7d-8af1-4134-936d-274a73de23c6"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "5.873817231789296`", "5.873817231789296`", 
      "574.4633832220924`", "1.7143195439503702`*^-106"},
     {"Group", "6", "22.37576308286394`", "3.72929384714399`", 
      "364.72751465013897`", "6.792395409536044`*^-281"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.556484387731377`", 
      "0.25941406462189615`", "25.370874737396786`", 
      "1.0513443060436248`*^-28"},
     {"\<\"Error\"\>", "1386", "14.171679033043855`", "0.010224876647217789`",
       "", ""},
     {"\<\"Total\"\>", "1399", "43.97774373542847`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432023088851333`*^9, 3.843203783510552*^9, 3.8432040623032837`*^9, 
  3.843204354238386*^9, 3.84320510624025*^9},
 CellLabel->
  "Out[1396]=",ExpressionUUID->"295052d9-4a20-480b-9026-073573356d7f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1397]:=",ExpressionUUID->"e065bc2c-e26c-43b4-9917-10ef122e8ebe"],

Cell[BoxData["0.13356340577921347`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432023097395687`*^9, 
  3.843203783603136*^9, 3.843204062410838*^9, 3.8432043542714753`*^9, 
  3.843205106302848*^9},
 CellLabel->
  "Out[1397]=",ExpressionUUID->"f6de169a-ba86-4861-804a-77e9c5f89c5f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ENBNB", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}},ExpressionUUID->"b4cc4d2a-1905-4d58-86cf-\
c7dbfe4a27f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayospars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayospars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203735607335*^9, 3.843203737916168*^9}, {
  3.843204015783373*^9, 3.8432040182527013`*^9}, {3.843204306449135*^9, 
  3.843204308864235*^9}},
 CellLabel->
  "In[1398]:=",ExpressionUUID->"90b12647-94b1-4fbb-ab83-0e09f5201fb7"],

Cell[BoxData["7.285714285714286`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.8432037836415243`*^9, 3.8432040624584074`*^9, 
   3.8432043543082895`*^9, 3.8432051063591237`*^9},
 CellLabel->
  "Out[1398]=",ExpressionUUID->"ff822bac-1c88-4637-9b77-f44aed06c7d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayospars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayospars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.843203738342523*^9, 3.84320374056324*^9}, {
  3.843204018352154*^9, 3.8432040206978917`*^9}, {3.8432043091845922`*^9, 
  3.8432043116703205`*^9}},
 CellLabel->
  "In[1399]:=",ExpressionUUID->"b2315aad-b241-4e1e-8e1a-a4d8c6ce7cf2"],

Cell[BoxData["34.142857142857146`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203783685481*^9, 
  3.843204062506754*^9, 3.843204354354189*^9, 3.8432051064312153`*^9},
 CellLabel->
  "Out[1399]=",ExpressionUUID->"ae01ad51-bcfa-48eb-be3d-065449438dfb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayospars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayospars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.8432037408350058`*^9, 3.8432037431439867`*^9}, {3.8432040208017015`*^9, 
  3.8432040230621047`*^9}, {3.8432043119786606`*^9, 3.8432043146133018`*^9}},
 CellLabel->
  "In[1400]:=",ExpressionUUID->"71f4994c-aa9e-439d-9160-077fc5271cd6"],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203783723936*^9, 
  3.843204062547219*^9, 3.84320435440132*^9, 3.8432051064846735`*^9},
 CellLabel->
  "Out[1400]=",ExpressionUUID->"b3a72324-9354-45e9-bc76-8941663b7da2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottyspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottyspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayospars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayospars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolaspars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolaspars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguespars", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguespars", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432037434342103`*^9, 3.843203748665327*^9}, {3.8432040231618757`*^9, 
  3.843204025577409*^9}, {3.8432043150029755`*^9, 3.84320431902954*^9}},
 CellLabel->
  "In[1401]:=",ExpressionUUID->"e7ef2e66-426c-4dd4-81e5-929709e64259"],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.843203783768177*^9, 
  3.8432040625962534`*^9, 3.843204354441471*^9, 3.843205106540538*^9},
 CellLabel->
  "Out[1401]=",ExpressionUUID->"3872be06-05f2-49ac-a36e-a80ab03739ef"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Observed", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}, {3.843203236007986*^9, 
  3.843203240657067*^9}},ExpressionUUID->"1c647191-bde3-4f47-9341-\
df4cc93423ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", "dottyspars", "}"}]}], "]"}], "]"}], ",", 
         "dottyspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", "hookspars", "}"}]}], "]"}], "]"}], ",", 
         "hookspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", "lindaspars", "}"}]}], "]"}], "]"}], ",", 
         "lindaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", "lodgespars", "}"}]}], "]"}], "]"}], ",", 
         "lodgespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", "nyayospars", "}"}]}], "]"}], "]"}], ",", 
         "nyayospars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", "violaspars", "}"}]}], "]"}], "]"}], ",", 
         "violaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", "voguespars", "}"}]}], "]"}], "]"}], ",", 
         "voguespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203270647889*^9, 3.843203394525511*^9}, {
  3.843203426549635*^9, 3.8432034349978504`*^9}, {3.8432037505175543`*^9, 
  3.843203752748629*^9}, {3.843204025692028*^9, 3.8432040289889507`*^9}, {
  3.8432043191402025`*^9, 3.843204322020508*^9}},
 CellLabel->
  "In[1402]:=",ExpressionUUID->"e47d5233-704a-4487-b557-33a4af2a3cd5"],

Cell[BoxData["84.85714285714286`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.84320343951612*^9, 3.843203783794284*^9, 
   3.8432040626653185`*^9, 3.843204354486467*^9, 3.8432051065935946`*^9},
 CellLabel->
  "Out[1402]=",ExpressionUUID->"30c195db-0cec-4d5b-8ff2-84aaf36e0f59"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", "dottyspars", "}"}]}], "]"}], "]"}], ",", 
         "dottyspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", "hookspars", "}"}]}], "]"}], "]"}], ",", 
         "hookspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", "lindaspars", "}"}]}], "]"}], "]"}], ",", 
         "lindaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", "lodgespars", "}"}]}], "]"}], "]"}], ",", 
         "lodgespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", "nyayospars", "}"}]}], "]"}], "]"}], ",", 
         "nyayospars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", "violaspars", "}"}]}], "]"}], "]"}], ",", 
         "violaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", "voguespars", "}"}]}], "]"}], "]"}], ",", 
         "voguespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.8432032875222225`*^9, 3.8432034131343436`*^9}, {
  3.843203753009065*^9, 3.8432037553109555`*^9}, {3.843204029100901*^9, 
  3.8432040317037697`*^9}, {3.8432043221177206`*^9, 3.8432043250423355`*^9}},
 CellLabel->
  "In[1403]:=",ExpressionUUID->"bfc887b6-335c-42f6-a88b-6e8986950d7f"],

Cell[BoxData["100.`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203440824523*^9, 
  3.843203783827556*^9, 3.8432040627216268`*^9, 3.8432043545245447`*^9, 
  3.8432051066412053`*^9},
 CellLabel->
  "Out[1403]=",ExpressionUUID->"71bd867c-6f62-448e-8cb6-d7c46eafb425"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", "dottyspars", "}"}]}], "]"}], "]"}], ",", 
         "dottyspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", "hookspars", "}"}]}], "]"}], "]"}], ",", 
         "hookspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", "lindaspars", "}"}]}], "]"}], "]"}], ",", 
         "lindaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", "lodgespars", "}"}]}], "]"}], "]"}], ",", 
         "lodgespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", "nyayospars", "}"}]}], "]"}], "]"}], ",", 
         "nyayospars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", "violaspars", "}"}]}], "]"}], "]"}], ",", 
         "violaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", "voguespars", "}"}]}], "]"}], "]"}], ",", 
         "voguespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.843203289198624*^9, 3.8432034145093603`*^9}, {3.843203755618435*^9, 
  3.8432037591618032`*^9}, {3.843204031814435*^9, 3.8432040357055902`*^9}, {
  3.843204325142517*^9, 3.843204328005783*^9}},
 CellLabel->
  "In[1404]:=",ExpressionUUID->"e27db1ae-74f4-4ba8-955f-8f10ba06b63b"],

Cell[BoxData["58.714285714285715`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203442360874*^9, 
  3.843203783861021*^9, 3.843204062770681*^9, 3.8432043546003327`*^9, 
  3.843205106693061*^9},
 CellLabel->
  "Out[1404]=",ExpressionUUID->"f2f7e83b-4988-4d6a-b3b1-f80c47f0b598"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", "dottyspars", "}"}]}], "]"}], "]"}], ",", 
         "dottyspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", "hookspars", "}"}]}], "]"}], "]"}], ",", 
         "hookspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", "lindaspars", "}"}]}], "]"}], "]"}], ",", 
         "lindaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", "lodgespars", "}"}]}], "]"}], "]"}], ",", 
         "lodgespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", "nyayospars", "}"}]}], "]"}], "]"}], ",", 
         "nyayospars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", "violaspars", "}"}]}], "]"}], "]"}], ",", 
         "violaspars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", "voguespars", "}"}]}], "]"}], "]"}], ",", 
         "voguespars"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432032904995956`*^9, 3.8432034170680695`*^9}, {3.8432037603835554`*^9, 
  3.843203766456238*^9}, {3.843204035811023*^9, 3.8432040414265823`*^9}, {
  3.8432043283852596`*^9, 3.8432043326472645`*^9}},
 CellLabel->
  "In[1405]:=",ExpressionUUID->"3ae9ef3d-3406-446d-af4c-3e74f9a1ad61"],

Cell[BoxData["39.42857142857143`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.8432034435089273`*^9, 
  3.843203783892887*^9, 3.8432040628136387`*^9, 3.8432051067421246`*^9},
 CellLabel->
  "Out[1405]=",ExpressionUUID->"1eebaf34-4c24-49a4-8c8c-cf94a1b33e33"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Maintained weight", "Section",
 CellChangeTimes->{{3.8426911378347073`*^9, 3.842691140154275*^9}, {
  3.8426911743027434`*^9, 3.8426911753528943`*^9}, {3.8426924162320967`*^9, 
  3.84269241943659*^9}},ExpressionUUID->"0f8beda5-51eb-43e3-8eb0-\
becc34f46e22"],

Cell[CellGroupData[{

Cell["Democ vs Comm", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019462315826`*^9}},ExpressionUUID->"5421897c-fcda-4b00-86ff-\
52a9045f5a28"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}},
 CellLabel->
  "In[1406]:=",ExpressionUUID->"0fc22316-d4ae-409f-bb61-5b8c610380af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}},
 CellLabel->
  "In[1420]:=",ExpressionUUID->"9fd034c8-aaa0-40e5-be31-86b28a726a17"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1421]:=",ExpressionUUID->"91b2b3cc-f9e4-477e-b184-efbe84933bde"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2497.9205719136075`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1422, 189, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781115415*^9, 3.8432051071300097`*^9},
 CellLabel->
  "During evaluation of \
In[1421]:=",ExpressionUUID->"3523a5e9-93c7-4e3d-a342-c414f5fec6d0"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.000012519719371439919`", 
      "0.000012519719371439919`", "0.16187240237025555`", 
      "0.6875004990446592`"},
     {"Group", "6", "3.9045496363812875`", "0.6507582727302146`", 
      "8413.911034576364`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.01277397441157424`", 
      "0.0021289957352623734`", "27.52662772051518`", 
      "3.666517518659663`*^-31"},
     {"\<\"Error\"\>", "1386", "0.10719758769703823`", 
      "0.00007734313686654995`", "", ""},
     {"\<\"Total\"\>", "1399", "4.0245337182092715`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432037811187725`*^9, 3.843205107138317*^9},
 CellLabel->
  "Out[1422]=",ExpressionUUID->"d6e2b5e4-f375-44eb-9855-76aee69793cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1423]:=",ExpressionUUID->"31edec09-ab93-4221-924b-a182de835cb8"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2497.9205719136075`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1423, 190, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.8432051072124386`*^9},
 CellLabel->
  "During evaluation of \
In[1423]:=",ExpressionUUID->"7a392ec7-5e7f-4464-b62b-027393de35ed"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2497.9205719136075`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1423, 191, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.843205107275172*^9},
 CellLabel->
  "During evaluation of \
In[1423]:=",ExpressionUUID->"0898e6ba-d691-4abe-af39-a48c4b85414e"],

Cell[BoxData["3.1108496655882428`*^-6"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432037812119827`*^9, 
  3.8432051072883673`*^9},
 CellLabel->
  "Out[1423]=",ExpressionUUID->"028b1739-da82-45ad-96e4-638e0a8e295b"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201954481023*^9}},ExpressionUUID->"83f3feb2-3657-499c-8a46-\
a7f76d55b8ad"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036025518847`*^9, 
  3.8432036088187733`*^9}},
 CellLabel->
  "In[1424]:=",ExpressionUUID->"2d37945e-5b49-4c12-be25-f936a6cc9018"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.8432021307129765`*^9},
 CellLabel->
  "In[1438]:=",ExpressionUUID->"a29ccb04-86e4-4494-9924-3305422bb0a9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1439]:=",ExpressionUUID->"333c03b6-962d-4e2a-9b72-f2e8ab645ed2"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2283.1365932488084`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1440, 192, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816017094`*^9, 3.8432051076519394`*^9},
 CellLabel->
  "During evaluation of \
In[1439]:=",ExpressionUUID->"d483fbb9-3aeb-4a58-b779-9474fa116fc3"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.0029974494594626755`", "0.0029974494594626755`", 
      "29.30837540177131`", "7.266448785806887`*^-8"},
     {"Group", "6", "3.749211156167741`", "0.6248685260279567`", 
      "6109.821561715946`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.0059723818022212605`", 
      "0.0009953969670368767`", "9.732763930882431`", 
      "1.6017876401333564`*^-10"},
     {"\<\"Error\"\>", "1386", "0.14175009340723077`", 
      "0.00010227279466611167`", "", ""},
     {"\<\"Total\"\>", "1399", "3.8999310808366556`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432021385871325`*^9, 3.8432037816047707`*^9, 3.84320510765707*^9},
 CellLabel->
  "Out[1440]=",ExpressionUUID->"31948e92-d3f3-4564-b565-8dbeaebe0389"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1441]:=",ExpressionUUID->"33f7daab-c957-49e9-8735-3bd93b41ae27"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2283.1365932488084`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1441, 193, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843205107724987*^9},
 CellLabel->
  "During evaluation of \
In[1441]:=",ExpressionUUID->"2b6ee6c8-fa47-4288-a579-e98e41c8b77e"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2283.1365932488084`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1441, 194, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843205107782753*^9},
 CellLabel->
  "During evaluation of \
In[1441]:=",ExpressionUUID->"2716472f-3d6d-487b-8fc7-046821e77cc7"],

Cell[BoxData["0.0007685903666840261`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432021514854956`*^9, 
  3.8432037816956253`*^9, 3.8432051077963467`*^9},
 CellLabel->
  "Out[1441]=",ExpressionUUID->"47cb4555-db0d-4e25-b830-96db4054d512"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201958219412*^9}},ExpressionUUID->"5b25fad5-3d7c-4735-8249-\
a0679ffbc462"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203614394541*^9, 
  3.8432036198484077`*^9}},
 CellLabel->
  "In[1442]:=",ExpressionUUID->"790a5638-2075-4355-9ebb-0a147a29b995"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"rand", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.84320219723689*^9},
 CellLabel->
  "In[1456]:=",ExpressionUUID->"66ffb605-0b54-4648-9480-d60129d94973"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1457]:=",ExpressionUUID->"c1a6b15c-26f4-4f66-aa95-cb9da6e34d65"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1839.4835432824957`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1458, 195, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202201809596*^9, 3.843203781945182*^9, 
  3.843205108233078*^9},
 CellLabel->
  "During evaluation of \
In[1457]:=",ExpressionUUID->"383bb40b-7c34-4bd7-973a-a3ee53b8e31e"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.07162092318477953`", "0.07162092318477953`", 
      "357.7174468005835`", "3.738664094016772`*^-71"},
     {"Group", "6", "3.737832767763874`", "0.6229721279606456`", 
      "3111.4929706654066`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.007345654975063454`", 
      "0.0012242758291772422`", "6.114760943014764`", "2.44988925202647`*^-6"},
     {"\<\"Error\"\>", "1386", "0.2775000224952475`", 
      "0.00020021646644678752`", "", ""},
     {"\<\"Total\"\>", "1399", "4.094299368418964`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022018345222`*^9, 3.8432037819495487`*^9, 3.8432051082379913`*^9},
 CellLabel->
  "Out[1458]=",ExpressionUUID->"f492e517-e80d-4228-914b-c7130caaa22e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1459]:=",ExpressionUUID->"9b6b3d8d-074d-4a95-807c-021ce34e1ce1"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1839.4835432824957`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1459, 196, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.843205108301553*^9},
 CellLabel->
  "During evaluation of \
In[1459]:=",ExpressionUUID->"d0c909c4-f5e6-4ea1-bcd5-aaed0e0448a2"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1839.4835432824957`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1459, 197, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.843205108362194*^9},
 CellLabel->
  "During evaluation of \
In[1459]:=",ExpressionUUID->"d43dc418-da08-4677-b1b8-6cbd7c996c67"],

Cell[BoxData["0.017492839858565676`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202202592086*^9, 
  3.8432037820797253`*^9, 3.8432051083741784`*^9},
 CellLabel->
  "Out[1459]=",ExpressionUUID->"c945b023-6090-4e30-aac5-10194f3b3451"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019666710215`*^9}},ExpressionUUID->"85b1c9b5-da39-4039-9126-\
578612f0bc5e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036301775594`*^9, 
  3.8432036348632784`*^9}},
 CellLabel->
  "In[1460]:=",ExpressionUUID->"50d24436-8f9b-410f-a1e2-50a76e5989f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "despot"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.843202251821741*^9},
 CellLabel->
  "In[1474]:=",ExpressionUUID->"baf7b7af-32b0-409c-9fd6-875db81baa3c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1475]:=",ExpressionUUID->"01de4b96-4f3d-49d2-a058-6f3e32a7c5a7"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2318.535033700866`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1476, 198, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.843203782358631*^9, 
  3.843205108738224*^9},
 CellLabel->
  "During evaluation of \
In[1475]:=",ExpressionUUID->"b6d5e98a-fbe9-43a4-b20e-17981c7a67ca"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.003397408082706832`", "0.003397408082706832`", 
      "34.155469589968675`", "6.3340657245681535`*^-9"},
     {"Group", "6", "3.8447696647081306`", "0.6407949441180217`", 
      "6442.161699277208`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.029156317942452326`", 
      "0.004859386323742054`", "48.853307511484964`", 
      "1.3566361433888154`*^-54"},
     {"\<\"Error\"\>", "1386", "0.1378639397777341`", 
      "0.00009946893201856716`", "", ""},
     {"\<\"Total\"\>", "1399", "4.015187330511024`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022568375087`*^9, 3.8432037823623514`*^9, 3.8432051087448483`*^9},
 CellLabel->
  "Out[1476]=",ExpressionUUID->"0f91937a-fd1d-4339-b90c-24d077e0b06b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1477]:=",ExpressionUUID->"815e0866-98f3-473d-b3bf-c1e3dbf3837d"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2318.535033700866`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1477, 199, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.84320510881415*^9},
 CellLabel->
  "During evaluation of \
In[1477]:=",ExpressionUUID->"3969f944-5b62-456f-91ee-6049a0324eba"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2318.535033700866`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1477, 200, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.84320510887195*^9},
 CellLabel->
  "During evaluation of \
In[1477]:=",ExpressionUUID->"07887997-e529-4345-bedb-35a1f798f0cc"],

Cell[BoxData["0.0008461393711048682`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202258467805*^9, 
  3.8432037825058584`*^9, 3.8432051088832607`*^9},
 CellLabel->
  "Out[1477]=",ExpressionUUID->"97fb9d4c-2c24-4e50-9c01-2c25b899a686"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 
  3.8426911900556355`*^9}},ExpressionUUID->"917748ac-8df6-434e-bc04-\
5d48ff97fe2f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203644202664*^9, 
  3.843203647744932*^9}},
 CellLabel->
  "In[1478]:=",ExpressionUUID->"ca2df31a-1487-449d-aecb-b51de440c5de"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}},
 CellLabel->
  "In[1492]:=",ExpressionUUID->"ce282099-6632-4861-8ef3-9634c8abe0a5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}},
 CellLabel->
  "In[1495]:=",ExpressionUUID->"fde877d9-732a-4956-8368-f23da5b8d0d3"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1866.4687436244556`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1496, 201, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8427057863575764`*^9, 3.8427083448470335`*^9, 
  3.8432037828131795`*^9, 3.843205109319064*^9},
 CellLabel->
  "During evaluation of \
In[1495]:=",ExpressionUUID->"114d59ab-94fe-4c18-94d0-7e8d3a473e29"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.07352730019476628`", "0.07352730019476628`", 
      "372.4549435026915`", "1.0784947103479776`*^-73"},
     {"Group", "6", "3.8427282532078246`", "0.6404547088679707`", 
      "3244.2442708433928`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.021192614211734018`", 
      "0.0035321023686223363`", "17.89198004912734`", 
      "4.5636306663206126`*^-20"},
     {"\<\"Error\"\>", "1386", "0.2736138688657508`", "0.000197412603799243`",
       "", ""},
     {"\<\"Total\"\>", "1399", "4.211062036480076`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.8427057863696804`*^9, 3.8427083448571405`*^9, 
  3.8432037828171196`*^9, 3.843205109322024*^9},
 CellLabel->
  "Out[1496]=",ExpressionUUID->"60964629-439b-478c-aa85-76510680bccd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1500]:=",ExpressionUUID->"87fbb957-b602-40b6-94af-1aa959b3e75c"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1866.4687436244556`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1500, 206, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.843205109793808*^9},
 CellLabel->
  "During evaluation of \
In[1500]:=",ExpressionUUID->"2f01fce0-3dc3-4569-88f6-3e53d688f8fd"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1866.4687436244556`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1500, 207, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432051098556957`*^9},
 CellLabel->
  "During evaluation of \
In[1500]:=",ExpressionUUID->"847eab28-b0c3-4754-9563-a1d891a3bf62"],

Cell[BoxData["0.01746051223131017`"], "Output",
 CellChangeTimes->{3.8427083710778227`*^9, 3.8432037832366447`*^9, 
  3.8432051098707514`*^9},
 CellLabel->
  "Out[1500]=",ExpressionUUID->"8e9fed52-34e3-4767-b0f6-cfaf3546206f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Despot vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201977267528*^9}},ExpressionUUID->"39384a03-0f4b-493b-a150-\
1b11a01c3c21"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "7"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036576648865`*^9, 
  3.843203692894718*^9}},
 CellLabel->
  "In[1501]:=",ExpressionUUID->"a38b3dee-cb8b-4d25-9e46-0de29ec2b2cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}, {3.8432022876973305`*^9, 
  3.843202303651292*^9}},
 CellLabel->
  "In[1515]:=",ExpressionUUID->"81ae33d1-cdfa-4f71-8d0e-e889f80a7e10"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1516]:=",ExpressionUUID->"7bc373fc-b9e1-422f-8d85-deb8240c52af"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1765.3816905951214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1517, 208, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037835063195`*^9, 3.8432051102584715`*^9},
 CellLabel->
  "During evaluation of \
In[1516]:=",ExpressionUUID->"c0285038-53b6-434b-855c-2d91577685cd"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.045314441338939915`", "0.045314441338939915`", 
      "203.80489526865333`", "3.0590510314199797`*^-43"},
     {"Group", "6", "3.698604706068777`", "0.6164341176781294`", 
      "2772.455912094776`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.0031760885278813156`", 
      "0.0005293480879802193`", "2.380780352659078`", "0.027148741155770224`"},
     {"\<\"Error\"\>", "1386", "0.3081663745759433`", 
      "0.0002223422615988047`", "", ""},
     {"\<\"Total\"\>", "1399", "4.0552616105115415`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432023088851333`*^9, 3.843203783510552*^9, 3.843205110264804*^9},
 CellLabel->
  "Out[1517]=",ExpressionUUID->"81518a2c-879f-44a0-969c-ab8220403bce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1518]:=",ExpressionUUID->"cf7bb91d-548f-4beb-8b1f-bb762f99a828"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1765.3816905951214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1518, 209, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432051103844748`*^9},
 CellLabel->
  "During evaluation of \
In[1518]:=",ExpressionUUID->"8d8aeaca-ca66-4146-b604-5492e55fa52c"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1765.3816905951214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1518, 210, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432051104485927`*^9},
 CellLabel->
  "During evaluation of \
In[1518]:=",ExpressionUUID->"aadaee67-2ea0-4e6e-b9aa-41a14a3dc3f6"],

Cell[BoxData["0.011174233795788044`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432023097395687`*^9, 
  3.843203783603136*^9, 3.8432051104542685`*^9},
 CellLabel->
  "Out[1518]=",ExpressionUUID->"2b89887e-f345-4543-9a0c-450670dc6cb2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ENBNB", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}},ExpressionUUID->"e352cf3b-013c-4f24-aa58-\
992aa600d311"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottymain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottymain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayomain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayomain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203735607335*^9, 3.843203737916168*^9}},
 CellLabel->
  "In[1519]:=",ExpressionUUID->"dddcbcb2-e4b8-46ea-b8ce-065e46f80a0b"],

Cell[BoxData["72.57142857142857`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.8432037836415243`*^9, 3.8432051105125203`*^9},
 CellLabel->
  "Out[1519]=",ExpressionUUID->"d1b26eeb-803a-4ab4-b3e3-b29b94d360f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottymain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottymain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayomain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayomain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.843203738342523*^9, 3.84320374056324*^9}},
 CellLabel->
  "In[1520]:=",ExpressionUUID->"b8d43102-6b5f-4d2f-a439-b47398e45625"],

Cell[BoxData["69.14285714285714`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203783685481*^9, 
  3.843205110571136*^9},
 CellLabel->
  "Out[1520]=",ExpressionUUID->"1619fc05-b430-4f4a-96ed-7c0a2e9e3553"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottymain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottymain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayomain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayomain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.8432037408350058`*^9, 3.8432037431439867`*^9}},
 CellLabel->
  "In[1521]:=",ExpressionUUID->"36e6058e-c68e-4550-91ec-220e0149d6de"],

Cell[BoxData["75.14285714285714`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203783723936*^9, 
  3.843205110630111*^9},
 CellLabel->
  "Out[1521]=",ExpressionUUID->"bdbe5e33-84a3-4cac-b2a8-bda341018780"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottymain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottymain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayomain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayomain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolamain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolamain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguemain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguemain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432037434342103`*^9, 3.843203748665327*^9}},
 CellLabel->
  "In[1522]:=",ExpressionUUID->"049baf87-c906-4ec0-9d18-eb2fbcdbaa56"],

Cell[BoxData["88.28571428571429`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.843203783768177*^9, 
  3.8432051106873283`*^9},
 CellLabel->
  "Out[1522]=",ExpressionUUID->"1a817b93-920d-4000-a193-17c234544e32"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Observed", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}, {3.843203236007986*^9, 
  3.843203240657067*^9}},ExpressionUUID->"4ea0221a-49e6-4e23-b8a3-\
cbec79f4caf2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", "dottymain", "}"}]}], "]"}], "]"}], ",", 
         "dottymain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", "hookmain", "}"}]}], "]"}], "]"}], ",", "hookmain"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", "lindamain", "}"}]}], "]"}], "]"}], ",", 
         "lindamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", "lodgemain", "}"}]}], "]"}], "]"}], ",", 
         "lodgemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", "nyayomain", "}"}]}], "]"}], "]"}], ",", 
         "nyayomain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", "violamain", "}"}]}], "]"}], "]"}], ",", 
         "violamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", "voguemain", "}"}]}], "]"}], "]"}], ",", 
         "voguemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203270647889*^9, 3.843203394525511*^9}, {
  3.843203426549635*^9, 3.8432034349978504`*^9}, {3.8432037505175543`*^9, 
  3.843203752748629*^9}},
 CellLabel->
  "In[1523]:=",ExpressionUUID->"d8b0d7e2-e69c-49ee-8697-bf9df4f6351a"],

Cell[BoxData["41.285714285714285`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.84320343951612*^9, 3.843203783794284*^9, 
   3.8432051107451887`*^9},
 CellLabel->
  "Out[1523]=",ExpressionUUID->"9f137cf3-d1a3-491c-836b-f1dcf62d9772"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", "dottymain", "}"}]}], "]"}], "]"}], ",", 
         "dottymain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", "hookmain", "}"}]}], "]"}], "]"}], ",", "hookmain"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", "lindamain", "}"}]}], "]"}], "]"}], ",", 
         "lindamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", "lodgemain", "}"}]}], "]"}], "]"}], ",", 
         "lodgemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", "nyayomain", "}"}]}], "]"}], "]"}], ",", 
         "nyayomain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", "violamain", "}"}]}], "]"}], "]"}], ",", 
         "violamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", "voguemain", "}"}]}], "]"}], "]"}], ",", 
         "voguemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.8432032875222225`*^9, 3.8432034131343436`*^9}, {
  3.843203753009065*^9, 3.8432037553109555`*^9}},
 CellLabel->
  "In[1524]:=",ExpressionUUID->"b95fb785-f480-48c1-9272-39c2867ac0ab"],

Cell[BoxData["41.57142857142857`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203440824523*^9, 
  3.843203783827556*^9, 3.843205110790969*^9},
 CellLabel->
  "Out[1524]=",ExpressionUUID->"4d20d2a2-110e-4868-9822-d6a3e37512ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", "dottymain", "}"}]}], "]"}], "]"}], ",", 
         "dottymain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", "hookmain", "}"}]}], "]"}], "]"}], ",", "hookmain"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", "lindamain", "}"}]}], "]"}], "]"}], ",", 
         "lindamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", "lodgemain", "}"}]}], "]"}], "]"}], ",", 
         "lodgemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", "nyayomain", "}"}]}], "]"}], "]"}], ",", 
         "nyayomain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", "violamain", "}"}]}], "]"}], "]"}], ",", 
         "violamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", "voguemain", "}"}]}], "]"}], "]"}], ",", 
         "voguemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.843203289198624*^9, 3.8432034145093603`*^9}, {3.843203755618435*^9, 
  3.8432037591618032`*^9}},
 CellLabel->
  "In[1525]:=",ExpressionUUID->"ffa2840b-6203-414b-b30f-f7fcebd78b34"],

Cell[BoxData["47.714285714285715`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203442360874*^9, 
  3.843203783861021*^9, 3.843205110842248*^9},
 CellLabel->
  "Out[1525]=",ExpressionUUID->"752cf310-ff4f-4dbd-a60c-5d1aa21ad269"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", "dottymain", "}"}]}], "]"}], "]"}], ",", 
         "dottymain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", "hookmain", "}"}]}], "]"}], "]"}], ",", "hookmain"}],
         "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", "lindamain", "}"}]}], "]"}], "]"}], ",", 
         "lindamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", "lodgemain", "}"}]}], "]"}], "]"}], ",", 
         "lodgemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", "nyayomain", "}"}]}], "]"}], "]"}], ",", 
         "nyayomain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", "violamain", "}"}]}], "]"}], "]"}], ",", 
         "violamain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", "voguemain", "}"}]}], "]"}], "]"}], ",", 
         "voguemain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432032904995956`*^9, 3.8432034170680695`*^9}, {3.8432037603835554`*^9, 
  3.843203766456238*^9}},
 CellLabel->
  "In[1526]:=",ExpressionUUID->"695512c2-5c06-4dcc-b864-1fe382055af4"],

Cell[BoxData["67.`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.8432034435089273`*^9, 
  3.843203783892887*^9, 3.843205110890358*^9},
 CellLabel->
  "Out[1526]=",ExpressionUUID->"a83b465a-0f0b-4124-986d-c258e2bf5a39"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Betweenness Centrality Broken", "Section",
 CellChangeTimes->{{3.8426911378347073`*^9, 3.842691140154275*^9}, {
  3.8426911743027434`*^9, 3.8426911753528943`*^9}, {3.8426924162320967`*^9, 
  3.84269241943659*^9}, {3.84320446335455*^9, 
  3.843204468097785*^9}},ExpressionUUID->"c13374e5-5b49-4b78-bcee-\
1ecccf74e765"],

Cell[CellGroupData[{

Cell["Democ vs Comm", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019462315826`*^9}},ExpressionUUID->"785c1f8e-c83b-45fc-9d05-\
be4d898bbdef"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432044948905406`*^9, 
  3.843204497506837*^9}},
 CellLabel->
  "In[1530]:=",ExpressionUUID->"8144515f-7d59-4bf9-864d-1044028f1391"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}},
 CellLabel->
  "In[1544]:=",ExpressionUUID->"0fb5adce-b1c4-4bca-8ba5-d280aad35d96"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1545]:=",ExpressionUUID->"fac8bf85-ca22-4be6-8da1-78d6afd32fe9"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1220.3571556003649`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1546, 215, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781115415*^9, 3.843204587953199*^9, 
  3.8432051382271357`*^9},
 CellLabel->
  "During evaluation of \
In[1545]:=",ExpressionUUID->"1fe0baa4-ce6e-458b-b9de-808635945b04"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "3.4729038292676933`", "3.4729038292676933`", 
      "30.521320221583235`", "3.9390194212676175`*^-8"},
     {"Group", "6", "775.9130725899762`", "129.31884543166268`", 
      "1136.5076852523944`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "2.593809519678871`", 
      "0.4323015866131451`", "3.7992457626160396`", "0.0009254519015351084`"},
     {"\<\"Error\"\>", "1386", "157.70761790183582`", "0.11378616010233464`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "939.6874038407585`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432037811187725`*^9, 3.8432045879564924`*^9, 3.8432051382358704`*^9},
 CellLabel->
  "Out[1546]=",ExpressionUUID->"383637ee-b060-4cc0-af4b-0a2919c58138"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1547]:=",ExpressionUUID->"cc00edf2-ce27-44fb-b51c-be2253fa98ca"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1220.3571556003649`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1547, 216, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.843204588017488*^9, 
  3.8432051383877316`*^9},
 CellLabel->
  "During evaluation of \
In[1547]:=",ExpressionUUID->"439c7b3d-67a8-48c9-b838-eeb17c972f32"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1220.3571556003649`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1547, 217, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.843204588017488*^9, 
  3.8432051384771776`*^9},
 CellLabel->
  "During evaluation of \
In[1547]:=",ExpressionUUID->"96171f55-0f85-4619-a8f2-297c7693e1f8"],

Cell[BoxData["0.0036958075792790125`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432037812119827`*^9, 
  3.8432045880807266`*^9, 3.843205138495199*^9},
 CellLabel->
  "Out[1547]=",ExpressionUUID->"8bc61dfc-8c3e-4b0d-ae33-d90b2cee710e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201954481023*^9}},ExpressionUUID->"e911b7c9-2c67-4fbd-9626-\
f637c33fd8a0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036025518847`*^9, 
  3.8432036088187733`*^9}, {3.8432044978049383`*^9, 3.8432045002881784`*^9}},
 CellLabel->
  "In[1548]:=",ExpressionUUID->"19889b2d-37a5-4cfe-b2d4-f7942060ab66"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.8432021307129765`*^9},
 CellLabel->
  "In[1562]:=",ExpressionUUID->"c9c0de69-46da-493b-b017-7a7a03594e5c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1563]:=",ExpressionUUID->"60cff17c-5fed-4688-94cd-2a719f90a08c"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1008.4322470109398`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1564, 218, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816017094`*^9, 3.8432045883531647`*^9, 
  3.8432051391043715`*^9},
 CellLabel->
  "During evaluation of \
In[1563]:=",ExpressionUUID->"8ada07e9-857f-4a81-a2ec-37b65b5df779"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "7.314332028664353`", "7.314332028664353`", 
      "67.75948084761386`", "4.2182820731922466`*^-16"},
     {"Group", "6", "502.5869212609759`", "83.76448687682931`", 
      "775.9885826890968`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "25.489249589361123`", 
      "4.24820826489352`", "39.355116151910856`", "2.3346553011252353`*^-44"},
     {"\<\"Error\"\>", "1386", "149.61248322618738`", "0.1079455145932088`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "685.0029861051888`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432021385871325`*^9, 3.8432037816047707`*^9, 3.843204588357154*^9, 
  3.843205139110346*^9},
 CellLabel->
  "Out[1564]=",ExpressionUUID->"1947b758-4877-4b06-88ed-6d8338fc53f9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1565]:=",ExpressionUUID->"6e4df809-6476-4913-8ab6-5ebb3d3e3bae"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1008.4322470109398`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1565, 219, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843204588409564*^9, 
  3.8432051392206755`*^9},
 CellLabel->
  "During evaluation of \
In[1565]:=",ExpressionUUID->"703d35d8-d568-47f2-8535-217e79629788"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1008.4322470109398`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1565, 220, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843204588409564*^9, 
  3.843205139320826*^9},
 CellLabel->
  "During evaluation of \
In[1565]:=",ExpressionUUID->"0ebca223-97e4-4e3d-989a-15d401af288b"],

Cell[BoxData["0.01067781042861201`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432021514854956`*^9, 
  3.8432037816956253`*^9, 3.8432045884568195`*^9, 3.8432051393532114`*^9},
 CellLabel->
  "Out[1565]=",ExpressionUUID->"cfdd097a-0466-4330-a34e-168e1153640d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201958219412*^9}},ExpressionUUID->"5dccd9be-bcfc-4877-8b46-\
e800b0f95eb9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203614394541*^9, 
  3.8432036198484077`*^9}, {3.8432045005780706`*^9, 3.843204503001483*^9}},
 CellLabel->
  "In[1566]:=",ExpressionUUID->"594c45ca-5c16-469c-9625-99a9b1675581"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"rand", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.84320219723689*^9},
 CellLabel->
  "In[1580]:=",ExpressionUUID->"11d721a1-845f-4555-9bd3-afdd7b994920"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1581]:=",ExpressionUUID->"9f9182cd-aedc-45c5-ad5c-d2e9f31dc647"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"991.6097718985234`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1582, 221, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202201809596*^9, 3.843203781945182*^9, 
  3.8432045887201366`*^9, 3.843205139942048*^9},
 CellLabel->
  "During evaluation of \
In[1581]:=",ExpressionUUID->"aaa7200c-ef49-4892-933f-59195a289f81"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "14.136181640049472`", "14.136181640049472`", 
      "142.93769897678018`", "2.0063813702987242`*^-31"},
     {"Group", "6", "446.11729454585304`", "74.35288242430883`", 
      "751.8175838878506`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "39.698158763297215`", 
      "6.616359793882869`", "66.90118085783108`", "3.470636330908167`*^-73"},
     {"\<\"Error\"\>", "1386", "137.0719403863592`", "0.09889750388626203`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "637.0235753355589`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022018345222`*^9, 3.8432037819495487`*^9, 3.8432045887234974`*^9, 
  3.8432051399515176`*^9},
 CellLabel->
  "Out[1582]=",ExpressionUUID->"a7a1be09-0d03-46ef-9428-3f9c9b203cfa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1583]:=",ExpressionUUID->"63a19a85-54f0-45b9-9a70-c292887591d7"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"991.6097718985234`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1583, 222, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.843204588774068*^9, 3.8432051401593924`*^9},
 CellLabel->
  "During evaluation of \
In[1583]:=",ExpressionUUID->"afe0fb9c-cfc2-4fd2-aa44-a5e332897b7a"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"991.6097718985234`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1583, 223, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.843204588774068*^9, 3.843205140250046*^9},
 CellLabel->
  "During evaluation of \
In[1583]:=",ExpressionUUID->"577540a1-4659-4474-b53e-6e04bbca4dfe"],

Cell[BoxData["0.0221909866249504`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202202592086*^9, 
  3.8432037820797253`*^9, 3.8432045888219457`*^9, 3.84320514026208*^9},
 CellLabel->
  "Out[1583]=",ExpressionUUID->"d1db5c84-1ab4-4458-b8e8-aa3045d448ad"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019666710215`*^9}},ExpressionUUID->"ad7d039d-09e4-464a-929d-\
9577b94fbe61"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036301775594`*^9, 
  3.8432036348632784`*^9}, {3.8432045033397074`*^9, 3.843204506102734*^9}},
 CellLabel->
  "In[1584]:=",ExpressionUUID->"090347d5-a91a-40a9-a23d-0dafd9f95075"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "despot"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.843202251821741*^9},
 CellLabel->
  "In[1598]:=",ExpressionUUID->"f9cc876c-5e3b-49f1-b89a-12f5656934b6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1599]:=",ExpressionUUID->"d561c600-d7fc-41f4-abba-fab3e7239d0d"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1770.2105957373765`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1600, 224, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.843203782358631*^9, 
  3.843204589133374*^9, 3.843205140819789*^9},
 CellLabel->
  "During evaluation of \
In[1599]:=",ExpressionUUID->"ecc2a0f8-de6b-4589-afc3-ccc44fe3e7d7"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "20.867309609821405`", "20.867309609821405`", 
      "659.7574610714022`", "2.4891847347191995`*^-119"},
     {"Group", "6", "530.1225046441622`", "88.35375077402702`", 
      "2793.4624720079764`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "30.435072664125983`", 
      "5.072512110687663`", "160.37657819703355`", "8.396393188453929`*^-155"},
     {"\<\"Error\"\>", "1386", "43.83745971170211`", "0.03162875881075188`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "625.2623466298116`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022568375087`*^9, 3.8432037823623514`*^9, 3.8432045891380825`*^9, 
  3.8432051408260493`*^9},
 CellLabel->
  "Out[1600]=",ExpressionUUID->"eb68ec09-e9d3-4a43-bee4-c73be407288b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1601]:=",ExpressionUUID->"6e73f683-1df8-4ee8-bd46-333ef2e73a0b"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1770.2105957373765`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1601, 225, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.843204589201516*^9, 3.8432051409439297`*^9},
 CellLabel->
  "During evaluation of \
In[1601]:=",ExpressionUUID->"7718b58d-0755-46e9-9062-96d3b5c6da2b"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1770.2105957373765`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1601, 226, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.843204589201516*^9, 3.8432051410386915`*^9},
 CellLabel->
  "During evaluation of \
In[1601]:=",ExpressionUUID->"f204e1f9-b481-4d42-bb8d-267e343e88c4"],

Cell[BoxData["0.033373686616980876`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202258467805*^9, 
  3.8432037825058584`*^9, 3.8432045892570734`*^9, 3.843205141061042*^9},
 CellLabel->
  "Out[1601]=",ExpressionUUID->"52694dc9-ab1b-46d3-b49b-950a8df55d2c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 
  3.8426911900556355`*^9}},ExpressionUUID->"4f8dcc77-532b-4c61-b8a3-\
e6ec14b53e27"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203644202664*^9, 
  3.843203647744932*^9}, {3.8432045063036966`*^9, 3.8432045090867963`*^9}},
 CellLabel->
  "In[1602]:=",ExpressionUUID->"2852f062-3451-40fb-b8cb-f1bc76c33e2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}},
 CellLabel->
  "In[1616]:=",ExpressionUUID->"3fbfb4b8-913d-4c9a-b1b4-bc0436343245"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}},
 CellLabel->
  "In[1619]:=",ExpressionUUID->"834f3aa9-b437-48ea-873d-c7daca6f97f0"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1912.370009512076`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1620, 227, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8427057863575764`*^9, 3.8427083448470335`*^9, 
  3.8432037828131795`*^9, 3.843204589573631*^9, 3.843205141773483*^9},
 CellLabel->
  "During evaluation of \
In[1619]:=",ExpressionUUID->"69d7e465-95a6-4783-ac0f-0da4a5cf5476"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "31.62245042552263`", "31.62245042552263`", 
      "1400.4164202245292`", "2.0187921768906534`*^-212"},
     {"Group", "6", "471.7938697515112`", "78.63231162525186`", 
      "3482.2722109902684`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "46.50299001558989`", 
      "7.750498335931647`", "343.2347901097922`", "7.417170011947703`*^-270"},
     {"\<\"Error\"\>", "1386", "31.296916871873933`", "0.022580748103805146`",
       "", ""},
     {"\<\"Total\"\>", "1399", "581.2162270644976`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.8427057863696804`*^9, 3.8427083448571405`*^9, 
  3.8432037828171196`*^9, 3.8432045895776997`*^9, 3.843205141784157*^9},
 CellLabel->
  "Out[1620]=",ExpressionUUID->"ce552a56-22bd-4f9b-bc27-f95e51a80753"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1624]:=",ExpressionUUID->"d07e5511-ca38-42fa-945a-a30f9a1da71a"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1912.370009512076`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1624, 232, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432045899664354`*^9, 3.8432051425160675`*^9},
 CellLabel->
  "During evaluation of \
In[1624]:=",ExpressionUUID->"fecfd61c-7b29-40e7-ab25-c99c7dc35eb6"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1912.370009512076`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1624, 233, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432045899664354`*^9, 3.8432051426022863`*^9},
 CellLabel->
  "During evaluation of \
In[1624]:=",ExpressionUUID->"d76d3891-1a06-4750-917f-ef08d70aa3d6"],

Cell[BoxData["0.05440737707072567`"], "Output",
 CellChangeTimes->{3.8427083710778227`*^9, 3.8432037832366447`*^9, 
  3.843204590007826*^9, 3.8432051426232204`*^9},
 CellLabel->
  "Out[1624]=",ExpressionUUID->"307de091-ecfc-49f5-9e23-3d35633db1e9"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Despot vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201977267528*^9}},ExpressionUUID->"f5187dc0-9453-4955-8d5b-\
08d2e465069d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "dottymax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lindamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "lodgemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "nyayomax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "violamax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "9"}], "]"}], "]"}], "/", "voguemax"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036576648865`*^9, 
  3.843203692894718*^9}, {3.84320450973641*^9, 3.843204513199148*^9}},
 CellLabel->
  "In[1625]:=",ExpressionUUID->"aee98e4d-d42c-4030-8356-fc543f70d4a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}, {3.8432022876973305`*^9, 
  3.843202303651292*^9}},
 CellLabel->
  "In[1639]:=",ExpressionUUID->"f3bcfc9e-f14d-48c2-a547-06b1d41c560b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1640]:=",ExpressionUUID->"a4e29b24-bcaa-445c-9b7a-09b6f82c6fa5"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1736.5003589037144`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1641, 234, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037835063195`*^9, 3.8432045902787943`*^9, 
  3.8432051432135963`*^9},
 CellLabel->
  "During evaluation of \
In[1640]:=",ExpressionUUID->"ce77ac5e-6cd8-480c-ad23-a0a0dfe52b04"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "1.1136775202043054`", "1.1136775202043054`", 
      "66.52752059944241`", "7.655636546873508`*^-16"},
     {"Group", "6", "266.1502982784877`", "44.358383046414616`", 
      "2649.827430598519`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.715850229295711`", 
      "0.2859750382159518`", "17.08323091800207`", "4.001990358239249`*^-19"},
     {"\<\"Error\"\>", "1386", "23.20178219622549`", "0.016740102594679285`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "292.1816082242132`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432023088851333`*^9, 3.843203783510552*^9, 3.8432045902824507`*^9, 
  3.843205143218363*^9},
 CellLabel->
  "Out[1641]=",ExpressionUUID->"ebfc985e-99d6-4604-bef5-b940fe300904"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1642]:=",ExpressionUUID->"a305f527-99b4-4f95-9089-3a6531625d4e"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1736.5003589037144`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1642, 235, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432045903385286`*^9, 
  3.8432051433149786`*^9},
 CellLabel->
  "During evaluation of \
In[1642]:=",ExpressionUUID->"3cd2afc6-c313-41da-8a56-0c89907994dd"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1736.5003589037144`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1642, 236, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432045903385286`*^9, 
  3.8432051434164066`*^9},
 CellLabel->
  "During evaluation of \
In[1642]:=",ExpressionUUID->"718aa88f-6d79-4f3f-b8db-a6cfae72fd78"],

Cell[BoxData["0.0038115935050562653`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432023097395687`*^9, 
  3.843203783603136*^9, 3.8432045903910294`*^9, 3.8432051434420643`*^9},
 CellLabel->
  "Out[1642]=",ExpressionUUID->"d7338233-5488-45fe-9025-2ec66a18ae47"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ENBNB", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}},ExpressionUUID->"3c8bab76-8fc9-4c75-b60b-\
a071ebbf3890"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203735607335*^9, 3.843203737916168*^9}, {
  3.8432045457671614`*^9, 3.843204548074067*^9}},
 CellLabel->
  "In[1643]:=",ExpressionUUID->"0204406d-6be3-4389-a293-0b0a3768ac25"],

Cell[BoxData["56.42857142857143`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.8432037836415243`*^9, 3.843204590429573*^9, 
   3.8432051435727186`*^9},
 CellLabel->
  "Out[1643]=",ExpressionUUID->"73dd671a-7a35-4f37-992b-23d8bea0d4cb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.843203738342523*^9, 3.84320374056324*^9}, {
  3.8432045483182783`*^9, 3.843204550596718*^9}},
 CellLabel->
  "In[1644]:=",ExpressionUUID->"fe7c629b-e10d-444f-9be5-fdc5311d4234"],

Cell[BoxData["38.285714285714285`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203783685481*^9, 
  3.843204590479581*^9, 3.843205143648246*^9},
 CellLabel->
  "Out[1644]=",ExpressionUUID->"bd6a1ca4-c53e-4cf8-9398-60ede50d3b81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.8432037408350058`*^9, 3.8432037431439867`*^9}, {3.843204550867911*^9, 
  3.843204553245033*^9}},
 CellLabel->
  "In[1645]:=",ExpressionUUID->"3218a27b-ecd1-4e3e-b5a0-7b3ff1538ffb"],

Cell[BoxData["72.57142857142857`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203783723936*^9, 
  3.843204590530256*^9, 3.8432051437153587`*^9},
 CellLabel->
  "Out[1645]=",ExpressionUUID->"8432a888-fc04-4dff-b1ff-6c60d4ab9907"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwbrok", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwbrok", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432037434342103`*^9, 3.843203748665327*^9}, {3.8432045535455246`*^9, 
  3.843204556547044*^9}},
 CellLabel->
  "In[1646]:=",ExpressionUUID->"d78241d9-2373-4fca-bb05-d2227aee1a6d"],

Cell[BoxData["83.`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.843203783768177*^9, 
  3.8432045905722857`*^9, 3.8432051437740707`*^9},
 CellLabel->
  "Out[1646]=",ExpressionUUID->"4e29d46f-89a7-4b10-95f2-61976b97424b"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Observed", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}, {3.843203236007986*^9, 
  3.843203240657067*^9}},ExpressionUUID->"cc03569f-361b-4736-b8ad-\
358751b6ae1e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", "dottybwbrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", "hookbwbrok", "}"}]}], "]"}], "]"}], ",", 
         "hookbwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", "lindabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", "lodgebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", "nyayobwbrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", "violabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "violabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", "voguebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203270647889*^9, 3.843203394525511*^9}, {
  3.843203426549635*^9, 3.8432034349978504`*^9}, {3.8432037505175543`*^9, 
  3.843203752748629*^9}, {3.843204556881672*^9, 3.8432045592523623`*^9}},
 CellLabel->
  "In[1647]:=",ExpressionUUID->"18e5b7fc-84db-46ca-8999-d42d6c9bde74"],

Cell[BoxData["33.285714285714285`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.84320343951612*^9, 3.843203783794284*^9, 
   3.843204590614386*^9, 3.843205143839511*^9},
 CellLabel->
  "Out[1647]=",ExpressionUUID->"306e5a48-d4da-4d96-8584-2195985a0466"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", "dottybwbrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", "hookbwbrok", "}"}]}], "]"}], "]"}], ",", 
         "hookbwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", "lindabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", "lodgebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", "nyayobwbrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", "violabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "violabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", "voguebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.8432032875222225`*^9, 3.8432034131343436`*^9}, {
  3.843203753009065*^9, 3.8432037553109555`*^9}, {3.843204559521934*^9, 
  3.8432045622989483`*^9}},
 CellLabel->
  "In[1648]:=",ExpressionUUID->"5edf1b1e-9650-46a9-9f39-c814ce0731ac"],

Cell[BoxData["24.285714285714285`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203440824523*^9, 
  3.843203783827556*^9, 3.843204590653248*^9, 3.843205143900406*^9},
 CellLabel->
  "Out[1648]=",ExpressionUUID->"8e65a333-3664-4006-bdb5-d45f22d48497"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", "dottybwbrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", "hookbwbrok", "}"}]}], "]"}], "]"}], ",", 
         "hookbwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", "lindabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", "lodgebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", "nyayobwbrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", "violabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "violabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", "voguebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.843203289198624*^9, 3.8432034145093603`*^9}, {3.843203755618435*^9, 
  3.8432037591618032`*^9}, {3.843204562715351*^9, 3.843204566074293*^9}},
 CellLabel->
  "In[1649]:=",ExpressionUUID->"61d96d48-8e59-4bd4-a534-f84aca71531d"],

Cell[BoxData["48.714285714285715`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203442360874*^9, 
  3.843203783861021*^9, 3.8432045906894803`*^9, 3.843205143964075*^9},
 CellLabel->
  "Out[1649]=",ExpressionUUID->"922f54c8-dced-43da-a662-cec4095ddfea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", "dottybwbrok", "}"}]}], "]"}], "]"}], ",", 
         "dottybwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", "hookbwbrok", "}"}]}], "]"}], "]"}], ",", 
         "hookbwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", "lindabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lindabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", "lodgebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", "nyayobwbrok", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", "violabwbrok", "}"}]}], "]"}], "]"}], ",", 
         "violabwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", "voguebwbrok", "}"}]}], "]"}], "]"}], ",", 
         "voguebwbrok"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432032904995956`*^9, 3.8432034170680695`*^9}, {3.8432037603835554`*^9, 
  3.843203766456238*^9}, {3.8432045664206195`*^9, 3.843204571082572*^9}},
 CellLabel->
  "In[1650]:=",ExpressionUUID->"052449e0-1cf4-470c-84d0-d4697448f8a1"],

Cell[BoxData["56.142857142857146`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.8432034435089273`*^9, 
  3.843203783892887*^9, 3.843204590735959*^9, 3.8432051440191684`*^9},
 CellLabel->
  "Out[1650]=",ExpressionUUID->"932a60f0-731b-42bd-919d-68ed99091ad8"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Betweenness Centrality Maintained", "Section",
 CellChangeTimes->{{3.8426911378347073`*^9, 3.842691140154275*^9}, {
  3.8426911743027434`*^9, 3.8426911753528943`*^9}, {3.8426924162320967`*^9, 
  3.84269241943659*^9}, {3.84320446335455*^9, 3.843204468097785*^9}, {
  3.843204647266605*^9, 
  3.8432046521308336`*^9}},ExpressionUUID->"d8179e7d-adfd-4a0e-858f-\
039f0440d6d8"],

Cell[CellGroupData[{

Cell["Democ vs Comm", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019462315826`*^9}},ExpressionUUID->"93afa108-555e-4033-b275-\
29e4ad8ae74e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432044948905406`*^9, 
  3.843204497506837*^9}, {3.8432046792210693`*^9, 3.8432046818177257`*^9}},
 CellLabel->
  "In[1651]:=",ExpressionUUID->"82958503-e66b-4895-b043-036c88f676e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}},
 CellLabel->
  "In[1665]:=",ExpressionUUID->"baf9d0af-7aa1-43da-a1a3-87d15a5c49c0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1666]:=",ExpressionUUID->"85259cf1-cbe5-4b12-a109-49197c68ccea"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3338.5703130371353`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1667, 237, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781115415*^9, 3.843204587953199*^9, 
  3.843204779626109*^9, 3.8432051446070175`*^9},
 CellLabel->
  "During evaluation of \
In[1666]:=",ExpressionUUID->"2080a549-5a41-4e49-8a43-8b51f80dc422"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.029892791041845612`", "0.029892791041845612`", 
      "26.641507217725067`", "2.8054696126468837`*^-7"},
     {"Group", "6", "194.22475774470695`", "32.37079295745116`", 
      "28849.989718664052`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.04746901970986528`", 
      "0.007911503284977545`", "7.051010110589239`", 
      "2.0758348763506883`*^-7"},
     {"\<\"Error\"\>", "1386", "1.5551450616289821`", 
      "0.0011220382840035946`", "", ""},
     {"\<\"Total\"\>", "1399", "195.85726461708765`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432037811187725`*^9, 3.8432045879564924`*^9, 3.84320477962973*^9, 
  3.8432051446155686`*^9},
 CellLabel->
  "Out[1667]=",ExpressionUUID->"db763c7d-4d36-4f5a-9c0e-9fa515a429c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1668]:=",ExpressionUUID->"303178b1-b141-471f-8c9b-52dfbf820f8a"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3338.5703130371353`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1668, 238, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.843204588017488*^9, 
  3.843204779682487*^9, 3.8432051447948356`*^9},
 CellLabel->
  "During evaluation of \
In[1668]:=",ExpressionUUID->"6642e5d1-22b0-4849-a6d8-29dbd7f1dadb"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3338.5703130371353`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1668, 239, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203781165828*^9, 3.843204588017488*^9, 
  3.843204779682487*^9, 3.843205144881257*^9},
 CellLabel->
  "During evaluation of \
In[1668]:=",ExpressionUUID->"6671c9d8-165e-456a-b965-248ccabbe59a"],

Cell[BoxData["0.00015262538818913742`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432037812119827`*^9, 
  3.8432045880807266`*^9, 3.8432047797350607`*^9, 3.8432051449126062`*^9},
 CellLabel->
  "Out[1668]=",ExpressionUUID->"ae0b47cd-4746-4a39-8d70-57bf9fd766b3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201954481023*^9}},ExpressionUUID->"aabc527f-1c35-443f-a429-\
7e45a9acf5ca"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036025518847`*^9, 
  3.8432036088187733`*^9}, {3.8432044978049383`*^9, 3.8432045002881784`*^9}, {
  3.843204682108426*^9, 3.8432046847091684`*^9}},
 CellLabel->
  "In[1669]:=",ExpressionUUID->"6282fdea-4722-49b0-baf6-26986c2b9434"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.8432021307129765`*^9},
 CellLabel->
  "In[1683]:=",ExpressionUUID->"4061263f-2b90-428f-89b3-cc7e4a5d7294"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1684]:=",ExpressionUUID->"a80743dc-b6b4-401d-99ae-4f677be1a95b"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3201.9642509367777`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1685, 240, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816017094`*^9, 3.8432045883531647`*^9, 
  3.8432047800297556`*^9, 3.8432051455218735`*^9},
 CellLabel->
  "During evaluation of \
In[1684]:=",ExpressionUUID->"96300a70-1309-4307-956e-542a9b3d4f9b"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.016375334793281127`", "0.016375334793281127`", 
      "11.285288191218466`", "0.00080245733001265`"},
     {"Group", "6", "205.87545031422522`", "34.31257505237087`", 
      "23646.985111272315`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.13437226073554598`", 
      "0.02239537678925766`", "15.434083297118132`", 
      "3.3811666911102906`*^-17"},
     {"\<\"Error\"\>", "1386", "2.011132869530835`", "0.0014510338164003137`",
       "", ""},
     {"\<\"Total\"\>", "1399", "208.03733077928487`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432021385871325`*^9, 3.8432037816047707`*^9, 3.843204588357154*^9, 
  3.8432047800336685`*^9, 3.8432051455340805`*^9},
 CellLabel->
  "Out[1685]=",ExpressionUUID->"cdd9c985-feb7-4a6f-9499-89962568506f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1686]:=",ExpressionUUID->"fb8dff1d-9b4f-4272-a9e0-2c17d69c38b8"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3201.9642509367777`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1686, 241, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843204588409564*^9, 
  3.8432047800928783`*^9, 3.843205145674075*^9},
 CellLabel->
  "During evaluation of \
In[1686]:=",ExpressionUUID->"8d9eb314-f518-4413-bd52-485c9f8d72aa"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3201.9642509367777`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1686, 242, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037816463437`*^9, 3.843204588409564*^9, 
  3.8432047800928783`*^9, 3.843205145760387*^9},
 CellLabel->
  "During evaluation of \
In[1686]:=",ExpressionUUID->"02190c86-fa34-4904-9195-70fb90df1fac"],

Cell[BoxData["0.0000787134440340151`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432021514854956`*^9, 
  3.8432037816956253`*^9, 3.8432045884568195`*^9, 3.8432047801592817`*^9, 
  3.8432051457747107`*^9},
 CellLabel->
  "Out[1686]=",ExpressionUUID->"723a1cb5-bf94-4738-b2fe-74b6a5670516"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201958219412*^9}},ExpressionUUID->"189c366b-3c59-4a6b-8548-\
c5858e71c83f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203614394541*^9, 
  3.8432036198484077`*^9}, {3.8432045005780706`*^9, 3.843204503001483*^9}, {
  3.8432046850204244`*^9, 3.843204687624551*^9}},
 CellLabel->
  "In[1687]:=",ExpressionUUID->"8ea121d1-92ae-454f-9dfc-7c7f0b1d6da1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"rand", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.84320219723689*^9},
 CellLabel->
  "In[1701]:=",ExpressionUUID->"8d473ea3-1eb0-4663-9a6d-abdb19db75a9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1702]:=",ExpressionUUID->"416154d7-24ce-4253-8eb5-8a2c6c82747c"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2431.9830482550647`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1703, 243, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202201809596*^9, 3.843203781945182*^9, 
  3.8432045887201366`*^9, 3.843204780420535*^9, 3.8432051464212666`*^9},
 CellLabel->
  "During evaluation of \
In[1702]:=",ExpressionUUID->"4d11f9a3-0951-42d6-9361-d3d24113b8e6"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.16269648809668524`", "0.16269648809668524`", 
      "36.32582711468221`", "2.136506747297357`*^-9"},
     {"Group", "6", "205.0190545828522`", "34.16984243047536`", 
      "7629.222997903602`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.0921586872536011`", 
      "0.015359781208933516`", "3.429433316246432`", "0.0022975270683068126`"},
     {"\<\"Error\"\>", "1386", "6.207631055174626`", "0.004478810285118777`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "211.4815408133771`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022018345222`*^9, 3.8432037819495487`*^9, 3.8432045887234974`*^9, 
  3.8432047804238405`*^9, 3.8432051464279037`*^9},
 CellLabel->
  "Out[1703]=",ExpressionUUID->"b196b765-5de9-45f8-8c9c-447f5b4a5b81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1704]:=",ExpressionUUID->"1a461ade-897c-4167-9f32-3e32ac875721"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2431.9830482550647`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1704, 244, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.843204588774068*^9, 3.843204780475527*^9, 3.843205146524954*^9},
 CellLabel->
  "During evaluation of \
In[1704]:=",ExpressionUUID->"056825d4-f7ac-4c8e-be67-a26296c3eb9a"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2431.9830482550647`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1704, 245, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432022025125046`*^9, 3.843203782034591*^9, 
  3.843204588774068*^9, 3.843204780475527*^9, 3.8432051465880394`*^9},
 CellLabel->
  "During evaluation of \
In[1704]:=",ExpressionUUID->"87950ab8-8e2d-40a2-8a7d-17cb4d9716cc"],

Cell[BoxData["0.0007693176788429849`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202202592086*^9, 
  3.8432037820797253`*^9, 3.8432045888219457`*^9, 3.843204780529309*^9, 
  3.843205146612444*^9},
 CellLabel->
  "Out[1704]=",ExpressionUUID->"4a30c305-816b-4557-95a3-c11217096b93"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019666710215`*^9}},ExpressionUUID->"a0fa8781-78a8-4de3-b434-\
87f2f0ab62d2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036301775594`*^9, 
  3.8432036348632784`*^9}, {3.8432045033397074`*^9, 3.843204506102734*^9}, {
  3.8432046879570055`*^9, 3.843204690568287*^9}},
 CellLabel->
  "In[1705]:=",ExpressionUUID->"7554c768-508b-470c-bf0f-9c496d7e4cdc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "despot"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.843202251821741*^9},
 CellLabel->
  "In[1719]:=",ExpressionUUID->"abd3d04d-a403-49c6-93cd-8075dfa10d06"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1720]:=",ExpressionUUID->"8f1856a0-6ef1-4a6b-947c-ff8becd3a996"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3222.294096680112`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1721, 246, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.843203782358631*^9, 
  3.843204589133374*^9, 3.8432047808639555`*^9, 3.843205147214116*^9},
 CellLabel->
  "During evaluation of \
In[1720]:=",ExpressionUUID->"3eca092f-1e5c-445a-939c-33ecb89d143d"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.09051762125454843`", "0.09051762125454843`", 
      "65.76047263899353`", "1.1099144798084041`*^-15"},
     {"Group", "6", "201.16790148911645`", "33.52798358151941`", 
      "24357.865533749227`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.2858728536487547`", 
      "0.04764547560812578`", "34.61413315633887`", "3.960090356217633`*^-39"},
     {"\<\"Error\"\>", "1386", "1.907793816317745`", "0.001376474614947868`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "203.45208578033748`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022568375087`*^9, 3.8432037823623514`*^9, 3.8432045891380825`*^9, 
  3.8432047808671627`*^9, 3.843205147218431*^9},
 CellLabel->
  "Out[1721]=",ExpressionUUID->"61a363a5-9cdb-4f1f-939b-fdced4e8fade"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1722]:=",ExpressionUUID->"e856fb33-e006-42a1-bcba-d36869194896"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3222.294096680112`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1722, 247, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.843204589201516*^9, 3.843204780922142*^9, 3.8432051473264275`*^9},
 CellLabel->
  "During evaluation of \
In[1722]:=",ExpressionUUID->"dc57b72d-80cf-4fef-b527-e48a54b0fdc6"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3222.294096680112`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1722, 248, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.843203782419218*^9, 
  3.843204589201516*^9, 3.843204780922142*^9, 3.843205147430278*^9},
 CellLabel->
  "During evaluation of \
In[1722]:=",ExpressionUUID->"b6d65fe5-2898-455b-bbae-f19ff772c871"],

Cell[BoxData["0.00044490878973970423`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202258467805*^9, 
  3.8432037825058584`*^9, 3.8432045892570734`*^9, 3.8432047809678493`*^9, 
  3.843205147453065*^9},
 CellLabel->
  "Out[1722]=",ExpressionUUID->"0ab7deeb-e7b3-4053-9786-2aac5d64567a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 
  3.8426911900556355`*^9}},ExpressionUUID->"b440b91c-63e5-4d73-98fc-\
e9fdadd6831b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.843203644202664*^9, 
  3.843203647744932*^9}, {3.8432045063036966`*^9, 3.8432045090867963`*^9}, {
  3.843204690894741*^9, 3.843204693446662*^9}},
 CellLabel->
  "In[1723]:=",ExpressionUUID->"093405d9-9d4a-48be-97b8-af733cdb1a2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}},
 CellLabel->
  "In[1737]:=",ExpressionUUID->"88f41193-33b6-4334-a1c9-9cb4701dc464"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}},
 CellLabel->
  "In[1738]:=",ExpressionUUID->"1b9aeb01-ccd5-4006-a596-eb8c13fd7430"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2427.611364741668`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1739, 249, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8427057863575764`*^9, 3.8427083448470335`*^9, 
  3.8432037828131795`*^9, 3.843204589573631*^9, 3.843204781259431*^9, 
  3.8432051480197797`*^9},
 CellLabel->
  "During evaluation of \
In[1738]:=",ExpressionUUID->"4363e1dc-e832-48ed-8ed6-b7749653fb0b"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.3320661893698684`", "0.3320661893698684`", 
      "75.39674352385897`", "1.063446594326926`*^-17"},
     {"Group", "6", "200.29978338234812`", "33.38329723039135`", 
      "7579.789752268465`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.25538165556216086`", 
      "0.04256360926036014`", "9.664210430284536`", "1.925933485660672`*^-10"},
     {"\<\"Error\"\>", "1386", "6.104292001961536`", "0.004404251083666332`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "206.9915232292417`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.8427057863696804`*^9, 3.8427083448571405`*^9, 
  3.8432037828171196`*^9, 3.8432045895776997`*^9, 3.843204781263569*^9, 
  3.8432051480263205`*^9},
 CellLabel->
  "Out[1739]=",ExpressionUUID->"f75370c3-d743-4a87-aaec-f51cf1a362e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1740]:=",ExpressionUUID->"6655228e-19f4-43e7-b68a-5f35ecbc0290"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2427.611364741668`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1740, 250, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432045899664354`*^9, 3.843204781332142*^9, 3.843205148208481*^9},
 CellLabel->
  "During evaluation of \
In[1740]:=",ExpressionUUID->"335afd4f-3348-45d1-b403-d12fde6d1933"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2427.611364741668`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1740, 251, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.842708370978103*^9, 3.8432037831929464`*^9, 
  3.8432045899664354`*^9, 3.843204781332142*^9, 3.8432051483020515`*^9},
 CellLabel->
  "During evaluation of \
In[1740]:=",ExpressionUUID->"2d753cc2-1eeb-4627-9852-a3c82e71bb18"],

Cell[BoxData["0.0016042501846904491`"], "Output",
 CellChangeTimes->{3.8427083710778227`*^9, 3.8432037832366447`*^9, 
  3.843204590007826*^9, 3.8432047813959026`*^9, 3.843205148327159*^9},
 CellLabel->
  "Out[1740]=",ExpressionUUID->"632f69d9-9bbd-4327-9596-fc3bf9638a97"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Despot vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201977267528*^9}},ExpressionUUID->"82698d84-d347-45c7-a5df-\
4a35b935c98b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "dottymax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lindamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "lodgemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "nyayomax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "hookmax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "violamax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "10"}], "]"}], "]"}], "/", "voguemax"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8426912152147465`*^9, 
  3.842691218525239*^9}, {3.8426924285598235`*^9, 3.8426924331354084`*^9}, {
  3.8426927306158085`*^9, 3.8426927836952267`*^9}, {3.8432036576648865`*^9, 
  3.843203692894718*^9}, {3.84320450973641*^9, 3.843204513199148*^9}, {
  3.843204693803775*^9, 3.8432046964379463`*^9}},
 CellLabel->
  "In[1741]:=",ExpressionUUID->"7f08a166-6eed-48c3-802e-9a868e461dd9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}, {3.8432022876973305`*^9, 
  3.843202303651292*^9}},
 CellLabel->
  "In[1755]:=",ExpressionUUID->"1e0c6386-5e4c-436a-8ded-a75a769bb0a1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1756]:=",ExpressionUUID->"31c296a7-d8d9-4544-a251-5bbb285ec1c8"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2418.138214464904`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1757, 252, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432037835063195`*^9, 3.8432045902787943`*^9, 
  3.843204781648299*^9, 3.8432051488744946`*^9},
 CellLabel->
  "During evaluation of \
In[1756]:=",ExpressionUUID->"796e7ab4-df35-433a-9b63-d57d6ebcd184"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.07583986151607292`", "0.07583986151607292`", 
      "16.02279950060026`", "0.00006589720379531959`"},
     {"Group", "6", "212.25019103856624`", "35.375031839761036`", 
      "7473.735198945698`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.04256980988796499`", 
      "0.007094968314660832`", "1.4989644297389642`", "0.174838660959088`"},
     {"\<\"Error\"\>", "1386", "6.560279809863388`", "0.00473324661606305`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "218.92888051983368`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432023088851333`*^9, 3.843203783510552*^9, 3.8432045902824507`*^9, 
  3.843204781651514*^9, 3.8432051488840017`*^9},
 CellLabel->
  "Out[1757]=",ExpressionUUID->"7ba3db25-520f-40d0-85ba-0672ba23850e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1758]:=",ExpressionUUID->"64498a2b-1d8d-4c67-b33a-e3ce9878e793"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2418.138214464904`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1758, 253, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432045903385286`*^9, 
  3.8432047817529316`*^9, 3.843205149007685*^9},
 CellLabel->
  "During evaluation of \
In[1758]:=",ExpressionUUID->"a508dd4e-0221-4ef6-9e9a-c5b24fcbc319"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2418.138214464904`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1758, 254, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843203783559578*^9, 3.8432045903385286`*^9, 
  3.8432047817529316`*^9, 3.843205149092196*^9},
 CellLabel->
  "During evaluation of \
In[1758]:=",ExpressionUUID->"8b9870e6-166e-40f8-a0ef-4efb7180b754"],

Cell[BoxData["0.0003464132339963355`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432023097395687`*^9, 
  3.843203783603136*^9, 3.8432045903910294`*^9, 3.843204781805044*^9, 
  3.8432051491197624`*^9},
 CellLabel->
  "Out[1758]=",ExpressionUUID->"743081eb-2216-468e-ba3b-54dbed4695ee"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ENBNB", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}},ExpressionUUID->"4ff372a4-4974-4646-8442-\
bc8c3b8214b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203735607335*^9, 3.843203737916168*^9}, {
  3.8432045457671614`*^9, 3.843204548074067*^9}, {3.843204741514248*^9, 
  3.843204744092155*^9}},
 CellLabel->
  "In[1759]:=",ExpressionUUID->"8f27a0fb-67e9-4e36-af3e-89d604ead716"],

Cell[BoxData["35.714285714285715`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.8432037836415243`*^9, 3.843204590429573*^9, 
   3.843204781851012*^9, 3.8432051492251253`*^9},
 CellLabel->
  "Out[1759]=",ExpressionUUID->"1a94d3d1-4322-4beb-bd6b-d00c8f9e9fef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.843203738342523*^9, 3.84320374056324*^9}, {
  3.8432045483182783`*^9, 3.843204550596718*^9}, {3.843204744428846*^9, 
  3.843204747069582*^9}},
 CellLabel->
  "In[1760]:=",ExpressionUUID->"e7560fba-1efb-4296-9b08-38520f25d9af"],

Cell[BoxData["46.285714285714285`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203783685481*^9, 
  3.843204590479581*^9, 3.8432047819035053`*^9, 3.843205149301837*^9},
 CellLabel->
  "Out[1760]=",ExpressionUUID->"aea1efff-d7b9-473f-a1f9-3f3bbb5b9bb5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.8432037408350058`*^9, 3.8432037431439867`*^9}, {3.843204550867911*^9, 
  3.843204553245033*^9}, {3.843204747398467*^9, 3.843204749899937*^9}},
 CellLabel->
  "In[1761]:=",ExpressionUUID->"2f154a19-81cb-4c36-94e5-8a767c57e4f1"],

Cell[BoxData["36.285714285714285`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203783723936*^9, 
  3.843204590530256*^9, 3.843204781952382*^9, 3.843205149374484*^9},
 CellLabel->
  "Out[1761]=",ExpressionUUID->"69bcdb5a-cfb2-48c4-bb8b-5ab86e887fa7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottybwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottybwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookbwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookbwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayobwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayobwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolabwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolabwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguebwmain", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguebwmain", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432037434342103`*^9, 3.843203748665327*^9}, {3.8432045535455246`*^9, 
  3.843204556547044*^9}, {3.8432047502288537`*^9, 3.843204752856665*^9}},
 CellLabel->
  "In[1762]:=",ExpressionUUID->"ee1c0424-8119-44a7-8afd-fba7b9407db7"],

Cell[BoxData["31.571428571428573`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.843203783768177*^9, 
  3.8432045905722857`*^9, 3.8432047819926662`*^9, 3.8432051494369392`*^9},
 CellLabel->
  "Out[1762]=",ExpressionUUID->"93b26c1e-6980-4ef3-b8ea-e47d0e86dd57"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Observed", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}, {3.843203236007986*^9, 
  3.843203240657067*^9}},ExpressionUUID->"2c530f80-4c6a-4833-a45c-\
b6a19891c7e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", "dottybwmain", "}"}]}], "]"}], "]"}], ",", 
         "dottybwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", "hookbwmain", "}"}]}], "]"}], "]"}], ",", 
         "hookbwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", "lindabwmain", "}"}]}], "]"}], "]"}], ",", 
         "lindabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", "lodgebwmain", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", "nyayobwmain", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", "violabwmain", "}"}]}], "]"}], "]"}], ",", 
         "violabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", "voguebwmain", "}"}]}], "]"}], "]"}], ",", 
         "voguebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203270647889*^9, 3.843203394525511*^9}, {
  3.843203426549635*^9, 3.8432034349978504`*^9}, {3.8432037505175543`*^9, 
  3.843203752748629*^9}, {3.843204556881672*^9, 3.8432045592523623`*^9}, {
  3.843204753147461*^9, 3.843204755642473*^9}},
 CellLabel->
  "In[1763]:=",ExpressionUUID->"3ac84315-9c4a-4881-8bf6-614bd4568755"],

Cell[BoxData["49.857142857142854`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.84320343951612*^9, 3.843203783794284*^9, 
   3.843204590614386*^9, 3.8432047820334406`*^9, 3.8432051495011888`*^9},
 CellLabel->
  "Out[1763]=",ExpressionUUID->"d0152b51-50bf-45e6-a0a1-9f61d17fa83d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", "dottybwmain", "}"}]}], "]"}], "]"}], ",", 
         "dottybwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", "hookbwmain", "}"}]}], "]"}], "]"}], ",", 
         "hookbwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", "lindabwmain", "}"}]}], "]"}], "]"}], ",", 
         "lindabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", "lodgebwmain", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", "nyayobwmain", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", "violabwmain", "}"}]}], "]"}], "]"}], ",", 
         "violabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", "voguebwmain", "}"}]}], "]"}], "]"}], ",", 
         "voguebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.8432032875222225`*^9, 3.8432034131343436`*^9}, {
  3.843203753009065*^9, 3.8432037553109555`*^9}, {3.843204559521934*^9, 
  3.8432045622989483`*^9}, {3.8432047559253693`*^9, 3.843204758506546*^9}},
 CellLabel->
  "In[1764]:=",ExpressionUUID->"d3a4ce32-3732-4885-aeba-062d28fae0b4"],

Cell[BoxData["51.857142857142854`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.843203440824523*^9, 
  3.843203783827556*^9, 3.843204590653248*^9, 3.8432047820733814`*^9, 
  3.8432051495653677`*^9},
 CellLabel->
  "Out[1764]=",ExpressionUUID->"6debeb42-b46c-4f28-9c9a-7b398e094f6a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", "dottybwmain", "}"}]}], "]"}], "]"}], ",", 
         "dottybwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", "hookbwmain", "}"}]}], "]"}], "]"}], ",", 
         "hookbwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", "lindabwmain", "}"}]}], "]"}], "]"}], ",", 
         "lindabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", "lodgebwmain", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", "nyayobwmain", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", "violabwmain", "}"}]}], "]"}], "]"}], ",", 
         "violabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", "voguebwmain", "}"}]}], "]"}], "]"}], ",", 
         "voguebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.843203289198624*^9, 3.8432034145093603`*^9}, {3.843203755618435*^9, 
  3.8432037591618032`*^9}, {3.843204562715351*^9, 3.843204566074293*^9}, {
  3.8432047588330526`*^9, 3.843204761654208*^9}},
 CellLabel->
  "In[1765]:=",ExpressionUUID->"41530edc-6636-4297-812d-35e894549f6a"],

Cell[BoxData["48.57142857142857`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843203442360874*^9, 
  3.843203783861021*^9, 3.8432045906894803`*^9, 3.8432047821169043`*^9, 
  3.8432051496254807`*^9},
 CellLabel->
  "Out[1765]=",ExpressionUUID->"0197e4b4-13b6-4e48-bf3f-77f437f135e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", "dottybwmain", "}"}]}], "]"}], "]"}], ",", 
         "dottybwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", "hookbwmain", "}"}]}], "]"}], "]"}], ",", 
         "hookbwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", "lindabwmain", "}"}]}], "]"}], "]"}], ",", 
         "lindabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", "lodgebwmain", "}"}]}], "]"}], "]"}], ",", 
         "lodgebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", "nyayobwmain", "}"}]}], "]"}], "]"}], ",", 
         "nyayobwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", "violabwmain", "}"}]}], "]"}], "]"}], ",", 
         "violabwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", "voguebwmain", "}"}]}], "]"}], "]"}], ",", 
         "voguebwmain"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432032904995956`*^9, 3.8432034170680695`*^9}, {3.8432037603835554`*^9, 
  3.843203766456238*^9}, {3.8432045664206195`*^9, 3.843204571082572*^9}, {
  3.8432047620483055`*^9, 3.8432047662439537`*^9}},
 CellLabel->
  "In[1766]:=",ExpressionUUID->"fd89ac9d-8580-4884-998d-5da32f85783a"],

Cell[BoxData["37.857142857142854`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.8432034435089273`*^9, 
  3.843203783892887*^9, 3.843204590735959*^9, 3.8432047821648674`*^9, 
  3.8432051496912*^9},
 CellLabel->
  "Out[1766]=",ExpressionUUID->"4479ef90-0b35-498d-af46-38ae6fde2024"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Percent correct", "Section",
 CellChangeTimes->{{3.8426911378347073`*^9, 3.842691140154275*^9}, {
  3.843205068632865*^9, 
  3.8432050708043623`*^9}},ExpressionUUID->"01ce04b3-4d18-47d8-a2a6-\
6528f7f732ac"],

Cell[CellGroupData[{

Cell["Democ vs Comm", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019462315826`*^9}},ExpressionUUID->"89819b4c-3403-4f58-a0c6-\
391c391a1dcb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.843204852928683*^9, 
  3.843204856693492*^9}},
 CellLabel->
  "In[1767]:=",ExpressionUUID->"4923e22d-ef88-4173-ab19-d239b52f0776"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}},
 CellLabel->
  "In[1781]:=",ExpressionUUID->"64b369ee-d9e4-49d6-8b5e-1958ce684754"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1782]:=",ExpressionUUID->"50739449-6c10-4429-b2db-8a3d2d838cc2"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1139.643804790327`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1783, 255, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843204999812236*^9, 3.843205150260561*^9},
 CellLabel->
  "During evaluation of \
In[1782]:=",ExpressionUUID->"df4ce99c-11f0-459a-a27f-419a99181dd6"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.067028738521838`", "0.067028738521838`", 
      "23.213289378916556`", "1.6093069295160362`*^-6"},
     {"Group", "6", "17.08377189929762`", "2.8472953165496033`", 
      "986.0709240226257`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "0.48954580140152615`", 
      "0.08159096690025436`", "28.25645785865629`", "5.44279725853235`*^-32"},
     {"\<\"Error\"\>", "1386", "4.002096819404037`", "0.0028875157427157554`",
       "", ""},
     {"\<\"Total\"\>", "1399", "21.64244325862502`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432049998177414`*^9, 3.843205150274372*^9},
 CellLabel->
  "Out[1783]=",ExpressionUUID->"3d53a490-b08d-4425-adb7-bb6ec17f4c1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1784]:=",ExpressionUUID->"eb80fc43-2637-4571-9367-b3689d5e3c5b"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1139.643804790327`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1784, 256, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843204999869*^9, 3.8432051504711633`*^9},
 CellLabel->
  "During evaluation of \
In[1784]:=",ExpressionUUID->"80afff5a-a61f-49ee-9cec-df7c014914c2"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1139.643804790327`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1784, 257, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843204999869*^9, 3.8432051505652776`*^9},
 CellLabel->
  "During evaluation of \
In[1784]:=",ExpressionUUID->"31fb1530-2b49-41b3-a048-cce47b0f44cf"],

Cell[BoxData["0.0030970966503574165`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432049999252276`*^9, 
  3.843205150588202*^9},
 CellLabel->
  "Out[1784]=",ExpressionUUID->"86d3670c-fbc2-4cd3-b79d-bd79d9fc906c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201954481023*^9}},ExpressionUUID->"0b8f0c3e-dbb1-4294-a905-\
fd0ed044b28c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8432021228532553`*^9, 
  3.843202128323515*^9}, {3.8432048570044546`*^9, 3.8432048595581665`*^9}},
 CellLabel->
  "In[1785]:=",ExpressionUUID->"0d7f720b-74f2-4ee4-b669-9b7dbfb42a0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.8432021307129765`*^9},
 CellLabel->
  "In[1799]:=",ExpressionUUID->"89ed1958-9c51-4dd7-91cb-83834fae6a48"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1800]:=",ExpressionUUID->"75eca037-4460-49ca-8329-f1dfdafe56e3"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"730.1465391282544`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1801, 258, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843205000179373*^9, 3.8432051511563244`*^9},
 CellLabel->
  "During evaluation of \
In[1800]:=",ExpressionUUID->"56cb2d34-92ca-410a-be0f-f575aa246455"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.5341660110267075`", "0.5341660110267075`", 
      "194.84868894066875`", "1.5642888667913295`*^-41"},
     {"Group", "6", "7.280804767347362`", "1.2134674612245604`", 
      "442.6386909891682`", "7.96869`*^-318"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.2617680275658785`", 
      "0.21029467126097973`", "76.70956245915488`", "7.601412169186985`*^-83"},
     {"\<\"Error\"\>", "1386", "3.799635990922442`", "0.0027414401088906508`",
       "", ""},
     {"\<\"Total\"\>", "1399", "12.876374796862391`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432021385871325`*^9, 3.843205000185465*^9, 3.8432051511660986`*^9},
 CellLabel->
  "Out[1801]=",ExpressionUUID->"3caf5c9e-da7d-4ffa-9727-4bf28975c649"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1802]:=",ExpressionUUID->"4fa02ccb-7310-4ffa-b25c-a547addcddbb"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"730.1465391282544`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1802, 259, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432050002423472`*^9, 3.8432051513041563`*^9},
 CellLabel->
  "During evaluation of \
In[1802]:=",ExpressionUUID->"10d3f7e1-d476-4892-a571-e65836d8fc9d"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"730.1465391282544`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1802, 260, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8432050002423472`*^9, 3.8432051513882637`*^9},
 CellLabel->
  "During evaluation of \
In[1802]:=",ExpressionUUID->"9bb5a8e2-f392-4be2-ab30-7049fbcfd1aa"],

Cell[BoxData["0.04148419251953342`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432021514854956`*^9, 
  3.8432050002889895`*^9, 3.843205151414843*^9},
 CellLabel->
  "Out[1802]=",ExpressionUUID->"3986ab40-e0b1-4f7a-99af-db610e851e39"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Democ vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201958219412*^9}},ExpressionUUID->"404dd7b7-01c6-4d7f-b3c0-\
fb8c2fa356fe"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violademoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedemoc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_democ\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.843202191807497*^9, 
  3.843202195013982*^9}, {3.8432048598834105`*^9, 3.8432048624215546`*^9}},
 CellLabel->
  "In[1803]:=",ExpressionUUID->"c56db8db-a98f-4ccc-8957-edc07662f5f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"rand", ",", "democ"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.84320219723689*^9},
 CellLabel->
  "In[1817]:=",ExpressionUUID->"02dfa7eb-3f91-4e0e-a261-095758ff6881"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1818]:=",ExpressionUUID->"70211b2c-0216-4d51-9ef6-a8fb56899d03"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "2.0951502562953053`", "2.0951502562953053`", 
      "775.3147126657375`", "6.84510805350553`*^-136"},
     {"Group", "6", "3.218053670888617`", "0.5363422784814361`", 
      "198.47457636122448`", "1.1769231418306735`*^-182"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "2.853974708159095`", 
      "0.47566245135984914`", "176.01988005100966`", 
      "1.4973558031224225`*^-166"},
     {"\<\"Error\"\>", "1386", "3.745418741301826`", "0.0027023223241715915`",
       "", ""},
     {"\<\"Total\"\>", "1399", "11.912597376644843`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022018345222`*^9, 3.843205000514063*^9, 3.8432051519712324`*^9},
 CellLabel->
  "Out[1819]=",ExpressionUUID->"43974fca-924e-4bf3-8f26-9acc45e8c7c6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1820]:=",ExpressionUUID->"ffa97c3c-c9a6-431b-b3aa-f3830b88fcc9"],

Cell[BoxData["0.17587686295878152`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202202592086*^9, 
  3.8432050005447273`*^9, 3.843205152038723*^9},
 CellLabel->
  "Out[1820]=",ExpressionUUID->"77dd90cb-703f-469f-85b2-c6e9f3b30c74"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Despot", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.8432019666710215`*^9}},ExpressionUUID->"c95f5312-5e3f-4ffb-abfd-\
2f234f4a0bfe"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.843202246062847*^9, 
  3.843202249973429*^9}, {3.8432048627124615`*^9, 3.8432048652663145`*^9}},
 CellLabel->
  "In[1821]:=",ExpressionUUID->"9ce19611-07a7-4566-ba78-194ca908dfd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "despot"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
   3.8426907345916443`*^9, 3.8426907376984916`*^9}, 3.843202251821741*^9},
 CellLabel->
  "In[1835]:=",ExpressionUUID->"79f67b4c-2e60-45d2-ae86-08bd03b3c21c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1836]:=",ExpressionUUID->"372fcb4a-593a-4c12-96f8-d0b84cfa79b4"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"943.6080216171375`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1837, 261, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.84320225681831*^9, 3.8432050008124723`*^9, 
  3.84320515254333*^9},
 CellLabel->
  "During evaluation of \
In[1836]:=",ExpressionUUID->"435d34ce-0118-4e0e-9149-9f281c2b0d17"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.9796361525707766`", "0.9796361525707766`", 
      "362.5725295184164`", "5.414829476459234`*^-72"},
     {"Group", "6", "11.120816904131665`", "1.8534694840219441`", 
      "685.9864424597973`", "0.`"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "2.8956909877558203`", 
      "0.48261516462597004`", "178.62039958732817`", 
      "1.8437460178197678`*^-168"},
     {"\<\"Error\"\>", "1386", "3.744838885799069`", "0.002701903958007986`", 
      "", ""},
     {"\<\"Total\"\>", "1399", "18.74098293025733`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432022568375087`*^9, 3.843205000814866*^9, 3.843205152556178*^9},
 CellLabel->
  "Out[1837]=",ExpressionUUID->"0e91d70d-6f52-4ad5-8f5c-9960eba4a2ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1838]:=",ExpressionUUID->"ee0b1015-0e1d-4167-a8c5-7fee7105a4c7"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"943.6080216171375`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1838, 262, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.8432050008639793`*^9, 
  3.8432051527215548`*^9},
 CellLabel->
  "During evaluation of \
In[1838]:=",ExpressionUUID->"9c9883ec-2c7c-48fd-bfe8-40ea4b056fc6"],

Cell[BoxData[
 TemplateBox[{
  "General", "munfl", 
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"943.6080216171375`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"", 2, 1838, 263, 
   21597925793380954738, "Local 2"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.843202258392992*^9, 3.8432050008639793`*^9, 
  3.8432051527713246`*^9},
 CellLabel->
  "During evaluation of \
In[1838]:=",ExpressionUUID->"405b9a96-f2c1-4171-8714-43f9a3e57bb3"],

Cell[BoxData["0.05227239981042581`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.843202258467805*^9, 
  3.8432050009140444`*^9, 3.843205152786649*^9},
 CellLabel->
  "Out[1838]=",ExpressionUUID->"a56d3a83-9a37-4510-90e3-9968f356d8c5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comm vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 
  3.8426911900556355`*^9}},ExpressionUUID->"04b68c9f-b9a7-4997-a0c7-\
add4309ce7dc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottycomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayocomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookcomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violacomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguecomm", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_comm\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.8432048656024714`*^9, 3.843204868069234*^9}},
 CellLabel->
  "In[1839]:=",ExpressionUUID->"5d0b8ebf-cd46-482f-a63a-d39ae1d8a935"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"comm", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}},
 CellLabel->
  "In[1853]:=",ExpressionUUID->"f1aecd79-646f-4e48-87b4-b1a5b6d12017"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}},
 CellLabel->
  "In[1854]:=",ExpressionUUID->"27002eb8-ff82-4812-8643-4b4878c654af"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "2.9116729005780115`", "2.9116729005780115`", 
      "1093.4685367476104`", "2.882492500448137`*^-177"},
     {"Group", "6", "6.052334869879825`", "1.0087224783133042`", 
      "378.8221857361479`", "6.409324739555676`*^-288"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "5.493628606142131`", 
      "0.9156047676903551`", "343.8521563898053`", 
      "3.5274924759029594`*^-270"},
     {"\<\"Error\"\>", "1386", "3.6906216361784523`", 
      "0.0026627861732889265`", "", ""},
     {"\<\"Total\"\>", "1399", "18.14825801277842`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.8427057863696804`*^9, 3.8427083448571405`*^9, 
  3.843205001124401*^9, 3.8432051532104597`*^9},
 CellLabel->
  "Out[1855]=",ExpressionUUID->"27cae9f5-33b2-4a04-9aa5-f66774ce466d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1856]:=",ExpressionUUID->"f9ee99cd-7336-4eb3-8236-5ba73fff4bac"],

Cell[BoxData["0.1604381477565431`"], "Output",
 CellChangeTimes->{3.8427083710778227`*^9, 3.8432050011507883`*^9, 
  3.8432051532534447`*^9},
 CellLabel->
  "Out[1856]=",ExpressionUUID->"77049caa-9da5-4bf9-beb1-9882acbd9af3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Despot vs Rand", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 
  3.843201977267528*^9}},ExpressionUUID->"ec15b78f-3ea2-40f5-961c-\
eb7976b435ad"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dottydespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dottyrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<dotty_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lindarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<linda_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lodgerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<lodge_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayodespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nyayorand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<nyayo_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookdespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hookrand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<hook_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violadespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"violarand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<viola_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguedespot", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_despot\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"voguerand", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"<<", "\"\<vogue_rand\>\""}], ")"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2", ",", "13"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.842690076722477*^9, 3.842690147607495*^9}, {
  3.842690712737766*^9, 3.842690718811389*^9}, {3.8432022831561136`*^9, 
  3.843202302232575*^9}, {3.8432048683654833`*^9, 3.843204871027439*^9}},
 CellLabel->
  "In[1857]:=",ExpressionUUID->"c91fc069-18b9-4b06-bda3-eada08b0c8f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"alg", ",", "grp"}], "}"}], ",", "100"}], "]"}], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{
               RowBox[{"ToString", "[", "grp", "]"}], "<>", 
               RowBox[{"ToString", "[", "alg", "]"}]}], "]"}], "]"}]}], "]"}],
           "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"alg", ",", 
         RowBox[{"{", 
          RowBox[{"despot", ",", "rand"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"grp", ",", 
         RowBox[{"{", 
          RowBox[{
          "dotty", ",", "hook", ",", "linda", ",", "lodge", ",", "nyayo", ",",
            "viola", ",", "vogue"}], "}"}]}], "}"}]}], "]"}], ",", "2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.842690150339322*^9, 3.842690333356285*^9}, {
  3.8426907345916443`*^9, 3.8426907376984916`*^9}, {3.8432022876973305`*^9, 
  3.843202303651292*^9}},
 CellLabel->
  "In[1871]:=",ExpressionUUID->"cfbd2bf7-7ea4-4e44-8eb8-858344d8f023"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aov", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group", ",", 
       RowBox[{"Algorithm", " ", "Group"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Algorithm", ",", "Group"}], "}"}], ",", 
     RowBox[{"NominalVariables", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Algorithm", ",", "Group"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"aov", "[", "\"\<ANOVATable\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.842705624755763*^9, 3.842705647464798*^9}, {
  3.8427057364246674`*^9, 3.8427057770111923`*^9}, {3.842947481857139*^9, 
  3.8429474846179976`*^9}, {3.843202068934272*^9, 3.8432020699214644`*^9}},
 CellLabel->
  "In[1872]:=",ExpressionUUID->"aac73ebc-4193-4b23-bd5b-6e16e51f309d"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"Algorithm", "1", "0.5135109313736921`", "0.5135109313736921`", 
      "204.04052167361843`", "2.7590987823453987`*^-43"},
     {"Group", "6", "1.383340782263164`", "0.23055679704386067`", 
      "91.61037530084015`", "5.767955422420563`*^-97"},
     {
      RowBox[{"Algorithm", " ", "Group"}], "6", "1.1318777879728876`", 
      "0.18864629799548127`", "74.95748717914606`", 
      "3.8410411812485737`*^-81"},
     {"\<\"Error\"\>", "1386", "3.488160807696858`", "0.0025167105394638227`",
       "", ""},
     {"\<\"Total\"\>", "1399", "6.516890309306602`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.842951082678825*^9, 3.8432020525235496`*^9, 
  3.8432023088851333`*^9, 3.8432050013639355`*^9, 3.8432051537868757`*^9},
 CellLabel->
  "Out[1873]=",ExpressionUUID->"af28201d-332e-43ea-8353-4b8fad9c15b7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], 
  RowBox[{
   RowBox[{"aov", "[", "\"\<ANOVATableSumsOfSquares\>\"", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]]], "Input",
 CellChangeTimes->{{3.842708365893241*^9, 3.842708370426915*^9}},
 CellLabel->
  "In[1874]:=",ExpressionUUID->"0205edaa-a61c-4ffc-8443-c46cd656b046"],

Cell[BoxData["0.0787969272154789`"], "Output",
 CellChangeTimes->{3.8429510852868595`*^9, 3.8432023097395687`*^9, 
  3.8432050013957477`*^9, 3.8432051538697815`*^9},
 CellLabel->
  "Out[1874]=",ExpressionUUID->"a843d10a-3b01-490a-94c6-c85e535cc317"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ENBNB", "Subsection",
 CellChangeTimes->{{3.8426911880469527`*^9, 3.842691197478464*^9}, {
  3.8432019363835473`*^9, 3.843201977267528*^9}, {3.8432027336119566`*^9, 
  3.8432027354727144`*^9}},ExpressionUUID->"f3f92c03-54a4-4e0b-babc-\
61f5cc69dd78"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottycorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottycorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookcorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookcorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayocorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayocorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violademoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedemoc", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843204905132121*^9, 3.843204911306919*^9}},
 CellLabel->
  "In[1875]:=",ExpressionUUID->"481f8662-0657-43ff-8a0b-fc3581d4d5ab"],

Cell[BoxData["61.714285714285715`"], "Output",
 CellChangeTimes->{{3.8432027602000427`*^9, 3.843202787285385*^9}, {
   3.8432028177674*^9, 3.843202827393709*^9}, 3.843202939958982*^9, 
   3.8432030038862886`*^9, 3.8432030867822437`*^9, {3.8432031250879784`*^9, 
   3.8432031289832554`*^9}, 3.84320500142898*^9, 3.8432051539384737`*^9},
 CellLabel->
  "Out[1875]=",ExpressionUUID->"95d93805-6a01-4e01-a460-1ba106482dff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottycomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottycorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottycorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookcomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookcorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookcorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayocomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayocorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayocorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violacomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguecomm", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203155041411*^9}, {3.8432049744599714`*^9, 3.843204977070508*^9}},
 CellLabel->
  "In[1876]:=",ExpressionUUID->"ed5183fb-e7df-4579-b8d7-0e68f4c4990c"],

Cell[BoxData["58.285714285714285`"], "Output",
 CellChangeTimes->{3.8432031881167307`*^9, 3.8432050014749994`*^9, 
  3.8432051539776306`*^9},
 CellLabel->
  "Out[1876]=",ExpressionUUID->"dc83897f-ac6f-4175-85f1-7a9c66036e8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottydespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottycorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottycorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookdespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookcorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookcorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayodespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayocorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayocorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violadespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguedespot", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.8432031666783547`*^9, 3.843203169270378*^9}, {
  3.8432049773952813`*^9, 3.843204979916463*^9}},
 CellLabel->
  "In[1877]:=",ExpressionUUID->"63869981-34e4-47c6-97bd-fd4ef5de8bfa"],

Cell[BoxData["78.`"], "Output",
 CellChangeTimes->{3.8432031970873566`*^9, 3.843205001512909*^9, 
  3.8432051540192385`*^9},
 CellLabel->
  "Out[1877]=",ExpressionUUID->"21da605d-e9b9-48a3-968c-995478fbfad3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"dottyrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsdottycorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsdottycorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"hookrand", ",", 
            RowBox[{"{", 
             RowBox[{"sparshookcorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparshookcorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lindarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslindacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslindacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"lodgerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparslodgecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparslodgecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"nyayorand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsnyayocorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsnyayocorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"violarand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsviolacorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsviolacorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"Join", "[", 
           RowBox[{"voguerand", ",", 
            RowBox[{"{", 
             RowBox[{"sparsvoguecorr", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"sparsvoguecorr", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.8432027530525537`*^9, 3.8432028269123697`*^9}, {
  3.843202933275467*^9, 3.8432029393854876`*^9}, {3.843202998557411*^9, 
  3.843203128707141*^9}, {3.843203182437647*^9, 3.8432031854782567`*^9}, {
  3.8432049802539263`*^9, 3.843204984427396*^9}},
 CellLabel->
  "In[1878]:=",ExpressionUUID->"01d5c6da-586a-4e97-a73a-66a77460e8ad"],

Cell[BoxData["82.28571428571429`"], "Output",
 CellChangeTimes->{3.8432032102557187`*^9, 3.8432050015482116`*^9, 
  3.8432051540709047`*^9},
 CellLabel->
  "Out[1878]=",ExpressionUUID->"a645ee56-3931-41a7-9be9-83d5aba2a901"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
},
WindowSize->{1584, 809},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"2f369220-f18e-4ac4-a4f1-a17c0a17080b"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 248, 4, 34, "Text",ExpressionUUID->"2fa25836-dd03-4419-8063-17fff163b302"],
Cell[809, 26, 366, 7, 28, "Input",ExpressionUUID->"30dff19c-bc2b-446c-9fec-40472009a359"],
Cell[CellGroupData[{
Cell[1200, 37, 255, 4, 67, "Chapter",ExpressionUUID->"991fa0b3-a6fe-44dc-99c5-aa960ad719fc"],
Cell[1458, 43, 2165, 35, 518, "Text",ExpressionUUID->"a0fddb59-3c08-400b-9e41-141eece93698"]
}, Closed]],
Cell[CellGroupData[{
Cell[3660, 83, 307, 5, 56, "Chapter",ExpressionUUID->"adf31fe2-fbb5-453c-b774-d91ca8f20e78"],
Cell[3970, 90, 930, 17, 143, "Input",ExpressionUUID->"213f8385-3ef6-42a9-9bb8-1e23639a4c61"],
Cell[CellGroupData[{
Cell[4925, 111, 217, 4, 67, "Section",ExpressionUUID->"d66b77ea-40cf-42a8-94c4-ef3a6cbad2dc"],
Cell[5145, 117, 851, 15, 28, "Input",ExpressionUUID->"0b6e94ef-2244-4007-9c63-1e0e12fd860e"],
Cell[CellGroupData[{
Cell[6021, 136, 453, 10, 28, "Input",ExpressionUUID->"be2cd88f-5041-440b-b6b7-87c420d89f93"],
Cell[6477, 148, 1350, 19, 32, "Output",ExpressionUUID->"82d134b7-e1b1-4e8c-a1dd-196376ba4121"]
}, Open  ]],
Cell[7842, 170, 715, 16, 28, "Input",ExpressionUUID->"a5a955ff-ac3f-4232-9f66-409ce59c6172"],
Cell[8560, 188, 813, 22, 28, "Input",ExpressionUUID->"d67e671e-0776-4e2e-8131-df4323187bdc"],
Cell[9376, 212, 2008, 42, 181, "Input",ExpressionUUID->"050df01a-f601-45b3-99fd-ee82ece908ee"],
Cell[11387, 256, 1216, 28, 28, "Input",ExpressionUUID->"71681af4-b1f1-4ec0-845e-ffbed0ae5d41"],
Cell[12606, 286, 490, 11, 28, "Input",ExpressionUUID->"91e62c8d-a216-4e20-a147-0818b37dead5"],
Cell[13099, 299, 548, 12, 28, "Input",ExpressionUUID->"e808d391-5856-43b4-b31d-814cb6d07779"],
Cell[13650, 313, 801, 21, 28, "Input",ExpressionUUID->"03547a0d-de00-4c4d-9704-1e9d927be882"],
Cell[CellGroupData[{
Cell[14476, 338, 621, 15, 48, "Input",ExpressionUUID->"85559a74-3eee-4f35-a73a-52762825b7ff"],
Cell[15100, 355, 371, 6, 32, "Output",ExpressionUUID->"d126e3c9-0cec-4fa5-acc0-4dcc3e30f76b"],
Cell[15474, 363, 371, 6, 32, "Output",ExpressionUUID->"1712fcd5-f031-4de2-9dbe-c323c68c3a98"]
}, Open  ]],
Cell[15860, 372, 470, 12, 28, "Input",ExpressionUUID->"38dea4b3-7e6b-4dc7-bf32-7950e6df1d1f"],
Cell[16333, 386, 892, 23, 28, "Input",ExpressionUUID->"1585971d-97ab-4b17-8f9d-fd2c7e7b4219"],
Cell[17228, 411, 720, 19, 28, "Input",ExpressionUUID->"ab33633a-04fd-45c2-b868-bbe5319547ed"],
Cell[CellGroupData[{
Cell[17973, 434, 1389, 35, 28, "Input",ExpressionUUID->"03ba8eb9-1ab7-4905-b83b-35534ed76af2"],
Cell[19365, 471, 33201, 534, 293, 5999, 89, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"0e0d5bdd-4add-405f-8c6e-aff6d02215f8"]
}, Open  ]],
Cell[52581, 1008, 663, 13, 28, "Input",ExpressionUUID->"24ddf478-05e8-4477-9bfc-860d4d816b05"],
Cell[CellGroupData[{
Cell[53269, 1025, 1869, 46, 48, "Input",ExpressionUUID->"02c2903e-e17f-4b8c-aa6e-26d18198a830"],
Cell[55141, 1073, 3063, 86, 71, "Output",ExpressionUUID->"30e2bfeb-9021-4b6e-879e-90018a984daa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58241, 1164, 2239, 54, 48, "Input",ExpressionUUID->"5c524a95-6e10-48f0-a86a-974d6da22b7a"],
Cell[60483, 1220, 49318, 1097, 332, "Output",ExpressionUUID->"c30808f0-bfe4-486a-9ab1-bb87cd23c75e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[109850, 2323, 269, 4, 53, "Section",ExpressionUUID->"671ac954-1f48-4492-bd0a-d27668089668"],
Cell[CellGroupData[{
Cell[110144, 2331, 156, 3, 53, "Subsection",ExpressionUUID->"a500f29c-bb95-4b5e-86a1-bbeb76709991"],
Cell[110303, 2336, 621, 11, 28, "Input",ExpressionUUID->"57946373-2359-434b-820d-a2bd36bfd245"],
Cell[CellGroupData[{
Cell[110949, 2351, 231, 4, 28, "Input",ExpressionUUID->"268fea71-3327-42ed-ba32-5ce6432a4333"],
Cell[111183, 2357, 743, 14, 32, "Output",ExpressionUUID->"5a5579b7-7b29-490f-b852-c92f9d992084"]
}, Open  ]],
Cell[111941, 2374, 468, 11, 28, "Input",ExpressionUUID->"1abc101b-0aac-4e38-82b5-16855bb357c6"],
Cell[112412, 2387, 863, 23, 28, "Input",ExpressionUUID->"677a760b-ad47-498e-9efb-ee53645d2935"],
Cell[113278, 2412, 1932, 42, 181, "Input",ExpressionUUID->"e962e57c-d967-4646-b8bb-95fea4492734"],
Cell[115213, 2456, 556, 14, 28, "Input",ExpressionUUID->"74ce761a-4886-4212-bf85-ce4d0de9e7c7"],
Cell[115772, 2472, 838, 22, 28, "Input",ExpressionUUID->"4450d26d-707f-4877-bebb-0844b2276f72"],
Cell[116613, 2496, 684, 18, 48, "Input",ExpressionUUID->"c7e51735-195d-495b-a200-4fd67ef32457"],
Cell[CellGroupData[{
Cell[117322, 2518, 377, 7, 28, "Input",ExpressionUUID->"de6fadc2-d6cb-49b0-aa90-3bfe2339e6ca"],
Cell[117702, 2527, 34094, 759, 308, "Output",ExpressionUUID->"71f7bb32-785e-4010-853c-d6edf7c44917"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151833, 3291, 374, 7, 28, "Input",ExpressionUUID->"8a787253-d2d8-48cf-a3c3-ad9d6597e2d9"],
Cell[152210, 3300, 9311, 205, 226, "Output",ExpressionUUID->"79f8f060-9321-41a8-afc9-64d7ff3406d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161558, 3510, 292, 6, 28, "Input",ExpressionUUID->"1de6ed1d-572e-42c7-aac0-63be38cb8d36"],
Cell[161853, 3518, 53296, 1093, 530, "Output",ExpressionUUID->"84e4ffbc-bc4e-44e0-83b9-d0e0af7e3f02"]
}, Open  ]],
Cell[215164, 4614, 2473, 66, 48, "Input",ExpressionUUID->"b812cd4e-0960-4948-94f1-67f6a81de503"],
Cell[217640, 4682, 2757, 75, 48, "Input",ExpressionUUID->"7d883d0a-b34c-4afd-9a0a-520ba3ea021c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220434, 4762, 156, 3, 53, "Subsection",ExpressionUUID->"144afebd-a7b7-4802-aac0-569b732de054"],
Cell[CellGroupData[{
Cell[220615, 4769, 456, 9, 28, "Input",ExpressionUUID->"4eeb851b-53db-4acb-8af7-5c874edccdc2"],
Cell[221074, 4780, 58615, 1222, 297, "Output",ExpressionUUID->"39eb052c-861f-44ea-8bc9-9c124bfc2bb5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[279726, 6007, 849, 18, 28, "Input",ExpressionUUID->"31bb6346-c66e-4167-8773-54537b6f13c7"],
Cell[280578, 6027, 1940, 33, 52, "Output",ExpressionUUID->"ebe28d61-916c-4d7f-9ed9-683f4af4e503"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282555, 6065, 538, 12, 28, "Input",ExpressionUUID->"2eb12b2a-04c0-4548-85b6-1f6cd221c1ab"],
Cell[283096, 6079, 7974, 141, 185, "Output",ExpressionUUID->"233d009d-51bf-4d4a-ac0c-3419a37ce1b3"]
}, Open  ]],
Cell[291085, 6223, 330, 7, 48, "Input",ExpressionUUID->"e992dc43-7f38-458e-803a-b34d01bcefbb"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[291464, 6236, 210, 4, 53, "Section",ExpressionUUID->"e165b4b9-8009-4bf8-8277-6bd66594e701"],
Cell[CellGroupData[{
Cell[291699, 6244, 213, 4, 28, "Input",ExpressionUUID->"4fe2a4ec-c75a-4f61-9101-2735e3c89b10"],
Cell[291915, 6250, 571, 10, 32, "Output",ExpressionUUID->"3b975aa7-608b-46e9-84a0-184752921bbb"]
}, Open  ]],
Cell[292501, 6263, 44504, 1055, 1530, "Input",ExpressionUUID->"b9ad3b0c-ae8d-47b1-9bf9-8c309fe66f8e"],
Cell[CellGroupData[{
Cell[337030, 7322, 246, 5, 28, "Input",ExpressionUUID->"e6a6ca04-563b-402d-8780-3cfb368b3991"],
Cell[337279, 7329, 1199, 23, 52, "Output",ExpressionUUID->"15974e90-f8d5-455a-ac1c-a2bd47cc4fe0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[338527, 7358, 209, 4, 53, "Section",ExpressionUUID->"dfc705b5-09bb-45a8-af9d-bc354663bbb5"],
Cell[CellGroupData[{
Cell[338761, 7366, 429, 8, 28, "Input",ExpressionUUID->"54c21042-76b5-48df-8bba-2130d5d8fd05"],
Cell[339193, 7376, 1916, 43, 52, "Output",ExpressionUUID->"e1c08c65-62f8-4da1-8c47-f44f65e61044"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341146, 7424, 259, 5, 28, "Input",ExpressionUUID->"7a52d858-d41f-4d67-a659-58e1ef82a8a8"],
Cell[341408, 7431, 575, 10, 32, "Output",ExpressionUUID->"ef2bce41-cc15-4ac7-8885-bba9a5690e00"]
}, Open  ]],
Cell[341998, 7444, 40218, 963, 1283, "Input",ExpressionUUID->"71bf6c7f-af36-4d94-bb83-11c5967f8c4e"],
Cell[CellGroupData[{
Cell[382241, 8411, 297, 6, 28, "Input",ExpressionUUID->"d5551c11-5d40-4c4e-b47b-31c2c8d4f218"],
Cell[382541, 8419, 1262, 24, 52, "Output",ExpressionUUID->"a3b9c43b-c896-44fe-ab81-afe720801eec"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[383852, 8449, 211, 4, 53, "Section",ExpressionUUID->"d8e85c89-59fb-4b0a-8c45-800904b40e25"],
Cell[CellGroupData[{
Cell[384088, 8457, 209, 4, 28, "Input",ExpressionUUID->"61cbd62b-b9d2-4c9c-ba08-708770bde322"],
Cell[384300, 8463, 513, 9, 32, "Output",ExpressionUUID->"ec82b026-24ab-403d-aff3-5006018afd5e"]
}, Open  ]],
Cell[384828, 8475, 37871, 925, 1226, "Input",ExpressionUUID->"53fbeab8-6831-4ee5-bbf5-2bc8693b05bc"],
Cell[CellGroupData[{
Cell[422724, 9404, 345, 7, 28, "Input",ExpressionUUID->"723d27ec-da8d-49f2-b921-14d30c9564ff"],
Cell[423072, 9413, 1266, 25, 52, "Output",ExpressionUUID->"adfb1d78-bc6e-43f5-91c8-11ed8fa2178f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[424387, 9444, 210, 4, 53, "Section",ExpressionUUID->"4e15b487-7246-411f-9cd9-c4396138481f"],
Cell[CellGroupData[{
Cell[424622, 9452, 211, 4, 28, "Input",ExpressionUUID->"eb80291f-2ea3-462e-9832-0468f30f44af"],
Cell[424836, 9458, 426, 8, 32, "Output",ExpressionUUID->"2a7c7afb-58f1-49cc-bc69-afb7e5dd2e3a"]
}, Open  ]],
Cell[425277, 9469, 32225, 785, 960, "Input",ExpressionUUID->"225bfa70-e653-40fc-8c02-0bd93e85d763"],
Cell[CellGroupData[{
Cell[457527, 10258, 244, 5, 28, "Input",ExpressionUUID->"1b28b2a9-09be-4782-b1bc-d23393f24f8c"],
Cell[457774, 10265, 1125, 23, 52, "Output",ExpressionUUID->"19f708ba-b6b4-4791-9151-19c8b376b3d8"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[458948, 10294, 242, 4, 53, "Section",ExpressionUUID->"24f54009-607d-4061-9263-bd3e8a79e5c7"],
Cell[CellGroupData[{
Cell[459215, 10302, 158, 3, 53, "Subsection",ExpressionUUID->"d7e01044-5b5f-434e-a4d5-e719adfc9241"],
Cell[CellGroupData[{
Cell[459398, 10309, 247, 5, 28, "Input",ExpressionUUID->"75b9931a-6bac-4866-add2-a25d5a0b6ca3"],
Cell[459648, 10316, 1472, 26, 52, "Output",ExpressionUUID->"c7523e75-3568-41ac-a887-1886e9d36171"]
}, Open  ]],
Cell[CellGroupData[{
Cell[461157, 10347, 418, 12, 28, "Input",ExpressionUUID->"ff439696-9df0-4394-8e1a-e85311453bfb"],
Cell[461578, 10361, 71576, 1436, 298, "Output",ExpressionUUID->"a5165129-385b-4c3b-b687-639105ee418d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[533191, 11802, 460, 11, 28, "Input",ExpressionUUID->"c35ba10c-b8cf-4afe-addb-d980b47e8386"],
Cell[533654, 11815, 18229, 363, 319, "Output",ExpressionUUID->"78fd1754-8c66-40d1-976b-58ff2f18cd95"]
}, Open  ]],
Cell[CellGroupData[{
Cell[551920, 12183, 462, 11, 28, "Input",ExpressionUUID->"2c81fffe-c9d0-4398-9254-40edd1cc0de3"],
Cell[552385, 12196, 13938, 281, 275, "Output",ExpressionUUID->"65965536-64a7-4282-a8f0-e6b09b9cac3e"]
}, Open  ]],
Cell[566338, 12480, 2396, 65, 48, "Input",ExpressionUUID->"2f8fecca-639c-41dd-8bb5-4af46f31112f"],
Cell[568737, 12547, 705, 17, 48, "Input",ExpressionUUID->"90600fee-7625-495c-92f5-afd93b0df866"],
Cell[CellGroupData[{
Cell[569467, 12568, 284, 5, 48, "Input",ExpressionUUID->"48ae135e-7917-465f-b349-7d00d28072ae"],
Cell[569754, 12575, 224, 5, 32, "Output",ExpressionUUID->"a12933bc-af4b-4aa7-af6d-4dcdc1d1cca4"],
Cell[569981, 12582, 224, 5, 32, "Output",ExpressionUUID->"a2c058c9-ec31-4b03-806e-ac6d4f8159db"]
}, Open  ]],
Cell[570220, 12590, 3776, 97, 181, "Input",ExpressionUUID->"dffc18ee-de75-4c53-a9df-c63148d04e2c"],
Cell[CellGroupData[{
Cell[574021, 12691, 1071, 30, 86, "Input",ExpressionUUID->"2a2590ac-ce5a-4596-8422-8aecf60bf334"],
Cell[575095, 12723, 231, 4, 32, "Output",ExpressionUUID->"7aa09eb0-47b9-477d-bf66-0a3f28957a71"],
Cell[575329, 12729, 229, 4, 32, "Output",ExpressionUUID->"c71fa260-932c-473e-a419-1e6bd1bafb82"],
Cell[575561, 12735, 246, 4, 32, "Output",ExpressionUUID->"4650edb9-d850-4b35-8397-05ba82e5adc1"],
Cell[575810, 12741, 246, 4, 32, "Output",ExpressionUUID->"6a54de89-87cc-442c-b8e1-f851d19ead2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576093, 12750, 968, 23, 48, "Input",ExpressionUUID->"861297e4-1491-4dbf-a6a6-adfd2258ea95"],
Cell[577064, 12775, 2483, 62, 52, "Output",ExpressionUUID->"015b7645-40f0-4ae1-b019-4ce3c6982215"],
Cell[579550, 12839, 2153, 54, 52, "Output",ExpressionUUID->"36bd65e3-5aee-4bfa-b9ae-f93006f1ab22"]
}, Open  ]],
Cell[CellGroupData[{
Cell[581740, 12898, 861, 22, 48, "Input",ExpressionUUID->"9a775b71-815d-419e-a905-2812eed99957"],
Cell[582604, 12922, 2646, 61, 71, "Output",ExpressionUUID->"92223c49-5706-4bd2-8b1a-948759eae477"],
Cell[585253, 12985, 2283, 53, 52, "Output",ExpressionUUID->"c6324b30-a5b8-489f-a60b-d9508469f911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[587573, 13043, 737, 20, 48, "Input",ExpressionUUID->"9dd3a91d-cf5f-409c-a320-b719101a1af5"],
Cell[588313, 13065, 266, 4, 32, "Output",ExpressionUUID->"9a981e40-9ec2-4114-8cd1-a1c743b3b46b"],
Cell[588582, 13071, 266, 4, 32, "Output",ExpressionUUID->"162f056e-5609-4101-983e-274f80c06129"]
}, Open  ]],
Cell[CellGroupData[{
Cell[588885, 13080, 731, 20, 48, "Input",ExpressionUUID->"35f856b7-d767-4dc5-a860-b6392559d4d7"],
Cell[589619, 13102, 241, 4, 32, "Output",ExpressionUUID->"74db8bca-dbe6-4aea-baea-f7f61ff452eb"],
Cell[589863, 13108, 244, 4, 32, "Output",ExpressionUUID->"029e59fd-ad01-4bef-98b6-18159d2b30a5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[590144, 13117, 745, 20, 48, "Input",ExpressionUUID->"67e8e82b-4e2e-47cd-8102-63e47d93a3e4"],
Cell[590892, 13139, 242, 4, 32, "Output",ExpressionUUID->"934be849-2a3d-4426-9fab-2825803c9161"],
Cell[591137, 13145, 242, 4, 32, "Output",ExpressionUUID->"38e0bd66-ba3b-4ad4-9752-d2dd87ee2133"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591416, 13154, 568, 13, 48, "Input",ExpressionUUID->"8f96b70b-8f6f-4220-8441-3a3fa38da16a"],
Cell[591987, 13169, 298, 5, 32, "Output",ExpressionUUID->"09cece21-fe20-4e00-aa5a-72d53ff75ea3"],
Cell[592288, 13176, 302, 5, 32, "Output",ExpressionUUID->"7a494594-cb74-4e61-9d89-4d3602be20f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[592627, 13186, 437, 10, 48, "Input",ExpressionUUID->"79177244-9b0f-41af-ab13-2ecf5149db2b"],
Cell[593067, 13198, 787, 14, 32, "Output",ExpressionUUID->"913aaf81-c542-485a-87a9-281e3e65511f"],
Cell[593857, 13214, 688, 13, 32, "Output",ExpressionUUID->"5edc18b9-0b3d-4a04-8832-0c69630db60c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[594582, 13232, 351, 6, 48, "Input",ExpressionUUID->"338bf711-1aeb-4c3e-910b-1af1bd629a89"],
Cell[594936, 13240, 256, 5, 32, "Output",ExpressionUUID->"52bf9174-cf2b-43a1-947f-817e1589862c"],
Cell[595195, 13247, 256, 5, 32, "Output",ExpressionUUID->"39e237d0-9fdd-4133-9255-aff082dc086a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[595488, 13257, 522, 12, 48, "Input",ExpressionUUID->"7d0f9049-03b6-48fc-bad4-978ef1b26780"],
Cell[596013, 13271, 270, 4, 32, "Output",ExpressionUUID->"28ba7fde-a1b5-4515-bca9-13920e8a4256"],
Cell[596286, 13277, 269, 4, 32, "Output",ExpressionUUID->"aee5758b-adaa-4db4-b356-449ac1dcec1c"]
}, Open  ]],
Cell[596570, 13284, 2302, 66, 48, "Input",ExpressionUUID->"58c136e4-7e20-4114-8219-e4acb308959a"],
Cell[598875, 13352, 636, 19, 28, "Input",ExpressionUUID->"dc16b8c5-8f80-4d57-b5eb-dd007d90a2f7"],
Cell[CellGroupData[{
Cell[599536, 13375, 594, 16, 28, "Input",ExpressionUUID->"ceef0b1b-204d-48dc-a5a7-80d00acf82b6"],
Cell[600133, 13393, 225, 4, 32, "Output",ExpressionUUID->"8ed3e1d5-82c4-4998-8140-e91a423356bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600395, 13402, 588, 16, 28, "Input",ExpressionUUID->"a6ac4567-b563-432f-9f21-3a68ec28e001"],
Cell[600986, 13420, 197, 3, 32, "Output",ExpressionUUID->"96554656-5a2e-428b-948d-41069c800079"]
}, Open  ]],
Cell[CellGroupData[{
Cell[601220, 13428, 424, 11, 28, "Input",ExpressionUUID->"7d1b5334-34a0-4fc3-ac9d-33cd5d01af34"],
Cell[601647, 13441, 197, 3, 32, "Output",ExpressionUUID->"7c84a9a6-e029-4c7b-83bd-6287d3032b18"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[601893, 13450, 156, 3, 37, "Subsection",ExpressionUUID->"6abcb041-76ce-4a77-891b-85d422d38f8b"],
Cell[CellGroupData[{
Cell[602074, 13457, 520, 11, 28, "Input",ExpressionUUID->"59b6b206-4dc5-447d-a336-395819ea9b0f"],
Cell[602597, 13470, 63682, 1337, 298, "Output",ExpressionUUID->"251885a2-2675-4b3b-976e-e0645df66c31"]
}, Open  ]],
Cell[CellGroupData[{
Cell[666316, 14812, 733, 16, 28, "Input",ExpressionUUID->"0bd5485b-5b96-4bd3-a390-3a592b7eb0d9"],
Cell[667052, 14830, 2568, 40, 52, "Output",ExpressionUUID->"4c7d66bf-c9f2-411c-b1c3-99798845ef36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[669657, 14875, 603, 14, 28, "Input",ExpressionUUID->"02742891-720d-41c3-9d2e-28e6a7f97b9c"],
Cell[670263, 14891, 6997, 103, 128, "Output",ExpressionUUID->"9da4a00c-57ea-4499-9450-88de2981b233"]
}, Open  ]],
Cell[CellGroupData[{
Cell[677297, 14999, 858, 23, 67, "Input",ExpressionUUID->"5f87165f-b281-44d1-b9c3-1d499da5a30e"],
Cell[678158, 15024, 254, 6, 32, "Output",ExpressionUUID->"afed7f81-7a39-4e43-b2c8-dfe063893689"],
Cell[678415, 15032, 257, 6, 32, "Output",ExpressionUUID->"1394cbf5-10d8-40c1-8444-f646834d4aff"],
Cell[678675, 15040, 275, 6, 32, "Output",ExpressionUUID->"637cd186-c40e-466b-b25d-c815533f1354"]
}, Open  ]],
Cell[CellGroupData[{
Cell[678987, 15051, 2799, 79, 67, "Input",ExpressionUUID->"8da4586d-2218-47f9-aec7-fab55eeaeb24"],
Cell[681789, 15132, 206, 4, 32, "Output",ExpressionUUID->"083ca781-8740-4cee-8d44-f134d697dd36"],
Cell[681998, 15138, 225, 4, 32, "Output",ExpressionUUID->"3faa0fd0-d3d5-450d-b1e1-4ab376e29017"]
}, Open  ]],
Cell[CellGroupData[{
Cell[682260, 15147, 2832, 80, 67, "Input",ExpressionUUID->"3ee53f72-80c5-49ce-b976-09df7ffc2f88"],
Cell[685095, 15229, 178, 3, 32, "Output",ExpressionUUID->"71788309-5c61-454f-a82e-1baed04b002a"],
Cell[685276, 15234, 194, 3, 32, "Output",ExpressionUUID->"37e33a04-4d8c-45b8-8aab-958bc2cc1683"]
}, Open  ]],
Cell[CellGroupData[{
Cell[685507, 15242, 2013, 53, 67, "Input",ExpressionUUID->"6f5207f3-4b7c-449c-8e10-9ca63edc6c44"],
Cell[687523, 15297, 271, 4, 32, "Output",ExpressionUUID->"4cabe5ad-7009-43d8-beb6-895fd982b318"]
}, Open  ]],
Cell[CellGroupData[{
Cell[687831, 15306, 636, 16, 28, "Input",ExpressionUUID->"bcf2099e-f1b6-43ae-b2cb-141670bda82b"],
Cell[688470, 15324, 17274, 526, 261, "Output",ExpressionUUID->"d2a4c57f-cb40-47ce-ad42-3629654d3fc8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[705781, 15855, 2789, 78, 67, "Input",ExpressionUUID->"a7c3f43e-793f-4f06-8ca0-3ea0dd38f69c"],
Cell[708573, 15935, 224, 4, 32, "Output",ExpressionUUID->"2ac692d1-f66a-4f2d-a70e-4832b209763f"],
Cell[708800, 15941, 222, 4, 32, "Output",ExpressionUUID->"0c28e359-a7b7-48ee-9c8f-01f3c4eaf4e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[709059, 15950, 3681, 105, 124, "Input",ExpressionUUID->"a1f8a78e-f627-4b03-a408-bee4f4e51bb7"],
Cell[712743, 16057, 300, 5, 32, "Output",ExpressionUUID->"a71938c6-cb42-4397-890a-4d77a9e48dc9"],
Cell[713046, 16064, 297, 5, 32, "Output",ExpressionUUID->"00b42544-13ee-4d83-abae-bcda45bce10c"],
Cell[713346, 16071, 300, 5, 32, "Output",ExpressionUUID->"2221a49a-1187-432e-a8ef-9634f5325a9c"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[713719, 16084, 355, 6, 56, "Chapter",ExpressionUUID->"5d0109e0-2395-41a8-96ac-f15398c0352c"],
Cell[CellGroupData[{
Cell[714099, 16094, 223, 4, 67, "Section",ExpressionUUID->"80295b08-cdca-45c6-aa1a-81e49d15fff4"],
Cell[714325, 16100, 687, 17, 143, "Input",ExpressionUUID->"648758a7-6ba2-44b9-9df4-f41570f8550c"],
Cell[715015, 16119, 3596, 99, 656, "Input",ExpressionUUID->"ad2fbaf2-cf1e-461e-8d50-ef1bd71a8172"],
Cell[718614, 16220, 809, 19, 143, "Input",ExpressionUUID->"ce73dd6b-c5e8-4ed2-8bde-57603e5c2cbd"],
Cell[719426, 16241, 3530, 87, 751, "Input",ExpressionUUID->"eb2bdc2f-18bf-4bfc-958a-3fcab2a14f70"],
Cell[722959, 16330, 1805, 39, 143, "Input",ExpressionUUID->"438d28fc-66d5-4e92-8d6b-c9cd37d09754"],
Cell[724767, 16371, 6419, 161, 751, "Input",ExpressionUUID->"adb22f3b-8ad9-4b76-af2e-dea07742bf5e"],
Cell[731189, 16534, 1665, 37, 143, "Input",ExpressionUUID->"72e5aa1c-dbc8-4426-849a-f78fb660d148"]
}, Closed]],
Cell[CellGroupData[{
Cell[732891, 16576, 313, 5, 53, "Section",ExpressionUUID->"6a77e014-0543-491f-899c-11dd4129f28f"],
Cell[733207, 16583, 219, 5, 34, "Text",ExpressionUUID->"4d461173-992b-4c7c-bf31-5d9dfc50b7af"],
Cell[733429, 16590, 764, 21, 48, "Input",ExpressionUUID->"120168b5-c898-4392-87bf-d90881affc25"],
Cell[CellGroupData[{
Cell[734218, 16615, 164, 3, 53, "Subsection",ExpressionUUID->"59ca0aa4-e6b8-491a-b1fc-d6a5df7b9101"],
Cell[734385, 16620, 13451, 375, 884, "Input",ExpressionUUID->"ff03b58b-4769-4249-9131-9226da887a75"],
Cell[CellGroupData[{
Cell[747861, 16999, 11568, 274, 827, "Input",ExpressionUUID->"ed735b3d-f611-4c3a-be32-697b6c5e8bf0"],
Cell[759432, 17275, 584648, 12574, 394, "Output",ExpressionUUID->"57a16f3b-4e76-4dad-a3f4-f7cfadc06197"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1344129, 29855, 216, 4, 37, "Subsection",ExpressionUUID->"acdda333-a033-4b92-92ce-c1c54664a340"],
Cell[1344348, 29861, 15676, 474, 1188, "Input",ExpressionUUID->"8e6313a5-f09e-4230-b806-3123b1571301"],
Cell[CellGroupData[{
Cell[1360049, 30339, 11782, 275, 789, "Input",ExpressionUUID->"ae6f5424-194d-4876-9a54-3edddb704940"],
Cell[1371834, 30616, 590762, 12702, 388, "Output",ExpressionUUID->"5f9dbc99-f3f2-4718-88a8-8422a4fa03f3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1962645, 43324, 259, 4, 37, "Subsection",ExpressionUUID->"1bbd635b-9153-427d-b2ed-d5d42e2b2d45"],
Cell[1962907, 43330, 3838, 118, 656, "Input",ExpressionUUID->"abcde9e7-1ea6-43c1-92ac-cd8d2fe64731"],
Cell[1966748, 43450, 9029, 265, 656, "Input",ExpressionUUID->"def859f4-ff2b-4fda-8c07-aa2510f4fdbb"],
Cell[CellGroupData[{
Cell[1975802, 43719, 11608, 271, 770, "Input",ExpressionUUID->"93cc6893-42f0-442f-bb47-a6fd4c9b77a0"],
Cell[1987413, 43992, 589250, 12681, 388, "Output",ExpressionUUID->"847fe089-76cf-443f-b1e4-940addfcee29"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2576712, 56679, 268, 4, 37, "Subsection",ExpressionUUID->"6d5b07d0-7149-4e26-b56d-4285fad188ba"],
Cell[2576983, 56685, 15862, 476, 1188, "Input",ExpressionUUID->"6175c3a5-b31d-4227-b6b6-95a3b3dd3aac"],
Cell[CellGroupData[{
Cell[2592870, 57165, 12029, 279, 789, "Input",ExpressionUUID->"ab375daa-291d-42ff-9154-b4f7baff0951"],
Cell[2604902, 57446, 580697, 12489, 394, "Output",ExpressionUUID->"96c0ceaa-1f0a-4aa1-8a01-405b6e206413"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3185648, 69941, 383, 6, 37, "Subsection",ExpressionUUID->"354b6efa-39fe-4897-8d06-269d8da03583"],
Cell[3186034, 69949, 16019, 477, 1188, "Input",ExpressionUUID->"456c60b0-5ca8-4773-9292-3e75eb99d1a8"],
Cell[CellGroupData[{
Cell[3202078, 70430, 11415, 264, 751, "Input",ExpressionUUID->"8f764c8a-fe7d-465f-a9ea-dd935029b539"],
Cell[3213496, 70696, 508972, 10996, 394, "Output",ExpressionUUID->"7ceaa755-9d51-4dee-a9a1-c01f133b3aea"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3722517, 81698, 386, 6, 37, "Subsection",ExpressionUUID->"23c73765-3918-4e15-9393-27a1aca294fb"],
Cell[3722906, 81706, 16180, 479, 656, "Input",ExpressionUUID->"23d75262-479f-41f9-ac33-6daa0aa751a1"],
Cell[CellGroupData[{
Cell[3739111, 82189, 11540, 265, 447, "Input",ExpressionUUID->"db7bef6e-6f41-4567-af93-d9d1a2a6b758"],
Cell[3750654, 82456, 502583, 10873, 392, "Output",ExpressionUUID->"a41c19f6-313c-4f00-9d69-abd2c9a0fdfb"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4253286, 93335, 416, 6, 37, "Subsection",ExpressionUUID->"9e598715-7ccc-4eda-bbba-15f20942b62f"],
Cell[CellGroupData[{
Cell[4253727, 93345, 12275, 305, 789, "Input",ExpressionUUID->"e0b21f40-7859-4990-bde8-9a98c1bddb09"],
Cell[4266005, 93652, 590448, 13175, 394, "Output",ExpressionUUID->"0dded28c-1067-4e13-9ff4-c8084faac368"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4856526, 106835, 403, 6, 56, "Chapter",ExpressionUUID->"9eaa2181-da55-4171-be2e-c193a911db7c"],
Cell[CellGroupData[{
Cell[4856954, 106845, 217, 4, 67, "Section",ExpressionUUID->"3f6a1489-4de5-4aa9-baf8-934498c74466"],
Cell[4857174, 106851, 612, 15, 143, "Input",ExpressionUUID->"10c66275-188c-4f0f-8c20-222c9e2003ea"],
Cell[4857789, 106868, 804, 18, 143, "Input",ExpressionUUID->"803e56a5-f9c7-4290-8237-80df9fedbf8c"],
Cell[4858596, 106888, 3424, 85, 751, "Input",ExpressionUUID->"827eb6e2-a777-4e0a-88ea-90425622b836"],
Cell[4862023, 106975, 1801, 38, 143, "Input",ExpressionUUID->"cb0c870f-e700-4532-b36a-9c9a917482d8"],
Cell[4863827, 107015, 6417, 160, 751, "Input",ExpressionUUID->"e818e5b7-fd59-4d26-bf61-35686eabe07b"],
Cell[4870247, 107177, 1661, 36, 143, "Input",ExpressionUUID->"5581d965-c4d8-4527-b3e2-aa73d185edde"]
}, Closed]],
Cell[CellGroupData[{
Cell[4871945, 107218, 161, 3, 53, "Section",ExpressionUUID->"82528df6-bf3a-4ebe-9020-15cae5650a42"],
Cell[CellGroupData[{
Cell[4872131, 107225, 216, 4, 53, "Subsection",ExpressionUUID->"a24b2f50-d922-4f7d-b553-a9fd8206fae9"],
Cell[4872350, 107231, 3497, 115, 276, "Input",ExpressionUUID->"2226f7b7-99c0-4aa3-a295-efe78e257b6d"],
Cell[4875850, 107348, 1344, 36, 48, "Input",ExpressionUUID->"a32a81b0-b061-4920-9415-3db3858e4b15"],
Cell[CellGroupData[{
Cell[4877219, 107388, 814, 18, 48, "Input",ExpressionUUID->"beeb4d1c-6b15-4f18-bd1e-16aff1584893"],
Cell[4878036, 107408, 1360, 29, 129, "Output",ExpressionUUID->"2fe06e83-847b-48d2-aca6-fc780dfab109"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4879433, 107442, 423, 10, 49, "Input",ExpressionUUID->"b310d7cc-297e-4c17-899d-ee6913514459"],
Cell[4879859, 107454, 199, 3, 32, "Output",ExpressionUUID->"591feb17-6ebc-465a-afc3-34e206f3c28e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4880107, 107463, 216, 4, 37, "Subsection",ExpressionUUID->"f3e654e3-f9d0-45e3-a064-e129b4afcaff"],
Cell[4880326, 107469, 3576, 116, 276, "Input",ExpressionUUID->"dfc43227-2639-4414-b616-9fd935c839be"],
Cell[4883905, 107587, 1371, 36, 48, "Input",ExpressionUUID->"2b815279-e48e-47b4-a483-4000d541125d"],
Cell[CellGroupData[{
Cell[4885301, 107627, 814, 18, 48, "Input",ExpressionUUID->"84e48865-68df-4af8-bcd5-01da7bcb55e6"],
Cell[4886118, 107647, 1393, 30, 129, "Output",ExpressionUUID->"e6a7ffdc-7174-4dc0-a815-5ca4fb7512d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4887548, 107682, 423, 10, 49, "Input",ExpressionUUID->"9bdea369-8926-42f0-8b49-1f9e589a637d"],
Cell[4887974, 107694, 224, 4, 32, "Output",ExpressionUUID->"c3808926-88c6-4b51-bb36-5600be7946c6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4888247, 107704, 214, 4, 37, "Subsection",ExpressionUUID->"6200f16e-4d48-4f83-80fd-5554d0737246"],
Cell[4888464, 107710, 3546, 116, 276, "Input",ExpressionUUID->"a92c7091-fbe8-448e-a58f-61f897be163a"],
Cell[4892013, 107828, 1366, 36, 48, "Input",ExpressionUUID->"8be4a3b3-c9f7-4653-bcb6-28d9fab528b3"],
Cell[CellGroupData[{
Cell[4893404, 107868, 814, 18, 48, "Input",ExpressionUUID->"be82ebb2-b974-4c90-8ec7-66fa38d083e4"],
Cell[4894221, 107888, 515, 11, 23, "Message",ExpressionUUID->"65da0f36-603b-4385-8d64-210869aa07f4"],
Cell[4894739, 107901, 1369, 30, 126, "Output",ExpressionUUID->"cfc82caa-6f0d-4894-bc57-b6cf64226967"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4896145, 107936, 423, 10, 49, "Input",ExpressionUUID->"db25142b-de8c-4d71-9d98-14d48ea080fb"],
Cell[4896571, 107948, 519, 11, 23, "Message",ExpressionUUID->"28b6417d-a0e4-4def-8ecb-cf3705ec5d02"],
Cell[4897093, 107961, 519, 11, 23, "Message",ExpressionUUID->"31fb81d2-e8e3-423e-95c0-27f6878baf9d"],
Cell[4897615, 107974, 221, 4, 32, "Output",ExpressionUUID->"c6430930-d0a6-49b1-aca8-0da35a1f8620"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4897885, 107984, 217, 4, 37, "Subsection",ExpressionUUID->"866e0dc4-d504-4116-ad6e-62f4780a57a4"],
Cell[4898105, 107990, 3560, 116, 276, "Input",ExpressionUUID->"6c4201f8-9d99-4437-8d44-a18ebd3aa0b0"],
Cell[4901668, 108108, 1368, 36, 124, "Input",ExpressionUUID->"a9721332-7f08-4f75-a726-f25cb1b525dc"],
Cell[CellGroupData[{
Cell[4903061, 108148, 814, 18, 67, "Input",ExpressionUUID->"d642f264-bf41-41f8-8c35-a954093585c9"],
Cell[4903878, 108168, 516, 11, 23, "Message",ExpressionUUID->"a34234de-364c-49c8-b552-4b423b8f4352"],
Cell[4904397, 108181, 1369, 30, 126, "Output",ExpressionUUID->"f0655799-61e4-4cbb-a4b7-7acfdd6f0a74"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4905803, 108216, 423, 10, 49, "Input",ExpressionUUID->"babaf00a-6784-4978-93ac-493ade891d3d"],
Cell[4906229, 108228, 514, 11, 23, "Message",ExpressionUUID->"7cb6d78b-dfc0-4d0d-b842-f9783e89703e"],
Cell[4906746, 108241, 517, 11, 23, "Message",ExpressionUUID->"ecfe6b4e-4ff4-4030-ba1a-181648c3f3b0"],
Cell[4907266, 108254, 222, 4, 32, "Output",ExpressionUUID->"0909c7ea-07eb-4d27-b51b-89e51566093f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4907537, 108264, 164, 3, 37, "Subsection",ExpressionUUID->"7d5f5194-10e9-4a47-b15b-c20f6daa9571"],
Cell[4907704, 108269, 3434, 114, 276, "Input",ExpressionUUID->"8d0503a8-f1df-447c-937f-04c12d5f4f7f"],
Cell[4911141, 108385, 1290, 35, 124, "Input",ExpressionUUID->"b00e43f0-9801-4238-b096-8c88384ee22b"],
Cell[CellGroupData[{
Cell[4912456, 108424, 766, 18, 67, "Input",ExpressionUUID->"c3edfa1b-bf42-4873-83fc-f6d112b3482f"],
Cell[4913225, 108444, 547, 12, 23, "Message",ExpressionUUID->"43be0afd-7fc9-44d4-a9ba-1cfbd6beaec8"],
Cell[4913775, 108458, 1341, 29, 126, "Output",ExpressionUUID->"a31692f1-6913-426f-96ca-a32fba43854e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4915153, 108492, 423, 10, 49, "Input",ExpressionUUID->"eb72e3f3-ea79-402a-b9aa-daf86b5dd31d"],
Cell[4915579, 108504, 516, 11, 23, "Message",ExpressionUUID->"9e71b09b-541b-4eb6-be97-34150da60f9b"],
Cell[4916098, 108517, 518, 11, 23, "Message",ExpressionUUID->"2b0fd691-20af-4e64-b850-6ed9c7a7c1e0"],
Cell[4916619, 108530, 198, 3, 32, "Output",ExpressionUUID->"44d4148d-a8f0-49ed-8592-1f6874c083b6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4916866, 108539, 215, 4, 37, "Subsection",ExpressionUUID->"54c604f4-d331-45aa-a8ef-48ccda23c3b8"],
Cell[4917084, 108545, 3562, 116, 276, "Input",ExpressionUUID->"3a3c3d0a-9732-4b0e-b557-c1cc11925d18"],
Cell[4920649, 108663, 1396, 37, 124, "Input",ExpressionUUID->"8c03584e-cbde-458e-9192-1e29b926db51"],
Cell[CellGroupData[{
Cell[4922070, 108704, 814, 18, 67, "Input",ExpressionUUID->"5af0cded-62ac-449a-9910-d046e43c8396"],
Cell[4922887, 108724, 1389, 30, 129, "Output",ExpressionUUID->"db68a12c-eddb-4b99-87e3-6bcd507d7177"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4924313, 108759, 423, 10, 49, "Input",ExpressionUUID->"90ce35fb-9804-4144-952f-d905af618d83"],
Cell[4924739, 108771, 225, 4, 32, "Output",ExpressionUUID->"dae79822-e00e-44ab-8c3c-5836fab0a8e6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4925013, 108781, 256, 4, 37, "Subsection",ExpressionUUID->"44d86a1f-cb6d-4bf6-a186-bb31baf574f7"],
Cell[CellGroupData[{
Cell[4925294, 108789, 4163, 114, 181, "Input",ExpressionUUID->"17cac955-2a56-4e9b-b0b1-51502c80a36a"],
Cell[4929460, 108905, 396, 6, 32, "Output",ExpressionUUID->"30f98919-6dd2-4642-944a-a658585fb6dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4929893, 108916, 4156, 114, 181, "Input",ExpressionUUID->"04741389-819c-4175-b1fb-5b9c575defeb"],
Cell[4934052, 109032, 197, 3, 32, "Output",ExpressionUUID->"1f5ac3f2-388c-4495-a13e-d189457ac3bc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4934286, 109040, 4218, 114, 257, "Input",ExpressionUUID->"57ce5257-8776-41d6-a5d8-286cd9b31249"],
Cell[4938507, 109156, 195, 3, 32, "Output",ExpressionUUID->"c5e2c6bd-d8d5-488f-8f01-57a781aed836"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4938739, 109164, 4204, 114, 181, "Input",ExpressionUUID->"74e8a600-b56b-4ca2-b496-4796ff5efa20"],
Cell[4942946, 109280, 180, 3, 32, "Output",ExpressionUUID->"5d13fe4d-fec5-4196-bc8f-32d6d3032435"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4943175, 109289, 308, 5, 37, "Subsection",ExpressionUUID->"ac5701bf-4abb-4d56-a571-1ac04a865f9c"],
Cell[CellGroupData[{
Cell[4943508, 109298, 3279, 94, 181, "Input",ExpressionUUID->"fdb8ef29-f4f9-40a0-a069-0bfd102a8900"],
Cell[4946790, 109394, 415, 6, 32, "Output",ExpressionUUID->"7c278b23-4b41-4efb-a8eb-752e2df37905"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4947242, 109405, 3225, 93, 181, "Input",ExpressionUUID->"09341d21-05a3-4eb4-ad4b-880c0b91deab"],
Cell[4950470, 109500, 222, 4, 32, "Output",ExpressionUUID->"5e19a329-1736-4343-b267-5a852b3ec135"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4950729, 109509, 3288, 94, 181, "Input",ExpressionUUID->"9ecad051-5543-404f-af19-ed251f9234e8"],
Cell[4954020, 109605, 223, 4, 32, "Output",ExpressionUUID->"8ccdc56d-176b-426e-8f15-e21e48d2c3f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4954280, 109614, 3276, 94, 181, "Input",ExpressionUUID->"2d3e6176-dd14-4930-aec8-58d8844eba4b"],
Cell[4957559, 109710, 225, 4, 32, "Output",ExpressionUUID->"ad819e1f-a744-4f5d-bded-5f1579400b61"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4957845, 109721, 311, 5, 53, "Section",ExpressionUUID->"6fd8a6ab-ecb9-447c-b9c2-07aaa1d4c896"],
Cell[CellGroupData[{
Cell[4958181, 109730, 216, 4, 53, "Subsection",ExpressionUUID->"b8607921-9a5d-4731-bcf9-9a6139ad7e48"],
Cell[4958400, 109736, 4257, 133, 276, "Input",ExpressionUUID->"46d121df-5c0b-401a-a867-8ff065b7b72f"],
Cell[4962660, 109871, 1344, 36, 48, "Input",ExpressionUUID->"00daa271-f29e-4332-8db0-b0dd7a931a53"],
Cell[CellGroupData[{
Cell[4964029, 109911, 814, 18, 48, "Input",ExpressionUUID->"6a07d9a4-79b0-41f9-b239-9986ec061da9"],
Cell[4964846, 109931, 545, 12, 23, "Message",ExpressionUUID->"38f863fc-61e5-420b-8041-c3625b3e6c53"],
Cell[4965394, 109945, 1397, 30, 126, "Output",ExpressionUUID->"767aaefc-5829-44b1-896c-ebd8fefd4c92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4966828, 109980, 423, 10, 49, "Input",ExpressionUUID->"babd5bfd-dcf1-4d3a-aa2b-e5063dce0872"],
Cell[4967254, 109992, 545, 12, 23, "Message",ExpressionUUID->"8176a149-890f-48ad-a9c4-8085b4b4bfbd"],
Cell[4967802, 110006, 545, 12, 23, "Message",ExpressionUUID->"81ea14ba-62d6-4220-a590-a62ef12a6535"],
Cell[4968350, 110020, 246, 4, 32, "Output",ExpressionUUID->"1c7f5021-9c47-4210-87a1-c1ddac50627e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4968645, 110030, 216, 4, 37, "Subsection",ExpressionUUID->"7eed36c5-1ef7-47a9-a327-1a70fb0c40a0"],
Cell[4968864, 110036, 4337, 134, 276, "Input",ExpressionUUID->"75b24d9c-d166-4779-a8b9-79a8d85d624a"],
Cell[4973204, 110172, 1371, 36, 124, "Input",ExpressionUUID->"ab5e6ef2-1cee-457a-b12c-3c51d108928a"],
Cell[CellGroupData[{
Cell[4974600, 110212, 814, 18, 67, "Input",ExpressionUUID->"427a568a-68b6-4522-bc35-d0fea51f824e"],
Cell[4975417, 110232, 543, 12, 23, "Message",ExpressionUUID->"4e830ea6-3b82-4465-8c97-31c0ed97c7ab"],
Cell[4975963, 110246, 1424, 31, 126, "Output",ExpressionUUID->"5390f762-0946-466d-9641-b4606c44da9f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4977424, 110282, 423, 10, 49, "Input",ExpressionUUID->"21738282-1713-4ad8-8817-18ab49635992"],
Cell[4977850, 110294, 543, 12, 23, "Message",ExpressionUUID->"a61e8532-1800-4c35-b529-5aa7f3648830"],
Cell[4978396, 110308, 545, 12, 23, "Message",ExpressionUUID->"ecae75a1-6465-4afc-880d-837ab57a8176"],
Cell[4978944, 110322, 272, 4, 32, "Output",ExpressionUUID->"f56500f3-775f-43a5-8d84-12e822bc9951"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4979265, 110332, 214, 4, 37, "Subsection",ExpressionUUID->"0183bf53-21b6-4736-ba03-8566da8d4d1b"],
Cell[4979482, 110338, 4308, 134, 276, "Input",ExpressionUUID->"52bf2f87-679a-4022-8ad4-1a4c379f6424"],
Cell[4983793, 110474, 1366, 36, 124, "Input",ExpressionUUID->"e0c01c6c-da00-45df-bbca-1eedb7de9044"],
Cell[CellGroupData[{
Cell[4985184, 110514, 814, 18, 67, "Input",ExpressionUUID->"6c22daf2-d54e-4505-b445-4e75b33d4e0f"],
Cell[4986001, 110534, 565, 12, 23, "Message",ExpressionUUID->"7ba82d08-c530-48a3-9b36-cbeb6620ae4f"],
Cell[4986569, 110548, 1430, 31, 126, "Output",ExpressionUUID->"27c2f51f-3f12-466c-87c1-e5ebcfab056f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4988036, 110584, 423, 10, 49, "Input",ExpressionUUID->"e014eead-2f49-4d9c-ab89-dd2ddce2dfa1"],
Cell[4988462, 110596, 569, 12, 23, "Message",ExpressionUUID->"41579fdc-ec6d-43b9-8acf-31ce90478931"],
Cell[4989034, 110610, 569, 12, 23, "Message",ExpressionUUID->"9c89289a-3df8-49a1-92f2-332f9623fb7f"],
Cell[4989606, 110624, 268, 4, 32, "Output",ExpressionUUID->"46b5830b-cd2f-49a9-908a-047557ec5b20"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4989923, 110634, 217, 4, 37, "Subsection",ExpressionUUID->"d669129f-2791-4484-a2e6-dc3cd0269d6e"],
Cell[4990143, 110640, 4322, 134, 276, "Input",ExpressionUUID->"ef40e02b-9ffb-48ed-bd63-8447054a57cd"],
Cell[4994468, 110776, 1368, 36, 124, "Input",ExpressionUUID->"caaf67ea-5b2c-44c4-8a66-5601937ce3db"],
Cell[CellGroupData[{
Cell[4995861, 110816, 814, 18, 67, "Input",ExpressionUUID->"4f38c0c0-064b-4b99-917b-f02d34c11387"],
Cell[4996678, 110836, 563, 12, 23, "Message",ExpressionUUID->"cf72e55e-3ce7-46f2-9fb5-18ee323ce996"],
Cell[4997244, 110850, 562, 12, 23, "Message",ExpressionUUID->"b98fcd71-bfa7-4c16-bc85-48a7bb5449f3"],
Cell[4997809, 110864, 1405, 31, 123, "Output",ExpressionUUID->"1ed32726-70f3-4742-9ad0-d6ba78b0d11e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4999251, 110900, 423, 10, 49, "Input",ExpressionUUID->"c656f880-8428-43bf-98b6-d7be4e7585e6"],
Cell[4999677, 110912, 564, 12, 23, "Message",ExpressionUUID->"62b43fff-8cf7-4aa2-b62e-ec7040664779"],
Cell[5000244, 110926, 567, 12, 23, "Message",ExpressionUUID->"cbf22075-34a2-4205-a18c-6d7840800e0f"],
Cell[5000814, 110940, 564, 12, 23, "Message",ExpressionUUID->"3c0ddb87-0e6a-426a-b3e8-76092c874dff"],
Cell[5001381, 110954, 533, 11, 21, "Message",ExpressionUUID->"b87069f2-a05a-4045-b4c8-fc8515dc5422"],
Cell[5001917, 110967, 269, 4, 32, "Output",ExpressionUUID->"3b757814-accc-4dc0-a1c1-a8b0faf76a2e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5002235, 110977, 164, 3, 37, "Subsection",ExpressionUUID->"7cbac9cf-d899-4a21-8228-14a254e51a5f"],
Cell[5002402, 110982, 4290, 134, 276, "Input",ExpressionUUID->"607688ec-d287-4298-bc1f-042d3d71630c"],
Cell[5006695, 111118, 1290, 35, 124, "Input",ExpressionUUID->"ec1d0ab2-a240-4e60-8de4-1febb8d19a8b"],
Cell[CellGroupData[{
Cell[5008010, 111157, 766, 18, 67, "Input",ExpressionUUID->"5e7527c2-a70b-4058-b97b-cdb2854da719"],
Cell[5008779, 111177, 590, 12, 23, "Message",ExpressionUUID->"23ab235c-d1f6-4fe3-aa41-aa46bdbab956"],
Cell[5009372, 111191, 593, 12, 23, "Message",ExpressionUUID->"0da5b90b-44a1-419a-ab68-0360e13f2d82"],
Cell[5009968, 111205, 1379, 30, 123, "Output",ExpressionUUID->"c465a2dc-8722-431f-a078-4f43a91ae8e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5011384, 111240, 423, 10, 49, "Input",ExpressionUUID->"75fc13ca-79ff-41ad-b730-a13d4e00a7a2"],
Cell[5011810, 111252, 567, 12, 23, "Message",ExpressionUUID->"df6ceb48-be6e-48c0-b3d3-2c91b713ac97"],
Cell[5012380, 111266, 569, 12, 23, "Message",ExpressionUUID->"349f23fb-8694-4471-a4b6-f66485f323fd"],
Cell[5012952, 111280, 569, 12, 23, "Message",ExpressionUUID->"7b2fb63e-1073-41ff-9aec-2b00f1f88f2c"],
Cell[5013524, 111294, 532, 11, 21, "Message",ExpressionUUID->"89a236a8-18cd-4080-9d39-a8880b07103e"],
Cell[5014059, 111307, 247, 4, 32, "Output",ExpressionUUID->"9ebbe920-53ab-44e0-a022-aa7968c2d91d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5014355, 111317, 215, 4, 37, "Subsection",ExpressionUUID->"a29db68a-92a0-4450-ae4b-ffc5c2990b88"],
Cell[5014573, 111323, 4316, 134, 276, "Input",ExpressionUUID->"4ed53566-ee2c-4c2e-8676-f3383f1a1a11"],
Cell[5018892, 111459, 1396, 37, 124, "Input",ExpressionUUID->"5ee8e238-9ca7-4c72-8c93-fbc189080caa"],
Cell[CellGroupData[{
Cell[5020313, 111500, 814, 18, 67, "Input",ExpressionUUID->"fe052f03-1f37-44cd-87ad-f9883f7884fd"],
Cell[5021130, 111520, 547, 12, 23, "Message",ExpressionUUID->"2f64b0ad-c810-4608-b28b-02d46f682261"],
Cell[5021680, 111534, 1426, 31, 126, "Output",ExpressionUUID->"c80b5a0d-4d29-403d-a503-1783073d0a03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5023143, 111570, 423, 10, 49, "Input",ExpressionUUID->"bcc07c46-4c47-4019-9789-c114bbac23b9"],
Cell[5023569, 111582, 545, 12, 23, "Message",ExpressionUUID->"fe8615a2-a75c-4b8b-8d89-7d0321263856"],
Cell[5024117, 111596, 545, 12, 23, "Message",ExpressionUUID->"2a7df637-dd11-4269-8df1-3e8cc0da8620"],
Cell[5024665, 111610, 270, 4, 32, "Output",ExpressionUUID->"28d5351e-3bc4-4dfd-9ead-414b4db37306"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5024984, 111620, 256, 4, 37, "Subsection",ExpressionUUID->"4b5fac04-6115-4998-be25-6eabe31bc38f"],
Cell[CellGroupData[{
Cell[5025265, 111628, 4260, 115, 181, "Input",ExpressionUUID->"9141d6bc-6821-49eb-a59b-f9c29b0b6ce9"],
Cell[5029528, 111745, 450, 7, 32, "Output",ExpressionUUID->"85c2b506-7ac9-47b1-b6fd-56138db1d67f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5030015, 111757, 4252, 115, 181, "Input",ExpressionUUID->"6f160f58-a0fb-428f-aaef-88155c17dd49"],
Cell[5034270, 111874, 244, 4, 32, "Output",ExpressionUUID->"57679797-dc3f-40d8-b8c8-fa17a63fb96a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5034551, 111883, 4324, 116, 257, "Input",ExpressionUUID->"a8ce0b74-01b8-4479-be11-d188a53516a5"],
Cell[5038878, 112001, 245, 4, 32, "Output",ExpressionUUID->"874fb916-7a0c-45de-87a6-f70a8cb4e6d9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5039160, 112010, 4306, 116, 181, "Input",ExpressionUUID->"c448d111-3389-4a89-ae62-ce1f2e42a1c9"],
Cell[5043469, 112128, 246, 4, 32, "Output",ExpressionUUID->"a393b13c-9308-425e-9561-dbe73284a632"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5043764, 112138, 308, 5, 37, "Subsection",ExpressionUUID->"f8377e85-df8d-4544-89bc-b29a5efb85cc"],
Cell[CellGroupData[{
Cell[5044097, 112147, 3378, 95, 181, "Input",ExpressionUUID->"3c2fb0b0-2af3-4d7d-919c-acdff70d393f"],
Cell[5047478, 112244, 466, 7, 32, "Output",ExpressionUUID->"9550839f-8bea-4228-b0a4-97dd97604be3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5047981, 112256, 3327, 95, 181, "Input",ExpressionUUID->"826202ec-b3ef-4b2f-9cc4-73f74ff55a9d"],
Cell[5051311, 112353, 251, 4, 32, "Output",ExpressionUUID->"55faa6b7-aa1a-4684-8c56-3ecbe617d420"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5051599, 112362, 3387, 95, 181, "Input",ExpressionUUID->"abc76313-e58e-420c-ae91-ea5fed98246d"],
Cell[5054989, 112459, 264, 4, 32, "Output",ExpressionUUID->"203d2a36-182c-4245-bb68-d823928c4f58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5055290, 112468, 3375, 95, 181, "Input",ExpressionUUID->"8db9fb93-7bc4-4e04-b348-273fbc4ab1d1"],
Cell[5058668, 112565, 271, 4, 32, "Output",ExpressionUUID->"1b3b62ad-25a3-482e-8a58-3b1de3e12cbb"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5059000, 112576, 357, 6, 53, "Section",ExpressionUUID->"1afa430f-d4cb-4300-a7ac-c8cbd5989025"],
Cell[CellGroupData[{
Cell[5059382, 112586, 216, 4, 53, "Subsection",ExpressionUUID->"086c431e-ad17-4dd5-bc75-1c1551c9f3a5"],
Cell[5059601, 112592, 4257, 133, 276, "Input",ExpressionUUID->"37382c14-b908-4a8a-a5de-f772378027ed"],
Cell[5063861, 112727, 1344, 36, 124, "Input",ExpressionUUID->"335d24cd-97d6-4841-9473-5a6789473643"],
Cell[CellGroupData[{
Cell[5065230, 112767, 814, 18, 67, "Input",ExpressionUUID->"750b690f-6025-4fa6-9796-f94758b35e1b"],
Cell[5066047, 112787, 1440, 31, 129, "Output",ExpressionUUID->"7b1e7943-cecc-483b-ba0a-a627068da680"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5067524, 112823, 423, 10, 49, "Input",ExpressionUUID->"a1a26a16-ae02-4262-9d86-7e6ce580bd5c"],
Cell[5067950, 112835, 268, 4, 32, "Output",ExpressionUUID->"4a436cf4-da26-49ea-a451-955d3bef2582"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5068267, 112845, 216, 4, 37, "Subsection",ExpressionUUID->"7a250fed-2a99-4286-96a6-ca11da8ad216"],
Cell[5068486, 112851, 4340, 134, 276, "Input",ExpressionUUID->"ad846edc-60cf-4311-8c77-41e2f312c7fa"],
Cell[5072829, 112987, 1371, 36, 124, "Input",ExpressionUUID->"99d219a8-e307-43b9-90d7-7f7af0db56dd"],
Cell[CellGroupData[{
Cell[5074225, 113027, 814, 18, 67, "Input",ExpressionUUID->"3a2d8858-a962-4738-943d-1501a8198557"],
Cell[5075042, 113047, 1458, 31, 129, "Output",ExpressionUUID->"7a880297-a162-4de9-80f4-5ee32c03dd4a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5076537, 113083, 423, 10, 49, "Input",ExpressionUUID->"9d848bc9-c77b-41c9-9d04-bc7e4b7ca07c"],
Cell[5076963, 113095, 299, 5, 32, "Output",ExpressionUUID->"bafde0a4-7c4e-4844-97ae-3a3e77b7d9a1"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5077311, 113106, 214, 4, 37, "Subsection",ExpressionUUID->"b969e70f-40f1-4128-b0ba-50cb87fede9a"],
Cell[5077528, 113112, 4308, 134, 276, "Input",ExpressionUUID->"bbcb7466-0b91-4d87-903d-2053d8da51c1"],
Cell[5081839, 113248, 1366, 36, 124, "Input",ExpressionUUID->"9fa78455-a13b-43df-82bb-c844036da895"],
Cell[CellGroupData[{
Cell[5083230, 113288, 814, 18, 67, "Input",ExpressionUUID->"1e9d04f0-df87-4173-bbca-bffc3b1ef814"],
Cell[5084047, 113308, 1460, 31, 129, "Output",ExpressionUUID->"0c0fe6f0-0567-4ab0-807b-a438256c767d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5085544, 113344, 423, 10, 49, "Input",ExpressionUUID->"201e580f-c07f-468c-80b7-08fdf685cf55"],
Cell[5085970, 113356, 298, 5, 32, "Output",ExpressionUUID->"acd079c6-c78f-4e4e-987f-8a7a2febabfe"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5086317, 113367, 217, 4, 37, "Subsection",ExpressionUUID->"2970f22c-469a-4cf5-9f68-7cbbec2b2d95"],
Cell[5086537, 113373, 4324, 134, 276, "Input",ExpressionUUID->"7855a84e-32b5-41b6-9b5b-0bff0a9811e1"],
Cell[5090864, 113509, 1368, 36, 124, "Input",ExpressionUUID->"f60ddfd0-22a0-4ef2-a514-8dfa93ea458c"],
Cell[CellGroupData[{
Cell[5092257, 113549, 814, 18, 67, "Input",ExpressionUUID->"30eb37c7-6b17-4261-8fee-ba4daaa0623a"],
Cell[5093074, 113569, 585, 12, 23, "Message",ExpressionUUID->"f68f9e67-f2cf-487b-8f7d-323d9addafe8"],
Cell[5093662, 113583, 1438, 30, 126, "Output",ExpressionUUID->"4e95d4b4-083e-4d46-8c59-49f0faddae56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5095137, 113618, 423, 10, 49, "Input",ExpressionUUID->"476aaae8-3c52-4fef-8e75-96de72afea63"],
Cell[5095563, 113630, 590, 12, 23, "Message",ExpressionUUID->"cd1e34bf-0cac-433c-ab7d-38829e0e69b7"],
Cell[5096156, 113644, 590, 12, 23, "Message",ExpressionUUID->"7ad1dfa4-3667-4de1-990e-15098741c627"],
Cell[5096749, 113658, 295, 5, 32, "Output",ExpressionUUID->"479e0e68-c716-4fd4-9ecf-1b1a4adea263"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5097093, 113669, 164, 3, 37, "Subsection",ExpressionUUID->"61ca2f04-f3dc-4007-8039-0f4c43712b1d"],
Cell[5097260, 113674, 4341, 135, 276, "Input",ExpressionUUID->"55a36cc1-b746-4aad-b5a4-5f010e1d90ad"],
Cell[5101604, 113811, 1290, 35, 124, "Input",ExpressionUUID->"92488bdc-32de-4b77-8e0f-0d8f88058876"],
Cell[CellGroupData[{
Cell[5102919, 113850, 766, 18, 67, "Input",ExpressionUUID->"8d83c436-89b3-486b-b067-e6d214858fce"],
Cell[5103688, 113870, 620, 13, 23, "Message",ExpressionUUID->"1a397661-9b1e-464e-b8b8-67047d522b6a"],
Cell[5104311, 113885, 1422, 31, 126, "Output",ExpressionUUID->"29e056be-0585-46bb-9d30-f26f210a317f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5105770, 113921, 423, 10, 49, "Input",ExpressionUUID->"810773b4-71f3-4162-8a8c-a07b33f7b91f"],
Cell[5106196, 113933, 588, 12, 23, "Message",ExpressionUUID->"8548f1ce-8ccb-449f-9007-a0eeb8fdb6ff"],
Cell[5106787, 113947, 589, 12, 23, "Message",ExpressionUUID->"12284c59-ca95-4c89-b2df-62a061360734"],
Cell[5107379, 113961, 270, 4, 32, "Output",ExpressionUUID->"5a8a3e0d-aa05-4a39-9f2d-ee30dc4130e0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5107698, 113971, 215, 4, 37, "Subsection",ExpressionUUID->"4852c954-1725-4a78-9a0c-cf9386207e55"],
Cell[5107916, 113977, 4367, 135, 276, "Input",ExpressionUUID->"e236a285-e1ae-4c6d-96e6-fec56e3c03cd"],
Cell[5112286, 114114, 1396, 37, 124, "Input",ExpressionUUID->"baaac07d-19cf-4c5a-a486-cda7465aa4dc"],
Cell[CellGroupData[{
Cell[5113707, 114155, 814, 18, 67, "Input",ExpressionUUID->"3bb9ec7d-8af1-4134-936d-274a73de23c6"],
Cell[5114524, 114175, 1458, 31, 129, "Output",ExpressionUUID->"295052d9-4a20-480b-9026-073573356d7f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5116019, 114211, 423, 10, 49, "Input",ExpressionUUID->"e065bc2c-e26c-43b4-9917-10ef122e8ebe"],
Cell[5116445, 114223, 295, 5, 32, "Output",ExpressionUUID->"f6de169a-ba86-4861-804a-77e9c5f89c5f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5116789, 114234, 256, 4, 37, "Subsection",ExpressionUUID->"b4cc4d2a-1905-4d58-86cf-c7dbfe4a27f9"],
Cell[CellGroupData[{
Cell[5117070, 114242, 4323, 116, 181, "Input",ExpressionUUID->"90b12647-94b1-4fbb-ab83-0e09f5201fb7"],
Cell[5121396, 114360, 473, 7, 70, "Output",ExpressionUUID->"ff822bac-1c88-4637-9b77-f44aed06c7d4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5121906, 114372, 4319, 116, 181, "Input",ExpressionUUID->"b2315aad-b241-4e1e-8e1a-a4d8c6ce7cf2"],
Cell[5126228, 114490, 267, 4, 70, "Output",ExpressionUUID->"ae01ad51-bcfa-48eb-be3d-065449438dfb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5126532, 114499, 4388, 116, 181, "Input",ExpressionUUID->"71f4994c-aa9e-439d-9160-077fc5271cd6"],
Cell[5130923, 114617, 250, 4, 70, "Output",ExpressionUUID->"b3a72324-9354-45e9-bc76-8941663b7da2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5131210, 114626, 4367, 116, 181, "Input",ExpressionUUID->"e7ef2e66-426c-4dd4-81e5-929709e64259"],
Cell[5135580, 114744, 251, 4, 70, "Output",ExpressionUUID->"3872be06-05f2-49ac-a36e-a80ab03739ef"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5135880, 114754, 308, 5, 37, "Subsection",ExpressionUUID->"1c647191-bde3-4f47-9341-df4cc93423ae"],
Cell[CellGroupData[{
Cell[5136213, 114763, 3444, 96, 181, "Input",ExpressionUUID->"e47d5233-704a-4487-b557-33a4af2a3cd5"],
Cell[5139660, 114861, 490, 7, 70, "Output",ExpressionUUID->"30c195db-0cec-4d5b-8ff2-84aaf36e0f59"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5140187, 114873, 3392, 95, 181, "Input",ExpressionUUID->"bfc887b6-335c-42f6-a88b-6e8986950d7f"],
Cell[5143582, 114970, 282, 5, 70, "Output",ExpressionUUID->"71bd867c-6f62-448e-8cb6-d7c46eafb425"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5143901, 114980, 3451, 96, 181, "Input",ExpressionUUID->"e27db1ae-74f4-4ba8-955f-8f10ba06b63b"],
Cell[5147355, 115078, 292, 5, 70, "Output",ExpressionUUID->"f2f7e83b-4988-4d6a-b3b1-f80c47f0b598"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5147684, 115088, 3443, 96, 181, "Input",ExpressionUUID->"3ae9ef3d-3406-446d-af4c-3e74f9a1ad61"],
Cell[5151130, 115186, 270, 4, 70, "Output",ExpressionUUID->"1eebaf34-4c24-49a4-8c8c-cf94a1b33e33"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5151461, 115197, 264, 4, 53, "Section",ExpressionUUID->"0f8beda5-51eb-43e3-8eb0-becc34f46e22"],
Cell[CellGroupData[{
Cell[5151750, 115205, 216, 4, 53, "Subsection",ExpressionUUID->"5421897c-fcda-4b00-86ff-52a9045f5a28"],
Cell[5151969, 115211, 4156, 132, 276, "Input",ExpressionUUID->"0fc22316-d4ae-409f-bb61-5b8c610380af"],
Cell[5156128, 115345, 1344, 36, 48, "Input",ExpressionUUID->"9fd034c8-aaa0-40e5-be31-86b28a726a17"],
Cell[CellGroupData[{
Cell[5157497, 115385, 814, 18, 48, "Input",ExpressionUUID->"91b2b3cc-f9e4-477e-b184-efbe84933bde"],
Cell[5158314, 115405, 518, 11, 23, "Message",ExpressionUUID->"3523a5e9-93c7-4e3d-a342-c414f5fec6d0"],
Cell[5158835, 115418, 1390, 31, 123, "Output",ExpressionUUID->"d6e2b5e4-f375-44eb-9855-76aee69793cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5160262, 115454, 423, 10, 49, "Input",ExpressionUUID->"31edec09-ab93-4221-924b-a182de835cb8"],
Cell[5160688, 115466, 518, 11, 23, "Message",ExpressionUUID->"7a392ec7-5e7f-4464-b62b-027393de35ed"],
Cell[5161209, 115479, 516, 11, 23, "Message",ExpressionUUID->"0898e6ba-d691-4abe-af39-a48c4b85414e"],
Cell[5161728, 115492, 229, 4, 32, "Output",ExpressionUUID->"028b1739-da82-45ad-96e4-638e0a8e295b"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5162006, 115502, 216, 4, 37, "Subsection",ExpressionUUID->"83f3feb2-3657-499c-8a46-a7f76d55b8ad"],
Cell[5162225, 115508, 4237, 133, 276, "Input",ExpressionUUID->"2d37945e-5b49-4c12-be25-f936a6cc9018"],
Cell[5166465, 115643, 1371, 36, 124, "Input",ExpressionUUID->"a29ccb04-86e4-4494-9924-3305422bb0a9"],
Cell[CellGroupData[{
Cell[5167861, 115683, 814, 18, 67, "Input",ExpressionUUID->"333c03b6-962d-4e2a-9b72-f2e8ab645ed2"],
Cell[5168678, 115703, 520, 11, 23, "Message",ExpressionUUID->"d483fbb9-3aeb-4a58-b779-9474fa116fc3"],
Cell[5169201, 115716, 1405, 30, 126, "Output",ExpressionUUID->"31948e92-d3f3-4564-b565-8dbeaebe0389"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5170643, 115751, 423, 10, 49, "Input",ExpressionUUID->"33f7daab-c957-49e9-8735-3bd93b41ae27"],
Cell[5171069, 115763, 518, 11, 23, "Message",ExpressionUUID->"2b6ee6c8-fa47-4288-a579-e98e41c8b77e"],
Cell[5171590, 115776, 518, 11, 23, "Message",ExpressionUUID->"2716472f-3d6d-487b-8fc7-046821e77cc7"],
Cell[5172111, 115789, 252, 4, 32, "Output",ExpressionUUID->"47cb4555-db0d-4e25-b830-96db4054d512"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5172412, 115799, 214, 4, 37, "Subsection",ExpressionUUID->"5b25fad5-3d7c-4735-8249-a0679ffbc462"],
Cell[5172629, 115805, 4207, 133, 276, "Input",ExpressionUUID->"790a5638-2075-4355-9ebb-0a147a29b995"],
Cell[5176839, 115940, 1366, 36, 124, "Input",ExpressionUUID->"66ffb605-0b54-4648-9480-d60129d94973"],
Cell[CellGroupData[{
Cell[5178230, 115980, 814, 18, 67, "Input",ExpressionUUID->"c1a6b15c-26f4-4f66-aa95-cb9da6e34d65"],
Cell[5179047, 116000, 541, 12, 23, "Message",ExpressionUUID->"383bb40b-7c34-4bd7-973a-a3ee53b8e31e"],
Cell[5179591, 116014, 1393, 29, 126, "Output",ExpressionUUID->"f492e517-e80d-4228-914b-c7130caaa22e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5181021, 116048, 423, 10, 49, "Input",ExpressionUUID->"9b6b3d8d-074d-4a95-807c-021ce34e1ce1"],
Cell[5181447, 116060, 543, 12, 23, "Message",ExpressionUUID->"d0c909c4-f5e6-4ea1-bcd5-aaed0e0448a2"],
Cell[5181993, 116074, 543, 12, 23, "Message",ExpressionUUID->"d43dc418-da08-4677-b1b8-6cbd7c996c67"],
Cell[5182539, 116088, 249, 4, 32, "Output",ExpressionUUID->"c945b023-6090-4e30-aac5-10194f3b3451"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5182837, 116098, 217, 4, 37, "Subsection",ExpressionUUID->"85b1c9b5-da39-4039-9126-578612f0bc5e"],
Cell[5183057, 116104, 4223, 133, 276, "Input",ExpressionUUID->"50d24436-8f9b-410f-a1e2-50a76e5989f3"],
Cell[5187283, 116239, 1368, 36, 124, "Input",ExpressionUUID->"baf7b7af-32b0-409c-9fd6-875db81baa3c"],
Cell[CellGroupData[{
Cell[5188676, 116279, 814, 18, 67, "Input",ExpressionUUID->"01de4b96-4f3d-49d2-a058-6f3e32a7c5a7"],
Cell[5189493, 116299, 539, 12, 23, "Message",ExpressionUUID->"b6d5e98a-fbe9-43a4-b20e-17981c7a67ca"],
Cell[5190035, 116313, 1406, 30, 126, "Output",ExpressionUUID->"0f91937a-fd1d-4339-b90c-24d077e0b06b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5191478, 116348, 423, 10, 49, "Input",ExpressionUUID->"815e0866-98f3-473d-b3bf-c1e3dbf3837d"],
Cell[5191904, 116360, 539, 12, 23, "Message",ExpressionUUID->"3969f944-5b62-456f-91ee-6049a0324eba"],
Cell[5192446, 116374, 539, 12, 23, "Message",ExpressionUUID->"07887997-e529-4345-bedb-35a1f798f0cc"],
Cell[5192988, 116388, 250, 4, 32, "Output",ExpressionUUID->"97fb9d4c-2c24-4e50-9c01-2c25b899a686"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5193287, 116398, 164, 3, 37, "Subsection",ExpressionUUID->"917748ac-8df6-434e-bc04-5d48ff97fe2f"],
Cell[5193454, 116403, 4191, 133, 276, "Input",ExpressionUUID->"ca2df31a-1487-449d-aecb-b51de440c5de"],
Cell[5197648, 116538, 1290, 35, 124, "Input",ExpressionUUID->"ce282099-6632-4861-8ef3-9634c8abe0a5"],
Cell[CellGroupData[{
Cell[5198963, 116577, 766, 18, 67, "Input",ExpressionUUID->"fde877d9-732a-4956-8368-f23da5b8d0d3"],
Cell[5199732, 116597, 569, 12, 23, "Message",ExpressionUUID->"114d59ab-94fe-4c18-94d0-7e8d3a473e29"],
Cell[5200304, 116611, 1379, 30, 126, "Output",ExpressionUUID->"60964629-439b-478c-aa85-76510680bccd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5201720, 116646, 423, 10, 49, "Input",ExpressionUUID->"87fbb957-b602-40b6-94af-1aa959b3e75c"],
Cell[5202146, 116658, 543, 12, 23, "Message",ExpressionUUID->"2f01fce0-3dc3-4569-88f6-3e53d688f8fd"],
Cell[5202692, 116672, 545, 12, 23, "Message",ExpressionUUID->"847eab28-b0c3-4754-9563-a1d891a3bf62"],
Cell[5203240, 116686, 226, 4, 32, "Output",ExpressionUUID->"8e9fed52-34e3-4767-b0f6-cfaf3546206f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5203515, 116696, 215, 4, 37, "Subsection",ExpressionUUID->"39384a03-0f4b-493b-a150-1b11a01c3c21"],
Cell[5203733, 116702, 4221, 133, 276, "Input",ExpressionUUID->"a38b3dee-cb8b-4d25-9e46-0de29ec2b2cb"],
Cell[5207957, 116837, 1396, 37, 124, "Input",ExpressionUUID->"81ae33d1-cdfa-4f71-8d0e-e889f80a7e10"],
Cell[CellGroupData[{
Cell[5209378, 116878, 814, 18, 67, "Input",ExpressionUUID->"7bc373fc-b9e1-422f-8d85-deb8240c52af"],
Cell[5210195, 116898, 520, 11, 23, "Message",ExpressionUUID->"c0285038-53b6-434b-855c-2d91577685cd"],
Cell[5210718, 116911, 1393, 29, 123, "Output",ExpressionUUID->"81518a2c-879f-44a0-969c-ab8220403bce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5212148, 116945, 423, 10, 49, "Input",ExpressionUUID->"cf7bb91d-548f-4beb-8b1f-bb762f99a828"],
Cell[5212574, 116957, 518, 11, 23, "Message",ExpressionUUID->"8d8aeaca-ca66-4146-b604-5492e55fa52c"],
Cell[5213095, 116970, 518, 11, 23, "Message",ExpressionUUID->"aadaee67-2ea0-4e6e-b9aa-41a14a3dc3f6"],
Cell[5213616, 116983, 249, 4, 32, "Output",ExpressionUUID->"2b89887e-f345-4543-9a0c-450670dc6cb2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5213914, 116993, 256, 4, 37, "Subsection",ExpressionUUID->"e352cf3b-013c-4f24-aa58-992aa600d311"],
Cell[CellGroupData[{
Cell[5214195, 117001, 4209, 114, 181, "Input",ExpressionUUID->"dddcbcb2-e4b8-46ea-b8ce-065e46f80a0b"],
Cell[5218407, 117117, 421, 6, 32, "Output",ExpressionUUID->"d1b26eeb-803a-4ab4-b3e3-b29b94d360f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5218865, 117128, 4201, 114, 181, "Input",ExpressionUUID->"b8d43102-6b5f-4d2f-a439-b47398e45625"],
Cell[5223069, 117244, 220, 4, 32, "Output",ExpressionUUID->"1619fc05-b430-4f4a-96ed-7c0a2e9e3553"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5223326, 117253, 4271, 115, 181, "Input",ExpressionUUID->"36e6058e-c68e-4550-91ec-220e0149d6de"],
Cell[5227600, 117370, 220, 4, 32, "Output",ExpressionUUID->"bdbe5e33-84a3-4cac-b2a8-bda341018780"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5227857, 117379, 4255, 115, 181, "Input",ExpressionUUID->"049baf87-c906-4ec0-9d18-eb2fbcdbaa56"],
Cell[5232115, 117496, 222, 4, 32, "Output",ExpressionUUID->"1a817b93-920d-4000-a193-17c234544e32"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5232386, 117506, 308, 5, 37, "Subsection",ExpressionUUID->"4ea0221a-49e6-4e23-b8a3-cbec79f4caf2"],
Cell[CellGroupData[{
Cell[5232719, 117515, 3330, 95, 181, "Input",ExpressionUUID->"d8b0d7e2-e69c-49ee-8697-bf9df4f6351a"],
Cell[5236052, 117612, 445, 7, 70, "Output",ExpressionUUID->"9f137cf3-d1a3-491c-836b-f1dcf62d9772"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5236534, 117624, 3276, 94, 181, "Input",ExpressionUUID->"b95fb785-f480-48c1-9272-39c2867ac0ab"],
Cell[5239813, 117720, 242, 4, 70, "Output",ExpressionUUID->"4d20d2a2-110e-4868-9822-d6a3e37512ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5240092, 117729, 3339, 95, 181, "Input",ExpressionUUID->"ffa2840b-6203-414b-b30f-f7fcebd78b34"],
Cell[5243434, 117826, 243, 4, 70, "Output",ExpressionUUID->"752cf310-ff4f-4dbd-a60c-5d1aa21ad269"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5243714, 117835, 3327, 95, 181, "Input",ExpressionUUID->"695512c2-5c06-4dcc-b864-1fe382055af4"],
Cell[5247044, 117932, 230, 4, 70, "Output",ExpressionUUID->"a83b465a-0f0b-4124-986d-c258e2bf5a39"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5247335, 117943, 324, 5, 53, "Section",ExpressionUUID->"c13374e5-5b49-4b78-bcee-1ecccf74e765"],
Cell[CellGroupData[{
Cell[5247684, 117952, 216, 4, 53, "Subsection",ExpressionUUID->"785c1f8e-c83b-45fc-9d05-be4d898bbdef"],
Cell[5247903, 117958, 4207, 133, 276, "Input",ExpressionUUID->"8144515f-7d59-4bf9-864d-1044028f1391"],
Cell[5252113, 118093, 1344, 36, 124, "Input",ExpressionUUID->"0fb5adce-b1c4-4bca-8ba5-d280aad35d96"],
Cell[CellGroupData[{
Cell[5253482, 118133, 814, 18, 67, "Input",ExpressionUUID->"fac8bf85-ca22-4be6-8da1-78d6afd32fe9"],
Cell[5254299, 118153, 543, 12, 23, "Message",ExpressionUUID->"1fe0baa4-ce6e-458b-b9de-808635945b04"],
Cell[5254845, 118167, 1385, 29, 123, "Output",ExpressionUUID->"383637ee-b060-4cc0-af4b-0a2919c58138"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5256267, 118201, 423, 10, 49, "Input",ExpressionUUID->"cc00edf2-ce27-44fb-b51c-be2253fa98ca"],
Cell[5256693, 118213, 543, 12, 23, "Message",ExpressionUUID->"439c7b3d-67a8-48c9-b838-eeb17c972f32"],
Cell[5257239, 118227, 543, 12, 23, "Message",ExpressionUUID->"96171f55-0f85-4619-a8f2-297c7693e1f8"],
Cell[5257785, 118241, 250, 4, 32, "Output",ExpressionUUID->"8bc61dfc-8c3e-4b0d-ae33-d90b2cee710e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5258084, 118251, 216, 4, 37, "Subsection",ExpressionUUID->"e911b7c9-2c67-4fbd-9626-f637c33fd8a0"],
Cell[5258303, 118257, 4287, 133, 276, "Input",ExpressionUUID->"19889b2d-37a5-4cfe-b2d4-f7942060ab66"],
Cell[5262593, 118392, 1371, 36, 124, "Input",ExpressionUUID->"c9c0de69-46da-493b-b017-7a7a03594e5c"],
Cell[CellGroupData[{
Cell[5263989, 118432, 814, 18, 67, "Input",ExpressionUUID->"60cff17c-5fed-4688-94cd-2a719f90a08c"],
Cell[5264806, 118452, 547, 12, 23, "Message",ExpressionUUID->"8ada07e9-857f-4a81-a2ec-37b65b5df779"],
Cell[5265356, 118466, 1404, 30, 126, "Output",ExpressionUUID->"1947b758-4877-4b06-88ed-6d8338fc53f9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5266797, 118501, 423, 10, 49, "Input",ExpressionUUID->"6e4df809-6476-4913-8ab6-5ebb3d3e3bae"],
Cell[5267223, 118513, 545, 12, 23, "Message",ExpressionUUID->"703d35d8-d568-47f2-8535-217e79629788"],
Cell[5267771, 118527, 543, 12, 23, "Message",ExpressionUUID->"0ebca223-97e4-4e3d-989a-15d401af288b"],
Cell[5268317, 118541, 274, 4, 32, "Output",ExpressionUUID->"cfdd097a-0466-4330-a34e-168e1153640d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5268640, 118551, 214, 4, 37, "Subsection",ExpressionUUID->"5dccd9be-bcfc-4877-8b46-e800b0f95eb9"],
Cell[5268857, 118557, 4255, 133, 276, "Input",ExpressionUUID->"594c45ca-5c16-469c-9625-99a9b1675581"],
Cell[5273115, 118692, 1366, 36, 124, "Input",ExpressionUUID->"11d721a1-845f-4555-9bd3-afdd7b994920"],
Cell[CellGroupData[{
Cell[5274506, 118732, 814, 18, 67, "Input",ExpressionUUID->"9f9182cd-aedc-45c5-ad5c-d2e9f31dc647"],
Cell[5275323, 118752, 564, 12, 23, "Message",ExpressionUUID->"aaa7200c-ef49-4892-933f-59195a289f81"],
Cell[5275890, 118766, 1411, 30, 126, "Output",ExpressionUUID->"a7a1be09-0d03-46ef-9428-3f9c9b203cfa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5277338, 118801, 423, 10, 49, "Input",ExpressionUUID->"63a19a85-54f0-45b9-9a70-c292887591d7"],
Cell[5277764, 118813, 566, 12, 23, "Message",ExpressionUUID->"afe0fb9c-cfc2-4fd2-aa44-a5e332897b7a"],
Cell[5278333, 118827, 564, 12, 23, "Message",ExpressionUUID->"577540a1-4659-4474-b53e-6e04bbca4dfe"],
Cell[5278900, 118841, 268, 4, 32, "Output",ExpressionUUID->"d1db5c84-1ab4-4458-b8e8-aa3045d448ad"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5279217, 118851, 217, 4, 37, "Subsection",ExpressionUUID->"ad7d039d-09e4-464a-929d-9577b94fbe61"],
Cell[5279437, 118857, 4271, 133, 276, "Input",ExpressionUUID->"090347d5-a91a-40a9-a23d-0dafd9f95075"],
Cell[5283711, 118992, 1368, 36, 124, "Input",ExpressionUUID->"f9cc876c-5e3b-49f1-b89a-12f5656934b6"],
Cell[CellGroupData[{
Cell[5285104, 119032, 814, 18, 67, "Input",ExpressionUUID->"d561c600-d7fc-41f4-abba-fab3e7239d0d"],
Cell[5285921, 119052, 562, 12, 23, "Message",ExpressionUUID->"ecc2a0f8-de6b-4589-afc3-ccc44fe3e7d7"],
Cell[5286486, 119066, 1413, 30, 126, "Output",ExpressionUUID->"eb68ec09-e9d3-4a43-bee4-c73be407288b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5287936, 119101, 423, 10, 49, "Input",ExpressionUUID->"6e73f683-1df8-4ee8-bd46-333ef2e73a0b"],
Cell[5288362, 119113, 565, 12, 23, "Message",ExpressionUUID->"7718b58d-0755-46e9-9062-96d3b5c6da2b"],
Cell[5288930, 119127, 565, 12, 23, "Message",ExpressionUUID->"f204e1f9-b481-4d42-bb8d-267e343e88c4"],
Cell[5289498, 119141, 271, 4, 32, "Output",ExpressionUUID->"52694dc9-ab1b-46d3-b49b-950a8df55d2c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5289818, 119151, 164, 3, 37, "Subsection",ExpressionUUID->"4f8dcc77-532b-4c61-b8a3-e6ec14b53e27"],
Cell[5289985, 119156, 4241, 133, 276, "Input",ExpressionUUID->"2852f062-3451-40fb-b8cb-f1bc76c33e2c"],
Cell[5294229, 119291, 1290, 35, 124, "Input",ExpressionUUID->"3fbfb4b8-913d-4c9a-b1b4-bc0436343245"],
Cell[CellGroupData[{
Cell[5295544, 119330, 766, 18, 67, "Input",ExpressionUUID->"834f3aa9-b437-48ea-873d-c7daca6f97f0"],
Cell[5296313, 119350, 590, 12, 23, "Message",ExpressionUUID->"69d7e465-95a6-4783-ac0f-0da4a5cf5476"],
Cell[5296906, 119364, 1385, 29, 126, "Output",ExpressionUUID->"ce552a56-22bd-4f9b-bc27-f95e51a80753"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5298328, 119398, 423, 10, 49, "Input",ExpressionUUID->"d07e5511-ca38-42fa-945a-a30f9a1da71a"],
Cell[5298754, 119410, 568, 12, 23, "Message",ExpressionUUID->"fecfd61c-7b29-40e7-ab25-c99c7dc35eb6"],
Cell[5299325, 119424, 568, 12, 23, "Message",ExpressionUUID->"d76d3891-1a06-4750-917f-ef08d70aa3d6"],
Cell[5299896, 119438, 248, 4, 32, "Output",ExpressionUUID->"307de091-ecfc-49f5-9e23-3d35633db1e9"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5300193, 119448, 215, 4, 37, "Subsection",ExpressionUUID->"f5187dc0-9453-4955-8d5b-08d2e465069d"],
Cell[5300411, 119454, 4266, 133, 276, "Input",ExpressionUUID->"aee98e4d-d42c-4030-8356-fc543f70d4a4"],
Cell[5304680, 119589, 1396, 37, 124, "Input",ExpressionUUID->"f3bcfc9e-f14d-48c2-a547-06b1d41c560b"],
Cell[CellGroupData[{
Cell[5306101, 119630, 814, 18, 67, "Input",ExpressionUUID->"a4e29b24-bcaa-445c-9b7a-09b6f82c6fa5"],
Cell[5306918, 119650, 547, 12, 23, "Message",ExpressionUUID->"ce77ac5e-6cd8-480c-ad23-a0a0dfe52b04"],
Cell[5307468, 119664, 1406, 30, 126, "Output",ExpressionUUID->"ebfc985e-99d6-4604-bef5-b940fe300904"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5308911, 119699, 423, 10, 49, "Input",ExpressionUUID->"a305f527-99b4-4f95-9089-3a6531625d4e"],
Cell[5309337, 119711, 545, 12, 23, "Message",ExpressionUUID->"3cd2afc6-c313-41da-8a56-0c89907994dd"],
Cell[5309885, 119725, 545, 12, 23, "Message",ExpressionUUID->"718aa88f-6d79-4f3f-b8db-a6cfae72fd78"],
Cell[5310433, 119739, 274, 4, 32, "Output",ExpressionUUID->"d7338233-5488-45fe-9025-2ec66a18ae47"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5310756, 119749, 256, 4, 37, "Subsection",ExpressionUUID->"3c8bab76-8fc9-4c75-b60b-a071ebbf3890"],
Cell[CellGroupData[{
Cell[5311037, 119757, 4288, 115, 181, "Input",ExpressionUUID->"0204406d-6be3-4389-a293-0b0a3768ac25"],
Cell[5315328, 119874, 447, 7, 70, "Output",ExpressionUUID->"73dd671a-7a35-4f37-992b-23d8bea0d4cb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5315812, 119886, 4280, 115, 181, "Input",ExpressionUUID->"fe7c629b-e10d-444f-9be5-fdc5311d4234"],
Cell[5320095, 120003, 243, 4, 70, "Output",ExpressionUUID->"bd6a1ca4-c53e-4cf8-9398-60ede50d3b81"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5320375, 120012, 4348, 116, 181, "Input",ExpressionUUID->"3218a27b-ecd1-4e3e-b5a0-7b3ff1538ffb"],
Cell[5324726, 120130, 244, 4, 70, "Output",ExpressionUUID->"8432a888-fc04-4dff-b1ff-6c60d4ab9907"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5325007, 120139, 4334, 116, 181, "Input",ExpressionUUID->"d78241d9-2373-4fca-bb05-d2227aee1a6d"],
Cell[5329344, 120257, 232, 4, 70, "Output",ExpressionUUID->"4e29d46f-89a7-4b10-95f2-61976b97424b"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5329625, 120267, 308, 5, 37, "Subsection",ExpressionUUID->"cc03569f-361b-4736-b8ad-358751b6ae1e"],
Cell[CellGroupData[{
Cell[5329958, 120276, 3407, 95, 181, "Input",ExpressionUUID->"18e5b7fc-84db-46ca-8999-d42d6c9bde74"],
Cell[5333368, 120373, 465, 7, 70, "Output",ExpressionUUID->"306e5a48-d4da-4d96-8584-2195985a0466"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5333870, 120385, 3356, 95, 181, "Input",ExpressionUUID->"5edf1b1e-9650-46a9-9f39-c814ce0731ac"],
Cell[5337229, 120482, 265, 4, 70, "Output",ExpressionUUID->"8e65a333-3664-4006-bdb5-d45f22d48497"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5337531, 120491, 3414, 95, 181, "Input",ExpressionUUID->"61d96d48-8e59-4bd4-a534-f84aca71531d"],
Cell[5340948, 120588, 267, 4, 70, "Output",ExpressionUUID->"922f54c8-dced-43da-a662-cec4095ddfea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5341252, 120597, 3404, 95, 181, "Input",ExpressionUUID->"052449e0-1cf4-470c-84d0-d4697448f8a1"],
Cell[5344659, 120694, 269, 4, 70, "Output",ExpressionUUID->"932a60f0-731b-42bd-919d-68ed99091ad8"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5344989, 120705, 379, 6, 53, "Section",ExpressionUUID->"d8179e7d-adfd-4a0e-858f-039f0440d6d8"],
Cell[CellGroupData[{
Cell[5345393, 120715, 216, 4, 53, "Subsection",ExpressionUUID->"93afa108-555e-4033-b275-29e4ad8ae74e"],
Cell[5345612, 120721, 4271, 133, 276, "Input",ExpressionUUID->"82958503-e66b-4895-b043-036c88f676e8"],
Cell[5349886, 120856, 1344, 36, 124, "Input",ExpressionUUID->"baf9d0af-7aa1-43da-a1a3-87d15a5c49c0"],
Cell[CellGroupData[{
Cell[5351255, 120896, 814, 18, 67, "Input",ExpressionUUID->"85259cf1-cbe5-4b12-a109-49197c68ccea"],
Cell[5352072, 120916, 565, 12, 23, "Message",ExpressionUUID->"2080a549-5a41-4e49-8a43-8b51f80dc422"],
Cell[5352640, 120930, 1427, 31, 126, "Output",ExpressionUUID->"db763c7d-4d36-4f5a-9c0e-9fa515a429c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5354104, 120966, 423, 10, 49, "Input",ExpressionUUID->"303178b1-b141-471f-8c9b-52dfbf820f8a"],
Cell[5354530, 120978, 565, 12, 23, "Message",ExpressionUUID->"6642e5d1-22b0-4849-a6d8-29dbd7f1dadb"],
Cell[5355098, 120992, 563, 12, 23, "Message",ExpressionUUID->"6671c9d8-165e-456a-b965-248ccabbe59a"],
Cell[5355664, 121006, 277, 4, 32, "Output",ExpressionUUID->"ae0b47cd-4746-4a39-8d70-57bf9fd766b3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5355990, 121016, 216, 4, 37, "Subsection",ExpressionUUID->"aabc527f-1c35-443f-a429-7e45a9acf5ca"],
Cell[5356209, 121022, 4352, 134, 276, "Input",ExpressionUUID->"6282fdea-4722-49b0-baf6-26986c2b9434"],
Cell[5360564, 121158, 1371, 36, 48, "Input",ExpressionUUID->"4061263f-2b90-428f-89b3-cc7e4a5d7294"],
Cell[CellGroupData[{
Cell[5361960, 121198, 814, 18, 48, "Input",ExpressionUUID->"a80743dc-b6b4-401d-99ae-4f677be1a95b"],
Cell[5362777, 121218, 571, 12, 70, "Message",ExpressionUUID->"96300a70-1309-4307-956e-542a9b3d4f9b"],
Cell[5363351, 121232, 1449, 31, 70, "Output",ExpressionUUID->"cdd9c985-feb7-4a6f-9499-89962568506f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5364837, 121268, 423, 10, 49, "Input",ExpressionUUID->"fb8dff1d-9b4f-4272-a9e0-2c17d69c38b8"],
Cell[5365263, 121280, 567, 12, 70, "Message",ExpressionUUID->"8d9eb314-f518-4413-bd52-485c9f8d72aa"],
Cell[5365833, 121294, 567, 12, 70, "Message",ExpressionUUID->"02190c86-fa34-4904-9195-70fb90df1fac"],
Cell[5366403, 121308, 303, 5, 70, "Output",ExpressionUUID->"723a1cb5-bf94-4738-b2fe-74b6a5670516"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5366755, 121319, 214, 4, 37, "Subsection",ExpressionUUID->"189c366b-3c59-4a6b-8548-c5858e71c83f"],
Cell[5366972, 121325, 4320, 134, 276, "Input",ExpressionUUID->"8ea121d1-92ae-454f-9dfc-7c7f0b1d6da1"],
Cell[5371295, 121461, 1366, 36, 48, "Input",ExpressionUUID->"8d473ea3-1eb0-4663-9a6d-abdb19db75a9"],
Cell[CellGroupData[{
Cell[5372686, 121501, 814, 18, 48, "Input",ExpressionUUID->"416154d7-24ce-4253-8eb5-8a2c6c82747c"],
Cell[5373503, 121521, 589, 12, 70, "Message",ExpressionUUID->"4d11f9a3-0951-42d6-9361-d3d24113b8e6"],
Cell[5374095, 121535, 1436, 30, 70, "Output",ExpressionUUID->"b196b765-5de9-45f8-8c9c-447f5b4a5b81"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5375568, 121570, 423, 10, 49, "Input",ExpressionUUID->"1a461ade-897c-4167-9f32-3e32ac875721"],
Cell[5375994, 121582, 587, 12, 70, "Message",ExpressionUUID->"056825d4-f7ac-4c8e-be67-a26296c3eb9a"],
Cell[5376584, 121596, 589, 12, 70, "Message",ExpressionUUID->"87950ab8-8e2d-40a2-8a7d-17cb4d9716cc"],
Cell[5377176, 121610, 297, 5, 70, "Output",ExpressionUUID->"4a30c305-816b-4557-95a3-c11217096b93"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5377522, 121621, 217, 4, 37, "Subsection",ExpressionUUID->"a0fa8781-78a8-4de3-b434-87f2f0ab62d2"],
Cell[5377742, 121627, 4336, 134, 276, "Input",ExpressionUUID->"7554c768-508b-470c-bf0f-9c496d7e4cdc"],
Cell[5382081, 121763, 1368, 36, 48, "Input",ExpressionUUID->"abd3d04d-a403-49c6-93cd-8075dfa10d06"],
Cell[CellGroupData[{
Cell[5383474, 121803, 814, 18, 48, "Input",ExpressionUUID->"8f1856a0-6ef1-4a6b-947c-ff8becd3a996"],
Cell[5384291, 121823, 585, 12, 70, "Message",ExpressionUUID->"3eca092f-1e5c-445a-939c-33ecb89d143d"],
Cell[5384879, 121837, 1439, 30, 70, "Output",ExpressionUUID->"61a363a5-9cdb-4f1f-939b-fdced4e8fade"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5386355, 121872, 423, 10, 49, "Input",ExpressionUUID->"e856fb33-e006-42a1-bcba-d36869194896"],
Cell[5386781, 121884, 586, 12, 70, "Message",ExpressionUUID->"dc57b72d-80cf-4fef-b527-e48a54b0fdc6"],
Cell[5387370, 121898, 584, 12, 70, "Message",ExpressionUUID->"b6d65fe5-2898-455b-bbae-f19ff772c871"],
Cell[5387957, 121912, 300, 5, 70, "Output",ExpressionUUID->"0ab7deeb-e7b3-4053-9786-2aac5d64567a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5388306, 121923, 164, 3, 37, "Subsection",ExpressionUUID->"b440b91c-63e5-4d73-98fc-e9fdadd6831b"],
Cell[5388473, 121928, 4304, 134, 276, "Input",ExpressionUUID->"093405d9-9d4a-48be-97b8-af733cdb1a2b"],
Cell[5392780, 122064, 1290, 35, 48, "Input",ExpressionUUID->"88f41193-33b6-4334-a1c9-9cb4701dc464"],
Cell[CellGroupData[{
Cell[5394095, 122103, 766, 18, 48, "Input",ExpressionUUID->"1b9aeb01-ccd5-4006-a596-eb8c13fd7430"],
Cell[5394864, 122123, 617, 13, 70, "Message",ExpressionUUID->"4363e1dc-e832-48ed-8ed6-b7749653fb0b"],
Cell[5395484, 122138, 1413, 30, 70, "Output",ExpressionUUID->"f75370c3-d743-4a87-aaec-f51cf1a362e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5396934, 122173, 423, 10, 49, "Input",ExpressionUUID->"6655228e-19f4-43e7-b68a-5f35ecbc0290"],
Cell[5397360, 122185, 588, 12, 70, "Message",ExpressionUUID->"335afd4f-3348-45d1-b403-d12fde6d1933"],
Cell[5397951, 122199, 590, 12, 70, "Message",ExpressionUUID->"2d753cc2-1eeb-4627-9852-a3c82e71bb18"],
Cell[5398544, 122213, 272, 4, 70, "Output",ExpressionUUID->"632f69d9-9bbd-4327-9596-fc3bf9638a97"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5398865, 122223, 215, 4, 37, "Subsection",ExpressionUUID->"82698d84-d347-45c7-a5df-4a35b935c98b"],
Cell[5399083, 122229, 4331, 134, 276, "Input",ExpressionUUID->"7f08a166-6eed-48c3-802e-9a868e461dd9"],
Cell[5403417, 122365, 1396, 37, 48, "Input",ExpressionUUID->"1e0c6386-5e4c-436a-8ded-a75a769bb0a1"],
Cell[CellGroupData[{
Cell[5404838, 122406, 814, 18, 48, "Input",ExpressionUUID->"31c296a7-d8d9-4544-a251-5bbb285ec1c8"],
Cell[5405655, 122426, 568, 12, 70, "Message",ExpressionUUID->"796e7ab4-df35-433a-9b63-d57d6ebcd184"],
Cell[5406226, 122440, 1433, 30, 70, "Output",ExpressionUUID->"7ba3db25-520f-40d0-85ba-0672ba23850e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5407696, 122475, 423, 10, 49, "Input",ExpressionUUID->"64498a2b-1d8d-4c67-b33a-e3ce9878e793"],
Cell[5408122, 122487, 566, 12, 70, "Message",ExpressionUUID->"a508dd4e-0221-4ef6-9e9a-c5b24fcbc319"],
Cell[5408691, 122501, 566, 12, 70, "Message",ExpressionUUID->"8b9870e6-166e-40f8-a0ef-4efb7180b754"],
Cell[5409260, 122515, 299, 5, 70, "Output",ExpressionUUID->"743081eb-2216-468e-ba3b-54dbed4695ee"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5409608, 122526, 256, 4, 37, "Subsection",ExpressionUUID->"4ff372a4-4974-4646-8442-bc8c3b8214b1"],
Cell[CellGroupData[{
Cell[5409889, 122534, 4337, 116, 181, "Input",ExpressionUUID->"8f27a0fb-67e9-4e36-af3e-89d604ead716"],
Cell[5414229, 122652, 470, 7, 70, "Output",ExpressionUUID->"1a94d3d1-4322-4beb-bd6b-d00c8f9e9fef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5414736, 122664, 4329, 116, 181, "Input",ExpressionUUID->"e7560fba-1efb-4296-9b08-38520f25d9af"],
Cell[5419068, 122782, 267, 4, 70, "Output",ExpressionUUID->"aea1efff-d7b9-473f-a1f9-3f3bbb5b9bb5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5419372, 122791, 4394, 116, 181, "Input",ExpressionUUID->"2f154a19-81cb-4c36-94e5-8a767c57e4f1"],
Cell[5423769, 122909, 265, 4, 70, "Output",ExpressionUUID->"69bcdb5a-cfb2-48c4-bb8b-5ab86e887fa7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5424071, 122918, 4382, 116, 181, "Input",ExpressionUUID->"ee1c0424-8119-44a7-8afd-fba7b9407db7"],
Cell[5428456, 123036, 271, 4, 70, "Output",ExpressionUUID->"93b26c1e-6980-4ef3-b8ea-e47d0e86dd57"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5428776, 123046, 308, 5, 37, "Subsection",ExpressionUUID->"2c530f80-4c6a-4833-a45c-b6a19891c7e1"],
Cell[CellGroupData[{
Cell[5429109, 123055, 3456, 96, 181, "Input",ExpressionUUID->"3ac84315-9c4a-4881-8bf6-614bd4568755"],
Cell[5432568, 123153, 491, 7, 70, "Output",ExpressionUUID->"d0152b51-50bf-45e6-a0a1-9f61d17fa83d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5433096, 123165, 3404, 95, 181, "Input",ExpressionUUID->"d3a4ce32-3732-4885-aeba-062d28fae0b4"],
Cell[5436503, 123262, 294, 5, 70, "Output",ExpressionUUID->"6debeb42-b46c-4f28-9c9a-7b398e094f6a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5436834, 123272, 3465, 96, 181, "Input",ExpressionUUID->"41530edc-6636-4297-812d-35e894549f6a"],
Cell[5440302, 123370, 295, 5, 70, "Output",ExpressionUUID->"0197e4b4-13b6-4e48-bf3f-77f437f135e0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5440634, 123380, 3457, 96, 181, "Input",ExpressionUUID->"fd89ac9d-8580-4884-998d-5da32f85783a"],
Cell[5444094, 123478, 292, 5, 70, "Output",ExpressionUUID->"4479ef90-0b35-498d-af46-38ae6fde2024"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5444447, 123490, 213, 4, 53, "Section",ExpressionUUID->"01ce04b3-4d18-47d8-a2a6-6528f7f732ac"],
Cell[CellGroupData[{
Cell[5444685, 123498, 216, 4, 53, "Subsection",ExpressionUUID->"89819b4c-3403-4f58-a0c6-391c391a1dcb"],
Cell[5444904, 123504, 3560, 116, 276, "Input",ExpressionUUID->"4923e22d-ef88-4173-ab19-d239b52f0776"],
Cell[5448467, 123622, 1344, 36, 48, "Input",ExpressionUUID->"64b369ee-d9e4-49d6-8b5e-1958ce684754"],
Cell[CellGroupData[{
Cell[5449836, 123662, 814, 18, 48, "Input",ExpressionUUID->"50739449-6c10-4429-b2db-8a3d2d838cc2"],
Cell[5450653, 123682, 515, 11, 23, "Message",ExpressionUUID->"df4ce99c-11f0-459a-a27f-419a99181dd6"],
Cell[5451171, 123695, 1359, 29, 126, "Output",ExpressionUUID->"3d53a490-b08d-4425-adb7-bb6ec17f4c1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5452567, 123729, 423, 10, 49, "Input",ExpressionUUID->"eb80fc43-2637-4571-9367-b3689d5e3c5b"],
Cell[5452993, 123741, 514, 11, 23, "Message",ExpressionUUID->"80afff5a-a61f-49ee-9cec-df7c014914c2"],
Cell[5453510, 123754, 514, 11, 23, "Message",ExpressionUUID->"31fb1530-2b49-41b3-a048-cce47b0f44cf"],
Cell[5454027, 123767, 226, 4, 32, "Output",ExpressionUUID->"86d3670c-fbc2-4cd3-b79d-bd79d9fc906c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5454302, 123777, 216, 4, 37, "Subsection",ExpressionUUID->"0b8f0c3e-dbb1-4294-a905-fd0ed044b28c"],
Cell[5454521, 123783, 3640, 116, 276, "Input",ExpressionUUID->"0d7f720b-74f2-4ee4-b669-9b7dbfb42a0a"],
Cell[5458164, 123901, 1371, 36, 124, "Input",ExpressionUUID->"89ed1958-9c51-4dd7-91cb-83834fae6a48"],
Cell[CellGroupData[{
Cell[5459560, 123941, 814, 18, 67, "Input",ExpressionUUID->"75eca037-4460-49ca-8329-f1dfdafe56e3"],
Cell[5460377, 123961, 517, 11, 23, "Message",ExpressionUUID->"56cb2d34-92ca-410a-be0f-f575aa246455"],
Cell[5460897, 123974, 1398, 29, 129, "Output",ExpressionUUID->"3caf5c9e-da7d-4ffa-9727-4bf28975c649"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5462332, 124008, 423, 10, 49, "Input",ExpressionUUID->"4fa02ccb-7310-4ffa-b25c-a547addcddbb"],
Cell[5462758, 124020, 519, 11, 23, "Message",ExpressionUUID->"10d3f7e1-d476-4892-a571-e65836d8fc9d"],
Cell[5463280, 124033, 519, 11, 23, "Message",ExpressionUUID->"9bb5a8e2-f392-4be2-ab30-7049fbcfd1aa"],
Cell[5463802, 124046, 248, 4, 32, "Output",ExpressionUUID->"3986ab40-e0b1-4f7a-99af-db610e851e39"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5464099, 124056, 214, 4, 37, "Subsection",ExpressionUUID->"404dd7b7-01c6-4d7f-b3c0-fb8c2fa356fe"],
Cell[5464316, 124062, 3610, 116, 276, "Input",ExpressionUUID->"c56db8db-a98f-4ccc-8957-edc07662f5f4"],
Cell[5467929, 124180, 1366, 36, 48, "Input",ExpressionUUID->"02dfa7eb-3f91-4e0e-a261-095758ff6881"],
Cell[CellGroupData[{
Cell[5469320, 124220, 814, 18, 48, "Input",ExpressionUUID->"70211b2c-0216-4d51-9ef6-a8fb56899d03"],
Cell[5470137, 124240, 1417, 30, 70, "Output",ExpressionUUID->"43974fca-924e-4bf3-8f26-9acc45e8c7c6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5471591, 124275, 423, 10, 49, "Input",ExpressionUUID->"ffa97c3c-c9a6-431b-b3aa-f3830b88fcc9"],
Cell[5472017, 124287, 246, 4, 70, "Output",ExpressionUUID->"77dd90cb-703f-469f-85b2-c6e9f3b30c74"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5472312, 124297, 217, 4, 37, "Subsection",ExpressionUUID->"c95f5312-5e3f-4ffb-abfd-2f234f4a0bfe"],
Cell[5472532, 124303, 3624, 116, 276, "Input",ExpressionUUID->"9ce19611-07a7-4566-ba78-194ca908dfd3"],
Cell[5476159, 124421, 1368, 36, 124, "Input",ExpressionUUID->"79f67b4c-2e60-45d2-ae86-08bd03b3c21c"],
Cell[CellGroupData[{
Cell[5477552, 124461, 814, 18, 67, "Input",ExpressionUUID->"372fcb4a-593a-4c12-96f8-d0b84cfa79b4"],
Cell[5478369, 124481, 540, 12, 23, "Message",ExpressionUUID->"435d34ce-0118-4e0e-9149-9f281c2b0d17"],
Cell[5478912, 124495, 1392, 30, 126, "Output",ExpressionUUID->"0e91d70d-6f52-4ad5-8f5c-9960eba4a2ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5480341, 124530, 423, 10, 49, "Input",ExpressionUUID->"ee0b1015-0e1d-4167-a8c5-7fee7105a4c7"],
Cell[5480767, 124542, 544, 12, 23, "Message",ExpressionUUID->"9c9883ec-2c7c-48fd-bfe8-40ea4b056fc6"],
Cell[5481314, 124556, 544, 12, 23, "Message",ExpressionUUID->"405b9a96-f2c1-4171-8714-43f9a3e57bb3"],
Cell[5481861, 124570, 246, 4, 32, "Output",ExpressionUUID->"a56d3a83-9a37-4510-90e3-9968f356d8c5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5482156, 124580, 164, 3, 37, "Subsection",ExpressionUUID->"04b68c9f-b9a7-4997-a0c7-add4309ce7dc"],
Cell[5482323, 124585, 3499, 115, 276, "Input",ExpressionUUID->"5d0b8ebf-cd46-482f-a63a-d39ae1d8a935"],
Cell[5485825, 124702, 1290, 35, 48, "Input",ExpressionUUID->"f1aecd79-646f-4e48-87b4-b1a5b6d12017"],
Cell[CellGroupData[{
Cell[5487140, 124741, 766, 18, 48, "Input",ExpressionUUID->"27002eb8-ff82-4812-8643-4b4878c654af"],
Cell[5487909, 124761, 1393, 30, 70, "Output",ExpressionUUID->"27cae9f5-33b2-4a04-9aa5-f66774ce466d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5489339, 124796, 423, 10, 49, "Input",ExpressionUUID->"f9ee99cd-7336-4eb3-8236-5ba73fff4bac"],
Cell[5489765, 124808, 225, 4, 70, "Output",ExpressionUUID->"77049caa-9da5-4bf9-beb1-9882acbd9af3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5490039, 124818, 215, 4, 37, "Subsection",ExpressionUUID->"ec15b78f-3ea2-40f5-961c-eb7976b435ad"],
Cell[5490257, 124824, 3624, 116, 276, "Input",ExpressionUUID->"c91fc069-18b9-4b06-bda3-eada08b0c8f2"],
Cell[5493884, 124942, 1396, 37, 124, "Input",ExpressionUUID->"cfbd2bf7-7ea4-4e44-8eb8-858344d8f023"],
Cell[CellGroupData[{
Cell[5495305, 124983, 814, 18, 67, "Input",ExpressionUUID->"aac73ebc-4193-4b23-bd5b-6e16e51f309d"],
Cell[5496122, 125003, 1417, 30, 129, "Output",ExpressionUUID->"af28201d-332e-43ea-8353-4b8fad9c15b7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5497576, 125038, 423, 10, 49, "Input",ExpressionUUID->"0205edaa-a61c-4ffc-8443-c46cd656b046"],
Cell[5498002, 125050, 249, 4, 32, "Output",ExpressionUUID->"a843d10a-3b01-490a-94c6-c85e535cc317"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5498300, 125060, 256, 4, 37, "Subsection",ExpressionUUID->"f3f92c03-54a4-4e0b-babc-61f5cc69dd78"],
Cell[CellGroupData[{
Cell[5498581, 125068, 4209, 114, 181, "Input",ExpressionUUID->"481f8662-0657-43ff-8a0b-fc3581d4d5ab"],
Cell[5502793, 125184, 419, 6, 32, "Output",ExpressionUUID->"95d93805-6a01-4e01-a460-1ba106482dff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5503249, 125195, 4204, 114, 181, "Input",ExpressionUUID->"ed5183fb-e7df-4579-b8d7-0e68f4c4990c"],
Cell[5507456, 125311, 225, 4, 32, "Output",ExpressionUUID->"dc83897f-ac6f-4175-85f1-7a9c66036e8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5507718, 125320, 4269, 115, 257, "Input",ExpressionUUID->"63869981-34e4-47c6-97bd-fd4ef5de8bfa"],
Cell[5511990, 125437, 208, 4, 32, "Output",ExpressionUUID->"21da605d-e9b9-48a3-968c-995478fbfad3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5512235, 125446, 4255, 115, 181, "Input",ExpressionUUID->"01d5c6da-586a-4e97-a73a-66a77460e8ad"],
Cell[5516493, 125563, 224, 4, 32, "Output",ExpressionUUID->"a645ee56-3931-41a7-9be9-83d5aba2a901"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)

